'''
  Folding@Home Client Control (FAHControl)
  Copyright (C) 2010-2011 Stanford University

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import gtk

icons = {'tiny': None, 'small': None, 'medium': None, 'large': None}
viewer_icons = {'tiny': None, 'small': None, 'medium': None, 'large': None}


def load_rgba_pixbuf(data, dim):
    return gtk.gdk.pixbuf_new_from_data(data, gtk.gdk.COLORSPACE_RGB,
                                        True, 8, dim, dim, dim * 4)
    

def get_icon(name):
    global icons

    if icons[name] is None:
        if name == 'tiny': icons[name] = load_rgba_pixbuf(icon_24_raw, 24)
        elif name == 'small': icons[name] = load_rgba_pixbuf(icon_32_raw, 32)
        elif name == 'medium': icons[name] = load_rgba_pixbuf(icon_64_raw, 64)
        else: icons[name] = load_rgba_pixbuf(icon_128_raw, 128)

    return icons[name]


def get_icon_image(name):
    image = gtk.Image()
    image.set_from_pixbuf(get_icon(name))
    image.show()

    return image


def get_viewer_icon(name):
    global viewer_icons

    if viewer_icons[name] is None:
        if name == 'tiny':
            viewer_icons[name] = load_rgba_pixbuf(viewer_icon_24_raw, 24)
        elif name == 'small':
            viewer_icons[name] = load_rgba_pixbuf(viewer_icon_32_raw, 32)
        elif name == 'medium':
            viewer_icons[name] = load_rgba_pixbuf(viewer_icon_64_raw, 64)
        else: viewer_icons[name] = load_rgba_pixbuf(viewer_icon_128_raw, 128)

    return viewer_icons[name]


def get_viewer_icon_image(name):
    image = gtk.Image()
    image.set_from_pixbuf(get_viewer_icon(name))
    image.show()

    return image


# RGBA 32x32x4
icon_32_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\62\1\67;\202\1" +\
    "DJ\226\0\20\22j\0\0\0\12\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\1\0\0\0\15\1SV\264\4\304\320\377\4\351\373\377\4\355" +\
    "\375\377\4\333\353\377\2s|\370\0\0\0J\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10" +\
    "\35\13\11yf<8\327U-+\377\21\20V\377\6J\322\377\5O\327\377\3}\327\377" +\
    "\1\325\347\377\1\365\377\377\4\356\377\376\3\200\213\377\0\0\0/\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0J\35\62\64\361K}\200\3774\204\216\376\0Q\271\377\6\36\352\377" +\
    "\5\26\376\377\5\27\376\377\5\26\377\377\6\11\354\377\4k\316\377\3\367" +\
    "\377\377\7\351\372\377\1(+\301\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\63\67\236\5\256\274\377\4\352\373\376" +\
    "\2\360\377\377\3\360\377\377\3\361\377\377\3\273\315\377\4\21\377\377" +\
    "\3\30\375\377\4\27\375\377\4\27\375\377\7\24\376\377\5]\313\377\7\367" +\
    "\377\377\3X_\374\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\34\35\5\2}F\33\27\270M\37\32\301=\27\23\261" +\
    "\0\0\0k\20\24\3l\25;\63\337\7\334\355\377\4\357\377\376\2\360\377\377" +\
    "\1\363\377\377\0\363\377\377\1\362\377\377\2\341\344\377\3\24\356\377" +\
    "\2\33\375\377\3\32\375\377\4\31\375\377\6\27\374\377\10\16\366\377\10" +\
    "\270\340\377\3Ya\377\0\0\0\13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    ",\37\37\0\0\0\0\6=\36\32\250\241f_\377\350\237\227\377\370\261\252\376" +\
    "\372\262\253\377\365\260\250\377\331\222\213\377\232iU\377\4\265\305" +\
    "\376\7\357\377\377\4\361\376\377\2\365\377\377\0\370\377\377\0\371\377" +\
    "\377\1\366\377\377\2\356\357\377\2\36\344\377\2\37\375\377\3\35\375\377" +\
    "\4\33\375\377\6\31\374\377\10\30\376\377\11N\324\376\3\679\352\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\5\5\0\0\0\0\17f,%\345\354\225\213" +\
    "\377\376\240\226\377\377\236\225\377\377\243\233\377\377\250\240\377" +\
    "\377\236\225\377\376\237\226\377\206kh\377\6\345\367\377\6\357\377\377" +\
    "\4\363\377\377\2\367\377\377\1\373\377\377\1\374\377\377\1\370\376\377" +\
    "\3\360\360\377\3 \343\377\3\42\375\377\3 \375\377\5\35\375\377\6\32\375" +\
    "\377\11\31\376\377\10\27\304\377\0\1\0\222\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0U\26\17\321\362wi\377\377\207|\377\377\205y\377" +\
    "\377\177u\377\377\252\245\377\376\331\326\377\377\204{\377\372\203x\377" +\
    "bYX\377\11\353\375\377\7\357\377\377\13\363\377\377\11\370\377\377\6" +\
    "\372\377\377\3\372\377\377\3\370\377\377\3\350\347\377\4\34\353\377\3" +\
    "\42\375\377\4 \375\377\5\35\375\377\7\33\375\377\11\31\376\377\10\21" +\
    "\270\377\0\0\0]\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\15\5\4^\322#" +\
    "\22\377\376_Q\377\377aU\377\377YP\377\377TM\377\376]W\377\377gb\377\377" +\
    "UN\377\372[Q\377\202>7\377\23\335\361\377A\361\377\3774\364\377\377," +\
    "\367\377\377#\371\377\377\36\370\377\377\32\366\377\377\21\317\330\377" +\
    "\31+\373\377\24/\375\377\20)\375\377\13!\375\377\11\33\374\377\13\32" +\
    "\376\377\5\14\215\377\0\0\0:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "`\14\5\324\372\36\13\376\377&\27\377\377;/\377\3774,\377\3772+\377\377" +\
    "/+\377\377.+\377\3761+\377\3765-\377\302*!\3779\215\227\377}\363\377" +\
    "\377l\362\377\377f\364\377\377\212\371\376\377N\366\377\377K\363\377" +\
    "\377<\250\316\377=O\377\3775J\375\3771D\375\3772@\374\377!.\375\377\22" +\
    "\36\377\377\7\16O\377\0\0\0#\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\14" +\
    "\223\21\5\377\377\32\12\377\376\26\7\377\377\26\12\377\377\32\21\377" +\
    "\377\30\22\377\377\25\22\377\377\24\21\377\377\25\21\377\377\31\22\377" +\
    "\351\31\20\377\200\22\13\377m\266\276\377\232\365\377\377\230\365\377" +\
    "\377\265\367\376\377\205\364\376\377\201\365\377\377o\234\320\377\304" +\
    "\311\376\377cn\376\377aj\376\377`h\375\377UZ\376\377\31%\335\377\4y~" +\
    "\377\0\0\0(\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\31\252\23\7\377\377" +\
    "\31\11\377\377\25\7\377\377\20\5\377\377\13\3\377\377\7\2\377\377\5\3" +\
    "\377\377\5\2\377\377\6\3\377\377\10\3\377\375\15\4\377\334\17\5\377\201" +\
    "\11\2\377Qrf\377y\302\317\377\232\346\361\377\240\353\367\377\212\334" +\
    "\336\377\213\223\343\377\244\250\376\377\215\223\377\377\211\216\377" +\
    "\377\207\214\377\377YY\342\377\12\312\347\377\5}\210\377\0\0\0.\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\31\250\23\7\377\377\31\11\377\377\24" +\
    "\6\377\377\17\4\377\377\12\3\377\377\7\2\377\377\3\1\377\377\3\2\377" +\
    "\377\4\1\377\377\7\3\377\377\14\4\377\376\21\5\377\321\12\6\377\253\227" +\
    "\6\377\227\201\0\377xq\13\377kg\14\377Fb\230\377\212\211\343\377\242" +\
    "\240\366\377\243\242\367\377\217\213\342\377[\227\321\377\32\335\356" +\
    "\377\15\355\377\377\3NU\377\0\0\0\15\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\14\207\16\4\377\377\30\10\377\376\25\6\377\377\20\4\377\377\12" +\
    "\3\377\377\6\2\377\377\3\0\377\377\2\0\377\377\4\0\377\377\10\1\377\376" +\
    "\14\3\377\377\21\5\377\301\26\5\377\374\345\4\377\367\330\4\377\363\326" +\
    "\4\377\330\277\4\377Qq:\377~\354\362\377e\313\343\377\221\320\342\377" +\
    "i\357\365\377]\366\377\377a\360\377\377!\301\323\377\0\1\0\264\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0M\10\2\320\367\30\10\376\377" +\
    "\26\6\377\377\21\4\377\377\14\3\377\377\10\1\377\377\4\0\377\377\4\0" +\
    "\377\377\5\0\377\377\12\2\377\377\16\3\377\372\22\5\377\300W\3\377\377" +\
    "\341\3\377\375\335\3\377\375\336\3\377\370\333\4\377\270\242\0\377Vq" +\
    "P\377\217\337\354\377\245\370\377\377\233\367\377\377\222\363\377\377" +\
    "g\275\311\376\3\27\30\360\0\1\1\27\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0W\270\23\5\377\377\27\7\377\377\22\4\377\377\17\3" +\
    "\377\377\13\1\377\377\10\0\377\377\7\0\377\377\11\1\377\377\14\1\377" +\
    "\377\20\3\377\336\11\4\377\334\274\2\377\374\336\3\377\375\336\3\377" +\
    "\375\336\3\377\375\337\3\377\363\331\4\377\301\255\2\377tp\12\377awG" +\
    "\377e\204^\377p~7\377\224\213\0\377\0\0\0\232\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0)\4\0\301\337\25\4\377\377\25" +\
    "\6\377\377\21\3\377\376\17\2\377\377\15\1\377\377\14\1\377\376\15\1\377" +\
    "\377\20\3\377\370\22\4\377\271M\3\377\377\346\3\377\375\335\3\377\375" +\
    "\336\3\377\375\336\3\377\374\340\3\377\375\343\4\377\372\343\4\377\353" +\
    "\327\5\377\335\315\6\377\340\321\7\377\361\342\11\377\222\213\6\377\0" +\
    "\0\0_\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    ";\4\65\207r\10C\377\313\22\1\377\373\25\5\377\377\24\3\377\377\22\3\377" +\
    "\377\22\2\377\377\22\3\377\373\24\4\377\275\35\3\377\362\337\3\377\374" +\
    "\342\3\377\375\340\2\377\375\337\1\377\375\340\2\377\375\341\2\377\375" +\
    "\344\4\377\375\345\5\377\375\351\6\377\375\353\7\377\376\356\11\377\370" +\
    "\353\12\377LA\3\377\0\0\0\33\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0b\4V\262\315\15\260\376t<I\377}\31\21\377\276" +\
    "\14\0\377\353\23\4\377\360\17\5\377\345\14\4\377\264#\4\377\351\324\4" +\
    "\377\374\345\4\377\375\343\3\377\375\342\2\377\375\341\2\377\375\342" +\
    "\2\377\375\343\3\377\375\345\4\377\375\350\5\377\375\351\6\377\375\354" +\
    "\7\377\375\356\11\377\317\307\10\377t\13\4\377\0\0\0\63\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0T\20\60\277\353\213" +\
    "\204\377\366\220\216\377\334\177\177\377\240jj\377a\77\42\377\311\244" +\
    "\6\377\330\300\7\377\377\363\6\377\374\351\5\377\375\350\4\377\375\346" +\
    "\3\377\375\345\3\377\375\345\3\377\375\345\3\377\375\345\3\377\375\350" +\
    "\5\377\375\351\5\377\374\353\6\377\375\355\10\377\355\345\10\377\307" +\
    "C\10\377\214\20\6\377\0\0\0\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\11\3\3F\323B\77\377\373qk\377\352ef\377\370ec\377" +\
    "\374\233\235\377\300sy\377wb\14\377\360\343\7\377\376\356\7\377\374\353" +\
    "\6\377\375\352\5\377\375\351\5\377\375\350\4\377\375\347\3\377\375\350" +\
    "\4\377\375\350\4\377\375\352\5\377\374\353\6\377\376\356\7\377\360\346" +\
    "\7\377\270c\6\377\377\25\11\377\202\16\4\377\0\0\0;\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0q\11\6\326\323Z\177\376\334\213" +\
    "\322\377\354\227\347\377\340\214\330\377\320c\224\377\3535@\377\271&" +\
    "2\377qO\13\377\335\323\6\377\374\354\7\377\375\354\6\377\375\353\5\377" +\
    "\374\352\5\377\375\353\5\377\374\352\5\377\374\353\5\377\376\354\6\377" +\
    "\374\353\7\377\336\332\7\377\276R\5\377\377\20\6\377\372\31\11\377N\11" +\
    "\2\377\0\0\0\26\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    " \253F\225\377\377\211\357\377\377\202\355\377\376\277\365\377\377\205" +\
    "\356\377\377\207\356\377\327Y\277\377\355\27\42\377\322\20\32\377h\24" +\
    "\6\377\255\215\6\377\340\334\6\377\366\351\6\377\372\353\6\377\372\353" +\
    "\6\377\372\353\6\377\365\351\6\377\334\332\6\377\272\207\5\377\331\33" +\
    "\3\377\377\21\4\377\377\26\7\377\340\27\7\376\14\1\0\317\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0]\11Q\261\376E\342\377\376" +\
    "P\347\377\376D\353\377\377N\360\377\376C\355\377\376F\351\377\377;\346" +\
    "\377\323\12n\377\376\6\20\377\324\6\14\377y\6\4\377\331\32\6\377\312" +\
    "E\5\377\306`\4\377\311c\4\377\305\134\3\377\313<\2\377\342\14\1\377\377" +\
    "\10\2\377\377\20\3\377\377\24\5\377\370\27\7\376`\11\2\377\0\0\0I\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\233\7\206\377\377" +\
    "\15\341\377\377\23\346\377\377\23\353\377\377\23\356\377\377\23\353\377" +\
    "\377\22\350\377\377\7\342\377\330\10\274\377\376\5\11\377\366\10\16\377" +\
    "\247\5\10\377\216\15\2\377\370\27\7\377\377\24\4\377\377\20\3\377\377" +\
    "\16\2\377\377\16\1\377\376\17\2\377\377\21\2\377\377\23\4\377\371\27" +\
    "\6\376\215\15\4\377\0\0\0\237\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\11\245\6\220\377\377\7\343\377\377\4\347\377\377" +\
    "\1\353\377\377\1\356\377\377\2\354\377\377\3\350\377\377\7\343\377\342" +\
    "\11\316\377\371\4\4\377\375\7\15\377\363\11\13\377\210\3=\377y\11\31" +\
    "\377\334\24\1\377\373\26\5\377\377\24\3\377\377\23\3\377\377\23\3\377" +\
    "\374\25\4\377\342\24\5\376c\11\2\377\0\0\0\243\42\2\1\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\216\5|\373\377\7\343" +\
    "\377\376\3\346\377\377\1\352\377\377\0\355\377\377\1\354\377\377\3\346" +\
    "\377\377\6\342\377\325\7\256\377\377\5\6\377\375\7\14\377\351\11\0\377" +\
    "\344\1\317\377\322\2\301\377\201\2j\377w\10#\376\220\14\1\377\243\16" +\
    "\3\377\221\14\3\377R\7\1\377\16\1\0\313\0\0\0D\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\09\1\61\251" +\
    "\370\7\333\377\377\3\343\377\376\1\346\377\377\0\350\377\377\1\347\377" +\
    "\377\3\343\377\377\6\343\377\322\4P\377\376\6\13\377\371\10\4\377\322" +\
    "\3}\377\377\1\353\377\376\2\345\377\370\5\334\377\177\3o\377\0\0\0\204" +\
    "\0\0\0Q\0\0\0K\0\0\0\32\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\22c\2V\361\370" +\
    "\5\333\377\377\2\344\377\377\1\343\377\377\3\343\377\377\4\345\377\315" +\
    "\6\206\377\376\6\4\377\351\6\4\377\324\4}\377\377\1\353\377\377\1\343" +\
    "\377\377\4\343\377\314\5\264\377\12\0\11\277\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\32,\0'\304\202\2r" +\
    "\377\255\3\230\377\213\2{\377\134\2\63\377t\2\0\377F\1\1\3639\1\62\344" +\
    "\251\3\225\377\341\4\306\377\321\4\270\377t\2e\377\5\0\5\263\15\0\13" +\
    "\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\36\0\0\0I\0\0\0\65\0\0\0\25\0\0\0\24\0\0\0\1" +\
    "\0\0\0\0\0\0\0@\0\0\0z\0\0\0t\0\0\0+\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0"


# RGBA 64x64x4
icon_64_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\27\1\26\30S\2\67:z\2\77C\241" +\
    "\2BG\222\2/\63h\0\0\09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\31\1-\60" +\
    "\244\4s|\377\5\255\273\377\5\301\321\377\5\313\332\377\5\311\330\377" +\
    "\5\274\312\377\4\230\243\377\2AF\331\0\23\24;\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\2\1R\4nv\377\6" +\
    "\302\320\376\6\340\362\377\6\353\374\377\4\356\377\377\4\356\377\377" +\
    "\4\356\377\377\4\355\375\377\4\347\370\377\6\320\340\376\4\231\244\377" +\
    "\1$'\250\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\3\0\0\0\23\0\0\0F\0\0\0i\0\1\0n\1" +\
    "\0\0\236\6\224\235\377\7\342\354\377\6\365\377\377\5\366\377\377\3\362" +\
    "\377\377\3\360\377\377\3\360\376\377\2\357\376\377\3\357\377\377\4\357" +\
    "\376\377\4\356\376\377\6\343\363\376\5\262\300\377\2\648\307\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\2\0\0\0#\14\7" +\
    "\6\237K\36\33\340w5-\372\226UL\377q<0\377#\23\66\377\6\30\204\377\6\37" +\
    "\271\376\6\34\310\377\6\32\311\377\6%\306\377\6\65\275\377\4_\257\377" +\
    "\2\315\325\377\0\376\377\377\2\363\377\377\2\361\376\377\3\360\377\377" +\
    "\4\355\376\377\7\345\365\376\5\254\272\377\1\22\23\211\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\5\3\3\3\0\0\0,-\27\25\267vFA\377\270xq\377\327\224" +\
    "\214\377\236tr\376($l\377\1\14\246\377\6\23\332\377\7\25\360\377\7\27" +\
    "\373\377\7\26\375\377\7\27\375\377\7\26\374\377\7\26\371\377\7\23\362" +\
    "\377\6\11\324\377\4\66\267\377\2\261\313\377\1\372\377\377\2\361\376" +\
    "\377\4\360\377\377\6\356\376\377\10\337\356\376\5\202\214\377\0\3\3\31" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\2\0\0\0\13\12\0\0s\60\37\35\375TOM\377<Y\134\376#Z]\377" +\
    "\22_c\377\0L|\377\6D\253\377\7*\315\377\7\23\356\377\7\27\377\377\6\27" +\
    "\375\377\5\30\375\377\5\27\375\377\5\30\376\377\5\27\376\377\6\30\376" +\
    "\377\6\26\376\377\7\26\370\377\7\13\331\377\4e\265\377\2\362\371\377" +\
    "\4\360\377\377\6\357\377\377\7\354\375\377\7\277\316\377\1'*\213\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\4\0\0\0'\1\31\32\311\5em\377\3\253\271\376\6\303\322\377\5\320\340" +\
    "\377\5\331\351\377\5\336\360\377\6\342\363\377\5\340\362\377\5\327\345" +\
    "\377\5\260\265\377\4.\275\377\4\27\377\377\4\30\374\377\4\27\374\377" +\
    "\4\27\374\377\4\27\374\377\5\30\375\377\6\30\375\377\6\27\376\377\7\27" +\
    "\375\377\10\26\355\377\5\63\246\377\4\361\370\377\6\360\376\377\10\357" +\
    "\376\377\11\332\353\377\3RY\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\1\13\13a\4ow\377\6\273\312\377\7\336\356" +\
    "\377\6\352\373\377\5\356\376\377\4\357\377\377\3\357\377\377\4\357\377" +\
    "\377\5\357\377\377\4\357\377\377\5\356\377\377\6\350\372\377\4\177\237" +\
    "\377\5\24\377\377\3\32\375\377\3\31\375\377\4\32\375\377\3\30\375\377" +\
    "\5\30\375\377\5\30\375\377\6\30\375\377\7\30\376\377\10\30\376\377\10" +\
    "\26\360\377\7A\256\377\5\371\377\377\10\357\377\377\11\344\365\377\6" +\
    "\202\214\377\0\0\0 \0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\2" +\
    "\5\2\35\36\235\5\234\251\377\7\330\351\377\7\353\373\376\6\356\377\377" +\
    "\3\357\377\377\3\357\377\377\2\360\377\377\2\361\377\377\2\360\377\377" +\
    "\2\360\377\377\3\357\377\377\3\357\377\377\4\356\376\377\4\261\265\377" +\
    "\4\25\354\377\3\33\374\377\3\32\375\377\3\32\375\377\3\31\375\377\3\32" +\
    "\375\377\5\31\375\377\5\30\374\377\6\27\375\377\7\27\375\377\10\30\375" +\
    "\377\11\22\350\377\6n\264\377\10\360\377\377\12\350\371\377\7\230\245" +\
    "\377\0\0\0\65\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\10\0\0\0>\0\7\11\200\15\17\20\232\17\21\22" +\
    "\233\15\21\21\232\3\12\13\212\0\0\0M\0\0\0\16\0\0\0\0\0\0\0\0\0\0\0\21" +\
    "\0\0\11\177\15\36\32\332\6\241\256\377\10\340\361\376\7\356\376\377\6" +\
    "\356\377\377\4\360\376\377\3\361\377\377\2\362\377\377\2\364\377\377" +\
    "\2\363\377\377\1\363\377\377\1\363\377\377\2\363\377\377\2\362\376\377" +\
    "\3\357\377\377\4\320\324\377\3\37\332\377\2\34\374\377\3\34\375\377\3" +\
    "\34\375\377\2\32\375\377\3\33\375\377\4\32\375\377\5\31\375\377\6\30" +\
    "\375\377\6\30\376\377\10\30\376\377\11\30\374\377\10\22\313\377\10\347" +\
    "\354\377\12\347\371\377\6\217\234\377\0\0\0+\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\2\3S9\25\22\267`*$\365\205HB\377" +\
    "\247_X\377\264g_\377\267i`\377\266g`\377\254e]\377\216QK\377_1,\371:" +\
    "\26\22\272\30\26\17\250[Z&\366le.\377\5\204\216\377\10\336\356\377\10" +\
    "\356\377\377\7\356\376\377\5\360\377\377\4\361\377\377\2\363\377\377" +\
    "\2\365\377\377\1\366\377\377\0\367\377\377\0\367\377\377\1\367\377\377" +\
    "\1\365\377\377\2\365\377\377\2\362\377\377\3\332\341\377\2)\320\377\3" +\
    "\37\375\377\2\35\375\377\1\36\375\377\3\36\375\377\3\34\375\377\4\34" +\
    "\375\377\5\32\375\377\6\31\374\377\6\31\375\377\7\30\376\377\10\30\376" +\
    "\377\11\25\362\377\10M\247\377\11\340\362\377\5hr\377\0\0\0\16\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\4\4C\77\35\32\337\221NF\377" +\
    "\303\201z\377\331\241\232\377\352\250\241\377\361\253\244\377\366\256" +\
    "\246\377\367\257\246\377\366\256\247\377\364\254\244\377\353\250\241" +\
    "\377\334\240\231\377\311\217\211\377\263kd\377\200YM\377\32TS\377\10" +\
    "\313\334\377\11\354\376\377\7\357\377\377\5\360\377\377\5\361\377\377" +\
    "\4\363\377\377\2\365\377\377\1\366\377\377\2\371\377\377\0\372\377\377" +\
    "\0\371\377\377\1\371\377\377\1\370\377\377\2\365\377\377\2\364\377\377" +\
    "\3\336\350\377\2\63\315\377\3 \375\377\2 \375\377\3\37\375\377\2\37\375" +\
    "\377\4\36\375\377\4\35\375\377\5\33\375\377\6\32\374\377\6\32\375\377" +\
    "\7\31\376\377\10\30\375\377\12\30\374\377\11\31\311\377\13\323\343\376" +\
    "\4BH\344\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\31\14\13\252\214" +\
    "A:\377\312\213\204\376\351\236\227\377\367\250\237\377\376\254\243\377" +\
    "\377\255\245\377\377\254\244\377\377\254\244\377\377\254\244\377\377" +\
    "\254\244\377\377\255\244\377\376\254\244\377\375\254\243\377\371\251" +\
    "\240\377\350\235\225\377\251vo\377\6\212\226\377\12\344\365\377\11\356" +\
    "\377\377\7\360\377\377\5\361\377\377\5\362\377\377\4\365\377\377\2\367" +\
    "\377\377\1\370\377\377\1\373\377\377\0\373\377\377\1\373\377\377\0\373" +\
    "\377\377\2\371\377\377\2\367\377\377\2\365\377\377\4\341\350\377\3\66" +\
    "\314\377\2!\375\377\2\42\375\377\2!\375\377\2!\375\377\4\37\375\377\4" +\
    "\36\375\377\5\35\375\377\6\34\375\377\6\32\374\377\7\32\375\377\10\31" +\
    "\376\377\12\31\376\377\11\24\334\376\12\233\253\377\5\34\36q\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\16\60\32\30\344\254\134R\377\340\222\212\376" +\
    "\367\237\226\377\376\243\231\377\377\244\232\377\376\243\231\377\377" +\
    "\242\231\377\377\243\233\377\377\246\236\377\377\247\237\377\377\244" +\
    "\234\377\377\243\233\377\377\242\231\377\377\244\232\377\376\243\230" +\
    "\377\350\226\214\377iD@\377\6\260\300\377\12\353\375\377\10\357\376\377" +\
    "\7\357\377\377\5\362\377\377\5\362\377\377\3\365\377\377\3\370\377\377" +\
    "\2\372\377\377\2\374\377\377\2\374\377\377\0\373\377\377\1\373\377\377" +\
    "\1\371\377\377\3\370\377\377\2\367\377\377\4\342\351\377\3\67\311\377" +\
    "\4#\375\377\3\42\375\377\3!\375\377\4\42\375\377\3 \375\377\5\37\375" +\
    "\377\5\35\375\377\6\33\375\377\6\33\375\377\7\32\375\377\11\32\376\377" +\
    "\12\32\376\377\11\24\344\377\12\62O\374\0\0\0\34\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\4\0" +\
    "\0\0\0\16;\32\26\341\267NB\377\352\217\204\376\374\231\216\377\376\232" +\
    "\217\377\377\232\217\377\377\230\217\377\377\227\215\377\377\230\216" +\
    "\377\377\237\225\377\377\262\253\377\377\275\267\377\377\253\242\377" +\
    "\377\233\222\377\377\231\216\377\377\227\215\377\373\226\215\377\334" +\
    "\204{\377.67\377\10\307\330\377\12\355\377\377\10\357\377\377\6\357\377" +\
    "\377\6\362\377\377\5\363\377\377\4\367\377\377\3\370\377\377\2\372\377" +\
    "\377\3\374\377\377\2\374\377\377\1\374\377\377\2\374\377\377\2\371\377" +\
    "\377\3\370\377\377\3\366\377\377\4\341\347\377\3\64\313\377\3#\375\377" +\
    "\4\42\375\377\4#\375\377\4\42\375\377\5!\375\377\5\37\375\377\6\36\375" +\
    "\377\7\34\375\377\7\34\375\377\10\32\374\377\11\31\376\377\13\32\376" +\
    "\377\11\25\344\377\3\59\336\0\0\0\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\64\27\24\301\264" +\
    ".\36\377\353\211~\377\374\215\202\377\377\216\202\377\376\215\201\377" +\
    "\377\214\200\377\377\212\177\377\377\211~\377\377\211\177\377\377\234" +\
    "\225\377\376\322\317\377\376\357\357\377\377\275\271\377\377\222\213" +\
    "\377\377\212\200\377\377\212\200\377\367\210|\377\320ri\377\34\67:\377" +\
    "\12\316\337\377\12\355\377\377\11\357\377\377\7\360\377\377\6\362\377" +\
    "\377\5\364\377\377\6\366\377\377\5\371\377\377\4\372\377\377\3\372\377" +\
    "\377\3\373\377\377\2\373\377\377\2\372\377\377\3\371\377\377\3\370\377" +\
    "\377\4\366\377\377\4\333\340\377\3,\320\377\4#\374\377\4$\375\377\4#" +\
    "\375\377\4#\375\377\5!\375\377\5 \375\377\6\36\375\377\6\34\375\377\7" +\
    "\34\375\377\10\33\375\377\11\32\375\377\13\32\376\377\12\27\341\377\3" +\
    "\69\336\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\4\12\12u\227%\31\377\344B0\376\375\204x\377" +\
    "\377\201u\377\376\177t\377\377}r\377\377zp\377\377vl\377\377sk\377\377" +\
    "tk\377\377\210\202\377\377\303\300\377\376\342\341\377\377\255\250\377" +\
    "\377\200w\377\377wm\377\377yo\377\365xm\377\312e[\377,/.\377\11\307\331" +\
    "\377\13\355\377\377\10\357\377\377\15\360\377\377\30\361\377\377\31\364" +\
    "\377\377\25\366\377\377\23\370\377\377\20\372\377\377\16\373\377\377" +\
    "\14\373\377\377\12\373\377\377\10\371\377\377\7\371\377\377\5\367\377" +\
    "\377\4\365\377\377\5\321\322\377\10'\333\377\10%\374\377\6$\375\377\6" +\
    "$\375\377\6#\375\377\5\42\375\377\6 \375\377\7\37\375\377\10\36\375\377" +\
    "\10\34\375\377\11\33\375\377\12\32\376\377\13\32\376\377\12\24\330\377" +\
    "\1\3#\255\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\11b\25\16\362\324+\30\376\371\77,\377\376" +\
    "re\377\377oa\377\377l^\377\377i]\377\377dY\377\377aW\377\377`V\377\377" +\
    "^V\377\377e^\377\377|w\377\377\211\204\377\377tn\377\377bZ\377\377`V" +\
    "\377\377e[\377\365eY\377\313WM\377V&\42\377\12\264\303\377\17\350\375" +\
    "\377\37\356\377\3778\362\377\377/\363\377\377,\364\377\377(\367\377\377" +\
    "$\367\377\377 \371\377\377\35\371\377\377\33\373\377\377\30\372\377\377" +\
    "\26\371\377\377\23\367\377\377\22\367\377\377\17\365\377\377\5\272\274" +\
    "\377\24*\350\377\22/\374\377\21.\375\377\17+\375\377\16)\375\377\14&" +\
    "\375\377\10!\375\377\7\36\375\377\10\35\375\377\11\34\374\377\12\33\375" +\
    "\377\13\33\375\377\13\31\374\377\11\22\305\377\0\0\5v\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\6" +\
    "\6\220\252\32\15\377\357&\24\377\376,\31\377\377_Q\377\377YL\377\377" +\
    "VJ\377\377SG\377\377PG\377\377ME\377\377KE\377\377JD\377\377JE\377\377" +\
    "NI\377\377OJ\377\377LF\377\377KD\377\377KE\377\377NG\377\370QG\377\322" +\
    "KA\377\2216-\377\20\207\225\377\42\340\365\377_\361\377\377Q\360\377" +\
    "\377I\362\377\377C\365\377\377>\367\377\3779\371\377\3776\370\377\377" +\
    "2\372\377\377.\371\377\377+\370\377\377(\367\377\377'\366\377\377%\365" +\
    "\377\377$\360\374\377\27\223\241\377#7\370\377 ;\374\377\368\374\377" +\
    "\35\65\375\377\32\62\375\377\30/\375\377\27-\375\377\23(\375\377\12\37" +\
    "\374\377\14\35\375\377\14\34\376\377\14\34\376\377\13\31\371\377\11\20" +\
    "\254\377\0\0\6D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\1\1\4[\22\13\353\323\32\12\377\373!\16\377\377\37" +\
    "\15\377\3777)\377\377E9\377\377C7\377\377A6\377\377>6\377\377=4\377\377" +\
    ";5\377\37794\377\37794\377\37784\377\37794\377\37784\377\377:4\377\377" +\
    ":4\377\377<5\377\373\77\67\377\335;3\377\2511*\377)GJ\377=\315\335\377" +\
    "w\361\376\377p\363\376\377h\363\377\377_\364\377\377W\364\377\377R\365" +\
    "\377\377U\367\377\377Y\370\377\377K\370\377\377C\370\377\377@\370\377" +\
    "\377>\365\377\377=\363\377\377=\352\370\377%m\233\3775J\377\3772H\375" +\
    "\377.D\375\377,A\374\377)@\374\377(=\374\377':\374\377&7\374\377&4\374" +\
    "\377\22!\375\377\23!\376\377\20\36\376\377\16\31\362\377\11\16\211\377" +\
    "\1\0\1,\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\4\0\0\65\224\22\6\376\351\34\12\376\377\35\14\377\376\33\13" +\
    "\377\377\31\12\377\3771#\377\3774'\377\3770&\377\377/&\377\377.&\377" +\
    "\377-&\377\377+%\377\377)%\377\377)$\377\377(%\377\377)%\377\377)%\377" +\
    "\377+%\377\377-&\377\376.&\377\354.&\377\274) \377u\30\21\377#\207\223" +\
    "\377\211\347\361\377\204\362\376\377\200\364\376\377z\363\377\377t\364" +\
    "\377\377s\365\377\377\242\371\377\377\321\374\377\377\213\371\376\377" +\
    "`\365\377\377\134\365\377\377[\363\377\377[\361\376\377U\337\354\377" +\
    "\77_\307\377Pb\377\377I\134\376\377AU\376\377>R\376\377<O\376\377<M\376" +\
    "\377<K\375\377\77I\375\377\77I\376\3770;\376\377\34'\376\377\26\42\376" +\
    "\377\17\26\343\377\14A^\377\0\1\1#\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\17\1\0\240\265\27\10\377\365\34" +\
    "\13\377\377\33\12\377\377\30\11\377\377\27\11\377\377\25\7\377\377 \24" +\
    "\377\377%\33\377\377\42\32\377\377!\32\377\377\37\31\377\377\36\31\377" +\
    "\377\34\31\377\377\35\31\377\377\33\30\377\377\34\31\377\377\34\31\377" +\
    "\377\35\31\377\377\37\31\377\377 \31\377\367#\31\377\325 \27\377\247" +\
    "\33\23\377G\33\30\377U\254\267\377\217\351\363\377\222\364\376\377\220" +\
    "\365\377\377\214\364\376\377\215\365\377\377\267\371\376\377\342\374" +\
    "\376\377\240\370\377\377|\365\377\377x\364\377\377v\362\376\377t\362" +\
    "\376\377a\317\330\377q\177\346\377\245\256\375\377\211\225\375\377]k" +\
    "\375\377Tb\375\377Tb\375\377T_\375\377V_\375\377V]\376\377V\134\376\377" +\
    "X^\376\377'/\376\377\36(\371\377\20%\272\377\6\242\253\377\0\6\6*\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "/\5\2\344\311\31\11\377\372\34\13\377\377\32\12\377\377\30\11\377\377" +\
    "\26\10\377\377\25\7\377\377\21\6\377\377\22\10\377\377\26\15\377\377" +\
    "\26\16\377\377\25\17\377\377\22\16\377\377\22\16\377\377\20\16\377\377" +\
    "\21\16\377\377\21\16\377\377\21\16\377\377\22\16\377\377\24\17\377\377" +\
    "\26\17\377\375\27\16\377\355\23\12\377\303\17\5\377\236\14\4\377C\36" +\
    "\34\377`\246\254\377\231\342\353\377\235\363\374\377\234\365\377\377" +\
    "\233\366\377\377\237\367\376\377\243\367\377\377\227\365\377\377\217" +\
    "\365\377\377\214\364\377\377\211\364\377\377\205\360\373\377X\240\252" +\
    "\377\243\247\366\377\362\363\375\377\311\314\375\377}\205\377\377mv\377" +\
    "\377lt\377\377lt\377\377ls\376\377ip\376\377hm\376\377hm\375\377-4\375" +\
    "\377\33\31\322\377\16\255\307\377\7\256\275\377\0\6\6X\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\10\4\362" +\
    "\321\31\11\377\375\34\13\377\376\32\12\377\377\27\10\377\377\26\10\377" +\
    "\377\25\7\377\377\21\6\377\377\17\6\377\377\15\4\377\377\12\4\377\377" +\
    "\12\4\377\377\11\6\377\377\12\5\377\377\11\5\377\377\10\5\377\377\11" +\
    "\5\377\377\12\5\377\377\12\6\377\377\12\5\377\377\13\5\377\376\14\4\377" +\
    "\372\20\5\377\345\17\5\377\276\20\5\377\235\15\5\377M\14\10\377Ax~\377" +\
    "\206\307\316\377\242\350\357\377\246\363\373\377\245\366\376\377\243" +\
    "\367\377\377\242\367\377\377\237\367\377\377\235\364\377\377\233\366" +\
    "\377\377\217\346\357\377[s\235\377\241\246\377\377\301\303\376\377\256" +\
    "\261\376\377\212\221\376\377\203\211\377\377\201\206\377\377~\204\377" +\
    "\377}\202\377\377{\201\376\377y~\377\377z\177\375\377$%\340\377\23\205" +\
    "\273\377\10\361\377\377\10\262\301\377\0\6\7d\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0G\11\4\362\324\31\11" +\
    "\377\375\33\12\377\377\32\12\377\377\27\10\377\377\25\7\377\377\23\6" +\
    "\377\377\21\5\377\377\17\5\377\377\15\4\377\377\12\4\377\377\10\4\377" +\
    "\377\7\3\377\377\5\2\377\377\5\3\377\377\5\3\377\377\5\2\377\377\5\2" +\
    "\377\377\6\3\377\377\11\4\377\377\12\3\377\376\14\4\377\377\16\4\377" +\
    "\372\21\6\377\345\21\6\377\302\20\5\377\231\15\5\377c\7\2\377.7\33\377" +\
    "6y}\377s\256\264\377\223\313\320\377\235\333\340\377\235\340\350\377" +\
    "\235\342\351\377\235\345\354\377\233\342\351\377\177\273\302\377\216" +\
    "\224\345\377\237\244\377\377\237\243\377\377\232\240\377\377\226\233" +\
    "\377\377\222\227\377\377\221\226\377\377\217\223\376\377\215\222\377" +\
    "\377\213\220\377\377\207\214\373\377JM\336\377\26\201\260\377\7\365\377" +\
    "\377\12\352\373\377\7\243\261\377\0\7\10.\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0G\11\3\362\324\31\11\377" +\
    "\375\33\11\377\377\32\11\377\377\27\10\377\377\25\6\377\377\23\6\377" +\
    "\377\20\5\377\377\17\5\377\377\13\3\377\377\12\4\377\377\10\3\377\377" +\
    "\6\2\377\377\4\2\377\377\4\3\377\377\4\1\377\377\4\3\377\377\3\3\377" +\
    "\377\6\2\377\377\7\2\377\377\11\4\377\377\13\3\377\376\16\4\377\377\20" +\
    "\4\377\372\22\5\377\353\23\7\377\301\21\6\377p\13\4\377\232\211\12\377" +\
    "\220\200\12\377h^\12\377A\77\22\377&;-\377\42DA\377#FC\377&@Y\377hq\237" +\
    "\377\237\242\352\377\252\255\377\377\250\253\377\377\246\252\377\377" +\
    "\245\250\377\377\242\246\377\377\240\244\377\377\237\242\377\377\236" +\
    "\241\377\377\232\235\374\377\222\225\360\377UT\300\377\20\276\315\377" +\
    "\11\361\377\377\12\357\377\377\13\344\365\377\7\221\236\372\0\6\7\24" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0C\10\3\362\321\30\11\377\375\33\12\377\376\31\11\377\377\26\10\377" +\
    "\377\25\6\377\377\23\6\377\377\20\5\377\377\17\4\377\377\13\3\377\377" +\
    "\11\3\377\377\10\2\377\377\6\2\377\377\4\2\377\377\3\1\377\377\4\2\377" +\
    "\377\4\1\377\377\3\1\377\377\5\2\377\377\10\3\377\377\11\3\377\377\13" +\
    "\3\377\377\16\4\377\376\17\4\377\377\22\5\377\373\25\7\377\332\23\6\377" +\
    "\202%\4\377\317\271\11\377\277\251\10\377\262\236\7\377\252\227\7\377" +\
    "\245\221\6\377\241\217\6\377\232\210\5\377\201o\1\377\22Og\377:I\236" +\
    "\377rp\331\377\243\246\356\377\262\265\366\377\261\264\371\377\255\260" +\
    "\372\377\253\256\370\377\251\253\362\377\226\224\344\377cb\263\3773\232" +\
    "\267\377&\350\362\377(\361\377\377\23\354\376\377\21\354\377\377\14\324" +\
    "\346\377\10\134d\355\0\0\0\10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0+\5\2\340\307\27\11\377\372\32\12\377" +\
    "\377\31\11\377\377\26\10\377\377\25\6\377\377\23\6\377\377\21\5\377\377" +\
    "\17\4\377\377\13\3\377\377\11\3\377\377\10\2\377\377\5\2\377\377\5\2" +\
    "\377\377\3\1\377\377\3\1\377\377\3\1\377\377\5\2\377\377\5\1\377\377" +\
    "\7\2\377\377\11\3\377\377\14\4\377\377\15\4\377\377\20\4\377\377\22\6" +\
    "\377\371\24\6\377\326\22\6\377\223`\4\377\366\332\5\377\356\322\5\377" +\
    "\346\313\5\377\337\305\4\377\333\301\4\377\330\277\5\377\310\260\5\377" +\
    "\247\224\3\377@S%\3777\305\320\377e\312\332\377Q\242\314\377J\207\276" +\
    "\377It\263\377Oy\264\377Z\207\270\377S\241\304\377@\304\326\377A\361" +\
    "\364\377F\370\377\377G\361\376\377H\357\377\3779\354\377\377\33\344\371" +\
    "\377\16\245\264\377\6\6\5~\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\15\1\0\226\262\25\7\377\364\32" +\
    "\11\377\377\31\10\377\377\26\10\377\377\25\7\377\377\23\5\377\377\21" +\
    "\5\377\377\16\3\377\377\14\3\377\377\12\2\377\377\7\2\377\377\6\2\377" +\
    "\377\3\1\377\377\3\1\377\377\3\1\377\377\4\1\377\377\3\0\377\377\5\1" +\
    "\377\377\10\1\377\377\11\3\377\377\13\3\377\377\16\3\377\377\20\4\377" +\
    "\377\23\5\377\363\24\6\377\304\21\6\377\327\275\4\377\376\340\5\377\374" +\
    "\335\4\377\373\335\5\377\372\334\5\377\371\334\5\377\371\333\5\377\353" +\
    "\320\5\377\301\253\4\377\211x\1\377\36ju\377\177\334\346\377\207\363" +\
    "\377\377\204\367\377\377\177\375\377\377\206\377\377\377\337\377\377" +\
    "\377\264\375\377\377l\365\377\377g\363\377\377g\362\377\377f\361\377" +\
    "\377d\360\377\377_\354\375\377\34\306\332\377\13OV\337\0\0\0\17\0\0\0" +\
    "\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\4\0\0,\220\21\6\375\347\31\11\376\376\31\11\377\376\27\10\377" +\
    "\377\26\6\377\377\24\6\377\377\21\5\377\377\17\4\377\377\14\3\377\377" +\
    "\12\2\377\377\11\1\377\377\6\1\377\377\5\1\377\377\4\0\377\377\4\1\377" +\
    "\377\4\0\377\377\5\0\377\377\6\1\377\377\11\1\377\377\12\2\377\377\14" +\
    "\3\377\377\17\3\377\376\21\4\377\376\23\5\377\352\23\6\377\253\31\5\377" +\
    "\370\332\5\377\375\335\4\377\375\335\4\377\375\336\4\377\375\336\4\377" +\
    "\375\335\4\377\375\336\4\377\370\333\5\377\333\303\4\377\255\232\4\377" +\
    "nb\4\377M\214\222\377\215\336\347\377\226\362\374\377\224\365\377\377" +\
    "\226\366\377\377\266\370\377\377\244\367\377\377\207\365\377\377\203" +\
    "\363\376\377\201\363\377\377~\363\376\377z\356\372\377[\321\336\376\17" +\
    "hq\372\0\0\0A\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3R\12\4\347\320\27\7\377\372\31" +\
    "\11\377\377\27\7\377\377\25\7\377\377\25\6\377\377\22\5\377\377\20\3" +\
    "\377\377\16\3\377\377\13\2\377\377\12\1\377\377\7\1\377\377\6\1\377\377" +\
    "\4\1\377\377\5\0\377\377\5\1\377\377\6\1\377\377\7\1\377\377\12\1\377" +\
    "\377\13\3\377\377\15\3\377\377\17\3\377\377\21\4\377\371\23\6\377\333" +\
    "\21\6\377\223H\3\377\375\336\3\377\375\335\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\335\4\377\375\336\4\377\374\337\5\377\361\325" +\
    "\5\377\315\267\3\377\243\222\4\377i\134\0\377G~\200\377\213\314\323\377" +\
    "\237\354\364\377\242\364\374\377\241\366\376\377\236\366\376\377\232" +\
    "\366\376\377\227\365\376\377\222\361\373\377\213\346\360\377s\300\310" +\
    "\377\36Y^\377\0\0\0\134\0\0\2\17\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\201" +\
    "\244\22\7\377\355\30\11\377\376\30\7\377\376\27\7\377\377\26\6\377\377" +\
    "\23\4\377\377\20\4\377\377\17\3\377\377\14\3\377\377\12\2\377\377\11" +\
    "\2\377\377\6\0\377\377\6\1\377\377\6\0\377\377\5\1\377\377\6\1\377\377" +\
    "\10\1\377\377\13\1\377\377\14\3\377\377\16\3\377\377\20\3\377\375\23" +\
    "\4\377\361\24\6\377\266\13\5\377\317\270\3\377\374\337\4\377\375\335" +\
    "\4\377\375\336\3\377\375\336\4\377\375\336\4\377\375\335\3\377\375\336" +\
    "\3\377\375\337\4\377\373\336\4\377\354\321\4\377\312\264\3\377\245\224" +\
    "\4\377\210{\3\3770@%\377J\215\227\377\211\276\304\377\231\323\332\377" +\
    "\233\334\343\377\231\334\343\377\221\321\331\377~\272\301\377K\177\207" +\
    "\377BG\25\377\77=\4\377\0\0\0!\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\2V\12\4\351\316\26\7\377\367\31\7\377\376\27\7\377\377\26\6\377" +\
    "\377\24\5\377\377\22\4\377\377\20\3\377\377\16\3\377\377\13\1\377\377" +\
    "\12\2\377\377\12\0\377\377\11\1\377\377\11\1\377\377\11\0\377\377\11" +\
    "\0\377\377\12\1\377\377\13\1\377\377\16\3\377\376\17\3\377\377\21\3\377" +\
    "\372\23\5\377\340\22\6\377\234;\4\377\377\345\4\377\375\337\4\377\375" +\
    "\336\3\377\375\335\3\377\375\336\3\377\375\335\3\377\375\335\3\377\375" +\
    "\337\4\377\375\337\3\377\375\340\4\377\372\337\5\377\355\324\5\377\321" +\
    "\275\4\377\262\241\4\377\235\216\3\377\200v\2\377]`\22\377\77L!\3775" +\
    "L6\377:M4\377HQ!\377sr\21\377\237\225\4\377\253\243\7\37696\3\363\0\0" +\
    "\0\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0T\205\16\5\377" +\
    "\335\26\7\376\373\30\10\377\377\26\6\377\376\25\6\377\377\23\4\377\377" +\
    "\21\4\377\377\17\2\377\377\16\3\377\377\14\1\377\377\14\2\377\377\13" +\
    "\1\377\377\13\0\377\377\14\0\377\377\14\1\377\377\14\2\377\377\16\2\377" +\
    "\377\20\2\377\377\21\4\377\375\23\4\377\356\23\6\377\266\11\5\377\310" +\
    "\256\3\377\375\337\4\377\375\337\2\377\375\336\2\377\375\336\3\377\375" +\
    "\336\3\377\375\336\3\377\375\337\2\377\375\336\2\377\375\337\3\377\374" +\
    "\341\4\377\374\342\4\377\373\341\4\377\363\333\4\377\342\316\5\377\315" +\
    "\274\5\377\272\253\5\377\260\242\5\377\253\236\5\377\253\237\5\377\261" +\
    "\245\5\377\274\260\7\377\314\300\10\377\332\317\11\377\271\261\10\377" +\
    "(%\2\271\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "#\4\1\234\244\22\5\377\345\26\7\377\373\30\10\377\377\26\6\377\376\24" +\
    "\5\377\377\23\4\377\377\22\3\377\377\21\3\377\377\17\2\377\377\15\2\377" +\
    "\377\15\1\377\377\15\2\377\377\15\2\377\377\15\2\377\377\16\2\377\377" +\
    "\20\3\377\377\21\3\377\376\23\3\377\367\24\4\377\327\22\5\377\236N\3" +\
    "\377\377\352\4\377\375\340\4\377\375\337\2\377\375\337\3\377\375\337" +\
    "\3\377\375\337\3\377\375\337\3\377\375\336\3\377\375\337\2\377\375\340" +\
    "\3\377\375\342\4\377\375\343\3\377\375\344\5\377\374\344\4\377\372\343" +\
    "\5\377\364\337\6\377\353\330\6\377\344\322\6\377\337\317\7\377\337\320" +\
    "\10\377\343\324\10\377\353\334\11\377\363\345\12\377\353\336\13\376\253" +\
    "\244\7\377\24\23\1i\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\42\63\6\27\377\250\21\4\377\342\26\7\377\371\27\7\377" +\
    "\376\27\6\377\377\24\5\377\376\23\4\377\377\22\3\377\377\21\3\377\377" +\
    "\21\2\377\377\20\3\377\377\20\2\377\377\21\2\377\377\21\2\377\377\21" +\
    "\3\377\377\21\3\377\376\23\4\377\372\24\5\377\342\24\5\377\236\27\5\377" +\
    "\344\321\3\377\374\342\3\377\375\341\3\377\375\340\3\377\375\337\3\377" +\
    "\375\340\2\377\375\337\2\377\375\337\3\377\375\340\2\377\375\340\3\377" +\
    "\375\341\3\377\375\341\4\377\375\344\4\377\375\344\5\377\375\345\4\377" +\
    "\375\346\6\377\375\350\6\377\374\350\7\377\373\351\10\377\373\351\7\377" +\
    "\372\352\10\377\373\353\11\377\375\356\12\377\375\355\12\377\337\324" +\
    "\11\377xr\7\377\0\0\0(\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\35\10\32o\223\10\200\3779\5#\377\236\20\4\377\327\25\6" +\
    "\377\363\26\6\377\375\27\6\377\377\25\5\377\377\24\4\377\377\24\4\377" +\
    "\376\23\5\377\377\22\3\377\377\22\3\377\377\23\4\377\377\23\4\377\377" +\
    "\23\5\377\376\24\4\377\372\25\5\377\350\23\5\377\270\16\5\377\323\271" +\
    "\4\377\376\345\4\377\375\344\4\377\375\342\3\377\375\341\3\377\375\341" +\
    "\2\377\375\337\2\377\375\337\2\377\375\340\1\377\375\341\3\377\375\340" +\
    "\3\377\375\342\3\377\375\343\3\377\375\343\4\377\375\345\5\377\375\345" +\
    "\4\377\375\347\6\377\375\351\6\377\375\351\6\377\375\353\7\377\376\354" +\
    "\7\377\375\355\10\377\376\356\10\377\376\357\12\377\367\351\11\377\316" +\
    "\303\11\3771$\4\373\0\0\0\13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0F\4=\256\271\11\241\377\254\11\227\377Y\4K\377n\13" +\
    "\4\377\273\22\5\377\340\25\6\377\363\26\6\377\374\26\6\377\376\26\5\377" +\
    "\377\24\5\377\377\23\4\377\377\23\4\377\377\23\4\377\377\24\5\377\376" +\
    "\26\5\377\370\26\5\377\345\25\6\377\273\20\4\377\270\231\3\377\376\347" +\
    "\5\377\374\344\4\377\375\344\4\377\375\343\3\377\375\342\3\377\375\341" +\
    "\3\377\375\340\1\377\375\340\1\377\375\340\1\377\375\341\3\377\375\341" +\
    "\3\377\375\343\3\377\375\343\4\377\375\344\4\377\375\345\5\377\375\346" +\
    "\4\377\375\350\6\377\375\350\6\377\374\352\6\377\374\353\10\377\376\354" +\
    "\7\377\376\356\10\377\375\356\10\377\374\356\12\377\355\340\12\377\265" +\
    "\252\7\377k\15\6\377\0\0\0\42\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0U\4J\275\330\11\275\376\336\7\305\377\212\13r\377" +\
    "e4;\377F\37\35\377p\10\0\377\265\21\4\377\320\24\5\377\343\25\6\377\357" +\
    "\26\6\377\365\26\6\377\367\27\6\377\366\27\6\377\362\26\6\377\352\25" +\
    "\6\377\331\24\6\377\242\20\4\377\273\234\4\377\375\350\5\377\374\347" +\
    "\4\377\375\345\4\377\375\345\4\377\375\344\3\377\375\343\3\377\375\343" +\
    "\2\377\375\343\3\377\375\341\2\377\375\342\3\377\375\343\2\377\375\344" +\
    "\3\377\375\344\3\377\375\344\4\377\375\345\4\377\375\347\5\377\375\350" +\
    "\4\377\375\350\6\377\374\351\6\377\376\353\6\377\375\353\10\377\376\354" +\
    "\10\377\376\355\10\377\375\356\11\377\366\350\12\377\327\316\10\377\215" +\
    "H\11\376\230\23\7\377\7\0\0;\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0X\4L\275\326\10\275\377\257<p\377\313\202{\377\312" +\
    "\204\203\377\270wu\377\204WV\377X.,\377T\23\17\377r\11\1\377\250\16\4" +\
    "\377\301\12\5\377\306\10\5\377\305\10\5\377\270\7\5\377\240\25\4\377" +\
    "\236O\4\377\322\276\6\377\377\354\6\377\374\351\6\377\375\350\4\377\375" +\
    "\350\5\377\375\345\3\377\375\345\4\377\375\345\3\377\375\344\2\377\375" +\
    "\344\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375" +\
    "\345\3\377\375\345\3\377\375\347\4\377\375\350\4\377\375\350\6\377\375" +\
    "\351\6\377\374\352\6\377\375\353\6\377\376\355\10\377\375\356\10\377" +\
    "\376\357\10\377\373\355\11\377\346\332\11\377\256\237\7\377\337\24\11" +\
    "\377\244\24\7\377\20\2\0C\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0G\4;\267\245EN\377\363\226\224\377\374\227\226\377\365" +\
    "\222\220\377\346\210\207\377\324}|\377\304tt\377\264mm\377\202UU\377" +\
    "9'\37\377\200s\4\377\265\244\7\377\306\262\7\377\313\274\7\377\354\343" +\
    "\7\377\377\365\7\377\376\354\7\377\374\352\5\377\375\352\6\377\375\351" +\
    "\5\377\375\350\5\377\375\347\4\377\375\346\3\377\375\346\4\377\375\346" +\
    "\3\377\375\346\3\377\375\345\3\377\375\346\3\377\375\346\3\377\375\346" +\
    "\4\377\375\346\3\377\375\347\4\377\375\350\5\377\375\350\4\377\375\352" +\
    "\5\377\374\352\5\377\374\353\7\377\376\354\7\377\376\355\10\377\375\355" +\
    "\11\377\374\355\10\377\356\341\11\377\302\274\7\377\257*\11\377\361\33" +\
    "\12\377\247\24\10\377\17\1\0D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0+\204%!\377\356\210\206\376\377\212\211\377\377\212" +\
    "\210\377\376\210\207\377\375\206\205\377\370\203\202\377\360\200\201" +\
    "\377\343\216\216\377\312\247\246\377\245zz\377I9\24\377\270\257\7\377" +\
    "\355\340\11\377\375\356\10\377\375\357\11\377\375\355\10\377\376\355" +\
    "\7\377\374\353\6\377\374\353\5\377\375\352\6\377\375\352\4\377\375\351" +\
    "\5\377\375\350\4\377\375\347\3\377\375\347\3\377\375\347\4\377\375\347" +\
    "\4\377\375\347\4\377\375\347\3\377\375\346\3\377\375\347\4\377\375\351" +\
    "\5\377\375\352\4\377\375\352\6\377\374\352\6\377\375\353\6\377\376\354" +\
    "\7\377\375\356\10\377\376\356\10\377\375\356\11\377\362\345\11\377\323" +\
    "\312\10\377\241Q\7\377\377\32\12\377\360\32\11\377\245\23\7\377\17\2" +\
    "\0D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0j\23\22\344\336" +\
    "HF\377\375|y\377\377yx\377\377xx\377\377xw\377\377uu\377\377rs\377\376" +\
    "sv\377\373\226\230\377\356\332\333\377\311\237\237\377\223GK\377D;\7" +\
    "\377\275\263\7\377\355\337\10\377\374\354\11\377\376\356\7\377\376\356" +\
    "\7\377\375\354\7\377\375\354\7\377\375\352\5\377\374\352\5\377\374\352" +\
    "\5\377\375\351\5\377\375\351\5\377\375\351\4\377\375\351\4\377\375\351" +\
    "\4\377\375\351\4\377\375\351\4\377\375\351\5\377\375\351\5\377\375\352" +\
    "\4\377\375\352\5\377\374\353\6\377\376\353\5\377\375\354\7\377\375\355" +\
    "\7\377\376\356\7\377\374\355\11\377\362\344\10\377\325\312\10\377\225" +\
    "a\7\377\371\23\10\377\377\33\12\377\355\31\11\376\237\23\6\377\14\2\0" +\
    "A\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\27\12\12\231\302\36\33\377" +\
    "\372LI\376\377mh\377\345bZ\377\272JW\377\262DY\377\263BV\377\324NP\377" +\
    "\376VX\377\377ej\377\373\201\210\377\352mr\377\304FJ\377\21602\377D<" +\
    "\6\377\271\257\6\377\351\334\10\377\373\354\10\377\376\356\10\377\376" +\
    "\355\7\377\376\353\6\377\376\353\6\377\375\352\5\377\374\352\5\377\375" +\
    "\353\5\377\375\352\4\377\375\352\4\377\375\351\5\377\375\351\5\377\375" +\
    "\351\5\377\374\352\4\377\374\351\4\377\375\353\4\377\374\352\5\377\374" +\
    "\352\5\377\375\353\6\377\376\353\7\377\375\355\7\377\376\356\10\377\373" +\
    "\354\10\377\357\341\10\377\322\307\7\377\216^\10\377\363\23\7\377\377" +\
    "\27\10\377\376\33\12\377\345\31\11\377\210\20\6\377\0\0\0\62\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\3\4\5\204\16\15\365\355!\31\376\2666" +\
    "N\377\277n\246\377\324\210\313\377\350\231\337\377\355\233\342\377\353" +\
    "\232\342\377\335\217\325\377\305w\265\377\263E}\377\343>D\377\375BM\377" +\
    "\350:D\377\30418\377\221$*\377B0\10\377\256\245\5\377\336\322\10\377" +\
    "\366\347\7\377\375\356\10\377\376\355\7\377\376\355\6\377\375\355\6\377" +\
    "\375\353\6\377\375\353\6\377\375\353\6\377\375\353\6\377\375\352\5\377" +\
    "\374\352\5\377\375\353\5\377\374\352\6\377\375\353\6\377\375\353\6\377" +\
    "\375\353\5\377\376\354\6\377\375\355\6\377\376\355\7\377\375\355\10\377" +\
    "\370\351\7\377\351\334\10\377\313\305\7\377\230L\6\377\365\22\6\377\377" +\
    "\26\7\377\377\30\11\377\374\32\11\377\326\30\10\377M\11\3\376\0\0\0\21" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\2\2V\237\17\20\377\262X\220\377" +\
    "\351\227\342\377\373\240\355\377\377\241\361\377\377\241\362\377\377" +\
    "\241\362\377\377\241\362\377\377\241\362\377\375\241\357\377\364\237" +\
    "\350\377\305r\276\377\275/Q\377\376,5\377\351*4\377\307%,\377\244\36" +\
    "$\377N\37\14\377\200{\4\377\313\300\7\377\353\335\7\377\370\352\10\377" +\
    "\375\355\7\377\376\356\6\377\376\355\7\377\376\354\6\377\375\354\6\377" +\
    "\375\353\6\377\376\353\5\377\375\353\5\377\376\353\5\377\375\353\5\377" +\
    "\375\353\5\377\376\354\6\377\376\355\6\377\376\356\6\377\375\355\7\377" +\
    "\372\352\10\377\360\341\7\377\334\321\7\377\254\242\7\377\2610\5\377" +\
    "\377\17\4\377\377\25\6\377\377\27\7\377\377\30\11\377\366\32\11\377\273" +\
    "\26\7\377\32\2\0\272\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0+\15" +\
    "\17\317\264Q\246\377\367\215\347\377\377\217\356\377\377\217\356\377" +\
    "\377\217\357\377\377\221\357\377\377\257\364\377\377\247\362\377\377" +\
    "\217\357\377\377\216\356\377\377\216\356\377\375\216\354\377\341p\326" +\
    "\377\263 R\377\375\35(\377\355\34'\377\321\31!\377\263\26\34\377h\5\14" +\
    "\377XD\5\377\255\243\7\377\332\317\6\377\353\336\7\377\366\347\10\377" +\
    "\373\354\7\377\375\355\6\377\375\356\7\377\376\356\7\377\376\356\7\377" +\
    "\376\356\7\377\376\356\7\377\376\356\7\377\375\355\7\377\375\355\6\377" +\
    "\372\353\6\377\366\347\10\377\354\336\7\377\335\322\6\377\274\266\7\377" +\
    "\237b\6\377\326\11\3\377\377\21\5\377\376\22\5\377\377\25\6\377\377\27" +\
    "\7\377\376\31\10\377\346\30\11\376\222\21\5\376\10\1\0B\4\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\4\1 \217\26~\377\357s\335\376\377{\353\377\376" +\
    "z\354\377\377x\354\377\377u\355\377\377}\357\377\376\335\372\377\376" +\
    "\302\370\377\377u\356\377\377t\354\377\377w\353\377\377y\354\377\375" +\
    "~\354\377\3328\310\377\275\31,\377\373\21\36\377\363\17\33\377\336\10" +\
    "\21\377\274\6\14\377\201\4\10\377c\7\4\377\207S\7\377\265\246\6\377\313" +\
    "\300\6\377\335\322\6\377\347\333\7\377\356\340\7\377\361\342\7\377\363" +\
    "\345\6\377\363\345\7\377\363\344\6\377\361\342\7\377\356\340\7\377\350" +\
    "\333\7\377\336\322\6\377\314\301\6\377\267\250\5\377\225Z\5\377\317\7" +\
    "\3\377\377\16\2\377\376\20\4\377\377\22\5\377\377\24\5\377\376\26\6\377" +\
    "\376\30\10\377\366\31\10\377\310\26\7\3779\6\3\347\0\0\0\15\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\09\14\63\310\330 \273\377\375c\345\376\377b" +\
    "\347\377\377`\350\377\377Z\352\377\377T\354\377\377S\355\377\377l\361" +\
    "\377\377e\361\377\377Q\355\377\377R\353\377\377U\353\377\377Y\350\377" +\
    "\377_\351\377\3731\335\377\302\22\236\377\377\5\21\377\375\6\23\377\367" +\
    "\10\22\377\341\10\17\377\264\6\12\377C\3\4\377\260\23\6\377\350\24\10" +\
    "\377\274\33\7\377\214L\5\377\245\220\6\377\263\251\6\377\277\267\5\377" +\
    "\303\273\7\377\304\273\7\377\303\273\7\377\277\270\5\377\264\252\5\377" +\
    "\246\223\6\377\212L\4\377\270\25\2\377\363\6\1\377\376\13\2\377\376\16" +\
    "\2\377\376\17\3\377\377\22\3\377\377\23\5\377\376\25\6\377\377\26\6\377" +\
    "\373\30\7\377\337\27\10\376\211\17\5\377\0\0\0I\0\0\0\2\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\5\0.\233\16\207\377\366 \326\377\376F\343\377\376G\346" +\
    "\377\377@\347\377\377:\353\377\3776\355\377\3775\356\377\3776\360\377" +\
    "\3775\357\377\3775\356\377\3776\355\377\3777\353\377\3778\350\377\376" +\
    ";\347\377\377\15\340\377\350\15\315\377\267\14'\377\375\6\23\377\375" +\
    "\7\22\377\363\10\21\377\320\7\14\377\232\6\11\377O\10\4\377\312\25\6" +\
    "\377\365\30\10\377\376\27\7\377\370\24\6\377\356\24\5\377\350\26\4\377" +\
    "\350\24\3\377\350\23\3\377\350\21\2\377\350\20\2\377\356\14\1\377\367" +\
    "\12\1\377\376\13\1\377\377\14\2\377\377\14\1\377\376\15\2\377\377\17" +\
    "\3\377\377\21\3\377\377\22\3\377\377\25\5\377\377\26\7\377\375\30\10" +\
    "\377\353\27\10\377\257\22\5\377\34\2\1\277\0\0\0\10\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\66\7/x\314\14\261\377\375\24\336\377\377\23\340\377" +\
    "\377\42\344\377\377\42\347\377\377\37\352\377\377\37\354\377\377\36\355" +\
    "\377\377\36\357\377\377\36\356\377\377\36\355\377\377\36\353\377\377" +\
    "\37\352\377\377\37\346\377\377\13\343\377\377\12\342\377\370\13\332\377" +\
    "\247\7~\377\373\5\21\377\375\6\21\377\373\7\20\377\352\10\16\377\301" +\
    "\7\13\377~\4\6\377t\14\5\377\320\25\7\377\365\30\7\377\376\26\6\377\377" +\
    "\26\5\377\377\23\4\377\377\22\3\377\377\21\3\377\377\20\2\377\377\16" +\
    "\2\377\377\16\1\377\377\15\1\377\377\16\1\377\377\16\2\377\377\17\2\377" +\
    "\377\20\3\377\377\21\3\377\377\22\4\377\376\24\5\377\377\26\6\377\374" +\
    "\27\6\377\355\27\7\377\276\24\6\377>\6\2\336\0\0\0\31\0\0\0\2\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0N\4C\262\337\13\303\377\377\13\341\377\376" +\
    "\13\342\377\377\7\345\377\377\12\350\377\377\14\353\377\377\14\355\377" +\
    "\377\14\355\377\377\14\356\377\377\14\356\377\377\14\355\377\377\14\353" +\
    "\377\377\13\351\377\377\6\346\377\377\7\343\377\376\11\342\377\375\13" +\
    "\336\377\306\11\255\377\367\5\24\377\374\6\21\377\374\7\20\377\371\10" +\
    "\17\377\343\7\15\377\271\7\12\377_\4\4\377s\14\3\377\315\24\6\377\362" +\
    "\27\10\377\375\26\7\377\377\25\6\377\377\24\5\377\377\22\4\377\377\21" +\
    "\3\377\377\22\2\377\377\21\2\377\377\21\3\377\377\20\3\377\377\21\2\377" +\
    "\377\22\2\377\377\21\3\377\377\23\3\377\377\24\5\377\377\26\6\377\373" +\
    "\30\6\377\350\27\7\376\272\23\5\377F\7\3\350\0\0\0\62\0\0\0\4\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0V\4K\270\344\12\310\377\377\11\341" +\
    "\377\377\10\343\377\377\6\345\377\377\5\350\377\377\4\352\377\377\3\355" +\
    "\377\377\2\356\377\377\2\356\377\377\2\356\377\377\3\355\377\377\3\353" +\
    "\377\377\4\351\377\377\5\347\377\377\6\344\377\377\11\342\377\376\12" +\
    "\337\377\317\11\263\377\367\5\24\377\374\6\17\377\374\6\17\377\375\10" +\
    "\16\377\367\11\15\377\337\10\13\377\261\7\10\377K\3!\377f\12\12\377\275" +\
    "\23\5\377\345\26\6\377\370\27\7\377\376\27\6\377\377\26\5\377\377\24" +\
    "\4\377\377\23\4\377\376\23\4\377\377\23\4\377\377\23\4\377\376\23\4\377" +\
    "\377\23\4\377\377\24\5\377\377\26\5\377\375\26\6\377\364\27\7\377\334" +\
    "\24\6\377\245\21\4\3776\5\2\335\0\0\0.\1\0\0\6\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0U\4J\270\344\11\310\376\377\10\341\377" +\
    "\377\7\343\377\377\6\345\377\377\4\350\377\377\3\352\377\377\2\355\377" +\
    "\377\2\356\377\377\1\356\377\377\1\357\377\377\2\356\377\377\3\353\377" +\
    "\377\3\350\377\377\4\347\377\377\6\344\377\376\10\342\377\376\12\337" +\
    "\377\315\10\263\377\367\5\22\377\374\6\17\377\374\7\17\377\375\10\15" +\
    "\377\375\11\15\377\366\12\15\377\310\11\4\377\234\3~\377\220\1\210\377" +\
    "<\4\31\377\224\17\3\377\311\23\5\377\345\25\7\377\364\26\5\377\373\27" +\
    "\6\377\375\26\5\377\376\25\4\377\376\25\5\377\376\24\5\377\376\25\4\377" +\
    "\375\26\6\377\371\26\6\377\360\26\6\377\335\25\6\377\272\21\5\377{\15" +\
    "\3\373\7\1\0\235\0\0\0\20\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0I\3@\252\333\11\300\377\377\10\341\377\376\7" +\
    "\343\377\377\5\345\377\377\4\347\377\377\3\352\377\377\1\354\377\377" +\
    "\2\355\377\377\0\357\377\377\0\356\377\377\2\355\377\377\3\352\377\377" +\
    "\3\351\377\377\4\346\377\377\6\343\377\377\10\343\377\374\12\336\377" +\
    "\300\10\246\377\370\5\17\377\374\6\17\377\374\7\16\377\376\10\14\377" +\
    "\376\11\15\377\372\12\15\377\251\10\12\377\343\1\334\377\313\3\273\377" +\
    "\255\2\235\377o\3d\377@\5\15\377\217\16\3\377\270\21\4\377\317\23\6\377" +\
    "\340\25\6\377\351\26\6\377\354\26\6\377\353\25\6\377\347\26\6\377\335" +\
    "\24\6\376\310\23\5\377\257\20\4\377w\14\3\376\35\2\1\302\1\0\0 \0\0\0" +\
    "\1\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0+\2%e\303\7\252\377\375\10\336\377\377\7\342\377\377\5\344" +\
    "\377\377\3\346\377\377\2\350\377\377\2\353\377\377\1\356\377\377\1\356" +\
    "\377\377\0\356\377\377\2\354\377\377\2\352\377\377\3\350\377\377\4\346" +\
    "\377\377\5\343\377\377\10\342\377\367\11\331\377\242\6h\377\374\5\15" +\
    "\377\374\6\15\377\375\7\15\377\376\10\14\377\375\11\14\377\347\11\12" +\
    "\377\317\3\244\377\376\1\354\377\362\2\336\377\336\2\313\377\307\3\263" +\
    "\377\255\3\232\377\210\4x\377S\4<\376:\5\7\377j\12\4\377\215\15\4\377" +\
    "\221\16\4\377\221\16\4\377\205\14\4\377[\10\3\377)\4\1\320\26\1\0a\0" +\
    "\0\0\30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\30\177\5o\377\360\11\324" +\
    "\377\377\7\342\377\376\5\343\377\377\4\345\377\377\2\347\377\377\1\351" +\
    "\377\377\1\353\377\377\0\353\377\377\0\353\377\377\1\352\377\377\2\350" +\
    "\377\377\4\346\377\377\4\344\377\376\6\343\377\377\10\341\377\335\10" +\
    "\306\377\320\4\21\377\375\6\15\377\374\6\14\377\376\7\14\377\376\11\15" +\
    "\377\363\12\12\377\244\7&\377\373\0\355\377\377\1\353\377\376\2\350\377" +\
    "\372\3\342\377\361\4\331\377\344\5\313\377\324\6\272\377\251\6\224\377" +\
    ".\1*\327\0\0\0B\0\0\0\62\0\0\0*\0\0\0)\0\0\0'\0\0\0\30\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0*\2%\221\310\6\257" +\
    "\377\372\10\334\376\377\5\343\377\376\4\344\377\377\2\345\377\377\1\347" +\
    "\377\377\1\347\377\377\0\350\377\377\0\350\377\377\1\347\377\377\3\346" +\
    "\377\377\3\345\377\377\5\343\377\377\7\342\377\367\10\331\377\264\7\203" +\
    "\377\377\5\13\377\374\6\13\377\375\7\14\377\376\10\14\377\367\10\12\377" +\
    "\273\10\20\377\365\0\345\377\377\0\352\377\377\1\351\377\376\2\347\377" +\
    "\377\3\345\377\376\5\343\377\374\6\337\377\356\10\321\376\224\5\201\377" +\
    "\0\0\0G\0\0\0\11\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12a\3V\354" +\
    "\331\6\277\377\373\7\336\376\377\5\342\377\377\3\343\377\377\2\344\377" +\
    "\377\2\346\377\377\2\345\377\377\2\346\377\377\2\345\377\377\2\343\377" +\
    "\376\4\343\377\377\6\342\377\372\7\334\377\306\7\256\377\334\5\6\377" +\
    "\376\6\14\377\376\7\14\377\375\7\13\377\362\10\11\377\273\7\25\377\343" +\
    "\2\327\377\377\1\346\377\377\1\346\377\377\2\347\377\377\3\344\377\377" +\
    "\4\344\377\376\5\342\377\372\10\334\377\312\7\262\377B\3;\257\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16r\4d\360" +\
    "\323\6\272\377\367\6\332\376\376\4\342\377\376\4\342\377\377\3\342\377" +\
    "\377\3\342\377\377\3\342\377\377\3\342\377\377\4\342\377\376\6\341\377" +\
    "\367\6\332\377\311\6\265\377\312\5\30\377\375\7\13\377\373\7\12\377\365" +\
    "\7\12\377\341\10\11\377\251\6+\377\367\2\345\377\376\3\343\377\377\3" +\
    "\343\377\377\2\343\377\377\3\343\377\377\3\343\377\376\5\342\377\367" +\
    "\7\332\377\320\6\266\377P\3F\342\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12A\29\324\261\5\233\377" +\
    "\336\6\304\376\364\5\327\377\373\4\337\377\375\4\340\377\374\4\340\377" +\
    "\371\5\334\377\357\6\323\377\334\6\302\377\240\6\204\377\332\6\15\377" +\
    "\352\7\11\377\331\6\10\377\277\6\10\377\220\6\14\377\263\5\221\376\364" +\
    "\6\330\377\375\5\340\377\377\3\342\377\377\4\343\377\377\3\343\377\377" +\
    "\4\342\377\372\5\335\377\352\6\316\376\272\6\244\377;\2\64\330\0\0\0" +\
    "\13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\1\32\0\27A\77\1\67\315\200\4q\377\261\5\233" +\
    "\377\275\5\246\377\270\4\242\377\232\4\210\377Z\3M\377R\3\26\377f\3\1" +\
    "\377g\3\4\377Q\3\4\3614\1\2\251'\1\2F\0\0\15!9\2\63\270\214\4{\377\306" +\
    "\5\256\377\333\5\301\377\343\5\310\376\341\4\307\376\324\5\272\377\263" +\
    "\5\234\377a\3U\375$\1\37^\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\27\13\1\13C\31\0\26J\25\1\22H\0\0\0.\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0!)\1" +\
    "&hH\2@\252R\3H\263Q\3G\262=\2\66\220\14\0\13E\0\0\0\5\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"


# RGBA 128x128x4
icon_128_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\4\0\0\0\10\0\0\0\13\0\0\0" +\
    "\14\0\0\0\13\0\0\0\6\0\0\0\3\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\5\0\0\0\17\0\0\0\36\0\0\0/\0\0\0A\0\0\0V\0\0\0d\0" +\
    "\0\0g\0\0\0\134\0\0\0K\0\0\0:\0\0\0)\0\0\0\32\0\0\0\14\0\0\0\3\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0" +\
    "\0\0\12\0\0\0\36\0\0\0B\0\0\0q\0\1\1\245\0\11\11\311\0\24\25\334\0\42" +\
    "%\355\1.\60\365\1\60\64\365\0$&\355\0\20\22\336\0\4\5\314\0\1\1\257\0" +\
    "\0\0\203\0\0\0U\0\0\0.\0\0\0\20\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\11\0\0\0\42\0\0\0T\0\0\0\242\0\27\30\335\1BG\367\2e" +\
    "m\374\3\202\214\376\3\220\232\377\3\232\246\377\3\235\252\377\4\240\254" +\
    "\377\3\231\245\377\3\216\232\377\3~\211\376\2^e\375\0\658\371\0\4\5\337" +\
    "\0\0\0\242\0\0\0_\0\0\0-\0\0\0\16\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0\25\0\0" +\
    "\0C\0\0\0\241\1'*\350\2_g\374\4\215\230\377\4\246\263\377\4\270\306\377" +\
    "\4\302\321\376\4\311\332\377\4\317\340\377\5\322\343\377\5\322\342\377" +\
    "\4\317\337\377\4\310\330\377\4\300\317\377\4\262\277\377\3\235\251\377" +\
    "\3x\201\377\1<@\373\0\5\5\341\0\0\0\234\0\0\0P\0\0\0\36\0\0\0\5\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\0\0\0" +\
    "\42\0\0\0k\0\17\20\322\2V]\374\4\223\236\376\5\260\276\377\5\307\326" +\
    "\376\5\326\345\377\6\337\357\377\5\343\365\377\4\347\367\377\4\351\372" +\
    "\377\5\352\373\377\4\352\372\377\5\351\372\377\5\350\370\377\5\344\364" +\
    "\377\5\333\354\377\5\317\337\377\4\273\311\377\4\241\255\377\2r|\377" +\
    "\0&)\371\0\0\0\312\0\0\0r\0\0\0.\0\0\0\11\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\3\0\0\0\4\0\0\0\5" +\
    "\0\0\0\6\0\0\0\10\0\0\0\20\0\0\0\60\0\0\0\207\1$&\354\3z\205\377\4\252" +\
    "\267\376\5\307\326\377\6\332\352\377\6\344\365\377\5\352\373\377\5\355" +\
    "\375\377\4\355\375\377\4\356\376\377\3\356\376\377\3\356\376\377\4\356" +\
    "\376\377\3\356\376\377\4\356\376\377\3\355\375\377\3\353\374\377\5\350" +\
    "\370\377\5\337\357\377\5\320\337\377\4\265\304\376\3\223\235\377\1HN" +\
    "\377\0\2\2\344\0\0\0\206\0\0\0\66\0\0\0\13\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\3\0\0\0\7\0\0\0\17\0\0\0\31\0\0\0&\0\0\0\62\0\0\0=\0\0\0D\0\0\0" +\
    "G\0\0\0N\0\0\0c\0\0\0\246\0+/\365\4\216\232\376\6\267\305\377\6\323\343" +\
    "\376\7\343\363\377\6\352\372\377\5\355\375\377\4\356\376\377\3\356\376" +\
    "\377\3\357\377\377\2\357\376\377\3\356\377\377\3\357\377\377\2\357\377" +\
    "\377\2\357\377\377\2\357\376\377\2\357\377\377\3\356\376\377\4\355\375" +\
    "\377\4\354\374\377\4\346\370\377\5\333\354\377\4\303\322\377\4\237\254" +\
    "\377\3[a\377\0\4\4\356\0\0\0\216\0\0\0\66\0\0\0\11\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0\10\0\0\0\24" +\
    "\0\0\0(\0\0\0B\0\0\0d\0\0\0\212\0\0\0\263\0\0\0\322\1\1\1\344\2\1\1\352" +\
    "\2\2\1\354\2\2\1\357\1\0\0\365\2-\61\374\5\225\241\376\5\304\320\377" +\
    "\6\342\354\376\7\356\367\377\7\362\374\377\4\370\376\377\3\365\377\377" +\
    "\3\363\377\377\3\361\377\377\3\357\377\377\3\357\377\377\1\361\377\377" +\
    "\2\360\377\377\2\357\377\377\1\357\377\377\2\357\377\377\2\356\376\377" +\
    "\3\356\377\377\3\357\376\377\3\355\375\377\4\356\375\377\5\351\372\377" +\
    "\5\340\361\377\6\312\331\377\4\241\257\377\3Zb\376\0\2\2\355\0\0\0\207" +\
    "\0\0\0-\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\4\0\0\0\16\0" +\
    "\0\0 \0\0\0A\0\0\0t\0\0\0\260\0\0\0\337\20\21\21\365.\31\30\375N\35\31" +\
    "\377h\36\26\377v\34\23\377{\35\23\377q\33\22\377S\24\14\377\22\33\33" +\
    "\376\4Kg\376\5@|\377\5/\217\377\5%\226\377\5 \235\377\5\36\225\377\5" +\
    ",\241\377\4E\242\377\2w\253\377\1\247\274\377\1\324\323\377\0\361\357" +\
    "\377\2\371\377\377\1\365\377\377\1\362\377\377\1\362\377\377\1\362\377" +\
    "\377\2\362\377\377\1\361\377\377\3\357\376\377\3\357\377\377\4\356\376" +\
    "\377\4\355\375\377\5\352\373\377\6\341\362\377\6\313\332\377\4\241\256" +\
    "\376\2EK\377\0\0\0\343\0\0\0q\0\0\0\37\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\5\0" +\
    "\0\0\20\0\0\0(\0\0\0U\0\0\0\224\3\4\4\325\35\16\14\366F\37\34\377n1," +\
    "\377\220\77\67\377\237QH\377\253e\134\377\254ph\377\210ZT\377C+/\377" +\
    "\27\22C\377\5\14l\377\4\14\230\377\5\13\264\377\6\15\311\377\6\20\330" +\
    "\377\6\22\336\377\6\23\341\377\6\22\341\377\6\20\335\377\6\15\330\377" +\
    "\6\11\314\377\6\6\302\377\5\15\266\377\5\35\241\377\4L\230\377\2\255" +\
    "\277\377\0\346\355\377\0\366\376\377\0\363\377\377\1\362\377\377\2\362" +\
    "\377\377\1\361\377\377\3\357\377\377\3\357\376\377\3\356\376\377\5\353" +\
    "\375\377\6\352\373\377\6\340\361\377\5\304\324\377\5\226\241\376\1'*" +\
    "\377\0\0\0\306\0\0\0R\0\0\0\17\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0\14\0\0\0#\0\0\0R\0\0\0\235\13" +\
    "\6\6\3410\33\30\375k2-\377\226QI\377\254ib\376\271\200y\377\304\220\212" +\
    "\377\306\224\216\377\234vq\377A3D\377\5\12U\377\4\14\217\377\5\17\264" +\
    "\377\5\20\304\377\6\23\330\377\6\24\347\377\6\25\361\377\7\25\366\377" +\
    "\7\25\371\377\7\25\371\377\7\26\372\377\7\25\370\377\7\25\367\377\6\25" +\
    "\362\377\6\24\357\377\7\24\350\377\6\24\342\377\6\20\327\377\6\7\267" +\
    "\377\4&\233\377\2\215\263\377\0\341\347\377\0\366\376\377\1\364\377\377" +\
    "\2\363\376\377\1\361\377\377\2\360\377\377\3\357\376\377\5\356\376\377" +\
    "\5\354\375\377\7\352\373\377\7\333\353\377\6\266\305\377\3s|\376\0\11" +\
    "\11\371\0\0\0\230\0\0\0/\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\2\0\0\0\10\0\0\0\27\0\0\0;\0\0\0\201\7\5\4\324/\32\30\375" +\
    "t>9\377\237ZT\377\260|v\377\276\213\206\377\306\215\206\377\316\220\211" +\
    "\377\303\211\201\377_EN\377\7\12Q\377\4\15\233\377\5\17\271\377\6\23" +\
    "\320\377\7\24\342\377\7\26\355\377\6\26\365\377\7\26\372\377\7\26\374" +\
    "\377\7\26\375\377\6\26\375\377\6\26\375\377\5\27\375\377\5\27\375\377" +\
    "\5\26\375\377\5\27\376\377\6\27\375\377\7\27\373\377\7\26\372\377\7\25" +\
    "\363\377\6\25\352\377\6\22\335\377\5\12\301\377\5&\230\377\1\245\300" +\
    "\377\0\360\364\377\2\364\377\377\2\362\377\377\2\361\376\377\4\357\377" +\
    "\377\4\356\376\377\5\356\376\377\7\355\375\377\7\347\367\377\6\320\340" +\
    "\377\5\243\261\377\19>\377\0\0\0\332\0\0\0_\0\0\0\21\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0\14\0\0\0%\0\0\0Y\1\0\0\260\30\16\16\364" +\
    "U+'\376|HC\376zUQ\377sUS\377hQN\377OGF\3778\77@\3774A@\377\22$.\377\3" +\
    "\30q\377\5\24\231\377\6\23\274\377\6\23\334\377\10\25\361\377\6\25\371" +\
    "\377\6\27\374\377\7\27\374\377\6\27\374\377\5\26\375\377\5\26\374\377" +\
    "\6\26\374\377\6\26\375\377\6\26\374\377\6\26\375\377\6\27\375\377\6\26" +\
    "\375\377\6\27\375\377\5\26\375\377\6\27\376\377\6\26\375\377\7\26\374" +\
    "\377\7\26\367\377\7\25\355\377\6\22\334\377\6\13\267\377\4R\233\377\2" +\
    "\334\344\377\1\365\375\377\2\362\377\377\4\360\377\377\4\357\377\377" +\
    "\4\357\377\377\7\356\376\377\7\354\374\377\7\337\360\377\6\272\312\377" +\
    "\3s}\376\0\6\6\372\0\0\0\227\0\0\0+\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\5\0" +\
    "\0\0\24\0\0\0\66\0\0\0~\3\1\1\330\33\17\16\374/%$\377\27\65\66\377\16" +\
    "IM\377\7ck\377\5u~\377\4\205\220\377\4\215\230\377\4\226\242\377\3\235" +\
    "\252\377\3\240\255\377\3\243\255\377\4\230\246\377\3\216\236\377\5p\224" +\
    "\377\5A\233\377\6 \302\377\6\24\353\377\6\27\375\377\6\27\375\377\6\27" +\
    "\375\377\6\26\374\377\6\27\375\377\6\27\375\377\6\27\375\377\6\27\375" +\
    "\377\6\27\375\377\6\27\374\377\6\26\374\377\5\26\374\377\5\27\375\377" +\
    "\5\26\375\377\6\27\376\377\7\26\374\377\6\25\372\377\6\25\365\377\6\24" +\
    "\347\377\7\16\317\377\6$\236\377\2\300\314\377\2\364\376\377\4\360\376" +\
    "\377\4\357\377\377\4\356\376\377\6\356\377\377\6\355\375\377\10\347\370" +\
    "\377\7\315\335\377\6\234\251\377\1%(\377\0\0\0\316\0\0\0M\0\0\0\11\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\1\0\0\0\11\0\0\0\37\0\0\0P\0\0\0\245\0\5\5\360\7-/\377\10[c\377" +\
    "\3\203\215\376\3\233\250\377\4\253\267\377\4\266\304\377\4\276\314\377" +\
    "\4\304\323\377\5\311\330\377\4\316\335\377\5\321\342\377\5\324\343\377" +\
    "\5\325\346\377\6\325\346\377\4\323\343\377\5\314\332\377\4\275\312\377" +\
    "\4\242\261\377\4m\236\377\4/\253\377\5\26\362\377\4\26\375\377\4\27\375" +\
    "\377\4\26\375\377\4\26\375\377\4\26\375\377\4\26\375\377\5\26\375\377" +\
    "\4\26\375\377\4\27\375\377\5\27\375\377\5\27\375\377\6\26\374\377\6\27" +\
    "\375\377\7\27\376\377\6\26\375\377\7\26\375\377\7\25\370\377\7\25\357" +\
    "\377\6\21\327\377\6\26\244\377\3\257\301\377\3\366\377\377\4\357\376" +\
    "\377\5\357\377\377\6\356\377\377\6\356\376\377\7\352\373\377\10\332\352" +\
    "\377\6\256\275\377\3U\134\377\0\0\0\363\0\0\0s\0\0\0\26\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\17\0\0\0" +\
    "\62\0\0\0w\0\5\5\315\1\62\65\373\3nx\377\4\232\250\377\5\262\300\377" +\
    "\5\303\322\377\5\317\337\377\6\330\350\377\4\335\356\377\5\342\363\377" +\
    "\4\345\366\377\4\346\370\377\5\351\371\377\4\351\373\377\5\352\374\377" +\
    "\5\353\374\377\5\353\374\377\5\352\373\377\5\346\367\377\4\340\362\377" +\
    "\6\330\351\377\5\306\322\377\3\220\232\377\3\42\276\377\5\26\376\377" +\
    "\4\27\375\377\4\27\375\377\4\27\375\377\4\27\375\377\4\27\375\377\3\27" +\
    "\375\377\4\30\375\377\5\27\375\377\4\26\375\377\5\26\375\377\5\27\375" +\
    "\377\5\26\374\377\5\26\374\377\6\27\375\377\7\27\376\377\7\26\375\377" +\
    "\10\26\373\377\10\25\362\377\7\21\335\377\5\25\250\377\3\255\301\377" +\
    "\4\365\377\377\5\357\376\377\5\356\377\377\6\356\377\377\7\354\376\377" +\
    "\7\341\362\377\7\274\313\377\4t~\376\0\4\4\375\0\0\0\230\0\0\0'\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\0\0\0\30\0\0\0" +\
    "H\0\0\0\240\1\36 \355\3hp\377\4\237\253\377\5\270\306\377\6\315\335\377" +\
    "\5\333\353\377\6\343\364\377\6\347\370\377\5\353\374\377\4\354\375\377" +\
    "\3\354\375\377\4\355\376\377\3\356\376\377\3\356\376\377\3\356\376\377" +\
    "\3\356\377\377\3\356\377\377\4\356\377\377\3\356\376\377\4\355\376\377" +\
    "\4\354\375\377\5\352\374\377\5\334\355\377\4\267\277\377\3:\250\377\5" +\
    "\25\376\377\4\31\375\377\3\31\375\377\4\31\375\377\4\30\375\377\4\30" +\
    "\375\377\4\30\375\377\4\27\375\377\3\27\375\377\4\27\375\377\5\30\375" +\
    "\377\5\27\375\377\5\27\375\377\5\30\375\377\5\27\374\377\6\30\375\377" +\
    "\7\27\375\377\7\27\375\377\7\26\373\377\10\25\363\377\7\22\333\377\6" +\
    "\32\242\377\4\274\315\377\5\363\377\377\6\357\377\377\7\360\376\377\10" +\
    "\356\376\377\10\345\366\377\7\306\326\377\5\212\226\377\0\15\16\376\0" +\
    "\0\0\267\0\0\09\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\0" +\
    "\0\0\35\0\0\0Z\0\5\5\303\2DJ\372\4\212\226\377\6\263\300\377\6\314\334" +\
    "\377\7\334\355\377\7\347\367\377\6\354\374\377\5\354\375\377\4\356\376" +\
    "\377\3\357\376\377\2\356\377\377\2\357\377\377\2\356\376\377\2\357\377" +\
    "\377\2\356\377\377\3\356\377\377\2\357\377\377\2\357\377\377\2\357\377" +\
    "\377\4\357\377\377\4\356\377\377\4\356\377\377\4\355\376\377\5\344\365" +\
    "\377\4\305\322\377\2L\240\377\3\25\370\377\4\32\374\377\4\32\375\377" +\
    "\4\31\375\377\3\32\375\377\3\32\375\377\4\32\375\377\4\31\375\377\4\31" +\
    "\375\377\4\31\375\377\4\30\375\377\5\30\375\377\4\30\375\377\4\27\375" +\
    "\377\5\27\375\377\6\30\375\377\6\27\374\377\6\26\375\377\10\27\375\377" +\
    "\10\27\373\377\10\27\361\377\10\21\325\377\6\61\240\377\5\336\344\377" +\
    "\5\360\377\377\6\356\376\377\10\356\376\377\11\350\371\377\10\314\335" +\
    "\377\6\225\242\377\0\25\27\377\0\0\0\317\0\0\0J\0\0\0\6\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0" +\
    "\0\0\1\0\0\0\1\0\0\0\1\0\0\0\1\0\0\0\1\0\0\0\1\0\0\0\1\0\0\0\1\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\4\0\0\0\15\0\0\0(\0\0\0i\0\7\7\325\2\134d\374\5\237\253" +\
    "\376\5\302\322\377\7\331\351\377\7\345\365\377\6\353\374\377\5\354\374" +\
    "\377\5\356\375\377\3\355\377\377\4\357\377\377\3\356\377\377\2\357\377" +\
    "\377\3\357\377\377\3\357\377\377\1\357\377\377\2\357\377\377\2\357\377" +\
    "\377\2\357\377\377\2\360\377\377\2\356\377\377\3\356\377\377\2\356\377" +\
    "\377\3\356\377\377\3\356\377\377\4\351\370\377\4\322\337\377\2m\232\377" +\
    "\3\27\350\377\4\33\375\377\4\32\375\377\3\32\375\377\3\32\375\377\3\31" +\
    "\375\377\3\31\375\377\2\31\375\377\3\32\375\377\3\32\375\377\3\30\375" +\
    "\377\3\31\375\377\5\27\375\377\4\30\375\377\4\30\375\377\6\30\375\377" +\
    "\5\30\375\377\7\26\374\377\10\30\376\377\10\27\374\377\10\27\372\377" +\
    "\7\25\355\377\7\16\313\377\6X\241\377\6\362\373\377\7\360\377\377\10" +\
    "\356\377\377\10\351\372\377\10\320\341\377\6\235\253\377\0!#\377\0\0" +\
    "\0\335\0\0\0W\0\0\0\11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\2\0\0\0\5\0\0\0\14\0\0\0\24\0\0\0\35\0\0\0&\0\0\0*\0\0\0,\0\0\0,\0\0" +\
    "\0,\0\0\0*\0\0\0'\0\0\0 \0\0\0\31\0\0\0\17\0\0\0\7\0\0\0\2\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\1\0\0\0\5\0\0\0\17\0\0\0$\0\0\0I\0\0\0\213\0\12" +\
    "\12\341\3em\375\5\245\262\376\6\312\331\377\6\336\360\377\7\352\371\377" +\
    "\6\354\375\377\5\355\375\377\5\356\376\377\4\356\377\377\4\356\376\377" +\
    "\3\357\377\377\2\357\377\377\3\360\377\377\3\361\377\377\2\361\377\377" +\
    "\2\362\377\377\2\362\377\377\2\362\377\377\2\362\377\377\2\361\377\377" +\
    "\1\361\377\377\2\360\377\377\3\360\377\377\2\356\377\377\2\356\377\377" +\
    "\3\353\372\377\4\327\345\377\3\206\241\377\3\33\330\377\3\32\375\377" +\
    "\2\32\375\377\2\32\375\377\3\31\375\377\3\31\375\377\3\31\375\377\3\30" +\
    "\375\377\2\30\375\377\3\32\375\377\4\31\375\377\3\31\375\377\5\30\375" +\
    "\377\5\30\375\377\4\27\375\377\5\30\375\377\5\27\375\377\7\27\375\377" +\
    "\6\26\374\377\10\26\375\377\10\27\374\377\10\26\371\377\7\24\346\377" +\
    "\7\23\266\377\6\237\271\377\7\361\376\377\10\356\377\377\11\351\373\377" +\
    "\10\321\341\377\6\236\254\377\0#&\377\0\0\0\343\0\0\0\134\0\0\0\13\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\0\0\0\22\0\0\0%\0\0\0\77\0\0\0]\0\0\0" +\
    "\201\0\0\0\237\0\0\0\263\0\0\0\274\0\0\0\277\0\0\0\300\0\0\0\277\0\0" +\
    "\0\274\0\0\0\265\0\0\0\244\0\0\0\210\0\0\0g\0\0\0I\0\0\0-\0\0\0\30\0" +\
    "\0\0\14\0\0\0\14\0\0\0\27\0\0\0\61\0\0\0^\0\0\0\236\0\0\0\326\4\12\11" +\
    "\367\4ai\376\6\247\265\377\7\315\336\376\10\342\363\377\7\352\373\377" +\
    "\6\355\375\377\6\355\376\377\4\357\377\377\5\356\376\377\3\357\377\377" +\
    "\3\360\377\377\2\360\377\377\2\360\377\377\1\362\377\377\1\362\377\377" +\
    "\2\363\377\377\2\363\377\377\1\363\377\377\0\362\377\377\0\362\377\377" +\
    "\1\363\377\377\1\363\377\377\1\361\377\377\1\361\377\377\3\360\377\377" +\
    "\3\357\377\377\2\355\374\377\3\334\353\377\2\237\255\377\2!\305\377\3" +\
    "\33\375\377\3\33\375\377\3\33\375\377\3\34\375\377\3\34\375\377\3\33" +\
    "\375\377\3\32\375\377\3\32\375\377\3\32\375\377\4\33\375\377\4\32\375" +\
    "\377\4\31\375\377\5\30\375\377\5\30\375\377\5\30\375\377\5\27\375\377" +\
    "\7\31\375\377\6\27\376\377\10\30\376\377\10\30\375\377\11\27\374\377" +\
    "\10\25\365\377\7\21\331\377\7-\241\377\10\346\356\377\10\356\376\377" +\
    "\11\351\372\377\11\316\337\377\6\231\247\377\0\32\35\377\0\0\0\341\0" +\
    "\0\0Z\0\0\0\13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\2\0\0\0\12\0\0\0\36\0\0\0C\0\0\0v\0\0\0\260\3\7" +\
    "\10\331\16\11\11\357\42\17\15\3733\25\21\376G\30\24\377M\34\27\377O\35" +\
    "\30\377O\36\30\377N\35\30\377L\34\27\377E\30\24\3772\23\20\377\35\16" +\
    "\14\375\13\10\10\362\1\5\5\334\0\0\0\257\0\0\0|\0\0\0\134\0\0\0X\0\0" +\
    "\0y\0\0\0\270\12\11\12\351+*\22\37610\23\377\11KL\376\6\241\257\377\7" +\
    "\313\333\377\10\343\364\377\7\352\374\377\7\356\375\377\6\356\376\377" +\
    "\5\356\377\377\5\357\377\377\4\360\377\377\3\360\377\377\2\361\377\377" +\
    "\3\362\377\377\2\363\377\377\2\363\377\377\2\364\377\377\1\363\377\377" +\
    "\0\363\377\377\1\363\377\377\1\364\377\377\1\364\377\377\1\363\377\377" +\
    "\0\363\377\377\1\363\377\377\2\363\377\377\1\362\377\377\3\361\377\377" +\
    "\3\357\375\377\3\340\356\377\2\254\266\377\2*\267\377\3\35\375\377\3" +\
    "\35\375\377\2\35\375\377\1\35\375\377\1\34\375\377\2\34\375\377\3\34" +\
    "\375\377\3\33\375\377\3\31\375\377\3\32\375\377\4\33\375\377\4\33\375" +\
    "\377\4\32\375\377\5\31\375\377\5\31\375\377\6\30\375\377\5\30\375\377" +\
    "\7\27\374\377\6\27\374\377\7\30\376\377\11\27\375\377\10\27\373\377\10" +\
    "\26\354\377\7\20\301\377\7\223\265\377\11\356\375\377\12\346\370\377" +\
    "\10\311\331\377\7\220\234\377\0\16\17\377\0\1\1\326\0\0\0Q\0\0\0\10\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\17\0" +\
    "\0\0-\0\0\0b\0\1\1\250\13\6\6\347$\24\23\377M\37\33\377v)!\376\2166," +\
    "\376\237D:\377\252TJ\377\256\134R\377\262\134S\377\264\134T\377\264\134" +\
    "T\377\264]T\377\261\134S\377\255\134R\377\250UL\377\232G=\377\2107.\377" +\
    "h(!\376&\21\17\377\20\10\7\377\4\2\2\357\1\1\1\353\26\26\16\376GD\36" +\
    "\377{x'\376|y2\377\27\77\67\377\5\224\241\377\7\306\324\377\10\341\362" +\
    "\377\10\352\374\377\10\356\376\377\6\356\376\377\5\355\376\377\5\357" +\
    "\377\377\4\360\377\377\3\360\377\377\3\361\377\377\3\362\377\377\2\364" +\
    "\377\377\1\364\377\377\1\365\377\377\0\366\377\377\0\367\377\377\1\367" +\
    "\377\377\0\367\377\377\0\367\377\377\0\366\377\377\0\366\377\377\1\365" +\
    "\377\377\1\364\377\377\1\363\377\377\1\363\377\377\2\362\377\377\3\360" +\
    "\375\377\2\343\360\377\2\264\274\377\2\61\253\377\3\35\377\377\3\36\374" +\
    "\377\2\36\375\377\2\35\375\377\2\35\375\377\1\35\375\377\3\36\375\377" +\
    "\3\36\375\377\3\34\375\377\3\34\375\377\4\33\375\377\3\33\375\377\5\32" +\
    "\375\377\5\32\375\377\5\32\375\377\6\31\375\377\6\31\375\377\6\31\374" +\
    "\377\7\31\376\377\10\27\375\377\10\30\376\377\11\30\375\377\11\27\366" +\
    "\377\10\22\332\377\7\61\235\377\10\343\357\377\11\343\365\377\10\300" +\
    "\320\377\5}\211\377\0\6\10\377\0\0\0\305\0\0\0B\0\0\0\5\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0+\0\0\0l\4\2\2\305\27\16" +\
    "\15\367O'#\377\20781\377\240D:\377\256d[\377\271\202|\377\304\224\217" +\
    "\377\315\235\230\377\325\240\234\377\330\243\235\377\333\243\237\377" +\
    "\334\246\240\377\334\246\240\377\334\246\237\377\331\243\236\377\330" +\
    "\242\234\377\323\236\232\377\313\231\225\377\277\221\215\377\260}w\377" +\
    "\236`X\377\223G\77\377y;4\377W3+\377i_&\377\213\212F\377\243\242p\377" +\
    "JR=\377\4r|\377\7\265\305\377\11\332\354\377\10\351\372\377\7\354\375" +\
    "\377\7\357\377\377\5\355\377\377\5\357\377\377\5\357\377\377\4\360\377" +\
    "\377\3\361\377\377\3\362\377\377\2\364\377\377\3\364\377\377\1\366\377" +\
    "\377\1\366\377\377\0\367\377\377\1\366\377\377\1\370\377\377\0\366\377" +\
    "\377\0\370\377\377\0\370\377\377\0\370\377\377\0\370\377\377\1\365\377" +\
    "\377\0\365\377\377\2\364\377\377\1\364\376\377\3\361\376\377\3\346\362" +\
    "\377\2\277\307\377\1\77\241\377\3\35\374\377\3\37\375\377\3\37\375\377" +\
    "\1\37\375\377\2\35\375\377\1\36\375\377\3\36\375\377\3\37\375\377\3\35" +\
    "\375\377\2\34\375\377\4\34\375\377\3\33\375\377\5\34\375\377\5\32\375" +\
    "\377\5\31\375\377\6\32\375\377\5\31\375\377\7\31\374\377\7\31\375\377" +\
    "\10\27\376\377\10\27\375\377\11\30\375\377\11\27\373\377\11\25\353\377" +\
    "\10\15\267\377\11\251\304\377\11\343\362\377\10\267\307\377\4kv\377\0" +\
    "\1\1\376\0\0\0\257\0\0\0\64\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\3\0\0\0\32\0\0\0S\1\2\2\263\35\22\22\365^'!\376\216<3\377\251ia\377" +\
    "\274\206\177\377\312\222\214\377\330\233\223\377\341\241\231\377\350" +\
    "\244\236\377\354\251\241\377\361\253\244\377\364\255\246\377\365\255" +\
    "\246\377\365\257\247\377\366\256\246\377\365\257\247\377\365\254\246" +\
    "\377\363\254\245\377\360\252\242\377\353\247\241\377\345\242\234\377" +\
    "\333\234\225\377\321\226\217\377\306\215\207\377\274\207\200\377\256" +\
    "rl\377\234MD\377vG<\377[U>\377\17IJ\377\6\240\257\377\10\320\341\377" +\
    "\11\347\370\377\11\354\375\377\10\357\376\377\10\360\377\377\6\356\377" +\
    "\377\4\360\377\377\4\360\377\377\3\361\377\377\4\362\377\377\2\364\377" +\
    "\377\3\365\377\377\1\365\377\377\2\366\377\377\1\367\377\377\0\370\377" +\
    "\377\1\370\377\377\0\371\377\377\1\370\377\377\0\370\377\377\0\370\377" +\
    "\377\0\370\377\377\0\370\377\377\1\367\377\377\0\365\377\377\2\364\377" +\
    "\377\1\364\377\377\3\363\376\377\3\347\362\377\3\300\310\377\1A\240\377" +\
    "\3\35\375\377\3\37\375\377\3 \375\377\3\37\375\377\1\36\375\377\3\37" +\
    "\375\377\2\36\375\377\3\36\375\377\2\37\375\377\3\35\375\377\4\34\375" +\
    "\377\4\34\375\377\5\33\375\377\5\32\375\377\5\33\375\377\6\31\375\377" +\
    "\5\31\375\377\7\31\375\377\7\30\374\377\10\30\376\377\10\30\376\377\11" +\
    "\27\376\377\11\30\375\377\11\26\363\377\10\20\321\377\10a\244\377\12" +\
    "\330\345\377\10\251\271\377\2LR\376\0\0\0\374\0\0\0\226\0\0\0'\0\0\0" +\
    "\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\0\0\0\60\0\0\0\211\21\14\13\346P \34" +\
    "\376\217C:\377\256ld\377\302\211\203\377\325\227\221\377\342\235\226" +\
    "\377\354\244\235\377\362\251\241\377\366\253\243\377\373\256\246\377" +\
    "\374\256\246\377\374\257\247\377\375\257\247\377\376\260\250\377\376" +\
    "\257\250\377\376\257\247\377\376\260\250\377\376\260\250\377\375\261" +\
    "\250\377\374\257\247\377\373\256\245\377\370\254\244\377\364\251\242" +\
    "\377\356\246\236\377\350\241\232\377\342\234\225\377\325\227\220\377" +\
    "\303\212\205\377\246le\377\77+)\377\5v\200\377\10\272\312\377\11\336" +\
    "\360\377\11\353\374\377\7\356\376\377\7\357\377\377\7\360\377\377\5\356" +\
    "\377\377\5\360\377\377\4\361\377\377\3\362\377\377\4\363\377\377\3\365" +\
    "\377\377\3\365\377\377\2\367\377\377\2\367\377\377\2\367\377\377\1\371" +\
    "\377\377\0\372\377\377\1\372\377\377\1\372\377\377\0\370\377\377\1\371" +\
    "\377\377\1\372\377\377\1\371\377\377\0\370\377\377\2\366\377\377\1\366" +\
    "\377\377\2\365\377\377\3\363\376\377\3\351\364\377\3\305\314\377\1F\236" +\
    "\377\3\36\373\377\3!\375\377\3!\375\377\2 \375\377\3!\375\377\2 \375" +\
    "\377\3\37\375\377\3 \375\377\2\36\375\377\4\36\375\377\4\35\375\377\4" +\
    "\35\375\377\5\34\375\377\5\33\375\377\5\33\375\377\5\32\375\377\7\32" +\
    "\375\377\6\32\375\377\6\31\375\377\7\31\375\377\10\31\375\377\10\27\376" +\
    "\377\11\27\374\377\12\27\371\377\11\24\340\377\10(\236\377\13\271\310" +\
    "\377\7\226\245\377\5!$\377\0\0\0\367\0\0\0y\0\0\0\31\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\21\0\0\0K\1\3\3\2670\30\26\372\1773,\377\251_X\377\302\205" +\
    "\177\377\327\225\216\377\346\234\224\377\361\243\233\377\366\247\236" +\
    "\377\373\252\242\377\375\254\243\377\376\254\243\377\376\254\244\377" +\
    "\377\254\243\377\377\254\244\377\377\254\243\377\376\253\243\377\377" +\
    "\253\243\377\377\253\243\377\377\253\243\377\377\253\243\377\377\254" +\
    "\244\377\377\254\243\377\376\254\243\377\375\254\243\377\375\254\243" +\
    "\377\373\252\242\377\372\251\240\377\364\245\235\377\351\235\225\377" +\
    "\323\217\210\377\252uo\377\32\62\64\377\5\226\244\377\11\314\335\377" +\
    "\11\346\370\377\11\355\376\377\10\356\377\377\10\357\376\377\7\357\377" +\
    "\377\5\360\377\377\5\360\377\377\4\362\377\377\3\363\377\377\4\363\377" +\
    "\377\3\366\377\377\3\366\377\377\2\367\377\377\2\367\377\377\1\371\377" +\
    "\377\0\372\377\377\1\373\377\377\1\372\377\377\1\372\377\377\1\373\377" +\
    "\377\1\373\377\377\1\372\377\377\0\372\377\377\1\370\377\377\2\366\377" +\
    "\377\1\366\377\377\2\364\377\377\3\363\376\377\3\351\364\377\3\305\314" +\
    "\377\1G\236\377\2\36\374\377\3!\375\377\3 \375\377\3\42\375\377\3!\375" +\
    "\377\3!\375\377\3!\375\377\3\37\375\377\3 \375\377\3\36\375\377\4\35" +\
    "\375\377\4\35\375\377\5\34\375\377\5\35\375\377\5\34\375\377\6\32\375" +\
    "\377\6\32\375\377\6\32\375\377\10\31\375\377\7\30\374\377\11\31\375\377" +\
    "\10\27\375\377\11\30\375\377\12\27\372\377\11\26\347\377\7\21\251\377" +\
    "\11\214\242\377\10lv\377\2\5\5\377\0\1\1\325\0\0\0W\0\0\0\16\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\1\0\0\0\24\0\0\0]\10\10\10\321F\36\32\376\227;2\377\265tl\377\320" +\
    "\216\206\377\343\226\216\377\357\237\226\377\366\243\232\377\373\246" +\
    "\234\377\375\247\236\377\376\247\235\377\376\247\236\377\377\247\236" +\
    "\377\377\246\236\377\377\246\236\377\377\246\236\377\377\247\237\377" +\
    "\377\247\237\377\377\247\237\377\377\250\240\377\377\247\237\377\377" +\
    "\247\237\377\377\246\236\377\377\246\235\377\377\246\236\377\377\246" +\
    "\236\377\376\247\236\377\376\247\236\377\376\250\236\377\371\245\234" +\
    "\377\355\235\224\377\325\215\206\377\226e^\377\12HN\377\7\252\271\377" +\
    "\11\330\352\377\12\352\373\377\10\355\376\377\10\356\377\377\10\357\377" +\
    "\377\6\355\377\377\5\360\377\377\5\360\377\377\5\363\377\377\4\363\377" +\
    "\377\3\366\377\377\3\365\377\377\2\366\377\377\2\370\377\377\1\370\377" +\
    "\377\2\372\377\377\2\372\377\377\0\372\377\377\1\373\377\377\1\373\377" +\
    "\377\1\373\377\377\1\372\377\377\1\372\377\377\1\371\377\377\1\371\377" +\
    "\377\2\370\377\377\1\367\377\377\2\366\377\377\3\364\376\377\3\352\364" +\
    "\377\2\305\313\377\2F\236\377\4\37\374\377\3!\375\377\3!\375\377\3!\375" +\
    "\377\3\42\375\377\3 \375\377\3 \375\377\2 \375\377\3 \375\377\4\37\375" +\
    "\377\3\36\375\377\5\35\375\377\5\36\375\377\5\33\375\377\5\34\375\377" +\
    "\6\32\375\377\6\32\375\377\6\31\375\377\10\32\375\377\7\31\375\377\11" +\
    "\30\375\377\11\31\376\377\12\30\376\377\11\30\374\377\12\26\353\377\10" +\
    "\14\264\377\7_\201\377\7\62\64\376\0\0\0\374\0\0\0\246\0\0\0\66\0\0\0" +\
    "\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\1\0\0\0\26\0\0\0`\15\12\12\334] \32\376\237>2\377\301\177w\376\333" +\
    "\216\205\377\353\227\216\377\366\235\224\377\372\241\230\377\375\242" +\
    "\230\377\376\242\230\377\377\243\231\377\377\242\230\377\377\242\231" +\
    "\377\377\241\230\377\377\241\230\377\377\241\232\377\377\242\232\377" +\
    "\377\244\234\377\377\245\235\377\377\247\237\377\377\246\236\377\377" +\
    "\244\234\377\377\243\233\377\377\241\231\377\377\241\231\377\377\241" +\
    "\230\377\377\241\231\377\377\242\231\377\377\242\231\377\376\242\227" +\
    "\377\370\236\225\377\351\225\214\377\321\207~\377uOK\377\6lw\377\10\267" +\
    "\307\377\12\340\361\377\12\354\375\377\10\356\377\377\10\357\377\377" +\
    "\7\357\377\377\6\356\377\377\6\360\377\377\5\361\377\377\5\362\377\377" +\
    "\3\363\377\377\4\364\377\377\3\366\377\377\2\370\377\377\3\367\377\377" +\
    "\2\372\377\377\1\372\377\377\1\372\377\377\1\373\377\377\1\374\377\377" +\
    "\1\374\377\377\0\374\377\377\1\374\377\377\1\373\377\377\1\372\377\377" +\
    "\2\371\377\377\2\370\377\377\3\367\377\377\2\366\377\377\3\365\376\377" +\
    "\3\352\363\377\2\307\315\377\2J\233\377\4 \372\377\3\42\375\377\3\42" +\
    "\375\377\3\42\375\377\2\42\375\377\3\42\375\377\3!\375\377\4\42\375\377" +\
    "\3 \375\377\4\37\375\377\3\36\375\377\5\36\375\377\4\35\375\377\5\35" +\
    "\375\377\6\34\375\377\5\33\375\377\7\33\375\377\6\31\375\377\10\32\375" +\
    "\377\7\31\375\377\11\31\376\377\11\31\376\377\12\30\376\377\12\31\374" +\
    "\377\12\26\353\377\7\15\273\377\11)Y\377\2\10\7\377\0\0\0\350\0\0\0p" +\
    "\0\0\0\32\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\26\0\0\0d\16\14\14\340n&\35\375\247:-\377\310\177" +\
    "v\377\342\217\205\377\362\226\214\377\370\233\221\377\374\235\223\377" +\
    "\375\234\223\377\377\235\222\377\377\235\222\377\377\234\222\377\377" +\
    "\233\222\377\377\233\222\377\377\233\222\377\377\233\222\377\377\235" +\
    "\224\377\377\240\226\377\377\245\234\377\377\251\241\377\377\255\245" +\
    "\377\377\254\245\377\377\250\240\377\377\242\231\377\377\237\226\377" +\
    "\377\234\223\377\377\233\222\377\377\233\222\377\377\234\222\377\377" +\
    "\233\222\377\374\233\222\377\365\227\215\377\343\214\203\377\306zq\377" +\
    "N;:\377\7\211\226\377\10\303\323\377\12\344\366\377\12\354\376\377\10" +\
    "\356\376\377\11\357\377\377\7\360\377\377\6\356\377\377\6\361\377\377" +\
    "\6\361\377\377\4\363\377\377\4\363\377\377\3\366\377\377\3\367\377\377" +\
    "\3\367\377\377\2\371\377\377\3\371\377\377\2\372\377\377\1\373\377\377" +\
    "\2\374\377\377\2\374\377\377\2\374\377\377\2\374\377\377\1\374\377\377" +\
    "\1\373\377\377\1\372\377\377\2\370\377\377\2\370\377\377\2\366\377\377" +\
    "\3\366\377\377\3\365\376\377\4\351\363\377\3\303\310\377\2D\234\377\4" +\
    "!\374\377\4#\375\377\4#\375\377\4#\375\377\4#\375\377\4#\375\377\4!\375" +\
    "\377\4\42\375\377\4!\375\377\3\37\375\377\5\37\375\377\4\37\375\377\5" +\
    "\37\375\377\6\36\375\377\5\34\375\377\5\33\375\377\7\33\375\377\6\33" +\
    "\375\377\10\31\375\377\7\30\374\377\11\31\376\377\11\31\376\377\11\30" +\
    "\376\377\12\31\374\377\12\26\353\377\10\20\275\377\4\6>\377\0\0\0\377" +\
    "\0\0\0\276\0\0\0D\0\0\0\12\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20\0\0\0]\14\13\13\333j#\34\375\250.\37" +\
    "\377\313ul\376\343\212\201\377\363\223\210\377\371\227\214\377\375\230" +\
    "\215\377\375\231\216\377\376\230\216\377\377\230\216\377\377\230\215" +\
    "\377\377\227\215\377\377\227\214\377\377\225\213\377\377\225\214\377" +\
    "\377\226\215\377\377\227\216\377\377\237\227\377\377\251\242\377\377" +\
    "\267\260\377\377\277\271\377\377\275\267\377\377\263\253\377\377\245" +\
    "\235\377\377\234\224\377\377\227\216\377\377\227\215\377\377\227\215" +\
    "\377\377\226\213\377\377\226\214\377\373\225\213\377\361\217\207\377" +\
    "\335\204|\377\271ng\377+/0\377\6\223\241\377\11\312\333\377\11\346\371" +\
    "\377\12\354\376\377\10\356\377\377\10\357\377\377\7\356\377\377\7\357" +\
    "\377\377\6\361\377\377\5\362\377\377\5\363\377\377\5\363\377\377\4\365" +\
    "\377\377\3\367\377\377\4\367\377\377\2\371\377\377\3\371\377\377\2\373" +\
    "\377\377\1\374\377\377\1\374\377\377\2\374\377\377\2\374\377\377\1\374" +\
    "\377\377\2\374\377\377\2\373\377\377\1\372\377\377\3\370\377\377\3\370" +\
    "\377\377\3\366\377\377\4\366\377\377\4\365\376\377\3\351\363\377\3\302" +\
    "\310\377\3B\240\377\4 \373\377\4#\375\377\4#\375\377\4#\375\377\4#\375" +\
    "\377\4#\375\377\4\42\375\377\3\42\375\377\4 \375\377\5!\375\377\5\37" +\
    "\375\377\4\37\375\377\6\37\375\377\5\35\375\377\6\35\375\377\7\34\375" +\
    "\377\6\33\375\377\10\33\375\377\10\32\375\377\11\31\374\377\10\32\376" +\
    "\377\12\32\376\377\12\31\376\377\13\32\373\377\12\26\353\377\10\20\275" +\
    "\377\3\5F\377\0\0\0\373\0\0\0\234\0\0\0+\0\0\0\4\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0\0G\10\10\10\316]#\35" +\
    "\376\244\42\23\377\313ZM\376\345\210~\377\364\215\201\377\373\222\207" +\
    "\377\375\221\206\377\376\221\206\377\377\221\206\377\376\221\206\377" +\
    "\377\222\206\377\377\221\206\377\377\220\205\377\377\220\205\377\377" +\
    "\217\204\377\377\216\204\377\377\217\205\377\377\223\213\377\377\240" +\
    "\230\377\377\263\255\377\377\313\307\377\377\331\326\377\377\326\322" +\
    "\377\377\303\276\377\377\254\244\377\377\233\223\377\377\222\211\377" +\
    "\377\217\205\377\377\217\205\377\376\221\205\377\377\221\205\377\372" +\
    "\216\202\377\356\210~\377\327{r\377\255b\134\377\26,-\377\6\232\250\377" +\
    "\11\317\337\377\12\347\372\377\12\355\376\377\11\356\377\377\10\357\377" +\
    "\377\7\357\377\377\7\357\377\377\7\361\377\377\6\363\377\377\5\363\377" +\
    "\377\5\364\377\377\5\365\377\377\4\366\377\377\4\367\377\377\3\370\377" +\
    "\377\3\372\377\377\3\373\377\377\3\372\377\377\3\373\377\377\2\373\377" +\
    "\377\2\373\377\377\2\373\377\377\2\374\377\377\2\373\377\377\3\372\377" +\
    "\377\2\370\377\377\3\370\377\377\2\366\377\377\3\365\377\377\3\364\375" +\
    "\377\5\347\361\377\3\273\303\377\3<\244\377\4\42\375\377\4#\375\377\3" +\
    "#\375\377\4\42\375\377\3\42\375\377\3\42\375\377\3#\375\377\5\42\375" +\
    "\377\5!\375\377\5!\375\377\4\37\375\377\6\37\375\377\5\35\375\377\6\35" +\
    "\375\377\6\35\375\377\7\34\375\377\7\34\375\377\10\33\375\377\10\33\375" +\
    "\377\11\31\374\377\10\32\376\377\12\32\376\377\12\32\375\377\13\30\373" +\
    "\377\12\27\351\377\10\20\272\377\3\6J\377\0\0\0\366\0\0\0\212\0\0\0 " +\
    "\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0" +\
    "\0-\1\3\3\257J\37\33\374\236%\27\377\3075$\377\344{p\377\364\211}\377" +\
    "\374\214\200\377\376\214\200\377\377\215\200\377\377\214\200\377\377" +\
    "\213\177\377\377\212\177\377\377\211~\377\377\212~\377\377\210}\377\377" +\
    "\207|\377\377\206{\377\377\205|\377\377\207~\377\377\214\204\377\377" +\
    "\236\227\377\377\273\265\377\376\335\332\377\375\363\364\377\375\356" +\
    "\355\377\377\321\316\377\377\257\251\377\377\230\220\377\377\213\202" +\
    "\377\377\210~\377\377\207}\377\377\210~\377\375\211~\377\371\207|\377" +\
    "\352\200u\377\322ri\377\250[T\377\27+,\377\6\233\251\377\11\317\340\377" +\
    "\13\350\372\377\12\355\376\377\11\356\377\377\10\357\377\377\10\361\377" +\
    "\377\7\357\377\377\7\360\377\377\6\362\377\377\4\362\377\377\5\365\377" +\
    "\377\4\365\377\377\6\366\377\377\5\370\377\377\5\370\377\377\4\371\377" +\
    "\377\3\372\377\377\3\372\377\377\2\372\377\377\2\373\377\377\2\373\377" +\
    "\377\2\373\377\377\3\372\377\377\2\372\377\377\2\371\377\377\3\370\377" +\
    "\377\3\370\377\377\3\367\377\377\3\366\377\377\3\363\375\377\4\345\360" +\
    "\377\3\264\273\377\3\64\252\377\5!\377\377\4\42\374\377\5#\375\377\4" +\
    "#\375\377\4#\375\377\4#\375\377\5\42\375\377\4!\375\377\5!\375\377\4" +\
    "!\375\377\4\37\375\377\6 \375\377\5\36\375\377\6\36\375\377\6\35\375" +\
    "\377\7\34\375\377\7\34\375\377\7\33\375\377\10\32\375\377\11\31\375\377" +\
    "\11\31\376\377\12\32\376\377\12\32\375\377\13\30\372\377\12\27\350\377" +\
    "\7\20\270\377\2\5D\377\0\0\0\363\0\0\0\200\0\0\0\35\0\0\0\1\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\30\0\0\0\200*\25\24\363" +\
    "\223\42\26\376\276.\35\376\341K:\377\363\203y\377\373\205z\377\375\206" +\
    "y\377\377\205y\377\377\204y\377\377\204x\377\377\202x\377\377\202v\377" +\
    "\377\201u\377\377\200u\377\377~t\377\377}s\377\377{q\377\377zq\377\377" +\
    "}t\377\377\202z\377\377\226\220\377\377\267\262\377\376\334\332\377\375" +\
    "\366\365\377\375\356\356\377\377\321\315\377\377\251\243\377\377\215" +\
    "\207\377\377\202y\377\377~s\377\377}s\377\377~t\377\376\177u\377\367" +\
    "\177t\377\350xn\377\315j`\377\247WN\377 ))\377\6\227\244\377\12\315\336" +\
    "\377\12\347\371\377\12\355\376\377\12\356\377\377\11\357\377\377\10\357" +\
    "\377\377\6\357\377\377\7\360\377\377\13\362\377\377\16\363\377\377\21" +\
    "\364\377\377\17\365\377\377\16\366\377\377\15\367\377\377\14\370\377" +\
    "\377\12\371\377\377\12\371\377\377\10\371\377\377\7\372\377\377\6\371" +\
    "\377\377\5\372\377\377\4\372\377\377\3\371\377\377\4\371\377\377\3\371" +\
    "\377\377\3\370\377\377\3\370\377\377\4\366\377\377\5\365\377\377\5\362" +\
    "\374\377\5\342\355\377\3\253\263\377\4-\272\377\5\42\376\377\5#\374\377" +\
    "\4#\375\377\4\42\375\377\4\42\375\377\4\42\375\377\4\42\375\377\4\42" +\
    "\375\377\5!\375\377\6!\375\377\6!\375\377\5\37\375\377\5\37\375\377\6" +\
    "\36\375\377\6\35\375\377\6\34\375\377\10\34\375\377\7\33\375\377\11\33" +\
    "\375\377\10\32\375\377\12\32\375\377\11\31\376\377\12\32\375\377\13\30" +\
    "\372\377\12\25\344\377\7\20\263\377\2\58\376\0\0\0\360\0\0\0u\0\0\0\27" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0\0L\14\10" +\
    "\11\331q\35\25\376\264)\32\377\3303\37\377\357VD\377\372\201u\377\375" +\
    "\200s\377\376\177q\377\376}r\377\377}q\377\377{p\377\377zo\377\377yn" +\
    "\377\377xl\377\377vl\377\377sj\377\377ri\377\377qg\377\377qg\377\377" +\
    "qg\377\377xo\377\377\207\201\377\377\244\236\377\377\304\302\377\375" +\
    "\332\330\377\377\324\321\377\376\272\265\377\377\227\222\377\377\202" +\
    "{\377\377wn\377\377tj\377\377tj\377\377uk\377\376wm\377\367vj\377\346" +\
    "pe\377\314d[\377\250RJ\3770)(\377\6\220\235\377\12\310\332\377\13\345" +\
    "\370\377\13\355\376\377\12\355\376\377\11\356\377\377\7\355\377\377\23" +\
    "\357\377\377\37\360\377\377\36\361\377\377\34\363\377\377\31\366\377" +\
    "\377\30\365\377\377\26\366\377\377\24\367\377\377\24\371\377\377\23\372" +\
    "\377\377\21\372\377\377\20\373\377\377\16\372\377\377\16\373\377\377" +\
    "\15\373\377\377\13\372\377\377\12\371\377\377\11\371\377\377\10\371\377" +\
    "\377\10\370\377\377\6\367\377\377\4\365\377\377\4\365\377\377\4\362\374" +\
    "\377\5\337\351\377\3\235\252\377\11)\312\377\12'\375\377\11&\375\377" +\
    "\10%\375\377\7%\375\377\6$\375\377\6#\375\377\6#\375\377\6#\375\377\5" +\
    "!\375\377\5!\375\377\5\37\375\377\7\37\375\377\7\36\375\377\6\36\375" +\
    "\377\7\34\375\377\10\35\375\377\7\33\375\377\10\33\375\377\11\33\375" +\
    "\377\11\33\374\377\12\31\375\377\12\32\376\377\13\31\375\377\13\27\371" +\
    "\377\12\24\337\377\10\17\253\377\0\2\42\377\0\0\0\351\0\0\0e\0\0\0\20" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0$\0\0\0\250G\30" +\
    "\24\374\244\36\20\377\316.\34\376\3524\37\377\370TB\377\374yl\377\375" +\
    "vi\377\377vi\377\377vi\377\377tg\377\377qe\377\377qe\377\377oc\377\377" +\
    "ka\377\377i_\377\377h]\377\377g]\377\377f\134\377\377e\134\377\377e]" +\
    "\377\377i`\377\377tl\377\377\206\177\377\376\232\226\377\377\247\243" +\
    "\377\376\245\241\377\377\223\217\377\377~w\377\377oh\377\377i`\377\377" +\
    "g]\377\377g^\377\377kb\377\376mb\377\367l`\377\346g[\377\313[R\377\253" +\
    "OF\377N,(\377\10\177\212\377\13\300\321\377\14\341\364\377\14\352\375" +\
    "\377\13\355\377\377\13\356\377\377)\360\377\377-\360\377\377*\361\377" +\
    "\377%\361\377\377$\366\377\377\42\366\377\377\42\365\377\377 \367\377" +\
    "\377\36\366\377\377\34\370\377\377\32\371\377\377\30\372\377\377\26\371" +\
    "\377\377\26\372\377\377\24\372\377\377\22\372\377\377\21\372\377\377" +\
    "\21\371\377\377\16\371\377\377\17\370\377\377\16\367\377\377\15\367\377" +\
    "\377\14\365\377\377\11\364\377\377\6\361\373\377\5\334\350\377\4\223" +\
    "\246\377\16*\322\377\20,\375\377\16+\375\377\15*\375\377\14)\375\377" +\
    "\13(\375\377\12'\375\377\12%\375\377\10%\375\377\10$\375\377\6\42\375" +\
    "\377\5 \375\377\7\37\375\377\7\36\375\377\6\35\375\377\10\36\375\377" +\
    "\10\34\375\377\7\34\375\377\11\32\375\377\11\32\375\377\12\33\374\377" +\
    "\11\32\376\377\13\33\376\377\13\31\374\377\13\27\367\377\12\24\330\377" +\
    "\7\16\240\377\0\1\23\377\0\0\0\331\0\0\0V\0\0\0\14\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0[\31\15\13\354\205\25\12\377\275" +\
    "#\23\377\342,\32\377\3651\35\377\373I9\377\376n`\377\376k^\377\377k^" +\
    "\377\377h[\377\377h[\377\377fY\377\377eX\377\377bW\377\377`U\377\377" +\
    "^T\377\377]T\377\377[R\377\377[R\377\377YQ\377\377YQ\377\377[S\377\377" +\
    "_Y\377\377gb\377\377rm\377\377yt\377\377ws\377\377pi\377\377d^\377\377" +\
    "^V\377\377\134T\377\377[R\377\377\134S\377\377_V\377\376bW\377\367`U" +\
    "\377\350^S\377\315VL\377\257JA\377g.)\377\15fo\377\14\265\304\377\20" +\
    "\334\357\377\20\350\375\377\24\355\376\377:\357\377\377<\361\377\377" +\
    "7\362\377\3775\361\377\3772\362\377\3771\365\377\377.\364\377\377+\366" +\
    "\377\377)\365\377\377'\367\377\377&\370\377\377$\367\377\377\42\370\377" +\
    "\377 \371\377\377\37\372\377\377\36\372\377\377\34\372\377\377\33\372" +\
    "\377\377\32\371\377\377\30\371\377\377\30\367\377\377\25\366\377\377" +\
    "\24\366\377\377\24\365\377\377\24\364\377\377\21\356\372\377\12\325\337" +\
    "\377\6x\232\377\25,\344\377\26\60\375\377\25\61\375\377\24/\375\377\23" +\
    "/\375\377\22-\375\377\21-\375\377\20,\375\377\20*\375\377\17*\375\377" +\
    "\16(\375\377\14$\375\377\11!\375\377\7\36\375\377\7\36\375\377\10\36" +\
    "\375\377\10\35\375\377\10\34\375\377\10\33\375\377\11\33\375\377\11\32" +\
    "\374\377\12\32\376\377\13\32\376\377\13\31\374\377\12\27\363\377\11\24" +\
    "\317\377\6\14\206\377\0\0\11\377\0\0\0\311\0\0\0G\0\0\0\7\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\42\1\1\1\247P\23\16\375\250\30\12" +\
    "\377\323#\22\377\357)\26\377\372+\30\377\3768%\377\377cT\377\377aT\377" +\
    "\377`S\377\377^Q\377\377^Q\377\377\134O\377\377YN\377\377WL\377\377U" +\
    "K\377\377TK\377\377RJ\377\377QI\377\377PI\377\377PH\377\377OH\377\377" +\
    "PI\377\377QK\377\377UO\377\377YT\377\377[V\377\377[V\377\377XR\377\377" +\
    "SN\377\377QJ\377\377PI\377\377QI\377\377RJ\377\377TL\377\375UK\377\371" +\
    "WM\377\353VK\377\321PE\377\264F<\377\2054.\377\26:=\377\14\242\262\377" +\
    "\26\320\344\377\26\345\372\377=\355\376\377Q\361\377\377I\361\377\377" +\
    "G\360\377\377B\361\377\377\77\363\377\377=\363\377\3779\365\377\3777" +\
    "\366\377\3775\367\377\3772\367\377\3771\370\377\377/\367\377\377-\367" +\
    "\377\377+\370\377\377*\371\377\377(\371\377\377&\367\377\377$\371\377" +\
    "\377\42\367\377\377!\367\377\377 \366\377\377\36\365\377\377\36\365\377" +\
    "\377\35\363\376\377\35\364\377\377\34\354\366\377\30\317\327\377\17d" +\
    "\226\377\35\64\360\377\358\374\377\33\65\375\377\33\65\375\377\32\64" +\
    "\375\377\30\62\375\377\30\61\375\377\26/\375\377\25.\375\377\24,\375" +\
    "\377\23,\375\377\23*\375\377\22)\375\377\17'\375\377\11\37\375\377\10" +\
    "\35\375\377\11\35\375\377\11\34\375\377\13\33\375\377\12\33\375\377\12" +\
    "\34\376\377\14\34\375\377\13\32\375\377\14\32\374\377\12\26\360\377\12" +\
    "\22\305\377\4\11m\377\0\0\2\377\0\0\0\272\0\0\0;\0\0\0\5\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\10\0\0\0O\23\7\6\350\212\22\10\377\276\32" +\
    "\14\377\343!\20\377\366%\22\377\375&\23\377\377%\23\377\376PB\377\377" +\
    "VI\377\377TH\377\377SG\377\377QE\377\377OD\377\377NC\377\377MB\377\377" +\
    "KB\377\377JA\377\377H@\377\377F@\377\377FA\377\377F@\377\377E@\377\377" +\
    "E\77\377\377E@\377\377EA\377\377FA\377\377GB\377\377GB\377\377FA\377" +\
    "\377FA\377\377F@\377\377F@\377\377FA\377\377GA\377\376IC\377\377JB\377" +\
    "\372KC\377\356KA\377\326H=\377\271@6\377\2317/\377/! \377\17\210\227" +\
    "\377\32\302\326\377*\342\365\377b\357\375\377_\360\376\377X\360\377\377" +\
    "U\360\377\377R\361\377\377M\362\377\377I\363\377\377F\364\377\377B\366" +\
    "\377\377A\367\377\377>\370\377\377<\370\377\377:\370\377\3778\371\377" +\
    "\3777\371\377\3775\371\377\3772\370\377\3771\371\377\3770\370\377\377" +\
    "-\367\377\377,\367\377\377+\366\377\377*\366\377\377(\365\377\377)\365" +\
    "\377\377)\362\376\377&\345\363\377 \304\315\377\31X\234\377&<\367\377" +\
    "%=\374\377$=\375\377\42=\375\377!:\375\377\379\375\377\378\375\377\35" +\
    "\66\375\377\34\64\375\377\33\61\375\377\32\61\375\377\32\60\375\377\31" +\
    ".\375\377\31-\375\377\30+\375\377\16\42\375\377\12\35\375\377\14\35\375" +\
    "\377\14\34\375\377\15\35\375\377\14\35\376\377\14\34\376\377\14\34\375" +\
    "\377\14\32\373\377\12\27\351\377\10\21\270\377\4\10P\377\0\0\0\377\0" +\
    "\0\0\255\0\0\0\61\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\31\1\0" +\
    "\0\217>\21\16\375\246\21\4\377\321\35\14\377\356!\16\377\373\42\17\377" +\
    "\375\42\16\377\377\36\14\377\3772#\377\377K\77\377\377J=\377\377G<\377" +\
    "\377G;\377\377F:\377\377E:\377\377C9\377\377B8\377\377@9\377\377@7\377" +\
    "\377>7\377\377>8\377\377=6\377\377;7\377\377<7\377\377;7\377\377;6\377" +\
    "\377;8\377\377;7\377\377;7\377\377;7\377\377;6\377\377<7\377\377<6\377" +\
    "\377=7\377\377=7\377\377@8\377\377@9\377\373B:\377\361B9\377\334\77\65" +\
    "\377\30091\377\2433+\377`!\33\377\30`i\377\30\257\302\377<\330\352\377" +\
    "t\356\373\377m\360\376\377k\361\377\377f\360\376\377b\361\377\377^\363" +\
    "\377\377X\362\377\377S\363\377\377O\363\377\377M\365\377\377J\366\377" +\
    "\377J\365\377\377I\366\377\377J\367\377\377I\370\377\377E\371\377\377" +\
    "@\370\377\377=\370\377\377;\370\377\3779\370\377\3778\367\377\3776\365" +\
    "\377\3776\365\377\3777\364\377\3776\363\376\3776\362\375\3772\341\357" +\
    "\377(\263\274\377!K\250\377/E\375\377.D\375\377-B\375\377,B\375\377*" +\
    "@\374\377(\77\374\377'>\375\377&<\375\377%<\375\377#9\375\377#8\375\377" +\
    "\42\66\375\377!4\375\377!4\375\377 2\375\377!1\375\377\24$\375\377\17" +\
    "\35\375\377\17\37\374\377\20 \374\377\17\37\376\377\16\35\376\377\16" +\
    "\34\375\377\15\32\372\377\13\27\340\377\10\21\253\377\7\5+\377\0\0\0" +\
    "\377\0\0\0\242\0\0\0*\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\09\12" +\
    "\3\4\316q\20\7\377\267\26\7\376\336\34\13\377\365\36\15\377\374\37\14" +\
    "\377\376\37\14\377\377\35\14\377\377\35\15\377\3779,\377\377C6\377\377" +\
    "\77\63\377\377\77\63\377\377=2\377\377=2\377\377;1\377\37791\377\377" +\
    "91\377\37780\377\37770\377\37770\377\37770\377\3775/\377\37750\377\377" +\
    "60\377\3773/\377\37740\377\37740\377\37740\377\3773/\377\3774/\377\377" +\
    "60\377\37760\377\37760\377\37770\377\37780\377\37780\377\374:2\377\365" +\
    "<2\377\34370\377\3102*\377\254.'\377\213( \377**+\377\23\220\237\377" +\
    "\77\307\327\377{\352\364\377x\357\375\377v\361\375\377t\362\377\377p" +\
    "\363\377\377l\362\377\377h\364\377\377d\363\377\377`\363\377\377[\362" +\
    "\377\377Y\363\377\377[\365\377\377`\367\377\377m\371\377\377o\371\377" +\
    "\377f\367\377\377X\370\377\377M\366\377\377I\366\377\377F\366\377\377" +\
    "F\366\377\377D\365\377\377D\364\377\377D\362\377\377D\360\376\377F\357" +\
    "\374\377A\334\351\377.\234\250\377-I\275\3779O\377\3778O\376\3776M\376" +\
    "\3773J\376\3772I\376\3771G\375\3770E\375\377.D\374\377.C\374\377-A\374" +\
    "\377,\77\374\377+>\374\377+=\375\377+<\375\377+9\375\377-;\374\377+8" +\
    "\374\377\27&\374\377\24#\376\377\24\42\376\377\24!\375\377\21 \376\377" +\
    "\20\35\375\377\16\32\367\377\13\25\325\377\10\17\222\377\20\5\12\377" +\
    "\0\0\0\373\0\0\0\230\0\0\0%\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\14\0" +\
    "\0\0g\35\6\4\364\223\21\5\377\307\30\11\377\351\34\12\377\372\35\14\377" +\
    "\375\35\13\377\377\33\13\377\377\32\12\377\377\31\11\377\377\35\16\377" +\
    "\3775(\377\3779,\377\3777+\377\3775)\377\3773)\377\3772)\377\3772)\377" +\
    "\3771)\377\3770(\377\3770(\377\377/'\377\377.'\377\377.(\377\377-'\377" +\
    "\377-'\377\377-'\377\377,'\377\377+'\377\377+(\377\377,(\377\377-(\377" +\
    "\377-'\377\377-'\377\377.(\377\377/(\377\377/(\377\3771)\377\3760)\377" +\
    "\3702*\377\3532)\377\322-$\377\267)!\377\235&\35\377[\31\24\377\32]d" +\
    "\377-\254\273\377}\333\347\377\177\354\371\377\200\360\375\377\177\362" +\
    "\376\377|\362\376\377y\362\377\377u\363\377\377r\364\377\377o\364\377" +\
    "\377k\364\377\377i\364\377\377p\366\377\377\205\367\377\377\245\371\377" +\
    "\377\260\372\377\377\236\372\376\377{\367\377\377`\365\377\377X\365\377" +\
    "\377T\365\377\377T\365\377\377S\363\377\377S\362\377\377T\361\377\377" +\
    "S\357\376\377S\355\371\377J\323\341\3771}\232\377>O\336\377FY\376\377" +\
    "DX\376\377AW\376\377>T\376\377<Q\376\377:O\376\3779O\376\3777L\375\377" +\
    "7J\375\3777I\375\3777H\375\3777G\375\3776F\374\3777E\374\3777C\374\377" +\
    "9E\375\3779D\375\3775@\375\377\32&\376\377\31%\376\377\30%\376\377\26" +\
    "\42\375\377\23\37\375\377\20\33\361\377\13\23\307\377\14\42l\377\14\10" +\
    "\6\377\0\0\0\371\0\0\0\220\0\0\0!\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\34\0\0\0\234>\5\1\377\252\23\7\376\326\31\11\377\360\33\12\377\374" +\
    "\34\13\377\376\33\13\377\377\33\13\377\377\31\12\377\377\31\12\377\377" +\
    "\26\7\377\377\32\14\377\377.\37\377\3770$\377\377.\42\377\377-\42\377" +\
    "\377+\42\377\377*!\377\377*!\377\377)\42\377\377(!\377\377'!\377\377" +\
    "(!\377\377& \377\377% \377\377$!\377\377$ \377\377$ \377\377# \377\377" +\
    "# \377\377$ \377\377$ \377\377$ \377\377$!\377\377% \377\377' \377\377" +\
    "'!\377\377(!\377\376)\42\377\372*\42\377\361* \377\335'\37\377\302&\35" +\
    "\377\250\42\30\377\213\35\25\3777\37\36\377\33|\210\377h\277\312\377" +\
    "\204\342\355\377\210\356\371\377\211\361\375\377\206\363\376\377\205" +\
    "\363\377\377\202\362\377\377\177\363\377\377}\362\377\377y\364\377\377" +\
    "z\364\377\377\206\366\377\377\254\370\377\377\332\373\376\377\354\374" +\
    "\375\377\317\374\376\377\231\371\377\377t\365\377\377g\364\377\377d\365" +\
    "\377\377d\363\377\377d\363\377\377b\361\377\377c\361\377\377c\361\376" +\
    "\377`\350\366\377R\313\326\3777k\234\377Ud\364\377]m\375\377^o\376\377" +\
    "Xh\376\377Oa\376\377HZ\376\377DW\376\377CV\376\377CU\376\377BT\376\377" +\
    "AQ\376\377AP\376\377BP\375\377BQ\376\377DP\376\377EO\376\377EN\375\377" +\
    "EO\376\377GP\376\37709\376\377 *\376\377\36)\376\377\31$\375\377\25 " +\
    "\373\377\21\33\350\377\13\22\261\377\13e|\377\3\42#\377\0\0\0\370\0\0" +\
    "\0\215\0\0\0\37\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\64\6\0\0\313c\13" +\
    "\4\377\267\26\10\377\340\32\12\377\366\34\13\377\375\34\12\377\377\32" +\
    "\12\377\377\30\11\377\377\31\12\377\377\27\12\377\377\26\10\377\377\24" +\
    "\6\377\377\31\13\377\377%\30\377\377(\35\377\377'\34\377\377%\34\377" +\
    "\377$\33\377\377#\33\377\377#\33\377\377#\34\377\377!\32\377\377 \32" +\
    "\377\377\37\32\377\377\36\32\377\377\36\32\377\377\36\32\377\377\36\32" +\
    "\377\377\35\31\377\377\35\32\377\377\35\32\377\377\36\32\377\377\36\32" +\
    "\377\377\36\32\377\377\37\32\377\377\37\32\377\377!\32\377\377 \32\377" +\
    "\377\42\32\377\375$\34\377\365$\32\377\347\42\32\377\317!\30\377\264" +\
    "\37\25\377\236\34\23\377t\23\14\377&24\3773\224\237\377\200\307\320\377" +\
    "\211\343\355\377\220\357\372\377\217\362\375\377\217\363\376\377\215" +\
    "\363\377\377\213\364\377\377\210\364\377\377\207\363\377\377\210\365" +\
    "\377\377\223\366\377\377\264\370\377\377\337\375\375\377\361\374\375" +\
    "\377\323\373\376\377\243\367\377\377\201\367\377\377u\364\377\377r\363" +\
    "\377\377q\363\377\377q\362\377\377r\363\377\377q\362\377\377o\361\375" +\
    "\377h\343\357\377Q\266\277\377Hd\253\377v\202\376\377\210\223\375\377" +\
    "\216\230\375\377~\212\375\377hw\376\377Xg\376\377Ra\376\377O_\376\377" +\
    "N]\376\377N\134\376\377MZ\376\377O[\376\377O[\376\377PZ\376\377OY\376" +\
    "\377PX\376\377QY\376\377QY\376\377QX\376\377LS\376\377#,\376\377\42+" +\
    "\376\377\37'\375\377\30!\363\377\21\27\325\377\16\65\225\377\6\242\253" +\
    "\377\2@E\377\0\0\0\371\0\0\0\217\0\0\0 \0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\6\0\0\0O\23\1\0\353\207\20\5\377\302\30\10\377\350\32\12\377\370\34" +\
    "\13\377\376\33\13\377\376\32\11\377\377\30\12\377\377\31\12\377\377\26" +\
    "\11\377\377\26\7\377\377\26\10\377\377\24\6\377\377\24\10\377\377\32" +\
    "\17\377\377 \26\377\377\37\26\377\377\36\26\377\377\35\26\377\377\34" +\
    "\25\377\377\32\24\377\377\32\24\377\377\32\24\377\377\32\25\377\377\31" +\
    "\24\377\377\31\25\377\377\27\25\377\377\27\25\377\377\30\24\377\377\27" +\
    "\25\377\377\30\25\377\377\27\25\377\377\30\25\377\377\31\25\377\377\31" +\
    "\24\377\377\32\25\377\377\33\24\377\377\32\24\377\376\33\25\377\375\35" +\
    "\25\377\372\36\26\377\360\36\26\377\335\35\24\377\303\33\23\377\253\25" +\
    "\15\377\227\17\7\377c\13\5\377\42AD\377K\232\243\377\205\311\321\377" +\
    "\217\344\355\377\225\357\370\377\225\362\375\377\225\364\376\377\223" +\
    "\365\377\377\220\364\376\377\220\364\377\377\220\364\377\377\227\365" +\
    "\377\377\247\367\376\377\276\371\377\377\307\372\377\377\266\370\377" +\
    "\377\235\367\377\377\211\365\377\377\202\364\377\377\200\364\377\377" +\
    "\177\363\377\377}\362\377\377|\362\377\377z\363\376\377x\360\373\377" +\
    "n\335\350\377N\234\246\377cr\305\377\236\245\377\377\300\305\375\377" +\
    "\313\317\375\377\260\265\375\377\207\222\375\377kv\375\377_k\376\377" +\
    "[g\376\377\134g\376\377\134g\376\377[e\376\377\134d\376\377\134d\376" +\
    "\377\134d\376\377]c\376\377\134c\376\377\134b\376\377[a\376\377[a\376" +\
    "\377[a\375\377)/\376\377&.\375\377!)\371\377\31!\346\377\20\30\265\377" +\
    "\16\233\257\377\6\266\305\377\3Ya\377\0\1\1\374\0\0\0\227\0\0\0$\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0g%\3\1\373\227\21\7\377\313\31\11" +\
    "\377\354\34\12\377\373\34\13\377\376\32\13\377\377\32\11\377\377\30\11" +\
    "\377\377\27\11\377\377\26\10\377\377\26\10\377\377\25\7\377\377\24\7" +\
    "\377\377\21\5\377\377\20\6\377\377\21\7\377\377\26\15\377\377\30\20\377" +\
    "\377\30\21\377\377\27\17\377\377\26\20\377\377\26\20\377\377\26\20\377" +\
    "\377\24\20\377\377\23\17\377\377\23\17\377\377\21\17\377\377\21\17\377" +\
    "\377\22\17\377\377\21\17\377\377\22\17\377\377\22\17\377\377\22\17\377" +\
    "\377\23\17\377\377\23\17\377\377\24\17\377\377\24\20\377\377\26\20\377" +\
    "\377\26\20\377\376\27\20\377\374\30\20\377\366\30\20\377\351\25\15\377" +\
    "\324\22\11\377\274\16\4\377\244\15\5\377\223\14\5\377]\12\5\377#\77C" +\
    "\377R\231\237\377\206\305\314\377\223\341\350\377\231\355\367\377\233" +\
    "\362\374\377\231\364\375\377\232\365\376\377\227\364\377\377\230\365" +\
    "\376\377\231\365\377\377\236\367\377\377\244\366\377\377\247\366\377" +\
    "\377\236\366\377\377\226\365\377\377\217\364\377\377\213\364\377\377" +\
    "\212\363\377\377\210\363\377\377\206\363\377\377\206\362\377\377\204" +\
    "\362\376\377\177\354\370\377p\322\334\377K\177\225\377\204\213\344\377" +\
    "\271\275\376\377\346\347\375\377\363\364\375\377\325\326\375\377\241" +\
    "\250\374\377}\206\376\377mw\376\377gr\376\377hr\376\377gp\376\377hp\376" +\
    "\377go\376\377go\376\377gn\375\377fm\375\377ek\375\377ek\376\377di\376" +\
    "\377ci\376\377ch\376\377/5\374\377'-\373\377\37&\355\377\25\31\310\377" +\
    "\23`\241\377\7\342\357\377\7\272\312\377\4lu\377\0\5\5\377\0\0\0\244" +\
    "\0\0\0+\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\17\0\0\0u\62\5\1\377\240\24\7\376" +\
    "\320\31\11\377\360\33\11\377\375\34\13\377\377\32\13\377\377\32\11\377" +\
    "\377\30\11\377\377\26\10\377\377\27\10\377\377\25\10\377\377\25\6\377" +\
    "\377\23\7\377\377\22\5\377\377\20\5\377\377\17\5\377\377\17\5\377\377" +\
    "\17\6\377\377\20\10\377\377\22\12\377\377\22\13\377\377\21\13\377\377" +\
    "\20\13\377\377\17\12\377\377\17\12\377\377\16\12\377\377\16\12\377\377" +\
    "\16\12\377\377\16\12\377\377\16\12\377\377\15\12\377\377\15\12\377\377" +\
    "\15\13\377\377\17\12\377\377\15\12\377\377\17\12\377\377\20\13\377\377" +\
    "\20\13\377\377\21\13\377\377\23\13\377\376\22\11\377\373\20\10\377\362" +\
    "\16\5\377\344\17\4\377\316\15\4\377\266\16\5\377\241\14\5\377\221\14" +\
    "\4\377b\13\5\377&57\377C\216\225\377\204\272\301\377\222\330\340\377" +\
    "\234\351\361\377\241\361\371\377\240\362\374\377\240\366\375\377\237" +\
    "\365\377\377\236\365\377\377\236\366\377\377\236\366\377\377\237\367" +\
    "\377\377\234\366\377\377\231\365\377\377\226\366\377\377\224\364\377" +\
    "\377\222\364\377\377\222\364\377\377\220\364\377\377\217\364\377\377" +\
    "\215\363\375\377\205\350\362\377p\303\313\377Vq\237\377\230\234\370\377" +\
    "\274\300\376\377\343\344\374\377\356\357\375\377\321\325\374\377\246" +\
    "\253\376\377\206\215\376\377y\201\377\377t}\377\377s{\377\377sz\377\377" +\
    "sz\377\377sz\377\377rx\377\377qx\376\377pw\376\377ou\376\377nt\375\377" +\
    "mr\375\377lq\376\377mr\375\377/5\374\377$+\362\377\33\37\330\377\27:" +\
    "\235\377\12\332\340\377\10\343\364\377\10\276\316\377\5x\203\377\0\11" +\
    "\11\377\0\0\0\257\0\0\0\63\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\21\0\0\0}=\6" +\
    "\2\377\244\24\7\377\324\31\11\377\363\33\11\377\375\33\12\377\377\32" +\
    "\12\377\377\31\12\377\377\27\11\377\377\26\11\377\377\26\10\377\377\26" +\
    "\7\377\377\25\6\377\377\23\7\377\377\21\5\377\377\21\6\377\377\20\6\377" +\
    "\377\15\5\377\377\14\4\377\377\14\4\377\377\12\4\377\377\11\4\377\377" +\
    "\12\4\377\377\11\5\377\377\12\6\377\377\12\6\377\377\11\6\377\377\11" +\
    "\5\377\377\10\5\377\377\10\5\377\377\11\5\377\377\12\6\377\377\12\6\377" +\
    "\377\12\6\377\377\12\6\377\377\12\6\377\377\12\6\377\377\12\5\377\377" +\
    "\12\5\377\377\13\4\377\376\13\5\377\376\15\4\377\375\15\4\377\371\17" +\
    "\5\377\360\16\4\377\340\16\5\377\312\16\5\377\263\16\5\377\241\15\4\377" +\
    "\223\14\5\377k\12\4\377%\37\37\3771qy\377e\251\261\377\223\307\315\377" +\
    "\232\335\344\377\237\352\361\377\244\361\371\377\245\364\374\377\245" +\
    "\365\375\377\244\366\376\377\243\367\377\377\241\367\377\377\240\367" +\
    "\377\377\237\366\376\377\235\365\377\377\234\365\377\377\233\363\377" +\
    "\377\231\364\377\377\230\364\377\377\227\365\376\377\225\362\373\377" +\
    "\212\340\352\377g\247\260\377lx\276\377\232\237\376\377\255\261\376\377" +\
    "\304\306\375\377\313\316\375\377\271\275\375\377\237\244\375\377\213" +\
    "\221\376\377\202\212\377\377\200\207\377\377\177\205\377\377~\204\377" +\
    "\377}\203\377\377{\201\377\377z\200\377\377z\200\377\377y\177\376\377" +\
    "y~\377\377x}\377\377v{\377\377uz\376\377rw\374\377#)\363\377\37&\334" +\
    "\377\33&\241\377\15\303\316\377\11\356\376\377\10\343\364\377\10\277" +\
    "\317\377\5}\210\377\0\12\13\377\0\0\0\263\0\0\0\67\0\0\0\3\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\22\0\0\0\200@\7\2\377\246\24\7\377\325\31\11\377\364\33" +\
    "\11\377\375\33\12\377\377\31\12\377\377\31\11\377\377\27\10\377\377\27" +\
    "\11\377\377\25\7\377\377\26\7\377\377\24\7\377\377\22\6\377\377\20\5" +\
    "\377\377\20\6\377\377\20\6\377\377\16\4\377\377\14\5\377\377\14\5\377" +\
    "\377\11\3\377\377\10\4\377\377\11\4\377\377\10\3\377\377\7\3\377\377" +\
    "\7\3\377\377\6\3\377\377\6\2\377\377\5\2\377\377\5\2\377\377\5\2\377" +\
    "\377\6\2\377\377\6\2\377\377\6\2\377\377\6\3\377\377\10\3\377\377\7\3" +\
    "\377\377\7\3\377\377\10\3\377\377\11\3\377\377\12\3\377\377\15\5\377" +\
    "\376\15\5\377\374\17\5\377\370\17\6\377\355\17\5\377\335\16\5\377\311" +\
    "\17\4\377\265\17\5\377\242\15\3\377\223\15\4\377u\11\2\3779\15\11\377" +\
    "\34:>\377;\204\215\377i\256\265\377\223\307\314\377\237\332\337\377\241" +\
    "\344\354\377\242\355\364\377\245\361\370\377\246\363\373\377\247\364" +\
    "\374\377\247\365\375\377\247\365\375\377\246\365\376\377\244\366\376" +\
    "\377\243\366\376\377\241\364\376\377\241\365\376\377\237\364\375\377" +\
    "\231\355\366\377\206\322\332\377[\203\226\377\213\220\350\377\231\236" +\
    "\377\377\240\244\376\377\250\254\375\377\253\256\375\377\243\247\376" +\
    "\377\227\234\376\377\217\225\377\377\213\220\377\377\212\216\377\377" +\
    "\210\215\377\377\207\214\377\377\206\213\377\377\205\212\377\377\203" +\
    "\211\377\377\202\207\377\377\201\206\377\377\201\206\377\377\200\205" +\
    "\377\377~\203\376\377~\203\374\377bh\364\377\36$\335\377  \241\377\16" +\
    "\264\301\377\7\362\377\377\11\354\375\377\11\341\362\377\10\273\313\377" +\
    "\4pz\377\0\6\6\377\0\0\0\260\0\0\0\64\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\22" +\
    "\0\0\0\202@\7\2\377\247\24\7\377\327\31\11\377\364\33\12\377\375\32\11" +\
    "\377\377\32\11\377\377\31\11\377\377\27\11\377\377\27\11\377\377\26\7" +\
    "\377\377\25\6\377\377\24\6\377\377\22\6\377\377\21\6\377\377\20\6\377" +\
    "\377\17\5\377\377\16\4\377\377\14\5\377\377\14\4\377\377\12\3\377\377" +\
    "\11\3\377\377\10\4\377\377\10\4\377\377\7\3\377\377\5\2\377\377\6\3\377" +\
    "\377\6\3\377\377\6\2\377\377\4\3\377\377\5\3\377\377\4\2\377\377\5\3" +\
    "\377\377\6\3\377\377\5\2\377\377\6\3\377\377\7\3\377\377\10\4\377\377" +\
    "\11\4\377\377\10\4\377\377\13\3\377\377\14\5\377\376\15\5\377\375\16" +\
    "\5\377\374\20\6\377\367\20\6\377\356\20\6\377\336\21\5\377\314\20\4\377" +\
    "\270\17\5\377\242\16\4\377\214\14\4\377v\12\4\377C\12\1\377()\17\377" +\
    "\35DF\377/z\202\377X\242\253\377}\271\276\377\225\311\316\377\240\325" +\
    "\332\377\242\333\341\377\243\342\347\377\242\344\353\377\240\347\357" +\
    "\377\241\347\357\377\241\350\360\377\242\353\361\377\240\352\361\377" +\
    "\242\353\363\377\237\347\357\377\227\332\342\377z\264\272\377Yl\221\377" +\
    "\232\236\372\377\234\241\377\377\236\243\376\377\236\243\377\377\237" +\
    "\243\377\377\232\240\377\377\230\235\377\377\224\231\377\377\222\227" +\
    "\377\377\221\226\377\377\220\225\377\377\217\224\377\377\215\222\377" +\
    "\377\215\221\377\377\213\220\377\377\213\220\377\377\212\216\377\377" +\
    "\211\216\377\377\207\214\375\377\204\210\373\377~\202\360\37702\334\377" +\
    "!!\245\377\21\256\275\377\6\363\377\377\10\355\377\377\11\354\375\377" +\
    "\10\336\360\377\10\265\305\377\4]g\377\0\0\1\377\0\0\0\243\0\0\0,\0\0" +\
    "\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\22\0\0\0\202@\7\2\377\250\24\7\377\330\30" +\
    "\11\377\364\32\12\377\375\32\12\377\377\32\12\377\377\30\10\377\377\27" +\
    "\10\377\377\25\11\377\377\25\7\377\377\25\7\377\377\23\5\377\377\21\5" +\
    "\377\377\20\5\377\377\20\4\377\377\17\4\377\377\15\5\377\377\14\3\377" +\
    "\377\12\3\377\377\11\4\377\377\7\4\377\377\7\2\377\377\6\2\377\377\5" +\
    "\3\377\377\4\2\377\377\4\3\377\377\4\3\377\377\3\3\377\377\3\1\377\377" +\
    "\3\1\377\377\3\3\377\377\3\3\377\377\4\3\377\377\6\3\377\377\6\2\377" +\
    "\377\5\3\377\377\7\2\377\377\10\2\377\377\11\3\377\377\11\4\377\377\12" +\
    "\3\377\376\15\4\377\376\16\4\377\376\17\4\377\374\20\4\377\370\21\6\377" +\
    "\357\20\5\377\342\22\5\377\320\21\5\377\271\20\6\377\236\16\5\377\202" +\
    "\14\4\377U\24\4\377uk\11\377vi\10\37781\5\377$5)\377\34WZ\377$y\202\377" +\
    "3\214\227\377M\237\247\377g\255\263\377{\265\272\377\206\272\300\377" +\
    "\206\274\301\377\210\275\303\377\207\276\306\377\204\301\307\377~\301" +\
    "\311\377m\267\277\377V\240\250\377Gs\207\377\215\222\336\377\243\247" +\
    "\377\377\241\245\377\377\240\245\377\377\240\244\377\377\240\244\377" +\
    "\377\236\243\377\377\234\241\377\377\233\240\377\377\232\236\377\377" +\
    "\230\235\377\377\227\233\377\377\226\232\377\377\224\231\377\377\224" +\
    "\230\376\377\224\230\376\377\223\227\376\377\221\225\376\377\220\224" +\
    "\374\377\214\220\367\377\210\213\351\377GH\320\377!1\232\377\13\306\305" +\
    "\377\6\363\377\377\10\357\377\377\11\355\376\377\11\352\374\377\12\332" +\
    "\354\377\10\252\273\377\3HO\377\0\0\0\370\0\0\0\220\0\0\0#\0\0\0\1\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\22\0\0\0\202@\7\2\377\247\23\7\377\327\31\11\377" +\
    "\364\33\12\377\375\32\11\377\377\32\12\377\377\30\10\377\377\27\11\377" +\
    "\377\26\7\377\377\26\6\377\377\25\7\377\377\22\5\377\377\21\6\377\377" +\
    "\20\4\377\377\17\5\377\377\17\5\377\377\15\4\377\377\12\4\377\377\13" +\
    "\4\377\377\11\3\377\377\10\2\377\377\10\3\377\377\6\3\377\377\6\3\377" +\
    "\377\4\3\377\377\3\1\377\377\3\1\377\377\4\1\377\377\2\2\377\377\3\2" +\
    "\377\377\3\1\377\377\4\1\377\377\4\1\377\377\4\1\377\377\6\3\377\377" +\
    "\5\3\377\377\7\3\377\377\7\3\377\377\10\2\377\377\11\3\377\377\13\4\377" +\
    "\377\13\3\377\377\16\5\377\376\17\4\377\376\20\5\377\374\21\5\377\371" +\
    "\22\6\377\362\23\5\377\346\23\6\377\320\22\5\377\262\20\5\377\224\15" +\
    "\5\377X\33\4\377\216\201\10\377\230\207\12\377\222\202\12\377\206x\11" +\
    "\377fY\6\37793\5\377('\15\377%1#\377!A<\377\34PP\377$[]\377#Z]\377'^" +\
    "`\377'WZ\377)Pe\377AZt\377dl\217\377\206\206\302\377\246\247\366\377" +\
    "\252\255\376\377\251\254\376\377\247\253\376\377\246\252\377\377\246" +\
    "\251\377\377\243\247\377\377\244\250\376\377\243\247\377\377\241\245" +\
    "\377\377\240\244\377\377\240\244\377\377\237\243\377\377\236\241\377" +\
    "\377\235\240\376\377\234\237\377\377\233\236\375\377\231\235\374\377" +\
    "\224\230\371\377\217\222\357\377\207\212\336\377FE\276\377#X\222\377" +\
    "\7\332\337\377\10\362\377\377\11\355\376\377\12\356\377\377\13\356\376" +\
    "\377\12\351\372\377\10\322\343\377\7\242\261\377\1/\63\376\0\0\0\360" +\
    "\0\0\0z\0\0\0\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\22\0\0\0\202@\7\1\377" +\
    "\246\23\6\377\325\31\11\377\364\33\12\377\375\32\12\377\377\31\11\377" +\
    "\377\30\10\377\377\27\11\377\377\25\10\377\377\26\6\377\377\25\7\377" +\
    "\377\22\5\377\377\21\5\377\377\17\4\377\377\20\5\377\377\17\4\377\377" +\
    "\15\3\377\377\13\4\377\377\13\4\377\377\10\2\377\377\11\3\377\377\7\3" +\
    "\377\377\7\2\377\377\7\3\377\377\4\3\377\377\4\1\377\377\4\2\377\377" +\
    "\4\2\377\377\3\2\377\377\3\2\377\377\3\2\377\377\4\2\377\377\4\2\377" +\
    "\377\3\1\377\377\4\3\377\377\6\3\377\377\6\2\377\377\10\3\377\377\7\3" +\
    "\377\377\11\2\377\377\12\4\377\377\15\3\377\377\16\4\377\377\17\5\377" +\
    "\377\17\5\377\376\21\5\377\375\23\6\377\371\24\6\377\362\24\7\377\342" +\
    "\22\5\377\304\22\5\377\244\15\5\377d/\3\377\262\241\11\377\256\233\11" +\
    "\377\245\223\10\377\236\214\11\377\231\210\7\377\225\204\10\377\221\200" +\
    "\7\377\211y\7\377~o\6\377vh\7\377tf\6\377rf\6\377pc\6\377l`\5\377+&\12" +\
    "\377$(p\377MN\260\377\214\216\324\377\242\245\351\377\251\254\366\377" +\
    "\252\255\372\377\255\260\375\377\253\256\376\377\252\255\376\377\253" +\
    "\256\376\377\252\255\377\377\251\254\377\377\247\253\377\377\246\251" +\
    "\376\377\246\251\376\377\245\250\376\377\243\246\376\377\242\245\374" +\
    "\377\240\243\372\377\234\237\365\377\226\231\355\377\216\221\340\377" +\
    "mn\307\3775F\232\377\37\245\263\377\26\361\371\377\12\361\377\377\13" +\
    "\357\377\377\13\355\377\377\15\355\377\377\13\353\375\377\13\346\366" +\
    "\377\11\307\330\377\7\222\237\377\0\27\31\377\0\0\0\345\0\0\0d\0\0\0" +\
    "\21\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\22\0\0\0\200>\6\2\377\245\23\6\377\325" +\
    "\31\11\377\362\31\12\377\375\32\12\377\377\32\11\377\377\30\10\377\377" +\
    "\27\10\377\377\26\10\377\377\25\7\377\377\25\6\377\377\22\6\377\377\22" +\
    "\5\377\377\20\4\377\377\20\5\377\377\16\4\377\377\14\3\377\377\13\4\377" +\
    "\377\12\4\377\377\12\2\377\377\10\3\377\377\7\3\377\377\7\3\377\377\5" +\
    "\1\377\377\5\1\377\377\4\2\377\377\4\2\377\377\4\2\377\377\4\2\377\377" +\
    "\4\2\377\377\4\2\377\377\4\2\377\377\4\2\377\377\3\2\377\377\4\1\377" +\
    "\377\5\1\377\377\7\3\377\377\10\3\377\377\7\3\377\377\12\2\377\377\13" +\
    "\4\377\377\13\4\377\377\15\4\377\377\17\5\377\377\20\5\377\376\21\5\377" +\
    "\376\23\6\377\375\24\5\377\367\24\7\377\352\23\7\377\317\22\7\377\245" +\
    "\16\5\377~R\4\377\324\277\10\377\312\263\10\377\300\252\7\377\270\242" +\
    "\10\377\261\235\7\377\253\230\7\377\247\224\6\377\245\222\6\377\242\220" +\
    "\6\377\242\220\6\377\240\216\6\377\236\214\6\377\232\210\6\377\223\203" +\
    "\6\377\207y\5\377%0\30\377\27ay\377+@\217\377AC\265\377st\324\377\225" +\
    "\227\342\377\245\250\352\377\253\256\361\377\253\256\364\377\254\257" +\
    "\370\377\254\257\371\377\252\255\372\377\252\255\373\377\252\255\372" +\
    "\377\250\253\371\377\246\251\366\377\243\246\363\377\237\241\355\377" +\
    "\231\233\345\377\212\212\326\377kl\277\377EY\240\377*\221\252\377$\335" +\
    "\344\377$\365\376\377&\357\377\377%\356\377\377\21\354\377\377\21\354" +\
    "\376\377\21\354\376\377\16\352\374\377\15\335\360\377\11\266\307\377" +\
    "\7oz\377\1\6\6\377\0\0\0\310\0\0\0L\0\0\0\12\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\21\0\0\0}\64\5\1\377\240\23\6\377\321\30\11\377\360\32\12\377" +\
    "\375\32\11\377\377\31\12\377\377\30\10\377\377\27\10\377\377\26\10\377" +\
    "\377\26\7\377\377\24\6\377\377\22\5\377\377\22\6\377\377\20\4\377\377" +\
    "\20\5\377\377\17\4\377\377\14\3\377\377\13\4\377\377\12\4\377\377\10" +\
    "\2\377\377\7\2\377\377\10\3\377\377\6\2\377\377\4\1\377\377\4\2\377\377" +\
    "\3\2\377\377\3\2\377\377\4\2\377\377\4\2\377\377\3\1\377\377\4\2\377" +\
    "\377\4\2\377\377\3\1\377\377\4\2\377\377\4\2\377\377\5\1\377\377\7\2" +\
    "\377\377\10\3\377\377\10\3\377\377\11\2\377\377\13\4\377\377\14\4\377" +\
    "\377\15\4\377\377\20\5\377\377\17\5\377\377\21\5\377\377\23\6\377\376" +\
    "\23\5\377\371\24\7\377\352\24\7\377\321\22\6\377\230\15\5\377\240}\5" +\
    "\377\356\324\7\377\343\311\6\377\334\302\6\377\325\274\6\377\316\266" +\
    "\5\377\310\260\5\377\303\255\5\377\300\252\5\377\276\250\5\377\275\247" +\
    "\5\377\273\245\5\377\266\241\5\377\255\231\4\377\241\216\4\377\225\204" +\
    "\3\377QF\1\377\21oz\377\34\250\264\377A\235\260\377:c\241\3770@\243\377" +\
    "8=\264\377IJ\302\377]^\316\377uw\330\377\206\210\336\377\224\226\341" +\
    "\377\223\225\341\377\221\223\340\377\214\215\334\377\201\202\324\377" +\
    "vt\312\377_c\270\377L]\247\3779o\240\3770\247\271\3771\340\343\3775\370" +\
    "\376\3774\364\377\3775\360\376\3776\356\377\3778\356\377\3771\355\377" +\
    "\377\27\352\376\377\27\352\375\377\23\345\370\377\16\316\341\377\10\237" +\
    "\256\377\11:\77\377\0\0\0\375\0\0\0\242\0\0\0\63\0\0\0\5\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\17\0\0\0u'\3\0\376\230\21\6\377\313\27\10\377\355" +\
    "\31\10\377\373\33\12\377\376\31\12\377\377\30\10\377\377\26\7\377\377" +\
    "\26\10\377\377\26\10\377\377\24\5\377\377\23\6\377\377\21\4\377\377\20" +\
    "\5\377\377\20\5\377\377\17\4\377\377\14\4\377\377\13\3\377\377\12\2\377" +\
    "\377\12\3\377\377\11\3\377\377\7\1\377\377\6\1\377\377\5\2\377\377\4" +\
    "\2\377\377\3\1\377\377\3\0\377\377\2\0\377\377\2\0\377\377\3\1\377\377" +\
    "\2\0\377\377\2\0\377\377\3\0\377\377\4\1\377\377\5\2\377\377\5\1\377" +\
    "\377\6\1\377\377\10\2\377\377\10\2\377\377\11\2\377\377\13\4\377\377" +\
    "\14\3\377\377\15\3\377\377\16\4\377\377\17\5\377\377\21\4\377\377\23" +\
    "\6\377\375\23\5\377\366\24\6\377\346\22\7\377\314\20\6\377\213\27\4\377" +\
    "\304\250\4\377\371\334\4\377\364\326\4\377\357\323\4\377\353\317\4\377" +\
    "\347\313\4\377\343\310\5\377\340\304\3\377\335\302\3\377\333\301\3\377" +\
    "\332\277\3\377\330\277\3\377\322\272\5\377\307\260\5\377\264\240\3\377" +\
    "\241\217\4\377\204u\1\377 >4\377\30\236\257\377[\325\342\377r\352\362" +\
    "\377m\334\334\377`\272\304\377P\231\262\377Ax\250\3774X\243\377-H\243" +\
    "\3773I\245\3778Q\247\3778Q\245\377\77[\243\377Bn\247\377A\204\252\377" +\
    "@\261\276\377A\332\334\377D\366\370\377E\372\377\377E\365\377\377E\362" +\
    "\376\377F\361\377\377H\360\377\377G\357\377\377I\356\376\377K\356\377" +\
    "\377&\351\375\377\37\346\373\377\30\333\357\377\20\270\311\377\7y\203" +\
    "\377\3\11\11\377\0\0\0\350\0\0\0t\0\0\0\34\0\0\0\2\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\14\0\0\0e\25\1\0\365\212\20\5\377\302\26\10\377\350\30\10" +\
    "\377\371\33\11\377\376\31\10\377\377\30\11\377\377\26\10\377\377\26\10" +\
    "\377\377\26\10\377\377\24\5\377\377\23\5\377\377\21\4\377\377\21\5\377" +\
    "\377\20\3\377\377\16\3\377\377\14\4\377\377\12\3\377\377\12\3\377\377" +\
    "\11\3\377\377\7\2\377\377\10\1\377\377\6\2\377\377\5\1\377\377\4\1\377" +\
    "\377\3\0\377\377\2\1\377\377\3\1\377\377\3\1\377\377\3\1\377\377\2\1" +\
    "\377\377\2\1\377\377\3\1\377\377\3\1\377\377\4\0\377\377\5\2\377\377" +\
    "\7\2\377\377\10\2\377\377\10\2\377\377\11\3\377\377\12\2\377\377\14\3" +\
    "\377\377\16\3\377\377\16\4\377\377\20\4\377\377\20\5\377\377\22\5\377" +\
    "\374\23\5\377\362\23\6\377\341\23\5\377\302\16\6\377\222@\3\377\347\316" +\
    "\3\377\374\336\5\377\372\334\5\377\371\333\5\377\367\331\5\377\365\330" +\
    "\5\377\363\326\4\377\362\325\5\377\361\324\5\377\357\324\5\377\357\323" +\
    "\5\377\355\322\5\377\350\315\4\377\335\303\4\377\307\260\4\377\257\233" +\
    "\3\377\231\210\3\377OH\6\377\31lw\377H\264\300\377y\336\351\377~\356" +\
    "\371\377~\363\376\377{\367\377\377x\366\377\377q\362\370\377l\357\357" +\
    "\377f\351\351\377g\353\351\377|\360\356\377\244\370\364\377\264\377\376" +\
    "\377\216\376\377\377h\372\377\377Y\365\377\377U\364\377\377V\363\377" +\
    "\377U\361\377\377W\360\377\377W\361\377\377W\357\377\377X\357\377\377" +\
    "W\355\377\377X\356\375\377@\352\375\377!\340\365\377\33\307\333\377\16" +\
    "\231\250\377\128<\377\0\0\1\376\0\0\0\266\0\0\0F\0\0\0\14\0\0\0\1\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\7\0\0\0M\10\0\0\340j\13\4\377\270\26\10\377" +\
    "\337\30\10\377\366\32\11\377\375\31\10\377\377\31\10\377\377\26\10\377" +\
    "\377\27\10\377\377\26\10\377\377\25\6\377\377\22\5\377\377\22\5\377\377" +\
    "\20\5\377\377\20\4\377\377\17\4\377\377\15\4\377\377\13\2\377\377\13" +\
    "\3\377\377\11\3\377\377\10\2\377\377\7\2\377\377\6\2\377\377\5\1\377" +\
    "\377\3\0\377\377\3\1\377\377\4\1\377\377\2\1\377\377\3\1\377\377\3\1" +\
    "\377\377\3\1\377\377\3\1\377\377\4\1\377\377\4\1\377\377\4\0\377\377" +\
    "\6\2\377\377\10\2\377\377\10\2\377\377\10\1\377\377\11\3\377\377\12\3" +\
    "\377\377\15\3\377\377\17\4\377\377\16\3\377\377\21\4\377\377\21\5\377" +\
    "\376\23\5\377\372\24\7\377\356\24\5\377\331\23\6\377\264\15\6\377\232" +\
    "e\2\377\370\335\4\377\374\336\5\377\374\337\5\377\374\336\5\377\373\334" +\
    "\5\377\374\334\5\377\372\334\5\377\372\333\5\377\371\334\5\377\371\335" +\
    "\5\377\371\333\5\377\370\333\5\377\365\330\5\377\353\317\4\377\327\277" +\
    "\3\377\276\250\4\377\244\222\4\377\207w\1\377*8 \377(\215\232\377w\307" +\
    "\320\377\203\344\356\377\206\357\372\377\205\363\376\377\204\362\377" +\
    "\377\201\363\377\377~\364\377\377{\364\377\377~\364\377\377\236\370\377" +\
    "\377\333\374\375\377\362\375\375\377\272\372\377\377\202\367\377\377" +\
    "l\364\377\377h\364\377\377g\363\377\377f\362\377\377g\362\377\377g\360" +\
    "\377\377e\361\377\377d\357\376\377c\356\376\377b\355\375\377Q\346\370" +\
    "\377!\317\344\377\26\251\272\377\14aj\377\1\1\1\377\0\0\0\347\0\0\0y" +\
    "\0\0\0#\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\64\1\0\0" +\
    "\273A\7\1\377\252\24\6\377\326\27\7\377\361\31\11\377\374\31\10\377\377" +\
    "\31\11\377\376\27\10\377\377\27\10\377\377\26\10\377\377\26\5\377\377" +\
    "\23\5\377\377\22\5\377\377\20\4\377\377\20\3\377\377\17\4\377\377\15" +\
    "\3\377\377\13\2\377\377\13\3\377\377\11\2\377\377\7\1\377\377\7\2\377" +\
    "\377\10\2\377\377\5\2\377\377\4\0\377\377\4\1\377\377\4\1\377\377\3\1" +\
    "\377\377\3\1\377\377\2\1\377\377\3\1\377\377\4\1\377\377\4\1\377\377" +\
    "\3\1\377\377\4\0\377\377\6\2\377\377\10\2\377\377\7\2\377\377\10\1\377" +\
    "\377\12\2\377\377\12\3\377\377\14\3\377\377\17\4\377\377\16\4\377\377" +\
    "\20\4\377\376\21\5\377\375\23\5\377\367\23\6\377\352\24\5\377\322\21" +\
    "\6\377\241\24\3\377\262\221\3\377\374\337\4\377\374\336\5\377\374\335" +\
    "\5\377\375\335\5\377\375\336\5\377\375\336\4\377\374\334\4\377\374\335" +\
    "\4\377\374\336\5\377\374\336\5\377\374\336\5\377\374\335\5\377\372\334" +\
    "\5\377\363\326\5\377\343\312\3\377\314\264\4\377\261\235\3\377\233\212" +\
    "\3\377oc\3\377\37C=\377O\237\250\377\177\314\325\377\213\346\360\377" +\
    "\217\360\372\377\216\362\375\377\215\364\376\377\211\362\377\377\211" +\
    "\364\377\377\214\365\377\377\244\366\377\377\323\372\375\377\342\374" +\
    "\375\377\270\370\377\377\215\366\377\377{\364\377\377y\363\377\377w\362" +\
    "\377\377v\362\377\377u\362\377\377u\362\377\377t\363\377\377r\360\376" +\
    "\377o\357\375\377m\351\370\377O\327\347\377\32\260\302\377\21|\210\377" +\
    "\5\20\21\377\0\0\0\370\0\0\0\247\0\0\0B\0\0\0\15\0\0\0\2\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\36\0\0\0\217 \2\0\376\227\21\5\377" +\
    "\312\26\7\377\352\30\10\377\371\31\11\377\376\31\11\377\377\30\10\377" +\
    "\377\27\10\377\377\27\6\377\377\26\6\377\377\23\6\377\377\23\5\377\377" +\
    "\20\4\377\377\17\3\377\377\17\4\377\377\16\3\377\377\14\2\377\377\13" +\
    "\3\377\377\12\2\377\377\11\2\377\377\11\2\377\377\7\1\377\377\6\1\377" +\
    "\377\4\1\377\377\3\1\377\377\3\1\377\377\3\1\377\377\4\0\377\377\4\0" +\
    "\377\377\3\1\377\377\3\1\377\377\3\1\377\377\4\1\377\377\4\1\377\377" +\
    "\6\1\377\377\10\2\377\377\11\2\377\377\11\1\377\377\12\2\377\377\14\3" +\
    "\377\377\14\3\377\377\17\4\377\377\16\4\377\376\20\4\377\376\22\5\377" +\
    "\374\23\5\377\364\24\6\377\343\22\6\377\313\21\5\377\212!\3\377\326\275" +\
    "\3\377\375\336\4\377\375\336\4\377\375\336\3\377\375\335\3\377\375\335" +\
    "\3\377\375\335\4\377\375\334\3\377\375\336\4\377\375\336\3\377\375\336" +\
    "\3\377\375\336\3\377\375\336\4\377\373\334\4\377\367\332\4\377\355\322" +\
    "\5\377\332\301\3\377\300\252\3\377\250\225\3\377\224\204\2\377^V\4\377" +\
    "!PP\377_\242\252\377\204\314\324\377\221\344\356\377\226\357\371\377" +\
    "\226\362\375\377\225\364\376\377\224\365\376\377\225\365\377\377\235" +\
    "\365\376\377\255\367\377\377\263\370\377\377\241\366\376\377\220\365" +\
    "\377\377\210\364\377\377\206\364\377\377\204\362\377\377\202\362\377" +\
    "\377\201\362\376\377\200\362\376\377~\361\376\377}\360\374\377x\352\365" +\
    "\377p\333\345\3773\266\303\377\23\203\220\377\11 !\376\0\0\0\376\0\0" +\
    "\0\311\0\0\0_\0\0\0\33\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\16\0\0\0a\13\0\0\351w\16\4\377\272\25\6\377\340\30\10" +\
    "\377\365\31\10\377\375\31\10\377\376\27\10\377\377\27\10\377\377\26\6" +\
    "\377\377\26\6\377\377\25\6\377\377\22\4\377\377\21\5\377\377\21\4\377" +\
    "\377\17\4\377\377\17\4\377\377\15\2\377\377\13\3\377\377\12\2\377\377" +\
    "\12\1\377\377\11\2\377\377\7\2\377\377\6\0\377\377\5\1\377\377\5\0\377" +\
    "\377\5\1\377\377\5\1\377\377\3\0\377\377\4\0\377\377\5\1\377\377\5\1" +\
    "\377\377\4\1\377\377\5\1\377\377\5\0\377\377\6\1\377\377\10\2\377\377" +\
    "\11\2\377\377\12\2\377\377\13\3\377\377\14\2\377\377\15\3\377\377\17" +\
    "\3\377\377\17\4\377\377\21\4\377\375\22\4\377\373\22\6\377\356\24\5\377" +\
    "\332\22\4\377\266\15\4\377\213P\2\377\357\324\4\377\375\336\3\377\375" +\
    "\336\4\377\375\336\4\377\375\335\4\377\375\335\4\377\375\335\4\377\375" +\
    "\335\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336\4\377\374" +\
    "\335\4\377\374\336\4\377\372\335\5\377\364\330\5\377\345\314\4\377\321" +\
    "\271\4\377\267\244\3\377\242\220\2\377\217\201\2\377UM\4\377'RP\377`" +\
    "\237\246\377\206\305\314\377\223\337\347\377\232\355\365\377\235\362" +\
    "\374\377\233\364\375\377\234\366\376\377\235\366\376\377\237\367\377" +\
    "\377\237\366\377\377\232\365\377\377\225\365\377\377\222\364\377\377" +\
    "\221\364\377\377\217\364\377\377\215\364\376\377\214\363\376\377\211" +\
    "\362\375\377\206\356\371\377\201\346\361\377v\325\337\377_\265\276\377" +\
    "\27\201\215\377\12\36 \376\0\0\0\377\0\0\0\335\0\0\0v\0\0\0)\0\0\0\10" +\
    "\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\0\0" +\
    "\09\1\0\0\273B\7\2\377\247\22\5\376\322\26\7\377\357\30\10\377\373\31" +\
    "\11\377\376\30\7\377\377\30\10\377\377\26\10\377\377\25\6\377\377\25" +\
    "\6\377\377\22\4\377\377\21\5\377\377\22\4\377\377\20\4\377\377\17\4\377" +\
    "\377\15\2\377\377\13\3\377\377\13\2\377\377\12\2\377\377\11\2\377\377" +\
    "\11\2\377\377\6\1\377\377\5\1\377\377\5\1\377\377\4\0\377\377\5\0\377" +\
    "\377\4\0\377\377\5\0\377\377\5\0\377\377\4\0\377\377\5\1\377\377\5\1" +\
    "\377\377\6\1\377\377\10\1\377\377\11\2\377\377\12\2\377\377\12\1\377" +\
    "\377\13\3\377\377\14\2\377\377\16\3\377\377\20\3\377\377\21\5\377\376" +\
    "\22\5\377\375\22\4\377\366\23\6\377\347\23\5\377\320\21\5\377\231\17" +\
    "\4\377\271\231\2\377\373\335\4\377\375\336\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\335" +\
    "\4\377\374\337\5\377\370\333\5\377\360\325\4\377\340\307\3\377\313\264" +\
    "\3\377\262\237\2\377\237\216\4\377\220\201\3\377]T\2\377'E<\377M\212" +\
    "\222\377\177\267\274\377\220\322\331\377\232\343\353\377\240\356\366" +\
    "\377\242\362\373\377\241\365\375\377\241\366\375\377\241\365\376\377" +\
    "\237\366\376\377\234\366\376\377\233\366\376\377\232\365\376\377\230" +\
    "\363\375\377\226\362\374\377\223\356\370\377\217\351\363\377\206\334" +\
    "\345\377y\310\320\377c\250\260\377\36s}\377\12\24\23\377\0\0\0\377\0" +\
    "\0\0\357\0\0\0\214\0\0\0\65\0\0\0\14\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\34\0\0\0\201\25\1\0\372" +\
    "\217\17\5\377\300\25\6\377\344\30\10\377\366\31\11\377\375\27\7\377\376" +\
    "\30\10\377\377\27\10\377\376\25\5\377\377\25\6\377\377\23\4\377\377\22" +\
    "\5\377\377\20\4\377\377\20\4\377\377\17\4\377\377\16\2\377\377\13\3\377" +\
    "\377\13\2\377\377\12\1\377\377\11\2\377\377\11\2\377\377\10\0\377\377" +\
    "\6\1\377\377\6\1\377\377\5\0\377\377\5\0\377\377\5\0\377\377\4\0\377" +\
    "\377\5\0\377\377\5\0\377\377\6\0\377\377\6\1\377\377\7\1\377\377\7\0" +\
    "\377\377\12\2\377\377\12\2\377\377\12\1\377\377\14\3\377\377\15\3\377" +\
    "\377\17\3\377\377\20\4\377\377\20\3\377\376\22\4\377\372\22\5\377\361" +\
    "\24\5\377\337\22\6\377\303\17\4\377\2210\3\377\341\307\2\377\375\337" +\
    "\4\377\375\335\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336" +\
    "\3\377\375\336\4\377\375\336\3\377\375\336\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\335\4\377\375\337\3\377\374\337\3\377\373\336" +\
    "\3\377\366\333\5\377\355\323\4\377\335\304\3\377\307\262\4\377\261\236" +\
    "\3\377\237\216\4\377\223\204\3\377sg\2\377,2\24\377.jo\377^\235\243\377" +\
    "\205\271\276\377\222\317\325\377\233\335\344\377\241\347\356\377\242" +\
    "\353\363\377\242\357\367\377\243\360\370\377\242\360\370\377\240\357" +\
    "\367\377\236\355\365\377\232\351\362\377\224\342\353\377\215\330\341" +\
    "\377\202\310\317\377s\257\265\377Q\220\230\377\37IG\37754\5\377\20\17" +\
    "\0\377\0\0\0\376\0\0\0\275\0\0\0J\0\0\0\21\0\0\0\3\0\0\0\1\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0\0" +\
    "M\2\0\0\323X\11\3\377\253\22\6\377\324\26\10\377\360\31\10\377\373\30" +\
    "\7\377\376\30\10\377\376\30\10\377\377\26\6\377\377\26\6\377\377\23\4" +\
    "\377\377\22\5\377\377\21\3\377\377\20\3\377\377\20\4\377\377\16\2\377" +\
    "\377\15\3\377\377\14\3\377\377\13\2\377\377\13\2\377\377\11\2\377\377" +\
    "\11\1\377\377\6\1\377\377\6\1\377\377\6\0\377\377\5\0\377\377\6\0\377" +\
    "\377\5\0\377\377\6\0\377\377\6\0\377\377\6\1\377\377\6\1\377\377\7\1" +\
    "\377\377\11\0\377\377\12\2\377\377\13\2\377\377\13\1\377\377\14\3\377" +\
    "\377\15\3\377\377\17\3\377\377\21\4\377\377\20\3\377\374\22\4\377\371" +\
    "\23\4\377\353\23\6\377\323\21\5\377\256\20\4\377\232m\2\377\367\335\2" +\
    "\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\336\2\377\375\336\4\377\375\336\4\377\375\336" +\
    "\4\377\375\336\4\377\375\336\4\377\375\335\4\377\375\337\4\377\375\336" +\
    "\4\377\374\337\4\377\372\336\3\377\365\332\5\377\353\322\3\377\333\303" +\
    "\4\377\310\263\4\377\263\241\3\377\242\222\4\377\226\207\2\377\210z\2" +\
    "\377XR\4\377\36*\34\377'go\377K\225\237\377v\252\257\377\216\273\277" +\
    "\377\222\305\313\377\224\315\323\377\225\321\330\377\223\322\330\377" +\
    "\221\320\327\377\216\313\321\377\211\303\311\377\201\265\273\377n\245" +\
    "\253\377R\215\223\377)LM\37703\17\377pj\4\377nj\3\377\17\16\0\376\0\0" +\
    "\0\374\0\0\0\214\0\0\0&\0\0\0\6\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0%\0\0\0\222\31" +\
    "\2\1\372\206\16\4\377\276\24\6\377\343\30\7\377\364\27\7\377\374\30\10" +\
    "\377\376\27\10\377\376\26\7\377\376\26\6\377\377\24\5\377\377\23\5\377" +\
    "\377\21\4\377\377\21\4\377\377\20\4\377\377\17\2\377\377\16\3\377\377" +\
    "\14\3\377\377\13\2\377\377\13\2\377\377\12\2\377\377\12\1\377\377\11" +\
    "\1\377\377\11\0\377\377\7\1\377\377\7\1\377\377\7\0\377\377\7\0\377\377" +\
    "\6\0\377\377\7\1\377\377\10\0\377\377\11\1\377\377\11\0\377\377\12\1" +\
    "\377\377\13\1\377\377\13\2\377\377\13\2\377\377\16\3\377\377\16\2\377" +\
    "\376\20\3\377\377\21\3\377\376\21\4\377\373\22\5\377\362\22\4\377\341" +\
    "\22\6\377\306\20\5\377\206 \2\377\327\275\2\377\375\337\4\377\374\336" +\
    "\3\377\375\336\4\377\375\336\3\377\375\336\3\377\375\336\3\377\375\336" +\
    "\3\377\375\336\2\377\375\336\3\377\375\336\3\377\375\336\3\377\375\336" +\
    "\3\377\375\336\3\377\375\336\4\377\375\336\3\377\375\337\4\377\375\337" +\
    "\4\377\373\337\3\377\372\335\4\377\365\332\4\377\353\322\4\377\335\307" +\
    "\3\377\313\266\4\377\271\247\3\377\250\227\4\377\234\216\3\377\223\206" +\
    "\3\377\207z\3\377bX\2\37705\17\377\27\62\60\377\37V]\377%r|\3774\212" +\
    "\225\377F\224\236\377P\225\237\377M\223\234\377F\207\221\377:u|\377&" +\
    "KM\377!/\42\377LL\11\377\203z\3\377\240\230\6\377\227\220\7\377xs\5\377" +\
    "\15\14\0\377\0\0\0\360\0\0\0q\0\0\0\30\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\15\0\0\0S\0\0\0\326I\7\2\377\244\22\5\376\316\25\6\377\352\30\7" +\
    "\377\370\27\10\377\374\30\10\377\376\27\7\377\376\25\6\377\377\25\5\377" +\
    "\377\23\4\377\377\23\5\377\377\22\3\377\377\21\3\377\377\17\3\377\377" +\
    "\16\2\377\377\16\3\377\377\15\2\377\377\14\1\377\377\13\2\377\377\12" +\
    "\1\377\377\13\0\377\377\11\0\377\377\11\1\377\377\11\1\377\377\11\1\377" +\
    "\377\11\1\377\377\11\1\377\377\11\1\377\377\11\1\377\377\12\0\377\377" +\
    "\13\1\377\377\12\2\377\377\14\2\377\377\13\2\377\377\16\2\377\377\16" +\
    "\3\377\377\17\2\377\376\21\4\377\375\22\4\377\375\23\3\377\367\23\5\377" +\
    "\353\23\4\377\326\21\5\377\251\20\4\377\231k\2\377\363\331\4\377\375" +\
    "\337\3\377\375\336\3\377\375\337\2\377\375\336\2\377\375\335\3\377\375" +\
    "\336\3\377\375\336\3\377\375\336\3\377\375\336\3\377\375\336\3\377\375" +\
    "\336\3\377\375\336\3\377\375\336\2\377\375\337\2\377\375\337\3\377\375" +\
    "\337\3\377\375\340\4\377\375\340\4\377\373\340\4\377\372\336\4\377\365" +\
    "\334\4\377\355\325\5\377\340\312\3\377\322\275\4\377\301\256\4\377\262" +\
    "\243\3\377\246\227\4\377\235\217\3\377\230\213\3\377\221\206\4\377\201" +\
    "v\2\377h]\0\377TK\0\377EA\6\3778=\17\3778=\20\377>\77\14\377JF\5\377" +\
    "ZR\1\377zr\2\377\233\222\5\377\255\243\7\377\270\256\7\377\267\255\10" +\
    "\377\244\235\6\377vq\5\377\5\4\0\377\0\0\0\337\0\0\0^\0\0\0\20\0\0\0" +\
    "\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0%\0\0\0\213\14\0\0\363t\14\4\377" +\
    "\265\22\5\377\331\27\7\377\360\27\10\377\372\27\10\377\374\30\10\377" +\
    "\376\27\7\377\376\26\6\377\377\24\5\377\377\24\5\377\377\22\4\377\377" +\
    "\22\4\377\377\21\4\377\377\20\3\377\377\20\3\377\377\17\3\377\377\14" +\
    "\2\377\377\13\1\377\377\13\1\377\377\12\2\377\377\13\2\377\377\13\1\377" +\
    "\377\12\1\377\377\11\1\377\377\13\1\377\377\13\1\377\377\13\1\377\377" +\
    "\13\0\377\377\13\1\377\377\12\2\377\377\13\2\377\377\13\1\377\377\16" +\
    "\2\377\377\17\2\377\377\17\2\377\376\20\3\377\376\22\4\377\375\22\3\377" +\
    "\373\22\4\377\362\23\5\377\341\22\4\377\306\15\4\377\227(\3\377\320\273" +\
    "\3\377\375\340\4\377\374\340\4\377\375\337\2\377\375\336\3\377\375\337" +\
    "\3\377\375\337\3\377\375\335\3\377\375\336\3\377\375\336\3\377\375\336" +\
    "\3\377\375\336\3\377\375\336\3\377\375\335\3\377\375\337\3\377\375\337" +\
    "\3\377\375\336\2\377\375\340\4\377\375\340\4\377\375\340\4\377\375\342" +\
    "\4\377\373\341\4\377\372\340\4\377\366\336\4\377\360\331\5\377\347\320" +\
    "\5\377\333\306\4\377\315\273\5\377\301\260\4\377\264\246\4\377\254\235" +\
    "\5\377\245\227\4\377\240\223\4\377\235\221\5\377\233\220\5\377\233\220" +\
    "\5\377\232\220\5\377\233\221\5\377\237\225\5\377\244\232\6\377\252\237" +\
    "\6\377\262\247\7\377\274\261\7\377\307\275\10\377\317\304\10\377\307" +\
    "\275\11\377\251\242\7\377ic\5\377\2\2\0\377\0\0\0\312\0\0\0I\0\0\0\11" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0D\0\0\0\273'\3\1\375" +\
    "\221\16\4\377\275\23\5\377\337\25\6\377\362\26\6\377\373\27\10\377\375" +\
    "\27\7\377\377\26\6\377\377\25\5\377\376\24\4\377\377\23\4\377\377\21" +\
    "\3\377\377\22\4\377\377\20\3\377\377\17\3\377\377\17\3\377\377\17\3\377" +\
    "\377\14\1\377\377\14\2\377\377\15\2\377\377\14\2\377\377\13\1\377\377" +\
    "\14\1\377\377\14\1\377\377\13\0\377\377\14\0\377\377\14\0\377\377\14" +\
    "\1\377\377\13\2\377\377\15\2\377\377\14\2\377\377\15\1\377\377\17\3\377" +\
    "\377\20\3\377\377\17\2\377\376\22\4\377\375\21\4\377\374\23\4\377\366" +\
    "\22\5\377\347\22\4\377\323\21\5\377\247\17\4\377\231l\2\377\367\335\4" +\
    "\377\375\340\3\377\375\340\4\377\375\340\2\377\375\336\3\377\375\337" +\
    "\3\377\375\336\3\377\375\336\3\377\375\336\3\377\375\336\3\377\375\335" +\
    "\3\377\375\335\3\377\375\335\3\377\375\336\3\377\375\337\3\377\375\337" +\
    "\3\377\375\337\3\377\375\340\3\377\375\337\4\377\375\340\4\377\375\342" +\
    "\4\377\375\342\3\377\374\342\4\377\373\342\5\377\370\340\5\377\364\334" +\
    "\4\377\356\330\5\377\345\320\5\377\333\311\4\377\321\300\4\377\310\270" +\
    "\5\377\301\260\5\377\272\254\4\377\265\250\5\377\262\245\5\377\262\245" +\
    "\5\377\262\246\6\377\264\251\6\377\271\254\6\377\276\262\7\377\305\271" +\
    "\7\377\316\302\10\377\327\313\11\377\340\324\11\377\337\323\11\377\314" +\
    "\302\11\377\245\235\7\377B>\3\377\0\0\0\376\0\0\0\260\0\0\0\67\0\0\0" +\
    "\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\30\0\0\0e\0\0\0" +\
    "\334C\6\1\377\234\21\5\376\305\24\5\377\343\25\7\377\363\27\6\377\373" +\
    "\30\7\377\376\26\7\377\376\25\5\377\377\25\5\377\377\24\5\377\377\23" +\
    "\3\377\377\21\4\377\377\22\4\377\377\20\2\377\377\20\3\377\377\20\2\377" +\
    "\377\16\3\377\377\14\1\377\377\14\2\377\377\14\1\377\377\13\2\377\377" +\
    "\15\2\377\377\13\2\377\377\14\2\377\377\14\2\377\377\14\2\377\377\13" +\
    "\2\377\377\15\2\377\377\15\1\377\377\15\1\377\377\20\3\377\377\21\3\377" +\
    "\377\17\3\377\377\21\2\377\376\22\4\377\374\22\3\377\370\23\5\377\357" +\
    "\24\4\377\333\23\4\377\300\17\4\377\214/\2\377\326\301\2\377\375\341" +\
    "\4\377\374\342\4\377\375\337\4\377\375\340\2\377\375\336\3\377\375\336" +\
    "\3\377\375\337\3\377\375\336\3\377\375\336\3\377\375\336\3\377\375\336" +\
    "\3\377\375\337\3\377\375\337\3\377\375\336\3\377\375\337\3\377\375\337" +\
    "\3\377\375\337\2\377\375\340\4\377\375\341\4\377\375\340\4\377\375\342" +\
    "\4\377\375\342\4\377\374\342\4\377\375\344\5\377\374\344\5\377\373\342" +\
    "\5\377\370\341\4\377\364\336\6\377\357\332\6\377\350\325\5\377\342\320" +\
    "\6\377\334\313\5\377\327\307\6\377\323\303\6\377\321\301\6\377\320\301" +\
    "\6\377\321\303\7\377\322\304\7\377\325\307\6\377\332\315\10\377\340\322" +\
    "\11\377\347\332\11\377\355\337\11\377\356\341\12\377\346\331\12\377\310" +\
    "\300\10\377\233\225\6\377\26\25\1\377\0\0\0\376\0\0\0\216\0\0\0$\0\0" +\
    "\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0)\0\0\0" +\
    "\213\7\0\0\362\134\11\2\377\244\21\4\377\312\24\6\377\344\25\7\377\363" +\
    "\27\7\377\373\27\6\377\375\26\7\377\377\25\6\377\376\25\6\377\377\24" +\
    "\4\377\377\22\3\377\377\23\4\377\377\21\3\377\377\21\2\377\377\21\3\377" +\
    "\377\20\2\377\377\17\3\377\377\15\1\377\377\15\1\377\377\15\2\377\377" +\
    "\15\2\377\377\15\2\377\377\14\2\377\377\15\2\377\377\15\2\377\377\15" +\
    "\2\377\377\15\1\377\377\16\2\377\377\17\2\377\377\20\2\377\377\21\3\377" +\
    "\377\21\3\377\376\22\3\377\375\22\3\377\372\23\4\377\363\23\4\377\343" +\
    "\23\5\377\313\21\5\377\235\24\3\377\252\207\2\377\371\341\3\377\375\341" +\
    "\3\377\375\341\4\377\375\337\3\377\375\337\2\377\375\337\3\377\375\337" +\
    "\3\377\375\336\3\377\375\337\3\377\375\337\3\377\375\337\3\377\375\337" +\
    "\3\377\375\337\3\377\375\337\3\377\375\337\3\377\375\337\3\377\375\336" +\
    "\3\377\375\337\2\377\375\337\3\377\375\340\4\377\375\341\4\377\375\343" +\
    "\4\377\375\343\4\377\375\342\4\377\374\344\5\377\375\343\5\377\374\344" +\
    "\5\377\373\344\4\377\373\344\6\377\370\343\5\377\366\342\6\377\363\337" +\
    "\6\377\360\335\6\377\355\334\6\377\352\331\6\377\351\331\6\377\350\331" +\
    "\7\377\351\332\7\377\352\333\7\377\354\336\7\377\357\340\10\377\363\344" +\
    "\11\377\366\350\11\377\367\350\11\377\365\347\13\377\343\327\12\377\277" +\
    "\265\10\377\204}\6\377\3\3\0\377\1\1\0\357\0\0\0k\0\0\0\26\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0G\0" +\
    "\0\0\303\16\2\4\377d\12\5\377\247\20\5\377\311\23\5\377\343\26\6\377" +\
    "\362\27\7\377\372\27\7\377\375\27\6\377\376\26\6\377\377\24\5\377\376" +\
    "\24\5\377\377\22\3\377\377\23\4\377\377\21\4\377\377\21\2\377\377\21" +\
    "\3\377\377\20\2\377\377\20\3\377\377\20\2\377\377\17\1\377\377\17\1\377" +\
    "\377\17\2\377\377\17\2\377\377\17\2\377\377\17\1\377\377\20\1\377\377" +\
    "\20\3\377\377\17\2\377\377\21\3\377\377\20\3\377\377\20\3\377\377\21" +\
    "\2\377\375\22\4\377\373\23\3\377\365\24\5\377\350\24\4\377\323\22\6\377" +\
    "\257\17\4\377\220R\3\377\351\325\3\377\376\344\4\377\375\341\4\377\375" +\
    "\341\4\377\375\341\3\377\375\340\3\377\375\340\3\377\375\337\3\377\375" +\
    "\336\2\377\375\336\3\377\375\336\3\377\375\336\2\377\375\337\2\377\375" +\
    "\337\3\377\375\336\2\377\375\336\3\377\375\336\3\377\375\337\3\377\375" +\
    "\337\3\377\375\341\3\377\375\341\4\377\375\341\3\377\375\342\4\377\375" +\
    "\342\3\377\375\343\5\377\375\343\5\377\375\343\5\377\374\344\5\377\375" +\
    "\346\5\377\374\346\5\377\374\346\6\377\373\346\5\377\373\346\6\377\371" +\
    "\345\7\377\370\346\7\377\367\344\10\377\366\345\10\377\367\345\7\377" +\
    "\366\346\10\377\367\346\11\377\370\350\10\377\372\352\12\377\373\354" +\
    "\12\377\374\355\12\377\374\355\11\377\362\344\12\377\332\317\11\377\262" +\
    "\253\7\377[U\4\377\0\0\0\376\0\0\0\312\0\0\0L\0\0\0\13\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0+\0\0\0\256" +\
    ";\7\64\3773\3#\377g\12\5\377\243\20\4\377\305\23\5\377\340\25\6\377\360" +\
    "\26\7\377\371\27\6\377\375\27\6\377\375\25\5\377\376\24\5\377\377\24" +\
    "\5\377\376\23\4\377\377\23\4\377\377\21\3\377\377\21\3\377\377\21\3\377" +\
    "\377\21\3\377\377\20\3\377\377\20\3\377\377\20\3\377\377\20\2\377\377" +\
    "\20\1\377\377\20\2\377\377\21\2\377\377\20\3\377\377\21\2\377\377\21" +\
    "\2\377\377\21\3\377\377\21\3\377\377\22\3\377\376\22\3\377\373\23\4\377" +\
    "\367\23\5\377\353\22\4\377\331\23\5\377\274\20\5\377\2136\3\377\316\266" +\
    "\3\377\374\344\4\377\374\343\4\377\375\343\4\377\375\341\4\377\375\341" +\
    "\3\377\375\340\3\377\375\340\3\377\375\340\3\377\375\340\3\377\375\340" +\
    "\2\377\375\340\1\377\375\337\2\377\375\337\1\377\375\336\1\377\375\340" +\
    "\3\377\375\340\3\377\375\340\3\377\375\340\3\377\375\340\3\377\375\341" +\
    "\2\377\375\340\2\377\375\341\4\377\375\343\4\377\375\344\3\377\375\344" +\
    "\4\377\375\344\5\377\375\344\5\377\375\345\4\377\375\346\6\377\375\346" +\
    "\6\377\375\347\6\377\375\350\6\377\375\351\7\377\374\350\7\377\374\351" +\
    "\6\377\374\352\10\377\374\352\10\377\374\353\7\377\374\353\10\377\375" +\
    "\354\11\377\375\355\10\377\375\356\11\377\375\356\12\377\375\355\12\377" +\
    "\372\353\11\377\355\341\12\377\316\304\11\377\244\234\7\377)&\2\377\0" +\
    "\0\0\376\0\0\0\242\0\0\0\60\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0\64\12\3\11\310m\7^\376\201\11" +\
    "q\3776\5'\377a\11\5\377\240\17\3\377\301\22\5\377\332\25\6\377\354\25" +\
    "\6\377\366\27\6\377\373\26\6\377\375\25\5\377\375\25\5\377\377\25\5\377" +\
    "\377\24\4\377\377\23\3\377\377\23\4\377\377\23\3\377\377\23\3\377\377" +\
    "\22\3\377\377\22\3\377\377\22\2\377\377\22\2\377\377\22\3\377\377\21" +\
    "\2\377\377\21\2\377\377\22\3\377\377\23\4\377\377\23\4\377\376\23\4\377" +\
    "\376\23\4\377\375\24\3\377\373\25\4\377\367\24\5\377\356\23\5\377\334" +\
    "\23\5\377\305\17\4\377\216\32\2\377\273\242\3\377\371\341\4\377\375\344" +\
    "\4\377\375\343\4\377\375\343\4\377\375\343\3\377\375\341\3\377\375\341" +\
    "\3\377\375\341\3\377\375\340\3\377\375\337\2\377\375\340\2\377\375\340" +\
    "\2\377\375\340\2\377\375\337\2\377\375\337\2\377\375\340\1\377\375\337" +\
    "\2\377\375\340\3\377\375\341\3\377\375\341\3\377\375\340\3\377\375\342" +\
    "\3\377\375\342\4\377\375\343\4\377\375\344\3\377\375\344\4\377\375\345" +\
    "\5\377\375\344\5\377\375\346\4\377\375\346\6\377\375\347\6\377\375\350" +\
    "\6\377\375\350\6\377\375\351\7\377\375\351\7\377\375\351\7\377\375\353" +\
    "\7\377\375\354\10\377\375\355\7\377\376\355\10\377\375\355\11\377\376" +\
    "\355\11\377\376\357\11\377\375\356\12\377\373\355\12\377\366\351\12\377" +\
    "\347\332\12\377\304\272\10\377\217\207\7\377\12\6\0\377\0\0\0\376\0\0" +\
    "\0\201\0\0\0\35\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\10\0\0\0R\37\5\33\347\212\6w\377\243\12\215\377" +\
    "\220\11~\377\77\4\64\377K\7\10\377\226\17\3\377\265\21\4\377\320\22\6" +\
    "\377\344\24\5\377\357\25\6\377\366\26\6\377\374\27\5\377\375\25\6\377" +\
    "\376\26\5\377\376\24\5\377\376\24\4\377\377\24\4\377\377\22\4\377\377" +\
    "\22\3\377\377\23\4\377\377\23\4\377\377\23\4\377\377\23\4\377\377\23" +\
    "\4\377\377\23\4\377\377\22\3\377\377\22\4\377\377\22\3\377\376\24\3\377" +\
    "\375\24\5\377\373\25\5\377\367\25\4\377\357\24\5\377\336\22\4\377\306" +\
    "\22\4\377\230\27\3\377\245\202\3\377\367\341\4\377\375\345\4\377\375" +\
    "\343\4\377\375\344\4\377\375\343\4\377\375\342\3\377\375\342\3\377\375" +\
    "\341\3\377\375\340\3\377\375\341\2\377\375\341\2\377\375\337\1\377\375" +\
    "\337\2\377\375\340\2\377\375\340\2\377\375\337\2\377\375\337\1\377\375" +\
    "\340\2\377\375\341\3\377\375\340\3\377\375\341\3\377\375\342\3\377\375" +\
    "\341\3\377\375\343\4\377\375\344\4\377\375\343\3\377\375\345\5\377\375" +\
    "\344\5\377\375\344\5\377\375\346\4\377\375\346\6\377\375\350\6\377\375" +\
    "\350\6\377\375\351\6\377\375\350\7\377\375\351\7\377\375\351\6\377\375" +\
    "\353\10\377\374\353\10\377\375\355\7\377\376\355\10\377\376\356\11\377" +\
    "\376\355\11\377\376\357\11\377\375\356\12\377\372\354\12\377\361\344" +\
    "\12\377\336\322\12\377\273\264\7\377kT\6\377\20\0\0\377\0\0\0\376\0\0" +\
    "\0u\0\0\0\25\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\17\0\0\0w\77\7\67\367\237\7\211\377\267\11\240\377" +\
    "\257\11\231\377\231\10\207\377Z\4O\3771\4\12\377|\14\4\377\245\21\5\377" +\
    "\300\22\5\377\326\23\5\377\345\25\6\377\360\27\6\377\366\25\5\377\373" +\
    "\26\4\377\374\26\6\377\376\26\4\377\376\24\3\377\377\23\3\377\377\23" +\
    "\3\377\376\22\4\377\377\24\3\377\377\24\3\377\377\24\4\377\377\24\3\377" +\
    "\376\24\4\377\377\23\4\377\377\23\3\377\376\24\3\377\375\25\5\377\373" +\
    "\26\5\377\365\26\6\377\354\25\5\377\337\23\4\377\310\22\5\377\236\25" +\
    "\3\377\225l\2\377\360\334\3\377\375\345\5\377\374\345\4\377\375\345\4" +\
    "\377\375\343\4\377\375\343\4\377\375\342\3\377\375\342\3\377\375\342" +\
    "\3\377\375\341\3\377\375\340\3\377\375\340\2\377\375\340\1\377\375\340" +\
    "\2\377\375\337\2\377\375\337\2\377\375\341\2\377\375\340\1\377\375\340" +\
    "\2\377\375\340\3\377\375\341\3\377\375\341\3\377\375\343\2\377\375\342" +\
    "\2\377\375\343\4\377\375\344\4\377\375\344\4\377\375\345\4\377\375\345" +\
    "\5\377\375\345\5\377\375\346\4\377\375\350\6\377\375\347\6\377\375\351" +\
    "\6\377\375\350\6\377\375\351\7\377\375\351\7\377\375\352\6\377\375\353" +\
    "\10\377\375\354\10\377\375\354\7\377\376\355\10\377\376\356\11\377\376" +\
    "\355\11\377\376\357\11\377\374\355\12\377\370\351\11\377\352\335\12\377" +\
    "\322\310\10\377\245\236\10\377n%\5\3779\4\2\377\1\0\0\376\0\0\0\200\0" +\
    "\0\0\33\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\25\0\0\0\215X\3M\375\256\7\230\377\314\11\263\377\305\11" +\
    "\255\377\264\10\236\377\237\6\214\377p\4d\3775\1\42\377P\10\6\377\224" +\
    "\17\3\377\257\21\4\377\303\21\4\377\326\23\5\377\343\24\6\377\354\25" +\
    "\6\377\363\26\5\377\370\26\5\377\373\25\5\377\374\26\5\377\375\24\4\377" +\
    "\377\25\4\377\377\24\4\377\377\24\4\377\377\24\4\377\377\24\4\377\377" +\
    "\25\4\377\376\25\4\377\374\25\5\377\373\25\4\377\370\26\5\377\363\26" +\
    "\6\377\352\26\6\377\334\24\4\377\313\22\5\377\235\15\3\377\217a\3\377" +\
    "\344\320\3\377\375\346\5\377\374\345\4\377\375\344\4\377\375\344\4\377" +\
    "\375\345\4\377\375\343\4\377\375\343\2\377\375\343\2\377\375\343\3\377" +\
    "\375\341\3\377\375\341\3\377\375\341\2\377\375\340\1\377\375\340\2\377" +\
    "\375\341\2\377\375\341\2\377\375\340\2\377\375\340\1\377\375\341\2\377" +\
    "\375\341\3\377\375\341\3\377\375\342\3\377\375\343\3\377\375\343\3\377" +\
    "\375\343\4\377\375\344\4\377\375\344\3\377\375\345\5\377\375\345\5\377" +\
    "\375\346\5\377\375\347\4\377\375\347\6\377\375\350\6\377\375\351\6\377" +\
    "\375\351\5\377\375\351\7\377\375\352\7\377\375\352\6\377\374\353\10\377" +\
    "\376\355\10\377\376\355\7\377\376\355\10\377\376\355\11\377\375\356\11" +\
    "\377\374\356\11\377\372\354\12\377\361\344\12\377\342\325\11\377\306" +\
    "\276\7\377\212n\10\377\220\23\6\377Y\11\4\377\1\0\0\376\0\0\0\226\0\0" +\
    "\0'\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\31\0\0\0\230c\4W\377\272\10\243\377\335\10\302\377\334\10\302" +\
    "\377\313\10\265\377\272\3\247\377\202\10t\377W\25\62\377\77\35\35\377" +\
    "-\14\13\377^\12\3\377\222\16\3\377\254\20\4\377\276\20\4\377\315\23\5" +\
    "\377\331\23\5\377\344\25\4\377\354\25\6\377\361\26\6\377\365\26\6\377" +\
    "\367\26\6\377\370\26\6\377\371\26\5\377\371\26\6\377\371\26\6\377\367" +\
    "\26\6\377\367\26\6\377\365\26\6\377\360\26\5\377\352\25\5\377\342\24" +\
    "\5\377\325\23\6\377\277\21\5\377\221\15\3\377\225n\3\377\354\333\4\377" +\
    "\374\350\5\377\375\346\4\377\375\346\5\377\375\346\4\377\375\346\3\377" +\
    "\375\345\4\377\375\345\3\377\375\344\4\377\375\344\3\377\375\343\3\377" +\
    "\375\343\3\377\375\343\3\377\375\342\3\377\375\342\2\377\375\342\2\377" +\
    "\375\341\1\377\375\341\2\377\375\342\2\377\375\342\3\377\375\342\3\377" +\
    "\375\342\3\377\375\343\3\377\375\343\3\377\375\343\3\377\375\344\4\377" +\
    "\375\343\4\377\375\345\4\377\375\345\3\377\375\345\5\377\375\347\5\377" +\
    "\375\347\5\377\375\350\4\377\375\350\6\377\375\351\6\377\375\351\5\377" +\
    "\374\351\7\377\375\353\6\377\375\353\7\377\375\352\6\377\374\354\10\377" +\
    "\376\355\10\377\376\356\7\377\376\356\10\377\375\356\11\377\375\356\10" +\
    "\377\373\355\11\377\366\350\11\377\351\334\10\377\324\311\10\377\260" +\
    "\251\7\377\207.\7\377\263\23\10\377q\16\5\377\1\0\0\376\0\0\0\256\0\0" +\
    "\0\63\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\33\0\0\0\233g\4Y\377\301\10\250\377\350\12\315\377\361\10" +\
    "\324\377\305\7\262\377~\36W\377\206C@\377\227a^\377\225ee\377\202WW\377" +\
    "J10\3771\21\20\377Q\11\3\377\200\14\2\377\235\16\3\377\256\20\4\377\274" +\
    "\21\4\377\311\22\5\377\325\24\4\377\336\24\4\377\344\25\5\377\350\25" +\
    "\5\377\351\25\5\377\351\25\5\377\351\25\5\377\350\25\5\377\345\25\6\377" +\
    "\341\24\5\377\333\24\4\377\322\24\5\377\307\22\4\377\260\20\4\377\202" +\
    "!\3\377\231w\3\377\357\337\4\377\376\351\6\377\375\350\4\377\375\350" +\
    "\5\377\375\350\5\377\375\346\5\377\375\345\3\377\375\345\4\377\375\344" +\
    "\4\377\375\345\4\377\375\344\3\377\375\343\2\377\375\344\3\377\375\344" +\
    "\3\377\375\342\3\377\375\342\3\377\375\342\3\377\375\342\2\377\375\342" +\
    "\3\377\375\342\3\377\375\342\3\377\375\343\3\377\375\344\3\377\375\344" +\
    "\3\377\375\343\3\377\375\344\3\377\375\344\4\377\375\344\4\377\375\345" +\
    "\4\377\375\345\3\377\375\346\5\377\375\347\5\377\375\350\5\377\375\347" +\
    "\4\377\375\350\6\377\375\350\6\377\375\351\5\377\375\351\7\377\374\352" +\
    "\7\377\375\352\7\377\374\353\6\377\375\354\10\377\376\355\10\377\376" +\
    "\356\10\377\375\356\10\377\375\355\11\377\374\355\11\377\371\352\12\377" +\
    "\357\342\11\377\336\323\11\377\307\300\7\377\212e\11\377\300\24\7\377" +\
    "\277\27\10\377\177\17\5\377\1\0\0\376\0\0\0\275\0\0\0>\0\0\0\5\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\33\0\0\0" +\
    "\233g\4Z\377\304\10\253\377\354\10\321\377\262\22\233\377\223@B\377\300" +\
    "xt\377\310\205\204\377\305\200\177\377\275{z\377\262sr\377\246kj\377" +\
    "\215\134[\377X:9\377*\27\27\3777\12\11\377d\12\4\377\204\14\4\377\227" +\
    "\16\2\377\252\17\3\377\272\20\4\377\306\22\4\377\315\22\4\377\321\22" +\
    "\4\377\323\23\4\377\323\22\4\377\320\22\4\377\315\22\4\377\310\22\5\377" +\
    "\276\20\4\377\255\20\3\377\231\26\4\377}<\3\377\301\256\5\377\364\342" +\
    "\5\377\374\352\6\377\375\350\6\377\375\350\4\377\375\347\5\377\375\350" +\
    "\5\377\375\347\4\377\375\346\5\377\375\345\3\377\375\346\4\377\375\345" +\
    "\4\377\375\345\4\377\375\344\3\377\375\344\2\377\375\344\3\377\375\344" +\
    "\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375\344" +\
    "\3\377\375\343\3\377\375\344\3\377\375\344\2\377\375\344\2\377\375\344" +\
    "\3\377\375\345\3\377\375\345\4\377\375\345\4\377\375\346\4\377\375\347" +\
    "\4\377\375\347\5\377\375\347\5\377\375\350\4\377\375\350\5\377\375\351" +\
    "\5\377\375\352\6\377\375\351\5\377\375\352\7\377\375\353\7\377\375\353" +\
    "\7\377\375\354\7\377\375\355\10\377\376\356\10\377\375\356\10\377\375" +\
    "\356\11\377\374\355\10\377\372\353\11\377\363\346\10\377\346\331\11\377" +\
    "\317\304\7\377\242\235\7\377\246%\10\377\343\30\11\377\300\27\10\377" +\
    "\206\21\6\377\1\0\0\377\0\0\0\305\0\0\0C\0\0\0\6\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\33\0\0\0\233g\4Y\377\274" +\
    "\6\245\377\214\36h\377\270XR\377\332\215\214\377\351\223\221\377\354" +\
    "\225\223\377\345\220\216\377\332\211\207\377\316\201\200\377\302yx\377" +\
    "\267qp\377\254kj\377\236ba\377\210TS\377]::\377-\30\30\377-\15\14\377" +\
    "J\10\5\377f\16\4\377\212\13\4\377\227\15\3\377\235\16\3\377\237\14\4" +\
    "\377\237\16\3\377\236\15\3\377\226\15\4\377~\26\3\377\202=\4\377\235" +\
    "{\4\377\303\267\6\377\360\343\6\377\375\353\6\377\375\352\6\377\375\351" +\
    "\6\377\375\352\5\377\375\350\5\377\375\351\4\377\375\351\5\377\375\350" +\
    "\5\377\375\350\5\377\375\346\3\377\375\345\4\377\375\346\4\377\375\346" +\
    "\4\377\375\346\4\377\375\345\2\377\375\344\2\377\375\344\3\377\375\344" +\
    "\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375\344\3\377\375\344" +\
    "\3\377\375\345\3\377\375\345\3\377\375\344\4\377\375\345\3\377\375\346" +\
    "\4\377\375\346\4\377\375\346\4\377\375\347\4\377\375\347\5\377\375\351" +\
    "\5\377\375\351\5\377\375\351\4\377\375\350\6\377\375\352\6\377\375\352" +\
    "\6\377\375\352\6\377\375\352\6\377\374\352\7\377\375\354\7\377\376\354" +\
    "\7\377\376\355\7\377\376\356\11\377\375\356\11\377\374\355\11\377\374" +\
    "\355\10\377\367\351\11\377\354\337\11\377\327\313\7\377\276\266\7\377" +\
    "\210L\10\377\342\25\11\377\351\33\12\377\302\30\11\377\210\20\6\377\1" +\
    "\0\0\377\1\0\0\311\0\0\0E\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\34\0\0\0\233T\3K\376}\37J\377\276ZV\377" +\
    "\345\214\212\377\365\223\222\377\373\226\225\377\371\226\225\377\365" +\
    "\223\222\377\356\215\214\377\346\211\210\377\334\203\202\377\323||\377" +\
    "\311vv\377\277pp\377\266ll\377\255hh\377\236aa\377\210UU\377f@@\377\35" +\
    "\24\15\377ec\4\377\215\211\4\377\250\244\6\377\272\265\7\377\301\272" +\
    "\6\377\305\276\6\377\313\304\6\377\332\321\7\377\356\341\10\377\373\354" +\
    "\7\377\376\356\7\377\376\355\7\377\375\353\7\377\374\352\6\377\375\352" +\
    "\6\377\375\352\6\377\375\351\5\377\375\350\4\377\375\351\5\377\375\351" +\
    "\5\377\375\347\5\377\375\347\4\377\375\346\4\377\375\345\4\377\375\345" +\
    "\4\377\375\345\4\377\375\345\3\377\375\345\3\377\375\345\3\377\375\345" +\
    "\3\377\375\345\3\377\375\345\3\377\375\344\3\377\375\346\2\377\375\345" +\
    "\3\377\375\345\2\377\375\345\4\377\375\345\4\377\375\345\4\377\375\345" +\
    "\4\377\375\345\4\377\375\346\3\377\375\350\5\377\375\347\5\377\375\351" +\
    "\5\377\375\351\5\377\375\350\4\377\375\351\6\377\375\352\6\377\375\351" +\
    "\6\377\375\352\6\377\374\352\7\377\375\353\7\377\375\354\7\377\376\354" +\
    "\7\377\375\355\7\377\375\356\11\377\375\356\11\377\374\355\11\377\367" +\
    "\350\11\377\357\341\11\377\336\321\10\377\303\272\6\377\221w\10\377\310" +\
    "\26\7\377\372\32\12\377\350\33\12\377\302\30\11\377\211\21\6\377\1\0" +\
    "\0\377\1\0\0\313\0\0\0F\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\2\0\0\0.\0\0\0\266N\26\35\377\265D@\377\342\204" +\
    "\203\377\370\217\215\377\375\222\220\377\376\223\221\377\375\221\220" +\
    "\377\374\217\216\377\372\216\215\377\365\212\212\377\360\210\207\377" +\
    "\351\203\203\377\343\200\177\377\333{{\377\322xx\377\311xx\377\275{{" +\
    "\377\257yy\377\241on\377qII\3775,\12\377\227\217\5\377\303\270\6\377" +\
    "\343\325\10\377\364\346\11\377\375\356\11\377\376\357\11\377\376\357" +\
    "\11\377\376\356\10\377\376\356\10\377\376\355\7\377\376\354\6\377\375" +\
    "\354\7\377\375\353\6\377\375\353\5\377\375\352\6\377\375\352\6\377\375" +\
    "\352\6\377\375\351\4\377\375\350\5\377\375\351\5\377\375\350\4\377\375" +\
    "\347\4\377\375\347\3\377\375\347\4\377\375\346\4\377\375\346\4\377\375" +\
    "\346\4\377\375\346\3\377\375\346\3\377\375\345\3\377\375\345\3\377\375" +\
    "\346\3\377\375\345\4\377\375\345\3\377\375\345\4\377\375\346\3\377\375" +\
    "\346\4\377\375\346\4\377\375\347\4\377\375\346\4\377\375\347\3\377\375" +\
    "\350\5\377\375\351\5\377\375\350\5\377\375\351\4\377\375\351\5\377\375" +\
    "\352\6\377\375\352\6\377\375\353\6\377\374\353\6\377\374\354\7\377\374" +\
    "\355\7\377\375\354\6\377\376\356\10\377\376\356\10\377\374\355\11\377" +\
    "\374\355\11\377\371\351\11\377\361\344\11\377\343\326\10\377\316\304" +\
    "\7\377\244\227\6\377\240&\7\377\366\31\11\377\372\31\11\377\350\32\12" +\
    "\377\302\27\7\377\210\20\5\377\1\0\0\377\1\0\0\313\0\0\0F\0\0\0\7\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0x\66\21" +\
    "\21\361\245'#\377\331tr\377\364\205\203\377\375\211\210\377\376\212\211" +\
    "\377\376\212\210\377\377\210\207\377\376\210\207\377\375\210\207\377" +\
    "\374\207\206\377\372\205\204\377\367\203\202\377\364\201\200\377\357" +\
    "\177\200\377\352\202\202\377\342\214\214\377\327\235\235\377\307\245" +\
    "\244\377\263\223\223\377\237qq\377W45\377IB\7\377\240\231\5\377\305\273" +\
    "\7\377\342\326\10\377\364\346\10\377\372\353\11\377\375\356\11\377\376" +\
    "\357\11\377\376\355\7\377\376\356\10\377\376\356\10\377\374\355\7\377" +\
    "\375\353\7\377\375\353\6\377\375\352\6\377\375\352\6\377\375\352\5\377" +\
    "\375\352\5\377\375\352\4\377\375\351\5\377\375\351\5\377\375\351\5\377" +\
    "\375\347\4\377\375\346\4\377\375\346\4\377\375\347\4\377\375\346\4\377" +\
    "\375\345\4\377\375\345\4\377\375\346\4\377\375\346\4\377\375\345\4\377" +\
    "\375\346\4\377\375\347\4\377\375\347\4\377\375\347\4\377\375\347\4\377" +\
    "\375\346\4\377\375\346\4\377\375\350\4\377\375\350\4\377\375\351\4\377" +\
    "\375\351\5\377\375\351\4\377\375\352\6\377\375\352\5\377\375\351\6\377" +\
    "\374\353\5\377\375\353\6\377\375\354\7\377\376\355\7\377\376\355\7\377" +\
    "\376\355\7\377\376\355\7\377\375\356\10\377\374\355\10\377\371\352\11" +\
    "\377\363\346\7\377\345\330\7\377\321\307\7\377\257\251\7\377\222:\6\377" +\
    "\354\25\10\377\376\33\12\377\371\31\12\377\350\32\12\377\301\27\7\377" +\
    "\207\17\5\377\1\0\0\377\1\0\0\313\0\0\0F\0\0\0\7\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0Q!\14\14\336\220\30\25\377\315" +\
    "FD\376\356|z\377\373\200\177\377\375\201\200\377\377\201\200\377\377" +\
    "\200\177\377\377\200\177\377\376\177\177\377\377\177~\377\376~}\377\376" +\
    "~}\377\375}}\377\374{{\377\372z|\377\367\202\204\377\362\232\233\377" +\
    "\352\274\275\377\334\321\321\377\310\274\274\377\262\213\213\377\233" +\
    "__\377A#!\377_W\6\377\244\233\5\377\311\276\7\377\344\330\7\377\363\345" +\
    "\10\377\372\353\11\377\374\355\11\377\375\356\7\377\376\356\10\377\376" +\
    "\356\10\377\375\355\7\377\375\354\6\377\375\354\6\377\375\352\5\377\375" +\
    "\353\6\377\375\353\6\377\375\352\6\377\375\351\4\377\375\352\5\377\375" +\
    "\351\5\377\375\351\5\377\375\351\5\377\375\351\4\377\375\350\4\377\375" +\
    "\346\4\377\375\347\4\377\375\347\4\377\375\347\4\377\375\346\4\377\375" +\
    "\346\4\377\375\347\4\377\375\346\4\377\375\346\4\377\375\346\4\377\375" +\
    "\347\4\377\375\347\4\377\375\347\3\377\375\350\4\377\375\350\5\377\375" +\
    "\350\5\377\375\352\5\377\375\352\5\377\375\351\5\377\375\352\6\377\375" +\
    "\353\6\377\375\352\6\377\375\352\6\377\374\354\7\377\376\354\6\377\376" +\
    "\354\7\377\376\355\10\377\376\356\10\377\375\356\7\377\374\355\11\377" +\
    "\371\352\10\377\363\345\7\377\347\332\10\377\323\307\10\377\267\257\7" +\
    "\377\222V\10\377\332\20\7\377\377\31\11\377\377\32\11\377\371\31\12\377" +\
    "\347\32\11\377\300\27\7\377\206\17\5\377\1\0\0\377\1\0\0\312\0\0\0F\0" +\
    "\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0/\11\4\4\272" +\
    "t\25\24\376\277\36\34\377\347][\377\371yw\377\375{y\377\376yw\377\376" +\
    "yw\377\377xw\377\377ww\377\377wv\377\377vu\377\377uu\377\376tt\377\377" +\
    "rs\377\376qr\377\376rt\377\375z}\377\372\225\227\377\365\277\277\377" +\
    "\354\333\333\377\333\311\312\377\305\224\224\377\256bd\377\216CD\377" +\
    "9\35\26\377f_\5\377\247\236\6\377\314\300\7\377\344\330\7\377\363\345" +\
    "\10\377\371\352\11\377\374\355\10\377\375\356\10\377\376\355\10\377\376" +\
    "\355\10\377\375\355\6\377\374\354\6\377\374\354\6\377\375\353\6\377\375" +\
    "\352\5\377\375\352\6\377\375\352\5\377\375\351\4\377\375\352\5\377\375" +\
    "\352\5\377\375\352\5\377\375\351\5\377\375\351\5\377\375\351\4\377\375" +\
    "\351\4\377\375\350\3\377\375\350\4\377\375\350\4\377\375\350\4\377\375" +\
    "\350\4\377\375\350\4\377\375\351\3\377\375\350\3\377\375\350\4\377\375" +\
    "\351\4\377\375\351\4\377\375\351\4\377\375\352\5\377\375\352\5\377\375" +\
    "\351\4\377\375\352\5\377\375\352\5\377\374\352\6\377\374\352\6\377\375" +\
    "\353\6\377\374\354\7\377\376\354\7\377\375\355\6\377\376\356\10\377\376" +\
    "\356\10\377\375\356\10\377\374\355\7\377\371\351\11\377\363\345\7\377" +\
    "\347\332\10\377\325\311\7\377\272\262\6\377\222`\6\377\310\22\6\377\376" +\
    "\30\11\377\377\31\11\377\377\32\12\377\371\32\11\377\344\32\11\377\275" +\
    "\26\7\377\177\17\4\377\2\0\0\377\0\0\0\307\0\0\0D\0\0\0\7\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0|I\17\17\370\256\33\30\377\336" +\
    "&#\376\365c`\377\375rp\377\376qo\377\377po\377\377po\377\377on\377\377" +\
    "on\377\377on\377\377mm\377\377jk\377\377hi\377\377fh\377\375dg\377\375" +\
    "dg\377\375jm\377\375}\201\377\372\234\240\377\364\264\266\377\352\252" +\
    "\254\377\330\203\205\377\300[]\377\252EG\377\20425\3778\34\21\377mg\5" +\
    "\377\252\241\5\377\313\300\6\377\343\326\10\377\362\344\7\377\371\352" +\
    "\11\377\374\355\7\377\376\356\10\377\375\355\7\377\375\356\7\377\375" +\
    "\355\6\377\376\353\7\377\374\353\6\377\375\353\6\377\375\352\5\377\375" +\
    "\353\6\377\375\353\6\377\375\351\4\377\375\352\5\377\375\351\5\377\374" +\
    "\351\4\377\375\351\4\377\375\351\5\377\375\351\4\377\375\351\4\377\375" +\
    "\351\3\377\375\351\3\377\375\350\4\377\375\350\3\377\375\350\3\377\375" +\
    "\350\4\377\375\350\4\377\375\351\4\377\375\351\5\377\375\351\5\377\375" +\
    "\351\5\377\375\352\5\377\375\351\5\377\375\353\5\377\375\352\5\377\375" +\
    "\353\6\377\375\352\5\377\374\352\5\377\374\354\7\377\374\353\6\377\376" +\
    "\355\6\377\374\355\10\377\376\355\10\377\376\356\10\377\374\355\7\377" +\
    "\371\352\11\377\363\344\7\377\346\332\7\377\326\312\7\377\276\271\5\377" +\
    "\216f\10\377\301\24\6\377\374\26\10\377\377\27\10\377\376\31\11\377\375" +\
    "\32\12\377\367\33\12\377\341\30\11\377\271\25\7\377r\15\5\377\2\0\0\377" +\
    "\0\0\0\300\0\0\0\77\0\0\0\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\0\0\0" +\
    "\77\27\7\7\327\220\23\22\376\316 \35\377\357)&\377\373^Z\377\376kh\377" +\
    "\377jg\377\360e_\377\333\134X\377\300OV\377\260FZ\377\257EZ\377\257D" +\
    "X\377\257CX\377\267ET\377\317MQ\377\344SQ\377\374UW\377\377Z`\377\376" +\
    "bh\377\375rx\377\372~\204\377\363y\177\377\351em\377\324PT\377\276AF" +\
    "\377\2518;\377\202+.\377;\34\17\377ha\5\377\245\234\6\377\306\274\6\377" +\
    "\341\323\7\377\360\342\10\377\370\352\7\377\374\355\10\377\375\356\10" +\
    "\377\375\356\10\377\375\355\7\377\375\354\7\377\375\354\7\377\374\353" +\
    "\6\377\375\353\6\377\374\352\6\377\375\352\5\377\375\353\6\377\375\351" +\
    "\4\377\374\352\4\377\375\352\5\377\375\351\5\377\375\351\5\377\375\351" +\
    "\5\377\375\352\5\377\375\351\5\377\375\350\5\377\375\352\3\377\375\352" +\
    "\5\377\375\352\5\377\375\352\4\377\375\352\5\377\375\352\5\377\375\352" +\
    "\5\377\375\351\5\377\375\352\5\377\375\351\5\377\375\352\4\377\375\352" +\
    "\5\377\375\353\6\377\375\352\5\377\375\354\7\377\375\354\7\377\375\353" +\
    "\6\377\376\354\7\377\375\355\6\377\375\356\10\377\375\356\10\377\373" +\
    "\354\10\377\367\351\7\377\360\342\10\377\345\330\10\377\322\307\7\377" +\
    "\273\263\6\377\213a\7\377\302\23\6\377\373\24\7\377\377\26\7\377\377" +\
    "\27\10\377\376\31\11\377\375\32\12\377\364\33\12\377\332\30\10\377\262" +\
    "\25\7\377X\10\3\377\0\0\0\376\0\0\0\263\0\0\0\67\0\0\0\4\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\26\1\0\0\207S\16\16\374\267\30\26\376\345%!\377" +\
    "\373)%\377\367JD\377\316RR\377\252C_\377\244Cz\377\253O\224\377\272^" +\
    "\251\377\301c\264\377\303d\266\377\304d\266\377\302d\266\377\275`\260" +\
    "\377\263Q\237\377\246@\206\377\2447h\377\272<O\377\345HL\377\377RY\377" +\
    "\375W`\377\372U]\377\362NV\377\346EM\377\323>D\377\2756;\377\25105\377" +\
    "\205%)\377;\30\17\377bZ\5\377\240\230\5\377\302\267\6\377\334\317\7\377" +\
    "\354\337\10\377\366\347\10\377\372\353\7\377\375\354\10\377\374\355\7" +\
    "\377\376\355\6\377\376\354\7\377\376\353\7\377\375\353\7\377\375\353" +\
    "\6\377\375\353\5\377\375\353\5\377\375\352\6\377\374\352\6\377\375\353" +\
    "\5\377\375\353\5\377\375\353\5\377\375\352\5\377\375\352\5\377\375\352" +\
    "\5\377\375\352\4\377\375\352\5\377\375\352\4\377\375\352\5\377\375\352" +\
    "\5\377\375\352\4\377\375\352\4\377\374\352\5\377\375\353\5\377\375\353" +\
    "\5\377\375\353\5\377\375\352\6\377\375\352\6\377\375\353\5\377\374\354" +\
    "\6\377\376\353\7\377\375\353\7\377\375\354\7\377\376\355\6\377\375\355" +\
    "\10\377\374\354\7\377\372\353\10\377\366\347\10\377\355\340\7\377\342" +\
    "\325\7\377\320\305\6\377\266\256\7\377\215[\6\377\310\21\4\377\375\24" +\
    "\6\377\377\26\10\377\376\26\10\377\377\27\10\377\376\30\10\377\374\32" +\
    "\11\377\360\32\11\377\321\30\10\377\246\23\6\3777\6\1\377\1\0\0\376\0" +\
    "\0\0\234\0\0\0+\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\09\25\5\5\321" +\
    "\225\15\15\376\322\32\30\377\360#\36\377\312%(\377\2419^\377\256[\235" +\
    "\377\310|\277\377\332\223\321\377\346\236\333\377\354\244\341\377\357" +\
    "\247\344\377\360\250\346\377\361\250\346\377\360\250\346\377\355\246" +\
    "\343\377\351\241\336\377\341\230\327\377\321\204\311\377\273a\256\377" +\
    "\242@\200\377\2565O\377\351=D\377\377@K\377\371\77I\377\362<E\377\345" +\
    "7A\377\3233<\377\276/6\377\252*/\377\207!%\377\77\24\17\377RJ\4\377\231" +\
    "\222\4\377\273\260\5\377\323\311\7\377\350\332\7\377\362\344\10\377\371" +\
    "\352\10\377\374\354\7\377\375\356\7\377\376\355\6\377\376\355\7\377\375" +\
    "\355\7\377\375\355\7\377\375\354\6\377\375\353\6\377\375\354\5\377\374" +\
    "\353\6\377\375\353\6\377\374\353\6\377\375\352\6\377\375\352\6\377\374" +\
    "\353\5\377\375\353\5\377\375\353\5\377\375\353\5\377\374\352\5\377\375" +\
    "\352\5\377\374\352\5\377\375\353\6\377\374\352\6\377\375\352\6\377\375" +\
    "\352\6\377\375\353\6\377\374\353\6\377\375\353\6\377\374\354\5\377\375" +\
    "\354\6\377\375\354\7\377\375\355\7\377\376\355\7\377\375\355\7\377\374" +\
    "\354\10\377\373\354\7\377\370\351\7\377\363\344\7\377\351\336\10\377" +\
    "\334\320\10\377\316\303\6\377\253\250\5\377\213I\6\377\314\20\3\377\375" +\
    "\24\6\377\376\26\6\377\377\26\10\377\377\26\10\377\377\30\10\377\375" +\
    "\31\10\377\372\32\11\377\351\31\11\377\306\26\10\377\225\21\5\377\25" +\
    "\1\0\377\1\0\0\376\0\0\0~\0\0\0\35\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\16\0\0\0m<\11\11\374\262\20\16\377\322\30\24\377\240*C\377\255]\235" +\
    "\377\322\210\311\377\345\230\332\377\361\237\345\377\367\242\352\377" +\
    "\373\245\356\377\374\245\357\377\376\247\361\377\376\247\361\377\376" +\
    "\247\362\377\375\247\361\377\375\246\360\377\374\245\357\377\372\244" +\
    "\354\377\364\241\351\377\354\235\340\377\335\222\323\377\302j\271\377" +\
    "\2337w\377\3040;\377\3734@\377\3714\77\377\3622=\377\346/9\377\324,5" +\
    "\377\300(/\377\253$*\377\223\37$\377P\21\22\377A5\6\377\207\177\4\377" +\
    "\255\244\5\377\311\275\6\377\337\322\7\377\354\336\10\377\366\347\10" +\
    "\377\372\353\10\377\374\355\6\377\374\356\6\377\376\356\6\377\375\355" +\
    "\7\377\376\354\7\377\376\355\6\377\375\354\7\377\374\353\5\377\376\353" +\
    "\6\377\374\354\6\377\375\354\6\377\374\353\6\377\375\352\6\377\375\352" +\
    "\6\377\374\352\6\377\375\352\6\377\374\353\6\377\376\354\6\377\375\354" +\
    "\6\377\374\352\6\377\374\354\6\377\374\354\6\377\375\354\6\377\375\353" +\
    "\6\377\375\353\6\377\374\354\5\377\376\354\7\377\376\355\7\377\376\356" +\
    "\7\377\375\355\7\377\375\355\7\377\373\354\7\377\371\351\10\377\365\346" +\
    "\10\377\355\340\7\377\344\330\7\377\325\311\6\377\302\271\5\377\237\222" +\
    "\6\377\217/\5\377\346\10\3\377\376\23\5\377\377\24\5\377\377\25\5\377" +\
    "\377\27\7\377\377\26\7\377\376\31\10\377\375\30\11\377\367\30\10\377" +\
    "\340\30\11\377\271\25\6\377x\16\4\377\3\0\0\377\0\0\0\350\0\0\0^\0\0" +\
    "\0\20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0 \5\1\1\255w\13\12\377\250\21\16" +\
    "\377\2224h\377\306x\274\377\343\217\326\377\363\230\344\377\372\235\353" +\
    "\377\376\237\357\377\376\236\357\377\377\237\361\377\377\236\360\377" +\
    "\376\236\362\377\377\236\361\377\377\240\362\377\377\237\362\377\377" +\
    "\237\360\377\377\236\361\377\376\236\361\377\376\236\357\377\374\235" +\
    "\355\377\367\233\351\377\354\225\340\377\330\210\313\377\261\77\240\377" +\
    "\234->\377\372*5\377\371+7\377\361*4\377\346(2\377\325%-\377\302\42)" +\
    "\377\260 %\377\235\34 \377i\22\26\377,\30\6\377ja\5\377\235\225\5\377" +\
    "\274\261\5\377\323\307\6\377\345\330\6\377\357\341\10\377\367\350\10" +\
    "\377\372\353\10\377\374\354\7\377\374\354\7\377\376\356\7\377\376\356" +\
    "\7\377\374\354\6\377\375\355\6\377\376\355\6\377\374\353\5\377\374\353" +\
    "\5\377\375\354\5\377\374\354\6\377\374\354\6\377\375\354\6\377\375\354" +\
    "\6\377\374\354\6\377\375\353\6\377\374\353\6\377\374\354\6\377\375\353" +\
    "\5\377\375\353\6\377\375\354\5\377\375\354\6\377\375\355\6\377\375\354" +\
    "\6\377\375\356\6\377\375\355\7\377\374\354\6\377\373\354\7\377\371\352" +\
    "\7\377\365\346\7\377\357\341\7\377\346\331\6\377\332\315\6\377\314\300" +\
    "\6\377\267\256\6\377\210g\10\377\251\26\3\377\365\16\4\377\377\22\5\377" +\
    "\377\24\6\377\377\24\6\377\377\25\5\377\377\27\7\377\377\27\10\377\376" +\
    "\31\11\377\373\31\11\377\361\30\11\377\324\27\10\377\252\23\6\377K\10" +\
    "\3\377\0\0\0\377\0\0\0\275\0\0\0A\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3" +\
    "\0\0\0=\32\4\5\333\203\12\13\377\220-w\377\316z\302\377\354\214\335\377" +\
    "\370\224\352\377\375\226\355\377\375\225\356\377\376\224\356\377\377" +\
    "\226\357\377\376\225\357\377\377\226\360\377\377\227\360\377\377\236" +\
    "\361\377\377\241\361\377\377\236\361\377\377\230\360\377\377\226\360" +\
    "\377\377\225\357\377\377\224\357\377\376\225\356\377\375\224\356\377" +\
    "\373\225\354\377\364\221\345\377\342\211\324\377\300<\256\377\221-E\377" +\
    "\371!,\377\370\42/\377\362#.\377\350!*\377\332\37)\377\307\34#\377\265" +\
    "\31\37\377\243\27\34\377\202\23\25\377<\15\11\377=5\5\377\222\213\5\377" +\
    "\260\247\4\377\312\277\7\377\336\321\6\377\352\334\7\377\361\342\7\377" +\
    "\366\350\7\377\371\353\6\377\373\354\7\377\375\355\7\377\375\355\7\377" +\
    "\376\355\7\377\375\356\6\377\375\354\6\377\375\354\6\377\375\354\6\377" +\
    "\374\354\5\377\375\354\6\377\376\353\5\377\375\353\6\377\375\353\6\377" +\
    "\375\354\6\377\375\354\5\377\375\353\5\377\375\354\6\377\374\354\5\377" +\
    "\375\355\6\377\375\355\7\377\376\355\7\377\375\354\7\377\374\355\7\377" +\
    "\373\354\6\377\370\351\10\377\365\346\6\377\357\341\7\377\350\333\7\377" +\
    "\336\321\7\377\320\305\7\377\304\274\6\377\226\224\7\377\2137\3\377\322" +\
    "\14\3\377\373\20\3\377\375\21\5\377\377\22\4\377\377\24\5\377\377\26" +\
    "\5\377\377\25\6\377\376\27\10\377\377\27\10\377\375\31\10\377\372\30" +\
    "\10\377\350\30\10\377\305\24\7\377\226\22\6\377\35\2\1\377\0\0\0\373" +\
    "\0\0\0\222\0\0\0&\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0g$\12\13\372" +\
    "\204\35j\377\313k\275\377\355\203\335\377\373\213\352\377\375\214\354" +\
    "\377\376\213\355\377\377\213\356\377\377\214\355\377\377\212\355\377" +\
    "\377\212\356\377\377\213\356\377\376\225\361\377\377\255\362\377\377" +\
    "\300\365\377\377\262\363\377\377\231\361\377\377\214\357\377\377\212" +\
    "\356\377\377\212\355\377\376\213\355\377\377\213\355\377\376\214\356" +\
    "\377\375\213\354\377\370\211\347\377\346\205\330\377\302\42\254\377\231" +\
    "'C\377\371\31$\377\371\33&\377\364\32%\377\353\32$\377\337\30!\377\316" +\
    "\26\37\377\274\26\34\377\254\23\30\377\230\13\16\377i\3\6\377\42\16\2" +\
    "\377`R\5\377\235\227\5\377\302\271\6\377\321\305\6\377\335\320\7\377" +\
    "\346\331\7\377\356\340\7\377\362\344\6\377\366\350\7\377\371\353\6\377" +\
    "\373\354\7\377\373\354\7\377\374\354\7\377\375\355\7\377\375\355\7\377" +\
    "\375\355\7\377\375\355\6\377\375\355\7\377\375\355\6\377\375\355\6\377" +\
    "\375\355\6\377\375\355\7\377\375\355\7\377\375\355\7\377\375\355\7\377" +\
    "\374\354\6\377\374\354\7\377\373\353\7\377\370\352\7\377\365\347\7\377" +\
    "\361\343\6\377\353\335\7\377\345\326\6\377\332\315\6\377\320\305\6\377" +\
    "\303\276\6\377\242\233\7\377\212P\6\377\261\17\2\377\360\13\2\377\376" +\
    "\17\2\377\376\20\3\377\377\22\5\377\376\23\4\377\377\24\5\377\377\26" +\
    "\7\377\377\25\5\377\377\27\10\377\375\27\10\377\374\31\10\377\362\30" +\
    "\10\377\334\27\7\377\263\24\6\377f\12\2\377\3\0\0\377\0\0\0\351\0\0\0" +\
    "f\0\0\0\23\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0$\0\0\0\256Z\25N\377\274" +\
    "6\251\376\346x\326\377\372\200\350\377\376\201\354\377\377\200\353\377" +\
    "\376\200\354\377\377\200\354\377\377\177\354\377\377\177\354\377\377" +\
    "~\355\377\377\200\356\377\377\225\361\377\375\310\367\377\375\360\373" +\
    "\377\376\324\370\377\377\234\361\377\377\201\356\377\377|\355\377\377" +\
    "~\355\377\377~\355\377\377\177\353\377\377\200\353\377\377\201\353\377" +\
    "\376\201\353\377\371\200\347\377\345X\317\377\271\35\244\377\260\36\63" +\
    "\377\377\23 \377\372\24 \377\366\24 \377\356\24\36\377\344\23\34\377" +\
    "\326\20\27\377\304\10\17\377\262\5\12\377\241\6\12\377|\4\7\377#\0\2" +\
    "\377d\37\5\377{b\6\377\251\237\6\377\276\266\5\377\315\302\5\377\327" +\
    "\312\6\377\337\322\6\377\346\330\6\377\354\336\7\377\360\341\7\377\363" +\
    "\344\7\377\365\347\7\377\367\347\7\377\370\351\6\377\371\351\7\377\372" +\
    "\352\7\377\372\352\7\377\372\352\7\377\372\352\7\377\372\352\7\377\371" +\
    "\351\7\377\370\350\7\377\370\350\7\377\366\350\7\377\365\346\7\377\362" +\
    "\343\7\377\357\341\7\377\352\334\7\377\344\326\6\377\335\317\6\377\325" +\
    "\310\5\377\312\277\5\377\272\262\4\377\244\225\6\377\210R\6\377\253\24" +\
    "\3\377\346\4\1\377\377\15\3\377\377\20\4\377\377\20\4\377\376\20\3\377" +\
    "\377\22\5\377\377\23\4\377\377\26\6\377\377\25\7\377\377\26\6\377\376" +\
    "\27\10\377\375\30\10\377\370\31\10\377\351\31\10\377\311\25\7\377\233" +\
    "\21\5\377,\3\2\376\0\0\0\377\1\0\0\264\0\0\0>\0\0\0\7\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\13\0\0\0a-\14(\362\253\25\223\377\332P\306\377\365t\343\377" +\
    "\375v\351\377\377w\353\377\377v\353\377\377t\353\377\377s\354\377\377" +\
    "s\353\377\377p\353\377\377n\355\377\377p\355\377\377\206\360\377\376" +\
    "\274\367\377\375\350\373\377\376\310\370\377\377\215\362\377\377p\356" +\
    "\377\377l\354\377\377m\353\377\377n\355\377\377q\352\377\377r\353\377" +\
    "\377t\353\377\377t\353\377\375u\352\377\366p\343\377\337\42\300\377\244" +\
    "\37\210\377\321\21\33\377\375\16\35\377\372\16\32\377\370\15\31\377\362" +\
    "\11\25\377\351\6\20\377\333\7\17\377\311\7\15\377\263\5\13\377\236\6" +\
    "\12\377D\2\4\377a\12\3\377\223\16\4\377\201\36\6\377\214^\6\377\236\220" +\
    "\5\377\265\255\5\377\305\273\5\377\316\304\5\377\326\311\5\377\334\320" +\
    "\6\377\341\324\6\377\345\327\6\377\350\333\6\377\351\334\7\377\353\336" +\
    "\5\377\354\337\5\377\354\337\5\377\354\337\6\377\354\337\5\377\354\337" +\
    "\5\377\354\337\5\377\354\336\6\377\351\334\6\377\347\332\6\377\344\326" +\
    "\6\377\340\323\6\377\332\316\6\377\325\310\5\377\313\301\5\377\301\270" +\
    "\5\377\256\246\6\377\232\204\5\377\214G\4\377\251\17\1\377\345\10\1\377" +\
    "\375\14\3\377\376\15\2\377\376\17\2\377\377\17\3\377\377\20\4\377\377" +\
    "\21\3\377\377\23\5\377\377\23\4\377\377\26\6\377\377\26\5\377\376\26" +\
    "\6\377\375\27\10\377\373\27\10\377\361\30\7\377\333\26\7\377\264\23\6" +\
    "\377m\13\4\377\7\0\0\377\0\0\0\360\0\0\0{\0\0\0\37\0\0\0\2\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\2\0\0\0+\5\3\4\311\202\21r\377\310\34\255\376\357T\325\377\373" +\
    "i\345\377\376j\347\377\376i\350\377\377g\350\377\377g\352\377\377e\352" +\
    "\377\377b\351\377\377`\352\377\377\134\353\377\377[\354\377\377f\356" +\
    "\377\377\206\362\377\377\233\365\377\377\213\363\377\377k\357\377\377" +\
    "\134\354\377\377Z\353\377\377Z\353\377\377\134\353\377\377_\353\377\377" +\
    "b\351\377\377c\351\377\377e\350\377\376g\350\377\375f\346\377\362!\322" +\
    "\377\320\31\267\377\237\25U\377\371\5\21\377\375\6\23\377\373\6\22\377" +\
    "\371\6\23\377\364\7\22\377\354\7\20\377\335\7\17\377\306\7\14\377\256" +\
    "\6\12\377\213\5\10\377.\3\3\377\225\20\5\377\300\22\7\377\312\17\7\377" +\
    "\262\31\7\377\2250\5\377\206^\6\377\242\217\5\377\257\245\6\377\272\262" +\
    "\5\377\304\273\5\377\313\300\5\377\317\304\6\377\322\307\5\377\324\311" +\
    "\6\377\326\312\6\377\326\312\6\377\326\312\6\377\326\312\6\377\326\312" +\
    "\6\377\326\311\6\377\324\310\5\377\322\306\5\377\316\303\5\377\311\276" +\
    "\5\377\301\271\5\377\267\256\4\377\255\241\5\377\231\202\5\377\204M\5" +\
    "\377\242\36\2\377\305\12\1\377\360\3\1\377\377\12\2\377\377\14\1\377" +\
    "\376\14\3\377\377\16\3\377\377\17\3\377\377\20\4\377\377\22\4\377\377" +\
    "\22\4\377\377\24\4\377\377\24\5\377\377\26\6\377\377\25\7\377\376\27" +\
    "\6\377\374\30\10\377\366\31\10\377\345\30\7\377\306\25\5\377\232\21\5" +\
    "\377(\3\1\376\0\0\0\377\0\0\0\274\0\0\0H\0\0\0\13\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\16\0\0\0lE\14=\371\261\23\231\377\342!\304\377\370E\334\377\376" +\
    "`\346\377\377^\346\377\377\134\347\377\377[\346\377\377X\350\377\377" +\
    "T\350\377\377Q\352\377\377N\353\377\377L\354\377\377J\355\377\377L\357" +\
    "\377\377T\360\377\377Z\361\377\377V\357\377\377N\356\377\377J\355\377" +\
    "\377J\355\377\377J\353\377\377L\354\377\377L\353\377\377O\350\377\377" +\
    "R\351\377\376R\347\377\377V\347\377\376M\345\377\372\30\332\377\347\26" +\
    "\312\377\263\16\230\377\302\13\31\377\376\6\24\377\374\7\22\377\374\7" +\
    "\22\377\372\6\22\377\365\10\21\377\353\6\17\377\327\7\14\377\275\7\13" +\
    "\377\245\5\11\377Y\3\4\377K\10\3\377\242\21\6\377\316\25\6\377\355\30" +\
    "\10\377\366\27\7\377\346\20\6\377\276\16\4\377\232#\6\377\231A\6\377" +\
    "\226Z\4\377\222w\5\377\224\200\5\377\247\231\5\377\256\244\6\377\261" +\
    "\245\6\377\261\246\5\377\261\247\5\377\261\247\4\377\261\246\6\377\260" +\
    "\245\6\377\255\242\6\377\241\222\5\377\223}\4\377\222o\4\377\231S\4\377" +\
    "\2261\3\377\240\24\2\377\314\2\0\377\360\6\0\377\377\11\0\377\376\12" +\
    "\2\377\377\12\2\377\377\14\2\377\377\15\2\377\377\17\3\377\377\16\3\377" +\
    "\377\20\3\377\377\20\4\377\377\21\4\377\377\22\4\377\377\24\4\377\377" +\
    "\24\6\377\376\25\6\377\376\25\6\377\375\27\7\377\371\30\10\377\355\30" +\
    "\10\377\321\25\6\377\251\21\5\377Z\11\2\377\5\0\0\377\0\0\0\351\0\0\0" +\
    "z\0\0\0\42\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0'\0\0\0\311\207\13u\377\313" +\
    "\30\260\376\360\42\321\377\375/\336\377\376T\344\377\377Q\345\377\377" +\
    "N\345\377\377K\347\377\377G\347\377\377D\350\377\377\77\351\377\377>" +\
    "\353\377\377<\354\377\377=\356\377\377;\357\377\377<\360\377\377=\360" +\
    "\377\377=\357\377\377;\356\377\377;\356\377\377;\356\377\377<\355\377" +\
    "\377<\354\377\377>\352\377\377\77\351\377\377@\347\377\377A\350\377\377" +\
    "C\346\377\376%\342\377\375\17\335\377\364\20\325\377\321\13\270\377\241" +\
    "\15S\377\373\4\21\377\375\6\23\377\375\7\22\377\374\6\21\377\371\7\22" +\
    "\377\363\7\17\377\344\6\15\377\315\7\14\377\263\6\11\377\222\5\10\377" +\
    "6\2\3\377u\14\5\377\262\22\5\377\327\26\7\377\356\27\7\377\372\30\10" +\
    "\377\375\27\10\377\373\25\6\377\365\23\6\377\346\22\5\377\321\25\5\377" +\
    "\306\26\3\377\271\32\3\377\263\34\3\377\263\32\2\377\264\32\2\377\264" +\
    "\32\2\377\264\31\1\377\264\30\1\377\263\30\1\377\264\30\1\377\275\24" +\
    "\1\377\311\20\1\377\326\15\1\377\353\11\0\377\367\11\0\377\374\12\0\377" +\
    "\377\14\1\377\377\13\1\377\376\13\2\377\377\13\1\377\377\13\2\377\377" +\
    "\14\1\377\377\16\2\377\377\20\3\377\377\20\2\377\377\21\4\377\377\22" +\
    "\3\377\377\21\3\377\377\23\4\377\377\25\5\377\377\25\6\377\376\26\7\377" +\
    "\376\30\10\377\371\30\10\377\361\27\7\377\334\26\7\377\270\22\5\377\204" +\
    "\15\5\377\26\1\0\376\0\0\0\376\0\0\0\254\0\0\0A\0\0\0\13\0\0\0\1\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\10\0\0\0Q%\13!\364\252\14\224\377\337\26\302\377\370\35" +\
    "\331\377\376!\336\377\3777\341\377\377B\344\377\377>\345\377\377:\345" +\
    "\377\3775\350\377\3773\352\377\3771\353\377\377/\353\377\377/\354\377" +\
    "\377.\355\377\377.\355\377\377.\357\377\377.\356\377\377.\356\377\377" +\
    ".\356\377\377.\355\377\377.\354\377\377/\353\377\377/\354\377\3770\353" +\
    "\377\3770\350\377\3771\347\377\3773\347\377\377/\346\377\376\13\340\377" +\
    "\376\15\337\377\372\14\332\377\344\13\307\377\254\12\212\377\333\7\22" +\
    "\377\375\5\23\377\375\5\23\377\375\7\22\377\373\6\20\377\367\7\20\377" +\
    "\356\6\17\377\334\6\15\377\303\7\12\377\252\6\11\377w\4\6\3772\3\2\377" +\
    "\214\17\4\377\274\23\5\377\335\26\6\377\360\27\10\377\372\30\10\377\376" +\
    "\27\6\377\377\26\7\377\377\26\6\377\376\25\5\377\376\23\4\377\375\21" +\
    "\4\377\375\20\4\377\375\20\3\377\375\16\3\377\375\16\3\377\375\15\2\377" +\
    "\375\14\2\377\375\13\2\377\375\13\1\377\375\13\1\377\376\13\1\377\377" +\
    "\13\1\377\377\13\1\377\377\14\1\377\377\14\1\377\376\13\1\377\377\14" +\
    "\2\377\377\14\2\377\377\14\2\377\377\14\1\377\377\16\2\377\377\17\3\377" +\
    "\377\17\3\377\377\20\3\377\377\22\4\377\377\21\4\377\377\22\3\377\377" +\
    "\24\4\377\377\25\5\377\376\27\7\377\376\27\7\377\373\30\10\377\362\27" +\
    "\7\377\341\26\7\377\301\23\5\377\223\20\4\3771\4\1\376\1\0\0\377\0\0" +\
    "\0\323\0\0\0e\0\0\0\32\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0\210" +\
    "g\11Y\374\277\14\246\377\354\22\315\377\374\27\335\377\376\30\337\377" +\
    "\377\30\337\377\377*\342\377\377.\344\377\377)\344\377\377'\347\377\377" +\
    "%\351\377\377$\352\377\377\42\353\377\377\42\354\377\377\42\355\377\377" +\
    "\42\355\377\377\42\357\377\377\42\357\377\377\42\356\377\377\42\356\377" +\
    "\377\42\355\377\377\42\353\377\377\42\353\377\377#\352\377\377#\351\377" +\
    "\377$\350\377\377$\346\377\377\42\345\377\377\13\343\377\377\12\342\377" +\
    "\377\13\341\377\375\13\337\377\356\12\321\377\302\10\251\377\263\5&\377" +\
    "\374\5\22\377\374\6\21\377\374\6\21\377\374\7\20\377\372\7\20\377\365" +\
    "\10\16\377\350\10\16\377\323\7\13\377\273\6\12\377\242\5\10\377f\3\5" +\
    "\377B\6\3\377\230\20\4\377\300\24\6\377\337\25\7\377\361\27\7\377\371" +\
    "\27\7\377\375\27\6\377\375\27\7\377\376\26\5\377\376\24\4\377\377\23" +\
    "\4\377\377\22\4\377\377\22\3\377\377\21\3\377\377\20\3\377\377\17\3\377" +\
    "\377\17\2\377\377\16\1\377\377\14\1\377\377\14\2\377\377\14\2\377\377" +\
    "\14\2\377\377\14\2\377\377\14\2\377\377\14\2\377\377\14\2\377\377\14" +\
    "\2\377\377\14\2\377\377\16\1\377\377\17\2\377\377\17\3\377\377\20\3\377" +\
    "\377\20\3\377\377\22\3\377\377\21\3\377\377\22\3\377\377\24\4\377\377" +\
    "\24\5\377\376\26\6\377\375\27\7\377\372\30\7\377\363\27\7\377\343\25" +\
    "\7\377\305\24\6\377\236\20\5\377H\6\1\376\1\0\0\377\1\0\0\353\0\0\0\206" +\
    "\0\0\0.\0\0\0\7\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0(\2\1\2\305\211\5w\375" +\
    "\317\13\263\377\364\16\326\377\375\20\336\377\377\21\340\377\377\17\340" +\
    "\377\377\16\340\377\377\27\344\377\377\34\346\377\377\33\350\377\377" +\
    "\32\350\377\377\30\351\377\377\30\353\377\377\30\354\377\377\30\355\377" +\
    "\377\30\355\377\377\30\357\377\377\27\356\377\377\30\356\377\377\30\356" +\
    "\377\377\30\354\377\377\30\354\377\377\30\352\377\377\30\352\377\377" +\
    "\31\351\377\377\32\350\377\377\25\345\377\377\11\343\377\377\7\342\377" +\
    "\377\11\342\377\377\11\341\377\375\12\337\377\366\12\327\377\323\11\271" +\
    "\377\240\6N\377\371\5\22\377\374\5\22\377\375\6\21\377\375\7\20\377\374" +\
    "\7\20\377\371\10\20\377\361\10\15\377\342\7\14\377\315\7\13\377\265\6" +\
    "\11\377\233\6\10\377K\3\3\377S\7\3\377\235\20\4\377\303\24\5\377\340" +\
    "\25\6\377\360\27\6\377\371\27\7\377\374\26\6\377\375\27\7\377\376\26" +\
    "\4\377\377\24\5\377\377\24\4\377\377\22\4\377\377\22\3\377\377\21\2\377" +\
    "\377\21\3\377\377\20\2\377\377\20\3\377\377\17\2\377\377\17\2\377\377" +\
    "\16\1\377\377\16\2\377\377\16\2\377\377\16\2\377\377\16\2\377\377\17" +\
    "\1\377\377\17\2\377\377\17\2\377\377\20\3\377\377\20\2\377\377\20\3\377" +\
    "\377\21\3\377\377\21\3\377\377\22\4\377\377\23\4\377\376\24\5\377\377" +\
    "\24\5\377\376\26\6\377\375\26\7\377\371\27\7\377\363\27\6\377\343\25" +\
    "\6\377\307\23\5\377\244\20\5\377[\10\2\377\7\0\0\377\1\0\0\366\0\0\0" +\
    "\242\0\0\0A\0\0\0\15\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0\0:\12\1" +\
    "\11\351\235\6\210\376\332\12\276\377\370\14\332\377\376\13\340\377\377" +\
    "\14\340\377\377\12\341\377\377\11\342\377\377\7\344\377\377\12\345\377" +\
    "\377\16\350\377\377\20\352\377\377\17\352\377\377\17\353\377\377\17\355" +\
    "\377\377\17\355\377\377\16\355\377\377\16\356\377\377\16\356\377\377" +\
    "\16\357\377\377\16\355\377\377\17\355\377\377\17\353\377\377\17\353\377" +\
    "\377\17\352\377\377\17\351\377\377\11\347\377\377\6\346\377\377\6\343" +\
    "\377\377\10\343\377\377\10\343\377\377\11\341\377\376\12\340\377\371" +\
    "\12\332\377\336\12\301\377\240\6r\377\357\4\21\377\375\6\22\377\375\5" +\
    "\20\377\375\7\21\377\375\6\17\377\373\7\17\377\367\10\17\377\356\10\14" +\
    "\377\337\10\14\377\307\6\13\377\260\6\10\377\223\6\7\377A\2\3\377V\10" +\
    "\4\377\237\17\4\377\303\23\5\377\336\24\6\377\357\26\6\377\370\27\7\377" +\
    "\374\27\7\377\376\27\5\377\376\25\6\377\376\24\5\377\377\24\5\377\377" +\
    "\22\4\377\377\22\3\377\377\20\3\377\377\21\2\377\377\21\2\377\377\21" +\
    "\3\377\377\21\2\377\377\21\3\377\377\20\1\377\377\20\1\377\377\20\2\377" +\
    "\377\20\1\377\377\20\3\377\377\21\3\377\377\21\3\377\377\21\3\377\377" +\
    "\20\3\377\377\20\3\377\377\22\3\377\377\23\3\377\377\23\5\377\377\25" +\
    "\5\377\377\25\5\377\375\26\5\377\375\27\5\377\371\27\7\377\360\27\7\377" +\
    "\342\24\6\377\307\23\5\377\244\20\5\377b\11\3\377\11\0\0\377\0\0\0\374" +\
    "\0\0\0\266\0\0\0R\0\0\0\25\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\6\0\0\0H\23\0\17\362\245\6\220\377\340\11\304\376\373\13\335\377\377" +\
    "\12\341\377\377\11\341\377\377\11\341\377\377\10\343\377\377\7\345\377" +\
    "\377\5\346\377\377\5\350\377\377\5\350\377\377\6\351\377\377\7\354\377" +\
    "\377\7\354\377\377\7\354\377\377\10\356\377\377\7\355\377\377\7\355\377" +\
    "\377\7\356\377\377\7\354\377\377\7\354\377\377\7\354\377\377\6\353\377" +\
    "\377\5\352\377\377\5\351\377\377\5\347\377\377\5\346\377\377\7\344\377" +\
    "\377\7\343\377\377\7\342\377\377\11\342\377\377\12\341\377\373\12\334" +\
    "\377\343\11\306\377\253\6\204\377\350\3\17\377\375\6\22\377\375\5\17" +\
    "\377\375\6\20\377\375\7\16\377\374\6\16\377\373\10\16\377\366\10\15\377" +\
    "\354\7\14\377\332\7\13\377\304\7\11\377\256\6\10\377\215\6\6\377>\3\2" +\
    "\377L\10\2\377\232\17\4\377\274\22\5\377\327\26\6\377\353\27\7\377\366" +\
    "\27\6\377\372\27\7\377\375\25\6\377\377\24\5\377\377\24\5\377\377\23" +\
    "\4\377\377\23\4\377\377\22\3\377\377\22\3\377\377\21\3\377\377\21\2\377" +\
    "\377\21\2\377\377\21\2\377\377\20\3\377\377\21\1\377\377\21\1\377\377" +\
    "\21\3\377\377\20\3\377\377\20\2\377\377\21\3\377\377\22\3\377\377\21" +\
    "\2\377\377\22\4\377\377\22\3\377\377\23\3\377\377\24\5\377\376\24\5\377" +\
    "\376\25\6\377\373\27\5\377\367\27\7\377\355\26\7\377\333\25\6\377\302" +\
    "\23\5\377\237\17\4\377U\10\2\377\11\0\0\376\0\0\0\375\0\0\0\301\0\0\0" +\
    "_\0\0\0\35\0\0\0\5\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\0\0\0" +\
    "N\25\0\22\364\251\6\223\376\342\11\306\377\372\12\334\377\377\11\341" +\
    "\377\377\7\342\377\377\7\343\377\377\7\342\377\377\6\346\377\377\6\346" +\
    "\377\377\4\350\377\377\5\351\377\377\3\352\377\377\3\353\377\377\3\354" +\
    "\377\377\3\354\377\377\3\356\377\377\2\356\377\377\2\356\377\377\2\356" +\
    "\377\377\3\355\377\377\3\355\377\377\3\353\377\377\3\353\377\377\3\352" +\
    "\377\377\5\351\377\377\5\347\377\377\6\346\377\377\6\345\377\377\7\342" +\
    "\377\377\7\342\377\377\10\341\377\377\12\340\377\374\11\335\377\345\11" +\
    "\310\377\257\6\211\377\346\4\16\377\375\5\21\377\375\6\17\377\375\6\17" +\
    "\377\375\6\16\377\375\7\16\377\374\7\16\377\373\7\15\377\365\10\14\377" +\
    "\352\10\14\377\330\10\12\377\303\7\11\377\247\6\10\377x\5\3\3771\2\23" +\
    "\377F\6\11\377\221\17\4\377\263\21\4\377\321\25\6\377\344\25\6\377\361" +\
    "\26\6\377\370\27\5\377\374\25\5\377\376\25\5\377\376\25\6\377\377\25" +\
    "\4\377\377\23\4\377\377\23\3\377\377\22\4\377\377\23\4\377\377\23\3\377" +\
    "\377\22\3\377\377\21\3\377\377\21\2\377\377\21\2\377\377\21\3\377\377" +\
    "\22\2\377\377\22\4\377\377\22\3\377\377\22\3\377\377\22\3\377\377\23" +\
    "\3\377\377\24\4\377\376\25\4\377\376\25\5\377\374\25\5\377\371\25\6\377" +\
    "\362\27\6\377\350\24\6\377\325\25\6\377\267\22\5\377\231\17\4\377J\6" +\
    "\1\377\6\0\0\376\0\0\0\376\0\0\0\303\0\0\0e\0\0\0\42\0\0\0\6\0\0\0\1" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\0\0\0P\25\0\22\365\252\6" +\
    "\224\376\343\11\306\377\373\12\335\377\377\11\340\377\377\10\341\377" +\
    "\377\6\342\377\377\6\344\377\377\6\345\377\377\5\347\377\377\4\350\377" +\
    "\377\4\351\377\377\4\352\377\377\3\353\377\377\3\354\377\377\3\355\377" +\
    "\377\3\356\377\377\2\356\377\377\2\356\377\377\2\356\377\377\3\356\377" +\
    "\377\2\355\377\377\3\354\377\377\3\352\377\377\4\352\377\377\4\351\377" +\
    "\377\5\347\377\377\5\346\377\377\6\345\377\377\5\342\377\377\7\343\377" +\
    "\377\10\341\377\377\11\340\377\374\12\335\377\346\11\311\377\260\6\212" +\
    "\377\346\4\16\377\375\5\20\377\375\6\17\377\375\5\16\377\375\7\16\377" +\
    "\375\7\16\377\375\7\15\377\374\7\16\377\372\11\15\377\364\11\14\377\351" +\
    "\10\13\377\327\10\13\377\267\7\10\377\202\6\4\377o\2X\377X\0Q\3775\3" +\
    "\14\377~\15\3\377\253\20\4\377\304\23\5\377\332\24\6\377\352\25\6\377" +\
    "\363\27\5\377\371\27\6\377\374\26\4\377\375\26\5\377\376\26\5\377\377" +\
    "\24\4\377\377\23\4\377\376\23\3\377\377\23\3\377\377\23\4\377\377\23" +\
    "\3\377\377\23\4\377\377\23\4\377\377\23\3\377\377\22\4\377\377\23\3\377" +\
    "\377\23\3\377\376\23\3\377\377\25\3\377\376\25\4\377\375\26\5\377\375" +\
    "\26\5\377\371\26\6\377\364\27\6\377\354\26\6\377\334\24\6\377\310\23" +\
    "\5\377\257\22\4\377\207\16\3\3774\4\1\376\2\0\0\377\0\0\0\373\0\0\0\274" +\
    "\0\0\0c\0\0\0\42\0\0\0\7\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\6\0\0\0P\25\0\22\365\250\6\222\376\342\10\306\377\372" +\
    "\11\334\377\377\10\341\377\377\7\342\377\377\6\342\377\377\5\343\377" +\
    "\377\5\345\377\377\5\346\377\377\4\350\377\377\4\350\377\377\2\352\377" +\
    "\377\2\353\377\377\3\354\377\377\2\355\377\377\1\357\377\377\2\357\377" +\
    "\377\2\357\377\377\1\357\377\377\1\357\377\377\3\356\377\377\2\353\377" +\
    "\377\2\352\377\377\3\352\377\377\4\350\377\377\4\347\377\377\4\346\377" +\
    "\377\5\345\377\377\6\344\377\377\7\342\377\377\11\341\377\377\11\340" +\
    "\377\374\12\335\377\346\11\311\377\257\6\211\377\346\3\15\377\375\4\20" +\
    "\377\375\6\17\377\375\5\17\377\375\7\16\377\375\7\16\377\375\10\15\377" +\
    "\374\10\15\377\374\10\15\377\372\11\15\377\364\10\13\377\346\10\13\377" +\
    "\303\10\10\377\204\6\23\377\233\1\220\377\241\1\225\377u\0m\3772\1\42" +\
    "\377[\11\5\377\225\17\3\377\262\21\4\377\311\23\5\377\333\24\6\377\347" +\
    "\25\6\377\361\26\6\377\366\26\6\377\372\26\6\377\374\26\6\377\375\26" +\
    "\4\377\376\24\4\377\377\24\5\377\377\24\3\377\377\24\4\377\377\23\5\377" +\
    "\377\23\3\377\377\23\3\377\377\23\3\377\376\23\4\377\376\24\5\377\376" +\
    "\26\5\377\375\26\5\377\372\26\6\377\367\26\5\377\362\26\5\377\350\25" +\
    "\6\377\335\24\6\377\314\22\5\377\265\21\5\377\234\20\3\377c\11\3\377" +\
    "\22\1\0\377\0\0\0\377\0\0\0\360\0\0\0\252\0\0\0Y\0\0\0 \0\0\0\6\0\0\0" +\
    "\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\0\0\0" +\
    "O\23\0\20\364\245\5\220\376\340\11\305\377\372\11\334\377\377\10\340" +\
    "\377\377\7\343\377\377\6\343\377\377\5\343\377\377\5\345\377\377\4\346" +\
    "\377\377\3\347\377\377\3\351\377\377\3\352\377\377\2\353\377\377\2\354" +\
    "\377\377\1\355\377\377\1\356\377\377\1\357\377\377\1\357\377\377\1\357" +\
    "\377\377\1\356\377\377\1\355\377\377\2\353\377\377\2\352\377\377\2\352" +\
    "\377\377\3\350\377\377\3\347\377\377\5\346\377\377\5\344\377\377\6\343" +\
    "\377\377\7\343\377\377\10\341\377\377\11\340\377\373\12\335\377\343\11" +\
    "\306\377\253\7\206\377\347\4\15\377\375\5\17\377\375\5\16\377\375\6\16" +\
    "\377\375\6\15\377\375\7\15\377\374\7\14\377\375\7\15\377\375\11\14\377" +\
    "\375\11\14\377\371\12\13\377\354\11\13\377\305\10\6\377\215\6D\377\310" +\
    "\1\276\377\272\1\253\377\251\2\233\377\222\1\206\377G\0C\3770\3\15\377" +\
    "o\13\4\377\233\16\3\377\262\20\4\377\305\22\4\377\325\23\5\377\342\24" +\
    "\5\377\352\25\5\377\361\25\6\377\365\25\4\377\370\26\4\377\373\26\5\377" +\
    "\374\26\5\377\375\26\5\377\375\26\5\377\375\26\5\377\375\26\5\377\374" +\
    "\26\5\377\373\26\5\377\370\25\4\377\365\26\5\377\362\25\6\377\353\25" +\
    "\4\377\343\24\5\377\326\24\5\377\307\22\5\377\265\20\4\377\236\17\3\377" +\
    "w\13\2\377/\3\1\377\0\0\0\376\0\0\0\374\0\0\0\327\0\0\0\207\0\0\0E\0" +\
    "\0\0\30\0\0\0\5\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\6\0\0\0H\13\0\11\357\236\6\210\377\332\10\277\376" +\
    "\370\11\331\377\376\10\340\377\376\7\343\377\377\6\343\377\377\6\344" +\
    "\377\377\4\345\377\377\4\346\377\377\4\347\377\377\3\351\377\377\3\351" +\
    "\377\377\2\352\377\377\2\353\377\377\1\355\377\377\1\356\377\377\1\356" +\
    "\377\377\1\357\377\377\1\356\377\377\0\356\377\377\2\355\377\377\2\353" +\
    "\377\377\2\352\377\377\3\352\377\377\3\351\377\377\3\345\377\377\5\346" +\
    "\377\377\4\344\377\377\6\343\377\377\7\342\377\376\7\341\377\376\11\340" +\
    "\377\371\11\332\377\337\11\303\377\237\5t\377\356\3\15\377\375\5\17\377" +\
    "\375\6\15\377\375\6\16\377\375\7\15\377\375\7\15\377\374\10\15\377\376" +\
    "\7\15\377\376\11\13\377\375\11\13\377\372\12\14\377\347\11\13\377\262" +\
    "\10\6\377\270\2\235\377\344\2\326\377\323\2\303\377\303\1\263\377\262" +\
    "\2\243\377\241\3\222\377{\2q\3777\1\60\3771\3\13\377s\14\4\377\226\16" +\
    "\3\377\252\17\3\377\272\20\3\377\307\22\5\377\325\22\4\377\336\24\5\377" +\
    "\345\23\4\377\352\25\6\377\356\25\5\377\360\26\4\377\357\24\5\377\357" +\
    "\24\6\377\360\24\4\377\356\24\4\377\352\24\5\377\346\24\4\377\340\23" +\
    "\5\377\326\22\4\377\312\23\5\377\275\20\3\377\254\20\4\377\231\17\2\377" +\
    "z\13\3\3762\3\1\377\3\0\0\376\0\0\0\375\1\0\0\356\0\0\0\243\0\0\0]\0" +\
    "\0\0*\0\0\0\15\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0;\2\0\2\331\213\4y\376\317" +\
    "\7\265\377\364\11\327\377\375\10\340\377\377\7\343\377\377\5\342\377" +\
    "\377\5\343\377\377\5\344\377\377\4\346\377\377\3\346\377\377\2\350\377" +\
    "\377\3\350\377\377\2\353\377\377\2\353\377\377\0\355\377\377\1\356\377" +\
    "\377\1\355\377\377\1\356\377\377\1\355\377\377\0\356\377\377\1\355\377" +\
    "\377\2\353\377\377\2\352\377\377\2\351\377\377\3\350\377\377\4\346\377" +\
    "\377\3\345\377\377\5\344\377\377\6\342\377\377\7\343\377\377\10\342\377" +\
    "\376\10\340\377\366\10\327\377\324\10\272\377\240\5Q\377\371\4\14\377" +\
    "\374\5\16\377\375\6\16\377\375\6\16\377\375\7\14\377\375\7\15\377\375" +\
    "\10\15\377\375\7\13\377\375\11\14\377\374\10\14\377\365\11\12\377\327" +\
    "\11\11\377\236\6\65\377\352\1\337\377\362\2\341\377\347\1\326\377\333" +\
    "\2\311\377\314\1\272\377\275\2\253\377\257\3\235\377\240\3\220\377~\2" +\
    "r\377F\1;\377,\2\23\377N\6\7\377w\12\4\377\226\16\4\377\250\17\3\377" +\
    "\265\20\4\377\277\21\4\377\306\21\5\377\312\22\5\377\315\23\5\377\316" +\
    "\23\5\377\316\23\5\377\316\23\5\377\314\22\5\377\306\21\5\377\301\21" +\
    "\4\377\265\20\4\377\252\17\4\377\231\16\4\377{\12\3\377N\6\1\377\36\1" +\
    "\0\377\4\0\0\377\0\0\0\375\1\0\0\356\0\0\0\265\0\0\0q\0\0\09\0\0\0\24" +\
    "\0\0\0\5\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0)\0\0\0\253i\4\134\375" +\
    "\300\7\247\377\355\10\320\377\375\10\336\377\376\7\342\377\377\7\342" +\
    "\377\377\5\343\377\377\5\344\377\377\3\345\377\377\3\346\377\377\3\350" +\
    "\377\377\1\351\377\377\2\351\377\377\2\352\377\377\0\354\377\377\1\355" +\
    "\377\377\0\355\377\377\0\355\377\377\1\355\377\377\1\354\377\377\1\354" +\
    "\377\377\2\352\377\377\1\351\377\377\2\350\377\377\3\347\377\377\3\345" +\
    "\377\377\3\345\377\377\5\343\377\377\6\342\377\377\7\342\377\377\7\340" +\
    "\377\375\11\337\377\357\10\321\377\304\7\253\377\260\4%\377\374\4\15" +\
    "\377\374\5\15\377\375\6\15\377\375\6\15\377\375\7\15\377\375\6\14\377" +\
    "\375\10\14\377\376\7\14\377\375\11\13\377\371\11\13\377\350\11\12\377" +\
    "\271\10\10\377\300\2\243\377\376\0\360\377\372\1\351\377\365\2\342\377" +\
    "\356\1\332\377\343\3\317\377\326\3\303\377\312\3\266\377\275\3\252\377" +\
    "\262\3\236\377\246\4\223\377\220\3\177\377c\3X\377B\2\64\377/\3\24\377" +\
    "\77\5\5\377^\10\2\377x\12\3\377\215\14\3\377\227\16\3\377\233\16\3\377" +\
    "\234\16\3\377\234\16\3\377\233\17\3\377\230\16\3\377\217\14\3\377{\12" +\
    "\3\377a\10\1\377\77\5\1\377\35\1\0\377\10\0\0\377\0\0\0\376\0\0\0\371" +\
    "\0\0\0\334\0\0\0\253\0\0\0s\0\0\0A\0\0\0\34\0\0\0\7\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\27\0\0\0z(\1#\373\252\6\225\377" +\
    "\340\7\305\377\370\10\332\377\375\7\340\377\377\5\342\377\377\6\342\377" +\
    "\377\5\343\377\377\4\345\377\377\3\346\377\377\2\346\377\377\3\347\377" +\
    "\377\1\351\377\377\2\352\377\377\0\353\377\377\1\354\377\377\0\353\377" +\
    "\377\0\354\377\377\0\354\377\377\1\354\377\377\0\353\377\377\2\352\377" +\
    "\377\1\351\377\377\2\350\377\377\2\346\377\377\4\345\377\377\4\344\377" +\
    "\377\5\343\377\377\6\341\377\376\7\342\377\376\10\340\377\372\10\334" +\
    "\377\345\10\311\377\256\6\214\377\330\4\14\377\375\5\15\377\375\6\15" +\
    "\377\375\6\15\377\375\6\15\377\375\6\14\377\375\10\14\377\375\7\13\377" +\
    "\375\10\14\377\374\11\14\377\360\10\12\377\320\7\7\377\235\5E\377\365" +\
    "\1\351\377\377\0\355\377\376\1\353\377\373\2\347\377\371\2\344\377\364" +\
    "\2\336\377\354\2\326\377\343\3\314\377\330\3\302\377\316\4\267\377\303" +\
    "\4\254\377\271\5\243\377\256\5\231\377\233\4\207\377p\4b\3772\1+\377" +\
    "\5\0\0\377\22\1\0\376\37\2\0\377+\3\1\377,\4\1\377-\3\1\377-\3\1\377" +\
    ",\3\1\377,\3\1\377!\1\0\377\24\1\0\377\10\0\0\377\2\0\0\375\0\0\0\367" +\
    "\1\0\0\340\0\0\0\274\0\0\0\213\0\0\0_\0\0\08\0\0\0\32\0\0\0\7\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0" +\
    "\0M\0\0\0\345\211\5w\377\314\7\263\377\361\7\324\377\374\10\336\377\376" +\
    "\7\341\377\377\6\342\377\377\5\343\377\377\3\344\377\377\3\344\377\377" +\
    "\3\345\377\377\3\347\377\377\1\347\377\377\1\351\377\377\1\352\377\377" +\
    "\0\353\377\377\0\353\377\377\0\352\377\377\0\353\377\377\1\353\377\377" +\
    "\0\352\377\377\2\350\377\377\1\347\377\377\2\347\377\377\2\345\377\377" +\
    "\4\344\377\377\4\344\377\377\4\342\377\377\6\342\377\376\7\341\377\375" +\
    "\7\337\377\363\10\326\377\322\7\272\377\240\5U\377\372\4\11\377\375\5" +\
    "\14\377\375\6\14\377\375\5\14\377\375\7\14\377\375\7\13\377\376\10\13" +\
    "\377\375\10\14\377\374\10\14\377\365\11\12\377\335\7\10\377\251\6\26" +\
    "\377\326\0\310\377\377\0\355\377\377\1\353\377\377\1\353\377\376\1\351" +\
    "\377\375\2\347\377\373\3\344\377\370\2\340\377\363\4\334\377\356\4\325" +\
    "\377\346\4\315\377\336\6\305\377\325\6\274\377\311\6\257\377\257\5\231" +\
    "\377\205\4t\3776\1\60\376\0\0\0\377\0\0\0\375\0\0\0\356\0\0\0\346\0\0" +\
    "\0\347\0\0\0\346\0\0\0\345\0\0\0\344\0\0\0\343\0\0\0\341\1\0\0\333\1" +\
    "\0\0\320\0\0\0\263\0\0\0\213\0\0\0c\0\0\0@\0\0\0%\0\0\0\21\0\0\0\5\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\1\0\0\0+\0\0\0\243H\2@\377\262\6\233\376\341\7\306\377" +\
    "\367\10\331\377\375\6\340\377\376\6\342\377\377\5\342\377\377\3\344\377" +\
    "\377\3\344\377\377\3\345\377\377\3\346\377\377\1\346\377\377\1\347\377" +\
    "\377\0\351\377\377\0\352\377\377\0\352\377\377\0\352\377\377\0\352\377" +\
    "\377\1\351\377\377\0\350\377\377\2\347\377\377\2\346\377\377\3\345\377" +\
    "\377\2\344\377\377\4\345\377\377\4\343\377\376\4\342\377\377\6\341\377" +\
    "\376\7\340\377\373\10\334\377\347\7\313\377\265\7\233\377\300\3\26\377" +\
    "\375\5\15\377\375\5\14\377\375\6\13\377\374\5\14\377\375\7\12\377\375" +\
    "\7\13\377\375\10\13\377\375\10\14\377\367\10\13\377\344\10\11\377\270" +\
    "\7\11\377\260\2\214\377\377\0\354\377\376\0\352\377\377\1\352\377\377" +\
    "\0\351\377\376\2\347\377\377\1\347\377\376\2\346\377\375\2\344\377\373" +\
    "\4\342\377\371\4\337\377\365\5\332\377\361\6\326\377\352\6\317\377\334" +\
    "\7\300\377\271\6\242\377}\4m\377\23\0\20\377\0\0\0\370\0\0\0\274\0\0" +\
    "\0\177\0\0\0j\0\0\0i\0\0\0g\0\0\0c\0\0\0b\0\0\0b\0\0\0_\0\0\0X\0\0\0" +\
    "K\0\0\09\0\0\0%\0\0\0\22\0\0\0\6\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\20\0\0\0`\4\0\4\352\204\4s\377\307\6\255\377\354\10\320" +\
    "\377\372\6\334\377\375\7\341\377\377\5\341\377\377\4\343\377\377\4\344" +\
    "\377\377\2\345\377\377\3\345\377\377\2\346\377\377\2\347\377\377\0\346" +\
    "\377\377\1\350\377\377\0\350\377\377\0\350\377\377\1\350\377\377\0\346" +\
    "\377\377\0\347\377\377\2\347\377\377\2\345\377\377\3\345\377\377\3\345" +\
    "\377\377\3\344\377\377\5\342\377\377\5\341\377\376\6\341\377\375\7\336" +\
    "\377\361\10\323\377\321\7\271\377\240\5T\377\367\4\7\377\374\5\13\377" +\
    "\375\6\14\377\375\5\13\377\375\7\14\377\376\7\14\377\375\7\12\377\374" +\
    "\10\12\377\370\11\13\377\347\7\12\377\301\7\4\377\243\4d\377\375\0\354" +\
    "\377\377\0\353\377\377\1\351\377\377\0\351\377\377\1\350\377\377\2\347" +\
    "\377\376\2\346\377\377\3\345\377\376\2\345\377\377\3\344\377\375\5\342" +\
    "\377\374\5\340\377\371\7\335\377\362\7\325\377\335\7\302\377\256\6\231" +\
    "\377S\2I\376\0\0\0\376\0\0\0\314\0\0\0`\0\0\0$\0\0\0\25\0\0\0\23\0\0" +\
    "\0\20\0\0\0\16\0\0\0\16\0\0\0\16\0\0\0\16\0\0\0\14\0\0\0\10\0\0\0\4\0" +\
    "\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\3\0\0\0/\0\0\0\241,\1'\375\244\5\221\376\324\6\273\377\361\7\325" +\
    "\377\373\7\337\377\375\5\341\377\377\4\342\377\376\3\343\377\377\2\344" +\
    "\377\377\3\343\377\377\2\345\377\377\1\346\377\377\1\346\377\377\1\346" +\
    "\377\377\1\345\377\377\1\346\377\377\1\346\377\377\1\346\377\377\1\346" +\
    "\377\377\2\346\377\377\1\344\377\377\3\343\377\377\3\344\377\377\4\343" +\
    "\377\377\5\342\377\377\6\341\377\375\7\337\377\366\7\330\377\336\7\303" +\
    "\377\246\5\205\377\323\3\14\377\375\5\13\377\375\6\13\377\375\5\13\377" +\
    "\374\6\14\377\375\6\13\377\375\7\13\377\374\7\12\377\366\10\13\377\347" +\
    "\10\11\377\303\7\0\377\237\5W\377\364\0\344\377\377\1\347\377\376\1\347" +\
    "\377\377\1\347\377\377\0\347\377\377\1\347\377\377\2\346\377\377\1\345" +\
    "\377\377\3\344\377\377\3\344\377\376\3\343\377\377\5\343\377\375\6\341" +\
    "\377\372\6\335\377\356\7\321\377\311\6\261\377\214\4z\377\24\0\22\377" +\
    "\0\0\0\356\0\0\0\205\0\0\0+\0\0\0\11\0\0\0\3\0\0\0\1\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16\0\0" +\
    "\0T\0\0\0\317N\1E\377\257\5\232\377\332\6\300\377\362\7\325\377\373\6" +\
    "\336\377\375\5\340\377\376\4\341\377\376\4\343\377\377\3\343\377\377" +\
    "\2\342\377\377\2\344\377\377\2\345\377\377\1\345\377\377\1\345\377\377" +\
    "\1\345\377\377\1\345\377\377\2\345\377\377\1\345\377\377\2\343\377\377" +\
    "\3\342\377\377\2\343\377\377\3\343\377\376\4\342\377\376\5\341\377\375" +\
    "\6\340\377\370\7\332\377\344\7\311\377\266\6\242\377\266\4\42\377\376" +\
    "\5\11\377\374\6\12\377\375\5\14\377\374\7\13\377\376\6\13\377\375\7\13" +\
    "\377\373\10\12\377\364\10\12\377\343\7\11\377\276\7\0\377\242\4\134\377" +\
    "\360\1\337\377\377\0\346\377\377\0\345\377\377\0\345\377\377\0\345\377" +\
    "\377\2\346\377\377\2\346\377\377\1\345\377\377\3\343\377\377\2\344\377" +\
    "\377\4\343\377\377\3\342\377\376\5\341\377\374\6\336\377\362\7\325\377" +\
    "\330\7\276\377\246\5\222\377:\1\63\376\0\0\0\375\0\0\0\263\0\0\0F\0\0" +\
    "\0\15\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0 \0\0\0u\6\0\5\346a\3V" +\
    "\377\261\5\234\377\332\5\277\377\360\7\324\377\372\6\334\377\375\4\340" +\
    "\377\376\4\342\377\377\2\343\377\377\2\343\377\377\3\342\377\377\2\343" +\
    "\377\377\1\343\377\377\2\342\377\377\2\342\377\377\1\342\377\377\2\343" +\
    "\377\377\2\343\377\377\2\342\377\377\3\342\377\377\4\343\377\376\4\342" +\
    "\377\376\5\341\377\375\6\337\377\366\7\331\377\345\7\312\377\276\5\254" +\
    "\377\245\5\63\377\370\5\10\377\375\5\12\377\375\6\13\377\375\7\12\377" +\
    "\374\6\12\377\374\7\13\377\371\7\12\377\357\7\11\377\334\7\10\377\261" +\
    "\7\6\377\250\5m\377\364\2\341\377\377\2\345\377\377\2\345\377\377\2\345" +\
    "\377\377\2\345\377\377\2\345\377\377\1\345\377\377\2\344\377\377\3\343" +\
    "\377\377\2\342\377\376\4\342\377\376\3\342\377\376\5\341\377\373\6\336" +\
    "\377\363\7\326\377\334\6\301\377\260\5\233\377\134\2P\376\1\0\0\377\0" +\
    "\0\0\326\0\0\0e\0\0\0\31\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\5\0\0\0/\0\0\0\212\7\0\6\356c\2W\377\255\4\230\376\323\5\272\377" +\
    "\353\6\317\377\367\6\332\377\373\5\337\377\375\4\341\377\376\3\341\377" +\
    "\376\3\343\377\377\3\341\377\376\2\342\377\377\2\341\377\377\2\341\377" +\
    "\377\2\341\377\376\3\342\377\377\2\341\377\377\3\342\377\377\3\341\377" +\
    "\377\5\342\377\376\5\341\377\374\6\335\377\364\6\327\377\342\6\306\377" +\
    "\276\5\252\377\235\6\65\377\366\5\7\377\375\6\13\377\374\6\13\377\373" +\
    "\7\11\377\371\7\13\377\365\7\12\377\357\7\11\377\343\6\10\377\314\6\5" +\
    "\377\240\6\27\377\274\3\230\377\374\2\343\377\376\3\342\377\376\2\342" +\
    "\377\377\2\342\377\377\1\342\377\377\1\342\377\377\2\342\377\377\2\342" +\
    "\377\377\2\342\377\377\2\343\377\377\3\342\377\376\4\342\377\375\4\340" +\
    "\377\372\6\335\377\360\6\324\377\332\6\300\377\261\4\234\377l\3`\376" +\
    "\4\0\4\377\0\0\0\351\0\0\0\202\0\0\0*\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0\08\0\0\0\221\4\0\3\357M\1D" +\
    "\377\240\4\214\376\303\4\254\377\337\6\305\377\357\6\323\377\367\5\332" +\
    "\377\373\5\336\377\376\3\341\377\375\3\341\377\377\4\343\377\376\4\341" +\
    "\377\376\4\341\377\376\4\341\377\377\3\341\377\375\4\341\377\375\4\340" +\
    "\377\375\5\337\377\373\5\335\377\366\5\331\377\354\6\317\377\330\5\275" +\
    "\377\257\4\234\377\242\4\42\377\366\5\11\377\372\7\13\377\366\6\12\377" +\
    "\362\6\11\377\351\6\10\377\340\6\10\377\324\5\10\377\305\5\6\377\251" +\
    "\7\6\377\225\6P\377\343\5\311\377\375\5\343\377\375\4\341\377\377\3\341" +\
    "\377\377\3\342\377\376\3\341\377\377\1\342\377\377\2\341\377\377\2\341" +\
    "\377\377\3\342\377\376\2\341\377\376\4\342\377\375\4\340\377\373\5\336" +\
    "\377\366\5\332\377\352\5\316\377\322\5\271\377\253\5\226\377i\2\134\377" +\
    "\4\0\4\377\0\0\0\364\0\0\0\223\0\0\08\0\0\0\10\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0\0\67\0\0" +\
    "\0\210\1\0\0\346!\0\36\377\201\3p\376\255\4\227\377\307\5\260\377\333" +\
    "\5\301\377\352\5\316\377\363\6\326\377\367\4\331\377\372\3\336\377\373" +\
    "\4\340\377\373\3\336\377\373\3\336\377\371\4\334\377\366\4\330\377\362" +\
    "\6\324\377\351\5\316\377\341\6\304\377\321\6\270\377\274\5\251\377\213" +\
    "\5d\377\274\5\16\377\351\6\10\377\347\6\11\377\340\6\10\377\327\6\10" +\
    "\377\312\6\10\377\272\5\7\377\253\5\6\377\220\5\7\377s\5\62\377\244\4" +\
    "\213\377\331\5\301\377\354\6\320\377\366\5\330\377\373\5\335\377\375" +\
    "\3\340\377\376\3\341\377\377\3\342\377\377\3\342\377\377\3\342\377\376" +\
    "\3\342\377\376\3\341\377\375\3\341\377\373\4\335\377\367\5\331\377\354" +\
    "\5\320\377\334\5\302\377\300\5\251\377\240\4\214\377G\1>\376\2\0\2\377" +\
    "\0\0\0\363\0\0\0\226\0\0\0>\0\0\0\13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\0\0\0-" +\
    "\0\0\0q\0\0\0\306\5\0\5\3754\1.\377\201\3r\377\247\3\224\377\273\4\244" +\
    "\377\312\4\262\377\327\4\274\377\335\4\303\377\341\5\306\377\341\5\306" +\
    "\377\340\5\306\377\333\4\300\377\321\4\270\377\305\4\255\377\273\4\244" +\
    "\377\245\3\223\377}\3c\377\203\3\35\377\261\4\4\377\274\5\5\377\267\5" +\
    "\6\377\264\4\6\377\253\4\6\377\236\4\5\377\203\3\5\376K\2\3\377\33\1" +\
    "\1\377\1\0\0\377\32\0\31\377t\2e\377\250\3\224\376\300\4\252\377\325" +\
    "\5\275\377\344\5\311\377\356\5\321\377\363\5\326\377\367\4\332\377\370" +\
    "\5\333\377\370\4\333\377\367\4\332\377\364\4\327\377\356\5\321\377\345" +\
    "\5\311\377\327\5\275\377\301\4\252\377\251\4\224\377u\3f\377\33\0\30" +\
    "\377\0\0\0\377\0\0\0\341\0\0\0\210\0\0\0:\0\0\0\15\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\5\0\0\0\36\0\0\0O\0\0\0\224\0\0\0\331\0\0\0\374" +\
    "!\0\35\377O\1E\377z\2l\377\226\3\204\376\245\3\220\377\251\4\225\377" +\
    "\252\4\225\377\247\4\223\377\236\3\213\377\212\2z\377g\2[\376;\2\62\377" +\
    "*\2\21\377@\1\0\377N\1\1\377K\1\2\377J\1\2\377I\2\3\3778\1\2\377&\1\2" +\
    "\377\14\0\0\377\0\0\0\377\0\0\0\376\0\0\0\356\0\0\0\340\0\0\0\345\0\0" +\
    "\0\371'\1\42\377h\2\134\377\230\3\206\377\260\3\233\377\301\4\251\377" +\
    "\314\4\263\377\324\4\271\377\327\4\275\377\326\4\275\377\324\4\273\377" +\
    "\314\4\263\377\302\4\252\377\261\4\233\377\232\4\206\377k\2^\376*\1%" +\
    "\377\0\0\0\377\0\0\0\371\0\0\0\304\0\0\0n\0\0\0-\0\0\0\11\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\16\0\0\0-\0\0\0[\0" +\
    "\0\0\221\0\0\0\315\0\0\0\354\0\0\0\373\17\0\15\376\42\0\36\377&\0!\377" +\
    "'\0!\377%\0 \377\30\0\25\377\5\0\5\376\0\0\0\376\0\0\0\373\0\0\0\363" +\
    "\0\0\0\360\0\0\0\360\0\0\0\360\0\0\0\360\0\0\0\360\0\0\0\355\0\0\0\347" +\
    "\0\0\0\335\0\0\0\275\0\0\0\225\0\0\0o\0\0\0W\0\0\0^\0\0\0\212\0\0\0\314" +\
    "\0\0\0\363\12\0\12\376;\1\64\377b\2V\377\202\3s\377\222\3\200\377\225" +\
    "\3\202\377\225\3\203\377\221\3\177\377\202\3s\377d\2X\377=\1\66\377\16" +\
    "\0\14\377\0\0\0\376\0\0\0\364\0\0\0\323\0\0\0\214\0\0\0L\0\0\0\34\0\0" +\
    "\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\2\0\0\0\17\0\0\0(\0\0\0I\0\0\0o\0\0\0\226\0\0\0\272\1" +\
    "\0\0\324\1\0\0\340\1\0\1\345\1\0\0\343\0\0\0\333\0\0\0\310\0\0\0\254" +\
    "\0\0\0\217\0\0\0{\0\0\0s\0\0\0r\0\0\0s\0\0\0s\0\0\0r\0\0\0m\0\0\0a\0" +\
    "\0\0Q\0\0\0<\0\0\0'\0\0\0\25\0\0\0\11\0\0\0\15\0\0\0%\0\0\0M\0\0\0~\0" +\
    "\0\0\265\0\0\0\344\0\0\0\364\0\0\0\375\1\0\1\376\1\0\1\376\1\0\1\376" +\
    "\0\0\0\376\0\0\0\376\0\0\0\375\0\0\0\365\0\0\0\347\0\0\0\271\0\0\0\203" +\
    "\0\0\0S\0\0\0(\0\0\0\14\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0" +\
    "\0\0\7\0\0\0\25\0\0\0(\0\0\0;\0\0\0J\0\0\0Q\0\0\0U\0\0\0S\0\0\0N\0\0" +\
    "\0D\0\0\0\63\0\0\0!\0\0\0\26\0\0\0\23\0\0\0\23\0\0\0\23\0\0\0\23\0\0" +\
    "\0\23\0\0\0\22\0\0\0\17\0\0\0\12\0\0\0\4\0\0\0\1\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\1\0\0\0\13\0\0\0\36\0\0\0:\0\0\0\134\0\0\0\200\0\0\0\236\0" +\
    "\0\0\264\0\0\0\276\0\0\0\301\0\0\0\276\0\0\0\264\0\0\0\240\0\0\0\202" +\
    "\0\0\0`\0\0\0=\0\0\0!\0\0\0\15\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\0\4\0\0\0\10\0\0\0" +\
    "\11\0\0\0\13\0\0\0\12\0\0\0\11\0\0\0\6\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0" +\
    "\16\0\0\0\35\0\0\0-\0\0\08\0\0\0<\0\0\0>\0\0\0<\0\0\08\0\0\0.\0\0\0\37" +\
    "\0\0\0\17\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\1\0\0\0\3\0\0\0\4\0\0\0\4\0\0\0\4\0\0\0\3\0\0\0\2\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0"


# RGBA 24x24x4
viewer_icon_24_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0Br\253\0K\177\265\0\0\0\0\0:i\241\2L\202\271" +\
    "\27S\206\272W\134\216\276\245W\221\306\327w\231\267\356\237\250\253\356" +\
    "\233\245\254\327\242\247\247\247\227\240\245W\226\237\241\30\231\234" +\
    "\230\4\0\0\0\0\246\251\246\0\237\242\237\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0@p\247+P\206\274\227V\220\305\357" +\
    "\205\241\271\377\234\256\272\377|\261\327\377\227\255\272\377\332\332" +\
    "\330\377\260\267\272\377\260\263\264\377\306\306\303\377\261\264\261" +\
    "\362\243\247\244\240\234\237\2345\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\77m\243\0\0\0\0\0@s\255\134R\212\301\352`\240\327" +\
    "\377|\260\331\377\324\330\332\377\322\325\326\377\304\317\327\377\343" +\
    "\347\350\377\355\355\354\377\325\336\342\377\212\246\272\377o\210\234" +\
    "\377\264\270\272\377\302\304\302\377\253\255\253\356\237\242\236k\0\0" +\
    "\0\0\236\241\236\0\0\0\0\0\0\0\0\0\217\221\217\0\0\0\0\0\0\0\0\0_\177" +\
    "\242Zr\223\264\377\224\264\320\377\265\312\332\377\341\342\341\377\350" +\
    "\351\350\377\357\360\360\377\366\366\366\377\366\367\367\377\364\363" +\
    "\363\377\315\322\325\377\362\360\357\377\260\323\353\377v\236\273\377" +\
    "\320\323\323\377\310\312\311\377\256\260\256\377\242\244\241k\0\0\0\0" +\
    "\0\0\0\0+Fo\0\210\213\202\0\0\0\0\0\222\225\221i\234\241\241\377\301" +\
    "\301\274\377\324\324\321\376\336\336\334\377\344\345\345\377\360\361" +\
    "\360\377\372\372\372\377\376\376\376\377\365\365\365\377\252\300\315" +\
    "\377\222\276\326\377\364\372\371\377\302\313\307\377\134\232\265\377" +\
    "\313\313\320\377\336\340\337\376\312\313\307\377\233\234\233\377otwk" +\
    "\0\0\0\0Az\274\0\0\0\0\0\223\224\2147\230\233\230\357\271\272\267\377" +\
    "\324\324\320\376\336\337\334\377\336\340\337\377\351\353\351\377\370" +\
    "\370\370\377\377\377\377\377\377\377\377\377\340\346\351\377\214\313" +\
    "\353\377\245\252\265\377\203n\227\377\12|\326\377\2\331\356\377)\301" +\
    "\305\377\266\260\262\377p\214\246\376U\202\257\377Bl\232\354.U\213+\0" +\
    "\0\0\0\4>\221\2H_y\232\223\233\237\377r\207\231\377Jv\236\377f\207\242" +\
    "\377\337\340\337\377\357\361\360\377\365\363\364\377\367\361\361\377" +\
    "\367\363\362\377\357\362\361\377X\272\277\377\0\273\276\377\0\207\347" +\
    "\377\0\0\377\377\0\0\367\377\0\305\374\377+n\213\377R\204\261\377V\215" +\
    "\302\377H{\261\3775]\222\227#Cu\2/V\213\308e\234\360Fu\247\377W\223\316" +\
    "\377g\247\340\377j\256\344\377\206\247\276\377\332\311\306\377\333\237" +\
    "\230\377\336\233\223\377\336\221\206\377+\253\253\377\0\377\377\377\0" +\
    "\377\377\377\0\365\355\377\0\0\377\377\0\0\377\377\0\33\362\377 T\134" +\
    "\377;^~\377L}\254\377K~\264\3777a\223\360-Q\203\30+O\202Y<i\236\377O" +\
    "\206\276\377Z\225\317\377d\241\332\377l\255\343\377p\232\303\377\320" +\
    "B6\377\377SB\377\377}t\377\365I;\377\27\315\322\377\0\377\377\377\0\377" +\
    "\377\377\0\345\353\377\0\0\377\377\0\0\377\377\0\0\346\377\33--\377+" +\
    "F^\377Dp\233\377I{\260\3779d\226\377)K{X*K}\247>k\241\377M\202\273\377" +\
    "X\221\313\377a\236\327\377j\254\343\377ti\210\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377sJO\377h\365\365\377c\375\374\377:\302\353" +\
    "\3777B\377\377\30\37\377\377\2(\275\377\32(-\377)C\134\377An\231\377" +\
    "Gy\255\377:e\230\377'Gu\246(Hx\331<h\235\377I|\265\377T\214\306\377]" +\
    "\231\323\377e\250\341\377\200Vq\377\377\0\0\377\376\0\0\377\376\0\0\377" +\
    "\377\0\0\377\370\0\0\377\224},\377\227\263]\377j\245\325\377\215\261" +\
    "\375\377I\257\377\377\6\246\267\377\32!/\377+Gb\377Bn\234\377Et\251\377" +\
    "8b\224\377$Co\330%Cq\3578b\226\377Du\254\377O\204\277\377X\222\314\377" +\
    "a\236\330\377m}\251\377\366\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\360\0\0\377\363\354\0\377\375\360\0\377\214\220,\377e\263\300\377U\266" +\
    "\263\377\268>\377\31(8\377+If\377@l\233\377\77m\242\3774[\215\377!>h" +\
    "\356!<h\3562Y\214\377=k\242\377H{\264\377R\211\304\377Z\224\317\377^" +\
    "\225\315\377\241$:\377\363\0\0\377\375\0\0\377\374\0\0\377\341z\0\377" +\
    "\377\377\0\377\376\375\0\377\377\377\0\377\361\343\0\377\313\274\0\377" +\
    "#,(\377\32,>\377.Np\377=i\232\377:e\231\377/T\203\377\368`\355\34\65" +\
    "]\330,O\177\3777a\226\377Ap\251\377J\177\270\377S\212\305\377]\213\307" +\
    "\377\246Ad\377\31452\377\2737\32\377\355\224\0\377\375\374\0\377\376" +\
    "\376\0\377\376\376\0\377\377\377\0\377\377\377\0\377\276p\1\377 \36)" +\
    "\377\36\63H\3773V}\377:e\227\3774[\215\377)Jv\377\32\62W\326\30-R\244" +\
    "$Co\377/U\207\3779d\232\377Br\253\377J\200\272\377\134h\226\377\354f" +\
    "\251\377\356u\304\377\323!+\377\267\213\0\377\375\377\0\377\377\377\0" +\
    "\377\377\377\0\377\372\377\0\377\342u\0\377\302\5\4\377#\37)\377\35\63" +\
    "M\3770T\177\3775\134\215\377-Q\177\377\42\77h\377\26+M\243\23&GU\35\66" +\
    "]\377(Iw\3770V\211\3779d\231\377;u\251\377\260 \271\377\377+\377\377" +\
    "\377\37\377\377\371\20\331\377\311\0\0\377\277\42\0\377\344`\0\377\347" +\
    "W\0\377\354\14\0\377\371\0\0\377s\21\20\377(++\377>GQ\377D^}\377.Q\177" +\
    "\377'Do\377\34\64X\377\23%DU\20!@\26\26,O\355!=f\377)Iw\3770U\207\377" +\
    "/f\224\377\324\0\310\377\377\0\377\377\377\0\377\377\376\0\356\377\371" +\
    "\0\1\377\300\0c\377\315\0G\377\276\0\6\377\257\5\7\377i\22\22\377 \42" +\
    "\42\377010\377XYV\377x}~\377-Ip\377 :`\377\25)I\355\20\37:\26\10\20\42" +\
    "\2\23$D\224\32\62W\377\42>g\377'Gt\377+R\201\377a0\213\377\377\0\362" +\
    "\377\377\0\377\377\360\0p\377\362\0L\377\377\0\376\377\262\2\246\377" +\
    "\35\34\31\377(#\42\377&)(\377010\377DFD\377bdd\377DUi\377 ;b\377\31/" +\
    "Q\377\20!=\224\6\15\34\2\0\0\0\0\15\30\61'\24&G\350\34\64Y\377\42=e\376" +\
    "&Cn\377%Hs\377%7\134\377\33 \66\377\13\25\34\377\30\23\60\3773\209\377" +\
    "\3\27\32\377\21\30\42\377021\377BCB\377MOM\377Y\134[\377Z`e\377%<_\376" +\
    "\33\63X\377\22%E\350\13\26-'\0\0\0\0\23#E\0\0\0\0\0\15\32\65U\24&E\377" +\
    "\37\66Z\377&>d\376'Ai\377\42=b\377\32\60M\377\24%;\377\21\42\66\377\20" +\
    "#\66\377\23\42\67\377\33%\64\377CEF\377TUV\377X[Y\377\77K]\377%<`\376" +\
    "\33\63X\377\23&F\377\14\32\65T\0\0\0\0\20!@\0\10\20 \0\0\0\0\0\0\0\0" +\
    "\0\15\32\63Q\25%B\377%8Z\377.Cg\377/Ej\377+@d\377&:[\377%9X\377%9Y\377" +\
    "%9X\377/;M\377ILP\377LOR\377>IY\377*@f\377\37\66\134\377\23&G\377\16" +\
    "\348Q\0\0\0\0\0\0\0\0\6\15\34\0\0\0\0\0\0\0\0\0\12\24)\0\0\0\0\0\12\26" +\
    "/R\24#@\347'9Z\3776Jp\377>Rx\377>Rx\377=Qv\377>Rw\377\77Sw\377DPe\377" +\
    "JNV\377@K]\377/Cj\377\36\64Z\377\22%H\346\14\32\67Q\0\0\0\0\13\27/\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\21)$\20\36" +\
    ":\221\34,M\357*<`\3774Gm\377<Ns\377\77Rv\377>Pu\377=H\134\3776<H\377" +\
    "\37\63X\377\24&G\357\16\37\77\221\14\30\64#\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\11\24\0\16\35<\0\0\0\0\0\0\0" +\
    "\14\1\11\23)\30\13\26,`\16\32\63\256\17\34\65\336\21\36\67\364\21\35" +\
    "\67\363\17\33\62\334\15\27,\254\11\24)_\11\23)\30\0\0\10\1\0\0\0\0\22" +\
    "$H\0\4\11\25\0\0\0\0\0\0\0\0\0\0\0\0\0"


# RGBA 32x32x4
viewer_icon_32_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Fx\261" +\
    "\0\0\0\0\0\0\0\0\0H{\262GO\203\271\220S\212\277\276T\215\302\342w\227" +\
    "\264\355\227\241\247\354\222\237\247\342\225\237\245\276\235\241\241" +\
    "\224\213\230\242G\0\0\0\0\0\0\0\0\234\240\240\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0;m\246\14K~\264\225S\212\300\377" +\
    "k\231\301\377\216\254\304\376x\255\326\377h\250\331\377\250\260\263\377" +\
    "\306\310\306\377\304\306\304\377\303\305\302\377\270\272\267\376\256" +\
    "\260\255\377\241\246\244\377\236\242\237\236\235\240\235\32\0\0\0\0\237" +\
    "\241\237\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Bq\251\0\0\0\0\0Fw\256\200Q\207\275\377" +\
    "`\235\322\377c\232\307\377\265\263\257\377\251\253\253\377\252\266\275" +\
    "\377{\274\351\377\233\254\267\377\345\346\345\377\346\347\346\377Zq\202" +\
    "\377\263\266\271\377\333\334\333\377\310\312\311\377\265\267\265\376" +\
    "\245\250\245\377\237\242\237\226\0\0\0\0\237\242\237\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0@n\245\09c" +\
    "\240\14Gy\260\332X\221\306\377e\244\331\377i\255\341\377\244\300\325" +\
    "\377\344\346\345\377\345\346\346\377\261\275\306\377\360\357\355\377" +\
    "\361\361\360\377\355\356\356\377\352\353\352\377\316\336\347\377y\234" +\
    "\265\377Zy\221\377\201\215\226\377\330\331\330\377\303\305\303\377\256" +\
    "\261\256\377\241\244\241\353\235\240\233\32\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0g\177\233\0\24U\244\30W~\252\366" +\
    "u\234\300\376\214\262\322\377\244\301\330\377\325\333\335\377\344\344" +\
    "\343\377\350\350\350\377\354\355\355\377\362\362\362\377\364\364\364" +\
    "\377\365\365\365\377\364\364\364\377\355\356\356\377\310\312\314\377" +\
    "\365\364\362\377\257\322\351\377e\247\326\377\220\231\240\377\333\334" +\
    "\333\377\310\312\311\377\264\267\264\376\242\245\242\377\234\237\234" +\
    ")\302\263\260\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\222\226\222\0" +\
    "\233\234\222\23\213\224\233\365\257\257\252\376\302\303\300\377\321\322" +\
    "\320\377\332\333\332\377\340\341\340\377\346\346\346\377\355\356\355" +\
    "\377\365\365\365\377\372\372\372\377\374\374\374\377\374\374\374\377" +\
    "\370\366\366\377\246\256\265\377x\246\301\377\367\367\365\377\364\364" +\
    "\363\377\276\322\341\377i\237\305\377\335\335\334\377\327\331\330\377" +\
    "\312\315\313\377\267\271\270\376\242\244\241\377\230\233\230\32\226\231" +\
    "\225\0\0\0\0\0\0\0\0\0\0\0\0\0\214\217\214\0\0\0\0\0\223\226\223\357" +\
    "\245\250\245\376\273\275\273\377\313\315\314\377\324\326\325\377\332" +\
    "\334\333\377\341\342\342\377\352\353\352\377\365\365\365\377\374\375" +\
    "\374\377\376\376\376\377\377\377\377\377\351\351\351\377k\224\253\377" +\
    "|\306\354\377\315\345\363\377\375\375\374\377\227\234\240\377'\204\232" +\
    "\3779\205\240\377\327\321\320\377\336\337\336\377\330\331\330\377\272" +\
    "\271\266\377\201\206\211\376fnu\355\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\216\221\215\233\233\236\232\377\264\266\264\377\317\321\316\377" +\
    "\334\334\331\377\336\337\336\377\335\337\336\377\345\346\345\377\360" +\
    "\360\360\377\373\373\373\377\376\376\376\377\376\377\376\377\377\377" +\
    "\377\377\330\341\346\377\224\330\371\377~\265\323\377\300\223\213\377" +\
    "ZO\205\377\0m\337\377\0\260\357\377\0\377\377\377\21\260\271\377\257" +\
    "\253\254\377{\213\231\377G{\252\377O\205\271\377@p\244\3773Z\217\200" +\
    "\0\0\0\0\0\0\0\0\62[\227\0\10@\220\16Xdr\377\260\262\255\377\201\212" +\
    "\222\377Jm\216\377Hq\225\377n\205\230\377\347\346\344\377\351\352\351" +\
    "\377\363\364\364\377\375\375\376\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\200\261\266\377\11\233\240\377\4\274" +\
    "\314\377\0j\353\377\0\0\377\377\0\0\377\377\0\26\353\377\0\375\377\377" +\
    "+m\213\377N\200\252\377W\216\300\377U\215\303\377K\177\264\3777`\225" +\
    "\377+O\205\15\62[\230\0\0\0\0\0/V\213\226\77o\247\377Cf\214\377U\216" +\
    "\306\377b\240\330\377i\252\340\377l\254\340\377\226\247\264\377\355\355" +\
    "\355\377\362\367\367\377\273\241\237\377\274\214\210\377\273\215\211" +\
    "\377\264\235\227\3776\215\214\377\0\377\377\377\0\377\376\377\0\376\377" +\
    "\377\0\344\350\377\0\0\377\377\0\0\377\377\0\0\377\377\0Q\360\377\36" +\
    "l~\377=c\203\377Ix\242\377P\205\270\377M\201\267\377>k\240\377,Q\203" +\
    "\225\0\0\0\0\0\0\0\0\61X\214\377Ev\256\377R\211\302\377Z\225\316\377" +\
    "b\236\327\377h\247\336\377n\260\344\377\134\225\300\377\306\310\311\377" +\
    "\272[R\377\377\236\217\377\377\254\240\377\377\246\231\377\364~o\377" +\
    "\0\336\347\377\0\376\376\377\0\377\377\377\0\377\377\377\0\356\351\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\355\377\34\658\377)CY\377;`" +\
    "\202\377Jz\251\377L\177\264\377Bq\245\377.S\204\377\0\0\0\0&GyI\64]\221" +\
    "\377Fx\257\377P\207\300\377Y\223\314\377`\235\326\377f\246\334\377m\256" +\
    "\342\377l\260\341\377\237\23\23\377\377^H\377\377E6\377\377tl\377\377" +\
    "\134Q\377\330)\32\377\0\352\362\377\0\376\376\377\0\377\377\377\0\377" +\
    "\377\377\0\332\347\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\335\377" +\
    "\31)+\377 5G\3773Ts\377Fs\240\377J|\260\377Cq\246\3771X\211\377$CrH&" +\
    "Fw\2227`\225\376Ev\256\377N\204\275\377W\220\312\377^\232\324\377e\243" +\
    "\333\377j\253\340\377U\203\252\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\376\0\0\377@pw\377i\377\377\377\203\376\376" +\
    "\3775\377\376\377'\266\346\377(:\377\377\16\33\377\377\13\20\377\377" +\
    "\0\21\253\377\30%.\377 4E\3773Ss\377Dr\237\377Hy\257\377Aq\245\3773Z" +\
    "\214\376$Bp\221%Eu\3016_\223\377Cs\252\377L\200\271\377T\214\306\377" +\
    "[\226\320\377b\240\330\377g\250\336\377kj\213\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\332\0\0\377L_X\377" +\
    "f\272\302\377p\322\337\377\211\254\351\377\234\244\377\377{\177\377\377" +\
    ";R\354\377\0\273\307\377\30 ,\377!6J\3775Wx\377Ds\242\377Fw\254\377\77" +\
    "m\242\3773Z\212\377#@m\300#Bp\3434\134\220\377@n\245\377I{\264\377P\207" +\
    "\301\377X\222\314\377_\233\324\377d\242\333\377^n\221\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\332\230\0\377\347\313\0\377\242\200\0\377D\244\334\377w\270\357" +\
    "\377M\302\351\377\33\377\377\377\4t\201\377\30%\63\377!8L\3775Y|\377" +\
    "Cq\241\377Ds\250\377<h\234\3771V\207\377 =h\342\42\77k\3561W\212\377" +\
    "<i\236\377Eu\256\377M\201\273\377T\214\307\377Z\225\320\377`\236\327" +\
    "\377Y\237\325\377\327\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\376\0\0\377\350\0\0\377\366\367\0\377\376\371\0\377\377\366" +\
    "\0\377\204{\27\377e\254\254\377e\277\313\377K\210p\377\20\30%\377\27" +\
    "&\64\377\429P\3775Y~\377An\237\377@n\243\3779c\226\377.R\201\377\37:" +\
    "c\354\37:e\355-R\202\3777b\227\377@o\246\377H{\264\377O\206\277\377W" +\
    "\217\312\377\134\227\321\377a\236\330\377YQm\377\374\0\0\377\377\0\0" +\
    "\377\377\0\0\377\376\0\0\377\377\0\0\377\327y\0\377\377\376\0\377\377" +\
    "\372\0\377\376\375\0\377\377\377\0\377\357\340\0\377\356\340\0\377\237" +\
    "\231\4\377\21\37/\377\30(8\377%>X\3776[\203\377>k\235\377;h\234\3775" +\
    "\134\216\377*Ly\377\34\65]\353\33\64]\342)Kz\3773[\216\377;g\235\377" +\
    "Cs\253\377J~\267\377P\210\302\377W\220\313\377[\226\321\377zG\247\377" +\
    "\203\26\77\377\250\0\0\377\360\0\0\377\355\0\0\377\320M\0\377\377\377" +\
    "\0\377\376\376\0\377\377\376\0\377\377\377\0\377\377\377\0\377\376\377" +\
    "\0\377\377\377\0\377m3\10\377\22#\60\377\32-\77\377*Fd\3778_\213\377" +\
    "<h\232\3777a\224\3770U\206\377&Eq\377\31\61V\341\30/U\276$Co\377.S\204" +\
    "\3776_\223\377=j\241\377Du\256\377K\177\271\377Q\207\302\377V\223\321" +\
    "\377\223BM\377\377rg\377\374da\377}[E\377\353\362\0\377\377\377\0\377" +\
    "\376\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\376\376\0\377" +\
    "\377\377\0\377\325\212\0\377\235\0\5\377\21\42\61\377\35\60E\377,Ln\377" +\
    "7`\217\3778b\225\3773Y\212\377,M{\377\42>g\377\26,O\275\24(K\217\37:" +\
    "b\376(Jx\3770U\207\3776a\226\377>k\243\377Du\256\377J~\270\377Bg\223" +\
    "\377\355H\217\377\350\206\347\377\352o\316\377\357\22\63\377\221\30\0" +\
    "\377\321\320\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\367\377\0\377\327p\0\377\377\0\0\377s\16\15\377\31$.\377\34\60" +\
    "F\377+Ko\3774[\213\3773Z\213\377.Q\177\377'Fp\377\35\66\134\376\23&G" +\
    "\216\20!@C\31\60U\377#Al\377*M{\3770V\211\3776`\226\377=k\242\377Cv\257" +\
    "\377\223(\245\377\377,\377\377\377;\377\377\376\34\376\377\370\30\372" +\
    "\377\370\0\1\377\212\0\0\377\3326\0\377\337r\0\377\342z\0\377\336T\0" +\
    "\377\350\5\0\377\377\0\0\377\353\0\0\377\36\37\37\377*,-\3777@J\377F" +\
    "[u\377+P\177\377.Q\200\377(Ht\377\42=f\377\30.Q\377\21\37=C\0\0\0\0\23" +\
    "'H\376\35\67_\377%Co\377+M|\3771V\210\3775_\224\3775n\240\377\322\0\303" +\
    "\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\354\09\377" +\
    "\377\0\0\377w\0\20\377\347\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\332\0\0\377/\26\26\377%%%\377./.\377KLK\377suq\377y\203\215\377%Fs\377" +\
    "#@h\377\34\65Z\377\23%C\375\0\0\0\0\0\0\0\0\20 >\217\31/T\377 ;c\377" +\
    "%Cn\377*Kz\377/T\205\3771_\222\377\260\14\255\377\377\0\377\377\377\0" +\
    "\377\377\377\0\376\377\377\0\377\377\352\0\25\377\370\0\0\377\366\0\344" +\
    "\377\272\0\252\377c\5\33\377p\16\15\377E\22\22\377\31!!\377$%$\377()" +\
    "(\377898\377VWV\377xzw\377Vet\377!>h\377\378^\377\27+M\377\17\358\216" +\
    "\0\0\0\0\2\6\13\0\4\10\24\10\23%E\377\33\63X\377 ;c\377$Bm\377(Hv\377" +\
    ",O\200\3775Bu\377\340\0\317\377\377\0\377\377\377\0\377\377\354\0o\377" +\
    "\352\0\3\377\367\0\306\377\377\0\377\377\317\0\277\377\17\26\34\377$" +\
    "%$\377&'&\377)*)\377./.\377898\377JLK\377bdc\377\134di\377\369b\377\37" +\
    "9`\377\31\60S\377\21\42>\377\1\5\14\10\2\5\10\0\0\0\0\0\0\0\0\0\17\34" +\
    "\67w\25)K\377\34\64Z\377!;c\377$@j\377&Ep\377)Iv\377\35Eg\3773&S\377" +\
    "\30\34/\377\20\24\35\377\0\25!\377:\15<\377:\15=\377\4\26\33\377\14\26" +\
    "\42\377\26\32 \377222\377=>=\377EFF\377OQO\377[^\134\377jkg\3771E^\377" +\
    "\379`\377\33\63X\377\24'H\377\15\31\63v\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\17\369\321\27+M\376\36\65Y\377#<b\377%\77h\377%Aj\377$\77" +\
    "h\377\37\67Z\377\27)C\377\21\37\62\377\17\33,\377\17\34-\377\20\34-\377" +\
    "\17\33,\377\17\34,\377 &+\377BDC\377PQQ\377WZY\377Z]\134\377OV\134\377" +\
    "0B_\377\378_\377\34\63X\377\26*L\376\16\35:\320\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\12\24)\0\2\2\3\7\17\359\360\31,L\376\42\67[\377'>" +\
    "c\377)@g\377(@f\377$;_\377\36\63S\377\32,G\377\30*C\377\30*C\377\30*" +\
    "D\377\30)C\377\30)B\377-3;\377KMM\377SUV\377TVX\377OST\377&=b\377\42" +\
    ":a\377\35\64Y\377\26*M\376\17\37=\357\1\0\5\7\12\24*\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\12\25*\0\4\12\31\20\16\34\66\357\31+J\376" +\
    "&9[\377.Bf\3771Fk\3770Fk\377-Bf\377)>`\377(<\134\377'<]\377(=]\377(<" +\
    "]\377&:Y\377>BH\377JNR\377KOR\377EJQ\3770Dd\377'\77f\377 7]\377\26*M" +\
    "\376\17\36=\356\5\16\36\17\13\27.\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\12\24(\0\0\0\4\5\15\31\63\314\27'E\377(;]\376" +\
    "4Hl\377:Nu\377=Qw\377<Pv\377;Pt\377:Os\377<Pu\377<Qu\377;Nq\377KOW\377" +\
    "JNU\377DKV\3777Ik\377,Bj\377\36\65\134\376\24(L\377\16\36<\313\0\0\0" +\
    "\4\13\27\60\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\11\22&\0\0\0\0\0\13\27\60o\20\37<\377 2U\3773Fl\377" +\
    "\77Sz\377CW~\377EX~\377FY\177\377GZ\200\377H[\201\377FVx\377MQZ\377H" +\
    "LT\3773Ho\377$:`\377\26*N\377\20!B\377\15\349n\0\0\0\0\12\25,\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\13\27\60\221\17\36;\377\30*L\377" +\
    "\42\64X\376+=`\3770Bf\3772Eh\3771Dg\377,=]\377/4<\377\36(;\376\21\42" +\
    "C\377\15\349\377\13\27\61\221\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\15\34S\11\23(" +\
    "\232\12\25,\311\12\26-\346\13\27/\365\13\27/\364\12\26-\345\11\25-\307" +\
    "\10\23(\230\6\15\33P\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"


# RGBA 64x64x4
viewer_icon_64_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0H{\261" +\
    "3I|\263lL\177\265\215M\202\266\275O\203\271\312M\204\271\326Y\207\266" +\
    "\336s\220\253\336\221\234\243\326\204\227\247\312i\214\255\275q\216\253" +\
    "\215v\220\251l\205\226\245;\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0T\205\261\0\0\0\0\0Dw\257\25I|" +\
    "\262sL\177\266\306N\203\270\377S\211\275\377W\217\303\377Z\223\310\376" +\
    "\134\226\312\377]\227\313\377~\237\274\377\256\256\247\377\252\254\251" +\
    "\377\251\253\251\377\251\253\250\377\251\252\246\377\247\251\244\376" +\
    "\245\247\243\377\242\245\241\377\235\242\241\377\223\235\242\306\210" +\
    "\227\243s@u\263\25\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Gw" +\
    "\257YJ}\264\315N\203\271\377U\214\301\377V\221\307\377Z\227\314\377^" +\
    "\233\320\377b\242\326\377h\246\330\377i\251\332\377a\236\313\377\214" +\
    "\236\251\377\273\276\273\377\274\277\274\377\274\276\273\377\272\274" +\
    "\272\377\270\272\270\377\266\270\266\377\263\265\263\377\257\262\257" +\
    "\377\253\256\253\377\247\252\247\377\245\247\243\377\237\243\241\377" +\
    "\226\236\240\322\230\237\237e\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0Ex\257\0\0\0\0\0Dw\256jJ|\263\365P\206\273" +\
    "\377W\220\305\376]\230\314\377a\231\310\377\253\263\266\377\272\274\270" +\
    "\377\301\301\276\377\261\300\311\377k\255\340\377s\264\345\377j\250\324" +\
    "\377r\207\226\377\324\325\324\377\320\322\321\377\317\321\320\377\317" +\
    "\320\317\377\314\316\315\377\314\316\314\377\306\310\306\377\303\305" +\
    "\304\377\276\301\276\377\271\273\271\377\263\265\263\377\255\260\255" +\
    "\377\247\252\247\376\243\245\242\377\237\242\237\377\236\241\236\221" +\
    "\246\244\237\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Ct\256\0\0\0\0\0Ar\253GGy\257" +\
    "\356O\204\272\377W\217\305\376]\231\316\377c\237\323\377m\237\307\377" +\
    "\305\306\303\377\313\316\314\377\321\323\322\377\323\324\323\377\330" +\
    "\330\327\377\237\301\331\377w\272\350\377u\267\344\377Qw\222\377\314" +\
    "\314\312\377\336\340\337\377\336\340\337\377\335\337\336\377\334\336" +\
    "\335\377\264\265\265\377IR[\377\272\273\273\377\322\323\322\377\316\317" +\
    "\316\377\307\311\307\377\300\302\277\377\270\272\270\377\260\263\260" +\
    "\377\250\254\250\377\243\245\243\377\237\242\237\377\236\241\237v\0\0" +\
    "\0\0\237\241\236\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0Br\251\0@j\253\4Dt\254\273K~\264\377T\213\301\376\134\226" +\
    "\314\377b\237\324\377h\247\332\377h\247\330\377c\213\252\377\240\241" +\
    "\237\377\227\231\230\377x{}\377\220\221\222\377\250\250\246\377v\216" +\
    "\237\377x\265\336\377\231\310\346\377\230\264\305\377\320\323\325\377" +\
    "\347\350\347\377\347\350\347\377\346\347\346\377\347\350\347\377Lbu\377" +\
    "V\210\251\377Set\377\332\333\332\377\343\344\343\377\336\340\336\377" +\
    "\325\327\325\377\313\315\313\377\302\304\303\377\271\273\271\377\260" +\
    "\263\260\377\250\252\247\377\242\245\242\377\236\241\236\340\236\241" +\
    "\236\42\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0@o\2507Du\255\373O\204\271\376W\217\306\377_\232\321\377e\243\330\377" +\
    "j\252\336\377m\257\341\377c\242\321\377\325\327\327\377\336\337\337\377" +\
    "\341\343\342\377\350\352\351\377\315\320\321\377i|\215\377\215\246\267" +\
    "\377\341\344\346\377\355\355\354\377\354\355\354\377\353\355\354\377" +\
    "\354\355\354\377\354\354\354\377\353\354\354\377\333\334\334\377\247" +\
    "\300\317\377\233\303\337\377\134\223\271\377N^m\377W_g\377ein\377\201" +\
    "\202\204\377\333\335\333\377\322\323\323\377\312\314\312\377\300\302" +\
    "\301\377\266\270\266\377\255\257\255\377\245\247\244\376\237\243\237" +\
    "\377\237\241\236l\0\0\0\0\240\242\237\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0@q\255\0\0\0\0" +\
    "\0\77m\246pFv\255\377P\205\274\376Y\222\311\377a\235\323\377f\245\332" +\
    "\377k\253\337\377m\256\341\377j\255\337\377p\246\316\377\345\343\341" +\
    "\377\342\343\342\377\343\345\345\377\347\350\347\377\351\352\352\377" +\
    "\360\360\357\377\357\356\356\377\356\357\357\377\357\357\360\377\357" +\
    "\360\360\377\357\360\357\377\357\357\357\377\356\360\360\377\356\357" +\
    "\357\377\356\357\357\377\356\357\357\377\360\360\357\377\341\347\353" +\
    "\377t\250\313\377e\240\307\377a\230\300\377Ly\232\377hnv\377\332\333" +\
    "\332\377\327\330\327\377\317\320\317\377\305\307\305\377\273\274\272" +\
    "\377\260\263\261\377\247\252\250\376\240\243\240\377\236\242\236\252" +\
    "\0\0\0\0\235\241\235\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0<m\247\0\0\0\0\0>l\245\233Ew\256\377O\206\276\377" +\
    "X\223\313\377^\234\325\377b\244\334\377d\246\335\377\200\262\331\377" +\
    "\255\310\332\377\332\335\335\377\341\341\337\377\341\343\342\377\345" +\
    "\346\345\377\347\350\350\377\351\352\352\377\353\354\354\377\356\357" +\
    "\356\377\360\360\360\377\361\362\361\377\362\362\362\377\363\363\362" +\
    "\377\362\363\363\377\361\363\363\377\363\362\363\377\361\362\362\377" +\
    "\357\357\357\377\363\364\364\377\360\360\360\377\357\360\360\377\361" +\
    "\361\360\377\223\302\341\377q\265\344\377q\261\335\377V\210\255\377\215" +\
    "\226\235\377\343\345\343\377\330\332\331\377\320\323\321\377\307\312" +\
    "\310\377\276\277\276\377\263\265\263\377\251\254\251\377\242\244\241" +\
    "\377\235\240\235\320\0\0\0\0\234\240\235\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\08h\243\251]\200\247\377\200" +\
    "\230\256\377\220\245\266\377\242\262\276\377\260\276\306\377\301\311" +\
    "\315\377\321\323\322\377\334\334\331\377\335\336\335\377\337\342\341" +\
    "\377\343\344\343\377\345\346\345\377\347\350\350\377\352\353\352\377" +\
    "\355\356\356\377\360\361\360\377\362\363\363\377\364\365\365\377\365" +\
    "\366\366\377\366\367\367\377\367\367\367\377\367\367\367\377\366\367" +\
    "\366\377\366\366\366\377\365\365\365\377\325\330\331\377KU`\377\363\363" +\
    "\362\377\361\362\361\377\360\360\360\377\364\362\361\377\300\331\350" +\
    "\377q\264\342\377q\260\335\377Rt\217\377\177\200\202\377\335\337\336" +\
    "\377\330\332\331\377\321\323\322\377\312\313\311\377\300\302\300\377" +\
    "\265\267\265\377\253\255\253\377\241\244\241\377\235\240\235\331\0\0" +\
    "\0\0\234\240\233\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\227\231\223\0" +\
    "\0\0\0\0Zx\235\232\212\225\234\377\244\245\241\377\254\256\254\377\267" +\
    "\271\267\377\300\303\300\377\312\314\312\377\321\323\322\377\326\330" +\
    "\327\377\333\335\334\377\336\337\337\377\341\342\341\377\343\344\343" +\
    "\377\346\347\347\377\351\353\352\377\355\356\356\377\360\361\361\377" +\
    "\364\364\364\377\367\367\367\377\370\371\370\377\372\372\372\377\373" +\
    "\372\372\377\372\373\373\377\373\373\373\377\371\372\372\377\372\371" +\
    "\371\377\375\376\376\377\315\322\326\377O\201\235\377\247\262\273\377" +\
    "\362\363\363\377\360\362\361\377\360\361\361\377\360\360\357\377\350" +\
    "\354\355\377\206\275\343\377m\254\331\377An\220\377\274\300\302\377\335" +\
    "\336\336\377\327\331\330\377\321\322\321\377\312\314\312\377\301\303" +\
    "\301\377\267\271\266\377\253\255\253\377\242\244\242\376\234\236\233" +\
    "\324\0\0\0\0\233\236\231\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\221\226" +\
    "\224\226\231\234\227\377\240\242\237\377\252\254\252\377\265\270\265" +\
    "\377\277\301\300\377\310\313\311\377\317\321\317\377\323\325\324\377" +\
    "\330\332\331\377\334\335\334\377\336\340\337\377\341\342\342\377\345" +\
    "\346\345\377\350\351\351\377\355\355\355\377\360\362\361\377\365\366" +\
    "\366\377\371\371\371\377\373\373\373\377\374\374\374\377\375\375\375" +\
    "\377\375\375\375\377\375\375\375\377\374\375\375\377\377\377\377\377" +\
    "\317\316\316\377px\200\377]}\221\377x\270\335\377\234\302\330\377\366" +\
    "\366\366\377\361\363\363\377\360\362\361\377\361\361\361\377\356\356" +\
    "\355\377}\242\274\377p\257\334\377\237\271\314\377\351\352\351\377\341" +\
    "\343\342\377\333\335\334\377\327\330\327\377\322\323\322\377\313\315" +\
    "\314\377\302\305\303\377\270\272\270\377\254\256\254\377\240\243\240" +\
    "\377\231\235\232\254\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\222\225\222" +\
    "w\224\227\224\377\234\237\234\377\247\251\246\377\262\265\263\377\275" +\
    "\277\275\377\306\310\307\377\314\316\315\377\321\323\322\377\326\327" +\
    "\326\377\331\332\331\377\333\335\334\377\336\340\337\377\342\343\343" +\
    "\377\346\347\347\377\353\354\353\377\360\361\360\377\366\366\366\377" +\
    "\371\371\371\377\374\375\374\377\375\375\375\377\376\376\376\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\247\251" +\
    "\255\377Px\220\377q\257\317\377\200\305\351\377\205\310\354\377\277\330" +\
    "\347\377\366\366\366\377\362\363\363\377\365\366\366\377\305\306\305" +\
    "\377Vj|\377a\223\271\377u\262\337\377k\210\237\377\345\346\344\377\344" +\
    "\344\344\377\337\340\337\377\332\333\332\377\327\330\330\377\324\325" +\
    "\324\377\316\317\316\377\307\311\307\377\300\302\300\377\262\264\262" +\
    "\377\243\247\243\377\237\241\234o\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\214\220\214\0\217\221\217" +\
    "*\221\224\220\377\230\233\227\377\242\245\242\377\257\261\257\377\271" +\
    "\274\272\377\303\305\303\377\312\314\312\377\320\322\320\377\324\325" +\
    "\324\377\326\330\327\377\332\333\332\377\334\335\334\377\337\341\340" +\
    "\377\344\344\344\377\351\352\351\377\356\357\356\377\364\365\365\377" +\
    "\371\372\371\377\374\374\374\377\376\376\376\377\377\377\377\377\376" +\
    "\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\215\223" +\
    "\231\377^\220\253\377\201\305\350\377\210\321\366\377~\311\356\377\353" +\
    "\363\367\377\371\371\371\377\366\366\366\377\364\365\364\377\201\177" +\
    "\203\377\23N_\377\3\220\237\377\0\245\261\377\0\230\246\377\26ez\377" +\
    "|}\203\377\351\352\352\377\340\341\341\377\335\336\335\377\333\334\333" +\
    "\377\313\314\313\377\253\253\251\377\222\222\221\377QYc\377>KX\3778E" +\
    "V\3779I^\377\15.f\16\63\134\225\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\215\221\215\346\223\226\223\376" +\
    "\235\240\235\377\252\254\252\377\265\270\266\377\277\302\300\377\310" +\
    "\312\311\377\316\320\316\377\323\324\324\377\326\330\327\377\331\333" +\
    "\331\377\333\334\334\377\336\337\337\377\341\342\341\377\345\347\346" +\
    "\377\354\354\353\377\361\362\362\377\367\367\367\377\374\374\374\377" +\
    "\375\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\375\375\377`\213\242\377\204\313\355" +\
    "\377\213\326\372\377\212\325\371\377\231\322\356\377\377\377\377\377" +\
    "\336\344\344\377\277\303\303\377\234\240\234\377\0\245\252\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\255" +\
    "\274\377z\200\202\377\345\346\345\377\333\334\334\377\341\341\337\377" +\
    "I[m\377;`\203\377Bo\231\377Jz\251\377Gx\251\377An\237\3778a\222\3762" +\
    "Y\215\272\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\212\216\212}\216\221\215\377\230\233\227\377\245\247\244" +\
    "\377\261\264\262\377\274\276\275\377\313\316\314\377\325\327\325\377" +\
    "\333\335\333\377\336\337\336\377\336\337\336\377\334\335\335\377\336" +\
    "\337\336\377\337\342\341\377\343\344\343\377\350\351\351\377\356\356" +\
    "\355\377\364\365\364\377\371\372\372\377\375\375\374\377\377\377\376" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\376\376\376\377\377\377\377\377\272\341\362\377\207" +\
    "\317\362\377\202\313\356\377OYg\377\206E\77\377t+#\377 \0<\377\0\0\246" +\
    "\377\0\0\334\377\0\0\335\377\0#\333\377\0p\325\377\0\364\362\377\0\377" +\
    "\377\377\0\377\377\377\0\253\272\377LQ[\377\217\220\221\377}\203\210" +\
    "\377Ix\241\377Z\222\304\377Z\223\311\377X\221\306\377S\211\300\377K\177" +\
    "\264\377Bq\245\3775^\222\3771X\217I\32)F\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0qx|\376\225\230\224\377\236\241\236\377" +\
    "\254\257\254\377\275\277\275\377\265\266\263\377S^i\377CUf\377<Re\377" +\
    "9Nb\377rz\201\377\317\317\315\377\342\343\342\377\343\344\343\377\345" +\
    "\346\346\377\352\353\352\377\357\360\357\377\365\367\366\377\373\373" +\
    "\373\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\247\243\243\377\21!&\377.]e\377%t~\377" +\
    "\0^\234\377\0\64\327\377\0\0\365\377\0\0\376\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\346\377\0\242\327\377\0\377\377\377\0\377\377\377" +\
    "\34ax\377Ep\223\377Fs\230\377U\213\270\377Z\221\303\377Y\222\306\377" +\
    "W\220\306\377T\213\301\377N\202\271\377Fv\254\377;f\233\3760V\212\357" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0,Q\204q\42Ah" +\
    "\377CO]\377\246\250\245\377\262\264\260\377]en\3775Ww\377Q\205\264\377" +\
    "[\224\307\377`\232\315\377a\235\315\377Y\220\273\3778Xt\377\331\331\330" +\
    "\377\345\346\345\377\347\350\347\377\353\354\354\377\361\362\361\377" +\
    "\367\367\367\377\374\373\374\377\376\376\376\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376" +\
    "\376\377\377\377\377\377\371\366\365\377N{\203\377\0\272\310\377\0\375" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0i\310" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\376\377\0\0" +\
    "\372\377\0\240\327\377\0\377\377\377\4\203\223\377O}\242\377M|\243\377" +\
    "P\202\255\377S\207\266\377T\213\275\377U\213\301\377S\213\300\377O\204" +\
    "\272\377Hz\260\377\77m\241\3773[\217\377.S\207m\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\60V\212\367:f\234\376>l\237\377JXi\3778Pk" +\
    "\377Hy\250\377X\220\306\377_\234\323\377d\242\331\377g\247\335\377j\253" +\
    "\340\377l\254\340\377b\234\310\377j}\216\377\356\356\355\377\351\352" +\
    "\351\377\355\356\355\377\362\362\362\377\367\370\367\377\377\377\377" +\
    "\377\375\377\377\377\304\312\313\377\247\255\255\377\247\256\256\377" +\
    "\311\317\317\377\377\377\377\377\377\377\377\377\263\260\262\377\36p" +\
    "|\377\0\374\377\377\0\377\377\377\0\376\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\252\322\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\376\377\0\0\351\377\0\354\356" +\
    "\377\0\215\232\377Ad\202\377Ah\211\377Fp\226\377Jz\244\377O\201\260\377" +\
    "R\206\271\377R\207\274\377P\204\272\377K}\263\377Bq\246\3778b\225\376" +\
    "-Q\204\365\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\27'>\0+Q\206\1342Z\217\377" +\
    "=j\241\377Gy\261\377K~\264\377O\204\271\377X\220\311\377\134\230\321" +\
    "\377`\235\325\377d\242\332\377g\246\335\377j\253\340\377m\256\342\377" +\
    "m\255\337\377P\204\253\377\267\273\276\377\352\353\353\377\356\356\356" +\
    "\377\365\365\365\377\325\333\333\377\200ZY\377\207:4\377\301_W\377\340" +\
    "yp\377\337xo\377\273]T\377\177C=\377V.\32\377(F)\377\0\372\377\377\0" +\
    "\376\376\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\376\377\0\306\323\377\0\0\377\377\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0f\327\377" +\
    "\10q\203\3772Nf\3774To\377:^~\377Bk\220\377Hv\242\377N\200\257\377O\203" +\
    "\267\377N\203\270\377K~\263\377Dt\251\377;f\232\377/T\206\377*M\201Z" +\
    "\24\42:\0\0\0\0\0\0\0\0\0\0\0\0\0,P\204\3236_\224\376@o\245\377I{\264" +\
    "\377O\205\275\377T\213\305\377X\222\314\377\134\227\321\377`\234\325" +\
    "\377d\241\331\377f\246\335\377j\252\340\377l\256\343\377o\261\344\377" +\
    "j\247\326\377Qs\216\377\362\361\357\377\366\366\366\377\216\200\200\377" +\
    "\240>5\377\376\235\217\377\377\252\234\377\377\252\236\377\377\251\235" +\
    "\377\377\251\235\377\377\252\234\377\377\250\233\377\352~r\377\0\214" +\
    "\234\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\316\325\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\16\322\377\21@E\377&=O\377)CX\3770Oi\3779]~\377Bm\224" +\
    "\377Ix\246\377L\200\261\377M\201\265\377J~\264\377Eu\253\377=i\235\377" +\
    "3Y\214\376)L}\320\0\0\0\0\0\0\0\0\0\0\0\0*O\211\32,Q\203\3778b\227\377" +\
    "Aq\250\377I|\264\377O\205\276\377T\213\305\377W\221\313\377\134\227\320" +\
    "\377_\233\324\377c\240\331\377f\245\334\377i\251\337\377m\255\342\377" +\
    "o\260\345\377p\261\343\377^\227\300\377\231\245\256\377~hi\377\327M@" +\
    "\377\377\217~\377\376\217\177\377\377\215}\377\377\221\203\377\377\276" +\
    "\263\377\377\250\233\377\377\215~\377\377\215}\377\254@4\377\0\330\350" +\
    "\377\0\377\376\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\313\323\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\313\377\31'*\377\36\61@\377\428J\377*DZ\3772Sp\377=d\210" +\
    "\377Er\236\377K|\255\377K~\262\377J}\262\377Ev\254\377>k\237\3775]\217" +\
    "\377*K{\377)N\204\30\0\0\0\0\0\0\0\0(J|x.T\207\377:e\232\377Br\251\377" +\
    "J}\265\377O\204\274\377S\212\303\377W\221\312\377[\225\320\377_\233\324" +\
    "\377b\237\330\377e\244\333\377i\250\337\377k\254\341\377o\257\344\377" +\
    "q\262\345\377g\243\320\377Uiu\377\306\3\0\377\377vc\377\377m[\377\377" +\
    "hV\377\377_P\377\377m`\377\377\356\354\377\377\266\256\377\377bS\377" +\
    "\377eT\377\223\35\22\377\0\337\355\377\0\377\376\377\0\377\377\377\0" +\
    "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\270\323\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\300\377\30&+\377\33" +\
    "+9\377\36\62A\377%=Q\377.Mh\377:^\202\377Cn\230\377Iy\250\377J|\260\377" +\
    "I|\261\377Ev\253\377\77l\241\3777_\222\377,O\177\377%Evu\0\0\0\0\0\0" +\
    "\0\0'Hz\3121W\212\377:f\234\377Cs\252\377I|\265\377N\203\274\377R\211" +\
    "\302\377V\217\311\377Z\225\317\377^\232\323\377a\236\327\377d\243\332" +\
    "\377h\247\336\377j\253\341\377m\256\343\377q\261\344\377c\240\315\377" +\
    "p\4\5\377\377\6\2\377\376C-\377\3778$\377\377-\35\377\377&\31\377\377" +\
    "%\32\377\377A9\377\3774*\377\377'\31\377\377/\37\377\267\15\1\377\0\246" +\
    "\267\377\14\377\377\377\6\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\217\315\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\231\377\30'/\377\31(\65\377\35/>\377#:N\377-Id\3778" +\
    "\134~\377Al\226\377Gw\247\377I{\256\377Hz\260\377Ev\253\377\77l\241\377" +\
    "7a\223\377.Q\202\377%Ds\310\0\0\0\0\0\0\0\0&Hx\3772X\214\377;f\234\377" +\
    "Br\251\377H{\263\377M\201\272\377Q\207\300\377U\216\310\377Y\223\315" +\
    "\377]\230\322\377`\235\326\377d\242\332\377g\246\334\377i\252\340\377" +\
    "m\255\342\377o\257\343\377@j\210\377\340\0\0\377\377\0\0\377\377\7\0" +\
    "\377\377\5\0\377\377\1\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\2\0\377\341\0\0\377\269F\377V\377\377\377N\376" +\
    "\376\3778\377\377\377-\377\377\377Q\377\377\377\25\377\377\377\15\377" +\
    "\377\377\16\377\377\377\1a\320\377\0\26\377\377\0\16\377\377\0\7\377" +\
    "\377\0\4\377\377\0\2\377\377\0\0\377\377\0\0\377\377\1\0R\377\27&\62" +\
    "\377\30'\64\377\34.>\377#:M\377-Je\3778\134\177\377Ak\226\377Gv\246\377" +\
    "Iz\256\377Gy\256\377Dt\251\377\77l\241\3777a\224\377.S\203\377$Cp\377" +\
    "\0\0\0\0#Cv9(Hy\3772Y\214\377;f\234\377Bq\250\377Gz\262\377L\200\271" +\
    "\377P\206\277\377T\214\306\377X\222\313\377[\227\320\377_\233\325\377" +\
    "c\240\331\377e\244\333\377h\250\336\377k\254\341\377p\261\346\377O4C" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377" +\
    "\374\0\0\377\214\0\0\377.\216\231\377\207\377\377\377|\376\376\377\205" +\
    "\377\377\377\351\377\377\377i\377\377\377X\377\377\377P\377\377\377H" +\
    "l\316\377\205\224\376\377%<\377\377!5\377\377$3\377\377%0\377\377\14" +\
    "\20\376\377\0\0\352\377\1_i\377\27%\60\377\30'\65\377\35/>\377$:P\377" +\
    "-Kg\3779]\200\377Bm\230\377Gv\246\377Gy\255\377Gx\255\377Cs\250\377>" +\
    "k\240\3777a\223\377/S\203\377%Cq\377\42Ao\66!\77mp(Iz\3772Y\214\377:" +\
    "f\233\377Ap\247\377Ex\257\377J~\267\377O\204\276\377S\212\303\377V\220" +\
    "\312\377Z\225\317\377^\232\323\377a\236\327\377d\242\333\377g\246\335" +\
    "\377i\252\340\377p\262\352\377n\37(\377\377\0\0\377\377\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\351\0\0\377v\0\0\377.ip" +\
    "\377\215\365\372\377\242\377\377\377\233\377\377\377\224\377\377\377" +\
    "\216\377\377\377_\326\332\377\241\243\370\377\311\316\377\377fr\377\377" +\
    "`j\377\377\134d\377\377W`\376\377!\33\374\377\0\232\325\377\0\220\236" +\
    "\377\27#.\377\31(\65\377\35/@\377%<R\377/Mj\3779_\204\377Bm\232\377F" +\
    "v\247\377Gx\255\377Ew\254\377Bq\246\377=j\237\3777`\222\377.S\202\377" +\
    "%Dq\377\37;fn\42\77m\224(Jy\3762X\213\377:d\231\377@n\245\377Du\255\377" +\
    "I{\264\377M\202\273\377Q\210\301\377U\216\310\377X\222\315\377\134\227" +\
    "\321\377_\234\325\377c\240\331\377e\244\334\377h\250\337\377m\261\351" +\
    "\377t\36'\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\355\0\0\377d\0\0\377B@\6\3771[T\377" +\
    ";\201\216\377C\223\241\377O\236\272\377r\227\317\377\240\246\377\377" +\
    "\230\236\377\377\221\230\377\377\215\222\376\377\211\220\377\377d`\354" +\
    "\377\0\226\323\377\0\377\377\377\2p\200\377\27$\60\377\30(\66\377\35" +\
    "\60B\377%>T\377/Nm\377:`\206\377Bn\232\377Fv\250\377Gx\254\377Du\252" +\
    "\377@o\244\377<h\234\3776_\221\377.R\202\377%Dq\376\37:f\221 <i\277'" +\
    "Hx\3770W\211\3778c\230\377>l\242\377Cs\252\377Gy\262\377K\200\271\377" +\
    "O\205\277\377T\213\305\377W\220\312\377[\225\320\377]\232\323\377a\236" +\
    "\327\377c\242\333\377g\246\335\377k\257\347\377m\37)\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\252\22\0\377\356\322\0\377\315\251\0\377\277\231" +\
    "\0\377\257\212\0\3774.\16\3772\200\324\377[m\324\377tn\342\377tq\343" +\
    "\377[n\325\377,\222\325\377\0\345\352\377\0\377\377\377\0\375\377\377" +\
    "\10\63\77\377\26$\61\377\31(\66\377\36\61C\377&>V\3770Po\377:`\210\377" +\
    "An\233\377Et\247\377Eu\252\377Cs\250\377\77l\242\377;f\232\3775]\216" +\
    "\377-Q\201\377%Do\377\358b\276\37;g\314'Hw\3770U\207\3776a\225\377=i" +\
    "\240\377Ap\247\377Ev\257\377J}\266\377M\203\275\377Q\210\302\377U\216" +\
    "\311\377Y\222\315\377\134\227\321\377_\234\325\377b\240\331\377d\243" +\
    "\334\377i\251\341\377N8J\377\377\0\0\377\376\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\277c\0\377" +\
    "\377\375\0\377\377\366\0\377\377\365\0\377\377\351\0\377\247\203\0\377" +\
    "#\202\217\377x\377\377\377]\377\376\377\241\377\376\377\207\377\377\377" +\
    "\77\377\377\377\77\376\376\3778\377\377\377\0\221\244\377\23\31#\377" +\
    "\26$\60\377\30(\67\377\36\61D\377&\77W\3770Pq\377:a\210\377Am\233\377" +\
    "Ds\246\377Ds\250\377Ap\245\377=j\236\3779d\227\3774Z\214\377-P~\377$" +\
    "Cn\377\34\66_\313\369e\327&Gu\377.S\204\3775]\222\377:f\234\377\77m\244" +\
    "\377Cs\254\377Gz\262\377K\200\272\377P\206\300\377S\213\306\377V\220" +\
    "\312\377Z\225\317\377]\231\322\377`\235\326\377c\240\332\377d\243\333" +\
    "\377Dt\233\377\333\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\376\0\0\377\356\0\0\377\323\273\0\377\376\370\0" +\
    "\377\377\371\0\377\377\370\0\377\377\372\0\377\356\317\0\377r\134\0\377" +\
    "9\204\216\377\224\377\377\377\234\377\377\377\222\377\377\377\207\377" +\
    "\377\377z\377\377\377%\223\241\377\15\24\33\377\24\42.\377\26$\61\377" +\
    "\30)8\377\36\62E\377&@Y\3770Qr\377:`\210\377@l\232\377Cq\244\377Bp\246" +\
    "\377\77m\242\377;g\234\3778a\223\3772X\211\377+M{\377#Al\377\34\65]\324" +\
    "\35\67b\342%Dr\377,Q\201\3773[\217\3779d\230\377=j\241\377Aq\250\377" +\
    "Ev\257\377I}\266\377M\202\274\377Q\210\302\377U\215\310\377W\221\314" +\
    "\377[\226\321\377^\232\323\377a\235\327\377c\241\332\377f\247\341\377" +\
    "k\14\21\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\267\26\0\377\377\377\0\377\377\371\0\377\377\371\0\377" +\
    "\377\371\0\377\377\373\0\377\377\371\0\377\350\311\0\377\222w\0\3779" +\
    "D\35\3778mn\377C\203\220\377<rv\377I](\377I=\0\377\22\37-\377\24!.\377" +\
    "\26$\61\377\31)9\377\37\63G\377'A[\3770Qs\3779`\211\377\77j\232\377A" +\
    "o\242\377\77n\243\377=j\236\377:d\230\3775^\220\3770U\206\377*Jx\377" +\
    "\42\77i\377\32\63Z\337\34\66_\341#Bn\377+N}\3772X\213\3777`\225\377;" +\
    "g\235\377\77m\245\377Cs\254\377Gz\262\377K\177\271\377O\204\276\377R" +\
    "\211\304\377V\217\312\377Y\223\316\377[\227\321\377^\233\325\377a\235" +\
    "\327\377a\237\330\377Gy\243\377\272\0\0\377\377\0\0\377\376\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\376\0\0\377\360\0\0\377\315\252\0\377\376\373\0\377\377" +\
    "\372\0\377\377\371\0\377\377\372\0\377\377\373\0\377\376\377\0\377\377" +\
    "\376\0\377\374\354\0\377\336\310\0\377\312\262\0\377\312\263\0\377\340" +\
    "\316\0\377\373\355\0\377PL\7\377\24\42.\377\24\42.\377\26$\62\377\32" +\
    "+<\377 5K\377(C_\3771Sv\3779a\213\377>j\232\377@l\240\377>k\240\377;" +\
    "g\233\3777a\224\3773[\213\377.R\202\377(Hu\377 <f\377\31\61V\336\32\62" +\
    "[\325!\77k\377)Kz\377/U\206\3774]\221\3778c\231\377=j\240\377Ap\247\377" +\
    "Dv\256\377H|\265\377L\201\273\377P\206\300\377S\212\306\377V\217\312" +\
    "\377Y\224\316\377\134\227\321\377^\232\324\377`\234\325\377b\241\332" +\
    "\377)!5\377\305\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\256=\0\377" +\
    "\377\377\0\377\377\374\0\377\377\373\0\377\377\373\0\377\377\373\0\377" +\
    "\377\375\0\377\377\377\0\377\377\376\0\377\376\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\370\361\0\377\31\35\26\377" +\
    "\24 ,\377\24\42/\377\27&\65\377\33-@\377\429P\377*Ge\3773V{\377:b\216" +\
    "\377=i\231\377=k\236\377<h\234\3778d\227\3775^\220\3771W\210\377,O}\377" +\
    "&Eq\377\36:b\377\30.T\322\30\61X\313 ;f\377'Gu\377-Q\202\3772Y\214\377" +\
    "6`\224\377:f\234\377>l\243\377Bq\251\377Fw\261\377J}\266\377M\203\274" +\
    "\377Q\207\301\377S\214\307\377W\220\313\377Y\224\316\377[\227\321\377" +\
    "\134\231\322\377[\233\322\377\206\0g\377a\0L\377\207\0\0\377\371\0\0" +\
    "\377\377\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\377\0\0\377\377" +\
    "\0\0\377\257\25\0\377\372\374\0\377\376\376\0\377\377\376\0\377\377\376" +\
    "\0\377\377\374\0\377\377\376\0\377\377\377\0\377\377\376\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\305\257\0\377\24\11\27\377\24 -\377\24\42\60\377\27'\67\377\34" +\
    "\60D\377$<V\377,Kl\3774Y\201\377:c\221\377<h\232\377<h\233\377:e\231" +\
    "\3776_\222\3773Z\213\377/S\203\377*Ky\377#Bl\377\35\67_\377\27-Q\312" +\
    "\27-S\274\358b\377%Dp\377+N}\3770U\207\3774\134\217\3778b\227\377;h\236" +\
    "\377\77n\245\377Cs\254\377Fy\262\377J~\270\377N\203\275\377Q\210\302" +\
    "\377T\213\307\377V\220\312\377Y\222\316\377[\225\317\377S\224\307\377" +\
    "\264\0\224\377\273\37l\377\215B>\377M\25\24\377k\0\0\377\277\0\0\377" +\
    "\353\0\0\377\352\0\0\377\312\0\0\377\256A\0\377\367\370\0\377\376\376" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\376\377\0\377\376\372\0\377\271,\0\3770\13\17\377" +\
    "\23 .\377\24#\61\377\31):\377\36\63I\377&@]\377.Or\3775\134\206\3779" +\
    "c\222\377;g\230\377:e\231\3778b\224\3774\134\216\3770V\207\377-P~\377" +\
    "(Ht\377\42\77i\377\34\64Z\377\25*N\273\25*O\215\33\65]\376\42\77k\377" +\
    "(Ix\377-Q\202\3771W\212\3775^\222\3779c\231\377<j\240\377@o\247\377D" +\
    "t\255\377Gy\263\377J\177\271\377N\203\275\377P\207\301\377T\214\307\377" +\
    "V\217\312\377W\221\314\377J\211\276\377\236##\377\377\212\207\377\377" +\
    "~|\377\367ii\377\327ZZ\377c69\377uk\0\377\344\331\0\377\362\364\0\377" +\
    "\377\377\0\377\376\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\376\376\0\377\377\377\0\377" +\
    "\266\201\0\377\377\0\0\3773\12\17\377\23 -\377\25#\62\377\31*<\377\37" +\
    "\65M\377(Cb\3770Rw\3776]\210\3779c\224\3779e\227\3778b\225\3775^\220" +\
    "\3772Y\212\377.R\202\377*Ly\377%Eo\377 ;c\377\31\61V\376\24'J\213\24" +\
    "(Jk\30\60W\377 <f\377&Er\377+N|\377/T\205\3772Z\214\3776_\224\3779e\232" +\
    "\377=j\241\377Ap\250\377Du\256\377Gz\263\377J\177\271\377M\203\275\377" +\
    "P\206\302\377S\213\306\377W\223\321\377j\27#\377\377TP\377\377ZS\377" +\
    "\377SL\377\377MK\377\377tx\377\363\276\300\377a\11\12\377\263\253\0\377" +\
    "\377\377\0\377\376\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\376\377\0\377\377\377\0\377" +\
    "\302\247\0\377\355\0\0\377\377\0\0\377*\12\17\377\22\37-\377\25#\62\377" +\
    "\31+=\377 6P\377)Ee\3770Rz\3775\134\211\3778a\222\3778b\223\3775^\221" +\
    "\3773Y\214\3770T\204\377,O|\377(Gt\377$Aj\377\36\67^\377\27-Q\377\23" +\
    "&Ei\21#C\61\26-Q\377\35\67_\377#Ak\377(Iw\377,O\177\3770U\207\3773[\216" +\
    "\3777a\226\377:f\234\377>k\242\377Aq\250\377Du\256\377Hz\263\377J\177" +\
    "\271\377M\202\274\377O\206\301\377<a\214\377\336\0\0\377\324\77u\377" +\
    "\324e\270\377\320m\313\377\326_\263\377\323.j\377\363\15\31\377\356\1" +\
    "\6\377`\1\0\377\232\222\0\377\377\373\0\377\377\377\0\377\377\376\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\376\0\377\377\377\0\377\377\374\0\377" +\
    "\271\220\0\377\354\0\0\377\376\0\0\377\362\0\0\377\36\30\27\377\33#," +\
    "\377\25\42\62\377\31+>\377 7Q\377(De\377/Rz\3774Z\210\3776^\217\3775" +\
    "]\217\3774Z\214\3770U\205\377.Q\177\377)Kw\377&Dn\377!=e\377\32\63Y\377" +\
    "\25*L\377\20 >.\0\0\0\0\24(J\377\33\62X\377 <e\377%Dp\377)Ky\377-P\201" +\
    "\3770V\210\3773[\217\3777`\226\377:f\234\377>k\243\377Ap\250\377Cu\256" +\
    "\377Gy\262\377J}\267\377N\204\300\377L'E\377\345e\334\377\377\214\377" +\
    "\377\376\211\377\377\377\245\377\377\376\212\377\377\377\215\377\377" +\
    "\341X\322\377\346\0\10\377\363\0\0\377\204\0\0\377VD\0\377\347\334\0" +\
    "\377\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\376" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\374\0\377\331\325" +\
    "\0\377\270A\0\377\374\0\0\377\376\0\0\377\377\0\0\377\247\0\0\377\34" +\
    "##\377$(*\377\23!\60\377\30)>\377\37\65O\377'Cd\377.Ow\3772W\205\377" +\
    "3Z\212\3773Y\213\3771V\206\377-Q\200\377+Ly\377(Fq\377$Ai\377\378_\377" +\
    "\31\60T\377\22%F\377\0\0\0\0\0\0\0\0\22$E\277\27.R\376\35\67_\377\42" +\
    "@j\377&Fs\377)L{\377-Q\202\3770V\210\3774\134\220\3777a\225\377:f\234" +\
    "\377=k\242\377@o\250\377Ct\255\377Ex\261\377:q\237\377\300\20\244\377" +\
    "\377S\377\377\377K\377\377\377@\377\377\377\263\377\377\377C\377\377" +\
    "\377C\377\377\377Q\377\377\334\12\270\377\370\0\0\377\376\0\0\377\257" +\
    "\0\0\377P\0\0\377\275R\0\377\277\245\0\377\342\340\0\377\357\361\0\377" +\
    "\361\363\0\377\356\357\0\377\334\327\0\377\274\225\0\377\277A\0\377\350" +\
    "\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\375\0\0\3775\12\12\377&" +\
    "'&\377'(*\377$*2\377'2@\377\32\61L\377#\77`\377+Ls\3770T\200\3771W\205" +\
    "\3770T\205\377.Q\200\377+Lz\377(Ht\377$Cm\377!<c\377\34\65Z\377\27,N" +\
    "\376\22\42B\275\0\0\0\0\0\0\0\0\20 >m\25*L\377\32\62X\377\37;c\377$B" +\
    "l\377'Gu\377*M|\377.Q\202\3770W\211\3774[\220\3776`\226\377:e\233\377" +\
    "<j\241\377@n\246\377Ct\256\377R,m\377\377\2\365\377\377\15\377\377\377" +\
    "\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\2\377\377\377\0\375\377\327\0\64\377\377\0\0\377\367\0\0\377\134\0\0" +\
    "\377\315\0\0\377\377\0\0\377\337\0\0\377\334\4\0\377\335\5\0\377\333" +\
    "\0\0\377\347\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\376\0\0\377\377\0\0\377\202\0\0\377\33! \377%&%\377)*)\377121\377BB" +\
    "A\377VYZ\377bjs\377jx\212\377)Ly\377.Q\200\377-P~\377*Lz\377(Hs\377%" +\
    "Dn\377\42>g\377\368^\377\31\61T\377\24(H\377\20\36;k\0\0\0\0\0\0\0\0" +\
    "\10\21\42\20\23%E\377\27.R\377\34\66\134\377 =f\377$Cn\377'Gt\377+N|" +\
    "\377-Q\202\3770V\211\3773[\217\3776`\224\3779c\232\377;h\237\377\77q" +\
    "\252\377\214\12|\377\377\0\377\377\377\0\376\377\377\0\377\377\377\0" +\
    "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377" +\
    "\0\377\377\326\0u\377\377\0\0\377\377\0\0\377\346\0\0\377D\0\0\377\321" +\
    "\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\226\0\0" +\
    "\377\26\32\31\377#$#\377%&%\377***\377232\377@A@\377STS\377ghg\377z|" +\
    "y\377\223\227\232\377Oh\210\377*Ky\377(Ht\377%Cm\377\42\77h\377 :`\377" +\
    "\33\64X\377\27+M\377\22\42A\377\7\16\34\16\0\0\0\0\0\0\0\0\0\0\0\0\20" +\
    " =\302\25*L\376\31\61W\377\368`\377!>h\377%Co\377'Hu\377+M{\377-Q\201" +\
    "\3770U\210\3773Z\215\3775^\223\3778b\230\3779k\241\377\233\7\207\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\335\0\205\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\257\0\3\377Y\0O\377\212\0\0\377" +\
    "\370\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\346\0\0\377]\3\3\377\26\33\33\377###\377$%$\377&&&\377" +\
    "+,+\377454\377CEC\377VWV\377jlj\377|~|\377\207\212\207\377ap\177\377" +\
    "'Fr\377%Do\377#\77h\377 ;b\377\34\66Z\377\31/R\377\24'F\376\17\369\300" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\24&M\0\16\32\65M\22$E\377\30.Q\377\34\64[\377" +\
    "\37:c\377\42\77i\377%Cn\377'Gt\377*Kz\377-O\200\377/T\206\3772X\213\377" +\
    "4\134\221\3777d\232\377x\17p\377\377\0\377\377\377\0\376\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376" +\
    "\377\377\0\377\377\330\0f\377\377\0\0\377\377\0\0\377\377\0\0\377\323" +\
    "\0n\377\366\0\346\377\242\0\215\377R\0.\377l\0\0\377\262\0\0\377\323" +\
    "\0\0\377\320\0\0\377\233\0\0\377U\6\6\377\32\25\24\377!##\377###\377" +\
    "#$#\377%&%\377))(\377/0/\377:;:\377IJI\377[][\377npn\377|~}\377\205\211" +\
    "\206\377Ras\377%Bl\377#\77h\377!<c\377\35\67\134\377\32\60U\377\26*K" +\
    "\377\21\42@\377\14\27/L\23%I\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20\37" +\
    "=\354\25)K\376\31\61V\377\35\67]\377 ;c\377\42>h\377$Cm\377'Fs\377*J" +\
    "y\377,N~\377.R\203\3771V\211\3773Z\216\37722^\377\377\0\350\377\376\0" +\
    "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\376\0\377\377\377\0\371\377\327\0\21\377\376\0\0\377\377\0" +\
    "\0\377\332\0\11\377\370\0\376\377\377\0\377\377\377\0\371\377\372\0\335" +\
    "\377|\0b\377\21\33\30\377\24\36\35\377\24\35\35\377\33! \377#%$\377#" +\
    "$#\377#$#\377$%$\377&&&\377())\377./.\377665\377BCB\377QRQ\377acb\377" +\
    "oqp\377|\177{\377_is\377\36;c\377\42>h\377!;b\377\379_\377\33\62W\377" +\
    "\27-O\377\22$C\376\16\34\67\353\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\14\31\61\134\23$E\377\27,O\377\33\63X\377\36\67^\377\37:c" +\
    "\377\42>h\377$Am\377&Fr\377(Iw\377*M|\377-P\201\377.S\205\377.X\210\377" +\
    "v\11j\377\377\0\371\377\376\0\377\377\377\0\376\377\377\0\377\377\377" +\
    "\0\376\377\376\0\376\377\377\0\377\377\313\0l\377\377\0\0\377\377\0\0" +\
    "\377\336\0\5\377\353\0\341\377\376\0\376\377\377\0\377\377\376\0\377" +\
    "\377\372\0\343\377 \11#\377 !\42\377\42#\42\377###\377#$#\377$%$\377" +\
    "%&&\377'('\377()(\377+,+\377/0/\377676\377\77@\77\377KML\377X[Y\377f" +\
    "hf\377qtr\377V_g\377\35\67^\377#>f\377 <d\377\379_\377\34\64Y\377\31" +\
    "/R\377\25(H\377\20 =\377\13\26+Z\377\377\377\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\20\36:\343\23'H\376\30.Q\377\32\62Y\377\35" +\
    "8_\377!;c\377\42>h\377$Ak\377&Dp\377'Gu\377*Kz\377+N~\377,P\200\377%" +\
    "Nw\377f\15`\377\361\0\326\377\377\0\374\377\377\0\377\377\377\0\374\377" +\
    "\366\0\347\377\316\0`\377\373\0\0\377\321\0\0\377\270\09\377\373\0\365" +\
    "\377\377\0\377\377\377\0\377\377\377\0\375\377\350\0\314\3773\10\60\377" +\
    "\13\26!\377\20\26\36\377\42#\42\377$$%\377&'&\377())\377+,+\377./.\377" +\
    "122\377565\377:<;\377BBA\377IKJ\377UWU\377`a`\377ikj\377rur\3770AY\377" +\
    "\42<b\377!<c\377\379`\377\35\66[\377\32\60U\377\26+L\377\22#A\376\15" +\
    "\33\64\342\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20" +\
    "\35;\0\12\23(8\21\42@\377\24)J\377\27.R\377\33\64Y\377\379_\377 :b\377" +\
    "\42=f\377#@j\377%Cn\377'Fr\377(Hu\377)Jy\377)Ky\377)Mz\377\32\62O\377" +\
    "H\26R\377]\16[\377@\20E\377\30\21\30\377,\15\25\377\21\16\26\377\1\24" +\
    "\37\377\12\17\32\377R\5G\377\225\0}\377\226\1}\377R\5G\377\7\20\27\377" +\
    "\14\26\42\377\14\25!\377\14\25!\377\11\21\33\377#$$\377+,+\377010\377" +\
    "564\3779;9\377>>=\377ACB\377GHF\377LNM\377TVT\377\134^\134\377cfd\377" +\
    "ilj\377gkk\377\34\64X\377!;b\377 :a\377\35\66\134\377\32\62V\377\27-" +\
    "P\377\24&F\377\17\36;\377\11\21$\66\14\31\60\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\15\32\63\247\22#C\377\26*" +\
    "L\377\31/S\377\35\65Y\377\378^\377!:b\377#=f\377$@i\377%Bl\377&Do\377" +\
    "&Fr\377'Fs\377'Eq\377$Bj\377!<a\377\34\64S\377\27*C\377\23!\65\377\17" +\
    "\33,\377\15\27&\377\14\26$\377\14\26#\377\14\27#\377\11\27!\377\11\27" +\
    "\42\377\15\26$\377\14\26#\377\14\26\42\377\14\26#\377\14\26$\377\11\22" +\
    "\35\377&''\377233\377999\377\77@@\377DFE\377IKJ\377MON\377RSR\377VXW" +\
    "\377[^\134\377_ca\377cfe\377ghf\377(<Y\377!:`\377\379`\377\35\66]\377" +\
    "\33\63W\377\30/R\377\24(I\377\21\42A\377\14\30\60\245\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\2\4\11\0\0\0" +\
    "\0\0\16\34\67\361\22$C\376\26*L\377\33\61U\377\35\65Z\377 9^\377#<c\377" +\
    "$=e\377$\77h\377%@j\377&Bl\377&Bm\377$Al\377$\77g\377!:_\377\34\63S\377" +\
    "\30+F\377\24$:\377\20\36\61\377\17\33,\377\16\31)\377\16\31(\377\16\31" +\
    "(\377\16\31(\377\16\31(\377\16\31(\377\16\30(\377\16\30'\377\15\31(\377" +\
    "\16\31(\377\11\23 \377121\377:;:\377BCB\377IKJ\377OQO\377TUT\377WYW\377" +\
    "X[Z\377Z]\134\377]_^\377_b`\377U[^\377-@\134\377\42:`\377\379`\377\36" +\
    "\66[\377\34\63X\377\31/S\377\25)K\377\22$D\376\15\33\66\360\0\0\0\0\1" +\
    "\2\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\13\24*\0\7\17\37%\17\359\377\23%C\376\30+M\377\34\61T\377" +\
    "\37\65Z\377\429_\377$<c\377&>e\377%\77g\377&\77h\377%@h\377%\77h\377" +\
    "#>e\377!:_\377\36\65V\377\32.L\377\26(A\377\23#9\377\22 \64\377\21\37" +\
    "\61\377\20\36\60\377\20\36\61\377\21\36\61\377\21\37\62\377\21\36\62" +\
    "\377\20\36\61\377\20\36\60\377\20\36\60\377\21\36\61\377\13\27%\377<" +\
    "=;\377BDC\377IKJ\377ORQ\377UWV\377WZY\377Y[[\377Y\134[\377Y\134[\377" +\
    "LRW\377-\77Z\377 9`\377\42;a\377 8^\377\36\67\134\377\34\63X\377\31/" +\
    "S\377\26*M\377\22$D\376\16\35:\377\7\17\37#\12\23(\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\11\22#W\20\359\377\23%D\377\30,L\377\34\61T\377 7Z\377$" +\
    ":^\377&=b\377(\77f\377'\77f\377(Ai\377'@f\377%>d\377#;_\377 7Y\377\36" +\
    "\63R\377\33.K\377\30*D\377\26'\77\377\25%=\377\25%<\377\25%<\377\26&" +\
    ">\377\25&=\377\26&=\377\26%=\377\25%<\377\25%<\377\25%<\377\22\35.\377" +\
    "CEC\377GIH\377MOO\377RTT\377UWW\377VYY\377WYZ\377TWX\377UWV\3770@X\377" +\
    "&>c\377$<b\377!9`\377\37\66\134\377\35\64Y\377\32\60S\377\25*M\377\22" +\
    "$D\376\17\37>\377\11\22'U\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\11\22%|\17\359\377\24$B\377\31,L\377\36\63T\377#7[\377&;`\377" +\
    ")\77d\377*Ag\377*Ag\377*Ag\377)Af\377'\77c\377%;_\377#7Y\377 4S\377\36" +\
    "\62O\377\34/K\377\33.J\377\33.J\377\33-J\377\34/K\377\33.K\377\33/K\377" +\
    "\33.J\377\33-I\377\33-I\377\33-G\377\30#\65\377GJI\377ILL\377MPQ\377" +\
    "PST\377QTV\377RUV\377PST\377NQR\377=GU\377&=d\377&>e\377#;b\377!7^\377" +\
    "\36\64Z\377\32\60U\377\26*L\377\23$E\376\20 \77\377\12\24*x\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\21%\206" +\
    "\17\348\377\23$A\377\31+K\377 3T\377$8[\377)=a\377-Af\377-Ch\377.Ch\377" +\
    ".Di\377-Dh\377,Ae\377)>b\377'<^\377%9Z\377$7W\377#7U\377\42\66U\377\42" +\
    "\67V\377\42\67V\377#8W\377#7W\377#7V\377#7U\377#6U\377\42\64O\377'/;" +\
    "\377HKM\377JMO\377LOQ\377LPR\377LOS\377KOR\377JMP\377AGQ\377)@f\377)" +\
    "Ah\377%=e\377#:a\377\37\66\134\377\32\60U\377\25*M\377\23%F\376\20\37" +\
    ">\377\12\24+\202\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\21$x\16\33\66\377\23\42\77\376\31" +\
    "+J\377!3T\377&9\134\377+\77a\377/Dg\3772Gl\3773In\3774Io\3773Jo\3772" +\
    "Gl\3770Ei\377.Cg\377.Be\377,Ac\377,Ac\377,Ac\377,Ac\377-Ac\377-Bd\377" +\
    "-Bc\377-Ac\377.Bc\377*<Y\377=BJ\377ILP\377IMR\377JNR\377JMR\377ILQ\377" +\
    "DHM\3778DZ\377/Ej\377,Ck\377)@h\377%<c\377 7]\377\33\61V\377\25*N\377" +\
    "\22$E\376\17\37>\377\12\25,u\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\20#O" +\
    "\14\31\63\377\21 =\376\30)H\377!3S\377(:]\377.Ae\3773Fj\3776Jo\3778M" +\
    "r\3779Ms\3779Nt\3778Ms\3777Lq\3777Kp\3776Kn\3776Jn\3776Jm\3775Jn\377" +\
    "6Ko\3777Ko\3777Lp\3778Lp\3778Lo\3775Ee\377GLS\377JOU\377JNU\377IMS\377" +\
    "HLR\377FIO\377AFP\3773Hp\3770Fm\377+Bj\377&=e\377 7^\377\31/U\377\23" +\
    "(M\377\22#E\376\16\36=\377\12\23)L\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\7\16\34\37\13\27\61\347\17\358\377\25%B\377\37\60P\377" +\
    "(;\134\377/Cf\3776Io\377:Ns\377<Qw\377>Sy\377\77T{\377\77Ty\377\77Ty" +\
    "\377\77Sz\377\77Sx\377\77Sx\377\77Sx\377\77Tz\377@Uz\377AUz\377ATz\377" +\
    "AUz\377>Op\377JOY\377LPY\377JOW\377IMU\377DJT\377<Kf\3776Ks\3772Hp\377" +\
    ",Ck\377%<c\377\35\63Z\377\26,P\377\23&J\377\21\42D\377\16\34;\346\6\16" +\
    " \35\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\7\16\37" +\
    "\0\0\0\0\0\12\25.\230\15\33\67\377\21\37=\376\30*I\377%7Z\377/Bg\377" +\
    "6Ip\377;Pv\377\77Sz\377AV}\377BV~\377CW}\377DW~\377EX~\377DX~\377EY\177" +\
    "\377EY\177\377FY\177\377GY\177\377G[\177\377G[\177\377BRr\377KO[\377" +\
    "KOY\377JNW\377HKR\377:Mp\3778Mu\3772Go\377*@f\377\37\65[\377\26,Q\377" +\
    "\23'K\377\21#E\376\20 B\377\15\32\65\225\0\0\0\0\10\21#\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\5\15\32)\13\27\60\323\16\36;\377\22#C\376\32-O\377$8]\3770Ch\3778Lr" +\
    "\377=Qx\377@Ty\377BU|\377CV|\377DX}\377FX~\377FY~\377GZ\177\377FY\177" +\
    "\377GZ\200\377HZ\177\377FX}\377EPl\377NR\134\377KOX\377HLT\377@FS\377" +\
    "0Ch\377)=c\377\36\63X\377\26+O\377\22&I\377\21#E\376\20!B\377\15\338" +\
    "\321\5\15\33(\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\14\32\0\0\0\0\0\7" +\
    "\20!N\13\27\60\343\20 @\377\21\42C\377\26)K\377\35\60T\377&:^\377.Af" +\
    "\3775Fk\3778Lo\377<Nr\377=Ot\377\77Rv\377ARv\377ASw\377@Sw\377@Rw\377" +\
    ">Pt\377;G`\377BFK\377=AE\3779<=\377\35)\77\377\27*K\377\23&I\377\22#" +\
    "E\377\20 A\377\20\37@\377\13\30\62\344\7\20\42N\0\0\0\0\6\15\33\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\7" +\
    "\20W\11\23)\331\15\34:\377\17 @\377\20!A\377\22#D\377\25'G\377\31*L\377" +\
    "\35.O\377 2T\377\42\64V\377#6W\377#6W\377\42\64V\377 2T\377\36\60Q\377" +\
    "\31*I\377\33%\67\377\35%\60\377\24\37\64\377\17\36=\377\17\36<\377\17" +\
    "\35<\377\15\32\66\377\11\22'\326\3\7\20W\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0*\5\13\30\214\10\21$\337\12\25,\377\16\34:" +\
    "\377\16\349\377\16\349\377\16\35:\377\17\35;\377\17\35;\377\17\36;\377" +\
    "\17\36;\377\17\36:\377\16\35:\377\16\349\377\16\348\377\15\338\377\15" +\
    "\33\67\377\11\24)\377\10\21#\333\5\13\30\210\0\0\0&\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\12\0\0\0M\3\10\23y\6\15\35\252\7\17 \302\7\17!\326\10\22&\346" +\
    "\11\22%\356\11\22%\356\10\22&\345\7\17 \325\7\17\37\300\6\15\34\247\3" +\
    "\10\22u\0\0\0H\0\0\0\10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0"


# RGBA 128x128x4
viewer_icon_128_raw = \
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Hy\262/H~\264oK}\264\204K}\265\220K\177" +\
    "\265\233K~\263\246L~\263\264K~\264\265K~\264\306H}\264\305H|\265\265" +\
    "_\207\257\264\216\233\243\246p\217\252\234E{\266\217I}\263\204H{\264" +\
    "mDy\262.\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0H{\263\20I{\262ZI}\263\220I}\263\324K~\264\371" +\
    "L\200\265\377M\202\267\377O\204\270\377P\205\272\376Q\207\273\377R\211" +\
    "\274\376S\211\274\377Q\211\276\377]\215\272\377t\224\261\377\214\235" +\
    "\250\377\236\243\241\377\245\245\237\377\241\243\240\377\244\245\237" +\
    "\376\226\237\243\377\200\226\251\376~\225\250\377{\223\251\377v\221\252" +\
    "\377y\221\251\371z\222\250\326\205\227\245\231\213\231\244s\217\232\242" +\
    "\42\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0>i\245\5H|\262`H|\262\232J}\263\377K\177\264\377N\202\267\377O" +\
    "\205\272\376R\207\274\377T\212\276\377V\215\301\377W\216\302\377X\220" +\
    "\304\377Y\221\306\377Z\222\306\377[\224\311\377Z\225\311\377{\234\271" +\
    "\377\252\251\243\377\247\251\245\377\245\251\245\377\246\250\245\377" +\
    "\246\251\245\377\246\250\245\377\245\250\244\377\245\247\244\377\244" +\
    "\247\243\377\243\246\244\377\243\245\242\377\242\245\241\377\241\245" +\
    "\241\377\241\244\241\377\241\244\240\377\241\243\237\377\237\242\237" +\
    "\377\220\233\242\377\204\226\243\236d\207\254a\0\16\335\5\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0H{\262}I{\262\306J~\264\377M\200\266\377O\205\272\376Q\210" +\
    "\274\377U\213\277\376W\216\301\377Y\221\304\377Z\224\310\377[\225\312" +\
    "\377]\227\314\377^\231\316\377`\232\316\377`\233\317\377a\233\316\377" +\
    "_\231\313\377n\232\276\377\260\260\253\377\254\257\256\377\255\260\256" +\
    "\377\255\260\256\377\255\260\256\377\255\257\255\377\254\257\255\377" +\
    "\254\256\254\377\253\256\253\377\253\255\252\377\252\254\252\377\251" +\
    "\253\251\377\250\253\247\377\246\251\246\377\245\250\245\377\244\247" +\
    "\244\377\243\246\243\377\243\245\242\376\241\245\241\377\242\244\240" +\
    "\376\242\244\237\377\223\235\241\377\205\225\244\306f\210\253\177\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Gx\260MHz\261\310I|\262" +\
    "\377L\200\266\377O\205\272\377R\210\275\377U\213\300\377W\217\304\377" +\
    "Z\222\306\377\134\225\312\377]\227\314\377_\232\317\377a\234\320\377" +\
    "c\237\322\377d\241\323\377e\242\325\377e\244\327\377f\245\327\377d\241" +\
    "\322\377]\227\302\377g\215\253\377\271\272\266\377\266\271\266\377\266" +\
    "\271\267\377\266\271\267\377\266\271\267\377\267\271\267\377\266\271" +\
    "\266\377\265\270\265\377\265\267\265\377\264\266\264\377\263\265\263" +\
    "\377\261\264\261\377\260\263\261\377\257\261\257\377\255\260\255\377" +\
    "\253\256\253\377\252\254\252\377\250\253\250\377\247\251\246\377\244" +\
    "\247\244\377\243\245\242\377\242\244\241\377\241\244\240\377\242\243" +\
    "\237\377\224\235\241\377\207\226\244\315\177\223\244Y\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0At\263\6Fx\260" +\
    "wHy\260\377K~\264\377N\202\270\376Q\207\274\377T\213\300\377W\216\304" +\
    "\377Y\222\307\377Z\225\311\377Z\226\314\377]\230\315\377_\233\316\377" +\
    "b\235\317\377d\240\322\377d\243\327\377h\247\331\377i\251\332\377j\252" +\
    "\334\377k\255\336\377k\253\334\377h\246\325\377]\225\277\377Il\210\377" +\
    "\304\305\301\377\300\303\300\377\301\304\300\377\301\304\300\377\301" +\
    "\303\300\377\301\303\300\377\300\302\300\377\300\302\300\377\277\300" +\
    "\277\377\275\300\276\377\275\276\275\377\274\275\274\377\272\274\272" +\
    "\377\270\272\270\377\267\271\267\377\264\267\264\377\263\265\263\377" +\
    "\260\262\260\377\256\261\256\377\255\260\254\377\252\255\252\377\250" +\
    "\252\250\377\246\250\246\377\243\246\243\377\243\244\242\377\240\243" +\
    "\237\377\240\243\236\377\231\237\237\377\234\240\236\230\232\236\240" +\
    "7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Cq\261\12Ew\256\237Hz\260\377K~\264\377" +\
    "N\204\272\377R\211\275\376V\215\302\377X\221\307\377[\225\311\377\134" +\
    "\230\314\377\134\230\314\377\201\243\275\377\250\260\263\377\256\264" +\
    "\263\377\262\267\266\377\266\272\271\377\272\274\272\377\271\276\277" +\
    "\377y\256\326\377m\256\336\377p\260\340\377q\262\342\377r\262\342\377" +\
    "m\254\333\377a\231\301\377Bg\205\377\270\271\267\377\314\315\315\377" +\
    "\314\315\315\377\315\315\315\377\314\316\314\377\312\315\313\377\313" +\
    "\315\312\377\312\314\312\377\311\313\312\377\310\312\310\377\306\311" +\
    "\307\377\306\310\306\377\304\307\304\377\303\305\303\377\301\303\301" +\
    "\377\276\301\277\377\275\277\275\377\273\275\272\377\267\272\270\377" +\
    "\265\270\266\377\262\264\262\377\260\262\257\377\255\257\255\377\252" +\
    "\255\252\377\247\252\250\377\246\250\245\377\243\245\242\376\241\243" +\
    "\240\377\240\242\240\376\236\241\236\377\235\241\236\335\237\241\237" +\
    "^\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "Dr\260\6Ev\256\243Fy\257\377K~\264\376N\203\271\377R\211\275\377V\216" +\
    "\302\377Y\222\310\377\134\226\313\377^\231\316\377a\233\317\377[\227" +\
    "\312\377\204\243\271\377\271\271\265\377\272\274\272\377\275\277\275" +\
    "\377\300\302\277\377\302\305\303\377\306\310\306\377\307\311\310\377" +\
    "\276\307\312\377i\252\332\377r\262\342\377t\266\346\377u\267\347\377" +\
    "r\263\342\377f\240\311\377Kx\230\377\223\226\231\377\325\327\325\377" +\
    "\325\327\325\377\324\327\325\377\325\327\325\377\324\326\325\377\324" +\
    "\325\324\377\323\324\324\377\323\324\323\377\322\324\322\377\321\322" +\
    "\321\377\317\322\320\377\317\320\317\377\317\320\317\377\271\272\271" +\
    "\377\307\311\307\377\307\311\310\377\304\307\305\377\302\304\302\377" +\
    "\277\301\277\377\274\277\274\377\271\273\272\377\266\270\266\377\263" +\
    "\265\263\377\260\261\257\377\254\257\254\377\251\254\251\377\247\251" +\
    "\246\377\244\246\243\377\242\244\241\377\237\243\237\377\237\242\237" +\
    "\377\237\242\236\352\240\241\236L\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0Cu\254zEw\256\377I|\263\376N\202\270\377R\210\275\377V\215\302" +\
    "\377Y\223\310\377\134\227\314\377_\233\320\377a\235\322\377b\236\320" +\
    "\377^\226\304\377\246\262\271\377\300\301\275\377\300\302\301\377\304" +\
    "\306\304\377\306\311\307\377\312\314\312\377\314\316\315\377\317\320" +\
    "\317\377\321\323\322\377\324\325\323\377\267\310\322\377o\260\336\377" +\
    "v\270\347\377x\271\351\377w\271\347\377n\253\326\377X\212\254\377\134" +\
    "jw\377\340\341\340\377\332\335\333\377\334\335\334\377\334\335\334\377" +\
    "\334\335\334\377\333\335\333\377\333\334\334\377\332\334\333\377\331" +\
    "\333\332\377\330\332\331\377\331\332\332\377\251\252\251\377qqp\377c" +\
    "dc\377\301\301\300\377\320\323\321\377\317\321\317\377\315\317\315\377" +\
    "\312\314\312\377\307\311\310\377\304\306\304\377\277\302\300\377\274" +\
    "\277\275\377\270\272\270\377\265\267\265\377\261\263\261\377\256\260" +\
    "\255\377\252\255\252\377\246\251\247\377\244\247\244\377\242\244\241" +\
    "\376\240\242\240\377\236\241\236\377\236\241\237\330\237\242\240-\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0Bt\255KCt\254\361Hy\257\377L\200\265\377Q\206\274\376U\214\302" +\
    "\377Y\221\307\377\134\225\313\377^\233\320\377b\236\324\377d\241\325" +\
    "\377d\241\323\377_\230\307\377\234\257\274\377\303\306\303\377\307\311" +\
    "\307\377\314\316\315\377\317\320\317\377\321\323\321\377\324\326\324" +\
    "\377\325\327\325\377\326\330\327\377\330\332\331\377\332\333\333\377" +\
    "\337\336\334\377q\252\323\377u\267\345\377y\274\352\377y\274\352\377" +\
    "s\264\340\377b\231\276\377Gcz\377\201\200\177\377\345\347\346\377\340" +\
    "\342\341\377\341\342\341\377\341\343\341\377\340\341\341\377\340\341" +\
    "\340\377\337\341\340\377\337\340\337\377\337\340\337\377\340\342\341" +\
    "\377`cg\377BN^\3774J]\377bfl\377\336\337\336\377\327\330\330\377\325" +\
    "\327\325\377\323\325\323\377\321\322\320\377\315\317\316\377\312\314" +\
    "\313\377\307\311\306\377\302\305\302\377\276\300\277\377\272\274\273" +\
    "\377\266\271\266\377\262\265\263\377\256\261\255\377\252\255\252\377" +\
    "\246\250\246\377\244\247\244\377\242\244\241\377\237\242\237\376\236" +\
    "\241\237\377\236\242\235\253\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0Cy\276\4Bs\253\300Ew\255\377J}\263\377O\204\272\376R" +\
    "\212\277\377W\217\306\377Z\224\312\377^\231\317\377a\236\323\377d\241" +\
    "\327\377g\245\331\377i\247\332\377f\243\322\377]\225\300\377Tv\221\377" +\
    "\215\215\213\377\215\216\215\377\201\202\202\377\207\210\207\377\215" +\
    "\215\215\377\217\221\220\377\250\252\250\377\343\344\344\377\341\343" +\
    "\341\377\336\337\336\377\313\314\313\377a\225\272\377s\263\337\377w\272" +\
    "\350\377v\272\350\377q\265\342\377b\234\303\377Bm\212\377\200\211\224" +\
    "\377\347\350\350\377\345\346\346\377\345\345\345\377\345\347\346\377" +\
    "\345\346\345\377\344\346\345\377\344\346\344\377\344\345\345\377\351" +\
    "\352\352\377\205\206\205\3778Un\377Is\220\377Is\217\377@Sg\377\220\222" +\
    "\220\377\343\343\343\377\334\335\335\377\332\334\333\377\330\332\330" +\
    "\377\325\327\326\377\323\325\323\377\320\321\320\377\315\316\315\377" +\
    "\310\313\311\377\303\306\304\377\277\302\300\377\273\275\273\377\267" +\
    "\271\267\377\262\264\263\377\256\261\256\377\252\254\251\377\246\251" +\
    "\246\377\243\246\243\377\241\244\241\377\237\242\237\376\237\242\235" +\
    "\377\236\241\235N\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Bq\253PCs\252\377Gy\260" +\
    "\376L\177\266\377P\206\274\377U\214\302\377Y\223\310\377]\227\315\377" +\
    "`\234\322\377c\240\325\377e\244\331\377i\250\334\377k\252\335\377k\252" +\
    "\334\377f\243\322\377]\222\270\377\231\243\253\377\275\277\275\377\266" +\
    "\270\267\377\267\270\270\377\262\263\263\377\214\217\221\377Z_g\377Q" +\
    "TZ\377rsr\377lll\377ikj\377aab\377U\205\247\377f\244\315\377\236\307" +\
    "\342\377\275\326\346\377\307\332\345\377\337\344\346\377\347\351\350" +\
    "\377\351\352\351\377\350\352\351\377\350\351\350\377\350\351\351\377" +\
    "\350\351\351\377\350\351\350\377\350\350\347\377\346\347\347\377\346" +\
    "\347\346\377\322\323\322\377ESb\377S\202\243\377a\230\274\377`\226\272" +\
    "\377O~\235\377IS_\377\250\252\251\377\337\340\340\377\342\343\343\377" +\
    "\345\346\345\377\341\342\341\377\336\337\336\377\333\334\333\377\325" +\
    "\326\325\377\321\323\321\377\315\317\316\377\311\313\311\377\304\306" +\
    "\304\377\277\301\277\377\272\274\273\377\266\271\267\377\261\264\261" +\
    "\377\255\257\254\377\251\253\251\377\245\250\245\377\242\245\241\377" +\
    "\240\242\240\377\236\241\236\377\236\241\237\272\243\244\236\4\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0Aq\252\261Dt\253\377I{\262\377N\202\270\376R\210\277\377V\216\304\377" +\
    "[\225\313\377^\231\317\377a\236\324\377e\242\327\377g\245\333\377j\252" +\
    "\335\377l\255\337\377m\256\337\377k\253\333\377b\236\313\377\250\274" +\
    "\311\377\327\330\327\377\331\332\331\377\333\334\333\377\335\336\336" +\
    "\377\336\340\337\377\343\345\343\377\345\347\346\377\274\303\306\377" +\
    "\226\233\240\377GVg\377\77Si\377>^z\377X\210\246\377\247\277\317\377" +\
    "\356\355\353\377\352\352\352\377\352\353\352\377\353\353\353\377\352" +\
    "\353\353\377\351\354\353\377\352\354\352\377\352\353\353\377\353\354" +\
    "\353\377\352\353\353\377\352\353\353\377\352\353\352\377\352\353\353" +\
    "\377\354\356\356\377\243\244\245\377\134\200\230\377d\236\305\377j\251" +\
    "\325\377j\247\322\377a\230\275\377Kv\224\377VY`\377kkk\377mom\377|}|" +\
    "\377\206\207\207\377\211\212\211\377\210\211\211\377\323\325\324\377" +\
    "\327\331\330\377\324\326\325\377\321\322\322\377\315\317\316\377\311" +\
    "\313\311\377\302\305\303\377\277\301\277\377\271\273\271\377\265\267" +\
    "\265\377\260\262\260\377\253\256\254\377\247\252\247\377\243\247\244" +\
    "\377\241\243\241\377\237\242\237\376\237\242\237\364\236\240\237;\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0@p\253\31Ap\250\357D" +\
    "u\254\376J|\264\377O\204\272\377S\212\301\377X\220\307\377[\226\314\377" +\
    "`\233\321\377b\240\325\377e\244\330\377h\247\333\377k\253\336\377l\255" +\
    "\340\377n\257\341\377n\260\341\377l\253\332\377f\236\310\377\334\333" +\
    "\332\377\333\335\334\377\335\337\336\377\337\340\340\377\340\341\340" +\
    "\377\341\342\341\377\342\343\343\377\344\345\344\377\345\346\345\377" +\
    "\350\350\350\377\322\330\332\377p\215\240\377\273\311\320\377\353\353" +\
    "\353\377\354\355\354\377\353\355\354\377\354\355\355\377\355\356\354" +\
    "\377\354\355\355\377\355\356\354\377\355\355\356\377\354\356\355\377" +\
    "\354\356\355\377\354\355\355\377\354\355\355\377\354\355\355\377\354" +\
    "\355\355\377\354\355\354\377\353\354\354\377\357\360\360\377\360\360" +\
    "\357\377\354\354\354\377\332\343\351\377\276\325\344\377y\255\320\377" +\
    "^\225\271\377My\231\377@Xq\377\77Tj\377DRd\377HS`\377IR_\377KS^\377i" +\
    "ij\377\314\316\315\377\333\335\334\377\327\330\330\377\323\325\323\377" +\
    "\317\321\320\377\313\315\314\377\307\310\307\377\301\303\301\377\274" +\
    "\276\274\377\267\271\267\377\262\264\262\377\255\260\256\377\251\254" +\
    "\251\377\245\250\245\377\242\244\242\377\237\243\237\376\237\241\236" +\
    "\377\237\241\237y\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Ao\251LAp\247\377" +\
    "Ev\255\376J~\265\377P\205\274\377U\214\302\377X\221\310\377\134\227\316" +\
    "\377a\234\323\377c\241\327\377f\244\331\377h\250\334\377k\253\337\377" +\
    "m\255\340\377o\257\342\377o\261\342\377o\257\340\377k\251\331\377\215" +\
    "\264\321\377\340\337\336\377\336\340\337\377\340\341\340\377\341\342" +\
    "\342\377\341\343\342\377\344\345\344\377\345\346\346\377\346\347\346" +\
    "\377\347\350\350\377\351\351\351\377\352\353\353\377\357\357\355\377" +\
    "\354\354\355\377\354\355\354\377\355\356\355\377\355\356\356\377\356" +\
    "\356\356\377\355\356\356\377\356\357\357\377\356\357\357\377\357\360" +\
    "\357\377\356\356\356\377\356\356\356\377\356\356\356\377\356\356\356" +\
    "\377\356\356\357\377\356\357\356\377\355\356\356\377\355\356\356\377" +\
    "\355\357\357\377\356\356\357\377\356\357\357\377\355\357\356\377\356" +\
    "\356\356\377\357\357\356\377\231\276\325\377`\230\277\377a\227\273\377" +\
    "_\223\266\377\134\220\263\377X\213\256\377S\203\245\377It\222\377;Qh" +\
    "\377bce\377\302\304\303\377\336\340\336\377\331\333\332\377\326\330\326" +\
    "\377\323\323\323\377\316\320\316\377\311\312\311\377\304\307\304\377" +\
    "\276\301\276\377\271\274\271\377\265\266\265\377\260\262\260\377\252" +\
    "\255\253\377\247\251\246\377\243\246\243\377\241\243\241\377\236\241" +\
    "\236\377\236\241\236\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\77m\246w@o\247\377Fw\257" +\
    "\377K\177\265\376P\206\274\377V\215\303\377Y\222\312\377^\231\316\377" +\
    "a\235\323\377d\242\330\377f\245\332\377h\250\334\377k\253\340\377l\255" +\
    "\340\377m\256\340\377n\257\340\377k\255\336\377l\254\334\377i\247\324" +\
    "\377x\237\275\377\343\343\341\377\341\342\342\377\342\343\343\377\343" +\
    "\344\344\377\344\346\345\377\345\347\346\377\347\347\347\377\350\351" +\
    "\350\377\351\352\352\377\352\354\353\377\353\355\354\377\355\355\355" +\
    "\377\355\356\355\377\356\357\357\377\357\357\357\377\357\360\360\377" +\
    "\360\361\360\377\360\360\360\377\357\361\361\377\360\360\360\377\360" +\
    "\360\361\377\360\361\360\377\357\360\357\377\357\360\357\377\360\360" +\
    "\360\377\360\361\360\377\357\360\360\377\357\357\356\377\357\357\357" +\
    "\377\356\360\357\377\356\357\357\377\356\360\357\377\356\357\357\377" +\
    "\356\360\357\377\356\357\357\377\363\361\360\377\274\322\342\377h\245" +\
    "\316\377l\252\322\377n\253\325\377l\251\324\377j\245\317\377b\232\301" +\
    "\377V\207\252\377<Yt\377XZ^\377\266\267\267\377\341\342\341\377\333\334" +\
    "\334\377\327\331\330\377\323\325\323\377\317\321\320\377\313\315\313" +\
    "\377\306\310\306\377\300\303\301\377\274\276\274\377\266\271\266\377" +\
    "\262\263\261\377\254\257\255\377\247\251\247\377\244\247\244\377\241" +\
    "\243\241\377\237\242\237\376\236\241\236\343\240\240\236\15\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0>l\246\253@o\246" +\
    "\377Fx\257\377L\177\266\377P\206\275\377U\215\303\377Z\223\312\377]\230" +\
    "\317\377a\235\324\377d\242\330\377f\245\333\377h\250\335\377k\253\340" +\
    "\377k\253\336\377h\252\334\377l\252\332\377\216\271\331\377\275\317\333" +\
    "\377\334\336\336\377\340\340\337\377\326\331\332\377\335\337\336\377" +\
    "\343\344\343\377\343\344\344\377\344\346\345\377\346\347\346\377\347" +\
    "\350\347\377\351\351\351\377\352\353\352\377\352\354\354\377\353\355" +\
    "\353\377\355\355\355\377\356\357\357\377\357\357\357\377\357\360\357" +\
    "\377\360\361\361\377\360\361\361\377\360\361\361\377\361\362\361\377" +\
    "\361\361\361\377\361\362\362\377\361\362\362\377\361\362\362\377\361" +\
    "\362\362\377\361\361\362\377\361\362\361\377\361\362\361\377\360\361" +\
    "\361\377\360\361\360\377\361\361\361\377\360\361\361\377\360\360\360" +\
    "\377\357\360\360\377\357\361\360\377\357\360\360\377\357\360\357\377" +\
    "\357\357\357\377\360\360\357\377\334\345\353\377u\261\332\377s\263\337" +\
    "\377t\266\343\377s\264\342\377p\257\334\377h\243\314\377Y\215\261\377" +\
    ">`|\377OTZ\377\316\317\317\377\336\340\337\377\333\334\334\377\330\332" +\
    "\330\377\324\326\325\377\320\322\321\377\314\316\315\377\310\311\310" +\
    "\377\301\304\301\377\275\277\276\377\267\272\270\377\262\265\263\377" +\
    "\255\260\255\377\251\254\250\377\244\247\244\377\242\244\241\377\237" +\
    "\241\236\376\236\241\235\371\233\240\234\25\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0=l\244\277@o\246\377Fw\256\377L\177\265\377P\206" +\
    "\276\377U\215\304\377Y\223\312\377]\230\317\377`\235\324\377c\241\331" +\
    "\377d\245\334\377d\247\336\377e\250\336\377f\245\327\377\211\263\324" +\
    "\377\261\307\325\377\332\333\331\377\336\336\334\377\335\336\336\377" +\
    "\337\337\337\377\340\342\341\377\342\343\342\377\342\344\343\377\343" +\
    "\344\344\377\345\347\346\377\346\347\346\377\347\351\347\377\351\352" +\
    "\352\377\352\352\353\377\352\354\354\377\354\355\354\377\355\356\356" +\
    "\377\356\357\357\377\357\361\357\377\360\361\361\377\361\362\362\377" +\
    "\362\363\363\377\362\363\363\377\363\363\363\377\363\364\363\377\363" +\
    "\364\364\377\364\364\364\377\363\364\364\377\363\364\363\377\362\364" +\
    "\363\377\363\364\363\377\363\363\364\377\364\364\364\377\362\364\362" +\
    "\377\362\362\363\377\362\362\362\377\346\347\347\377\352\353\352\377" +\
    "\362\362\362\377\360\360\361\377\360\361\361\377\360\361\360\377\357" +\
    "\360\360\377\357\360\360\377\357\357\357\377\351\355\356\377\211\276" +\
    "\340\377q\263\341\377u\266\344\377u\267\345\377r\262\337\377i\244\317" +\
    "\377X\212\256\3777Yv\377\350\350\346\377\343\344\343\377\337\340\337" +\
    "\377\334\335\334\377\330\332\330\377\325\326\325\377\321\322\322\377" +\
    "\314\317\315\377\310\312\311\377\303\305\304\377\276\277\276\377\271" +\
    "\274\270\377\263\265\263\377\257\261\256\377\251\254\251\377\245\250" +\
    "\245\377\242\244\242\376\237\241\237\376\235\240\234\377\236\241\236" +\
    "%\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0=k\244\324@m\245\377Bv\256\377P\201\264" +\
    "\377Z\212\272\377e\222\275\377s\234\301\377\200\243\303\377\212\252\306" +\
    "\377\223\260\311\377\235\267\313\377\252\277\315\377\266\305\317\377" +\
    "\275\310\317\377\321\323\322\377\331\331\326\377\331\333\331\377\332" +\
    "\334\333\377\334\335\334\377\336\340\340\377\340\342\341\377\342\342" +\
    "\342\377\343\344\343\377\343\345\344\377\345\346\346\377\345\346\347" +\
    "\377\347\351\350\377\351\351\351\377\351\353\352\377\353\354\353\377" +\
    "\354\355\355\377\356\357\357\377\357\360\360\377\361\361\361\377\362" +\
    "\363\363\377\362\363\363\377\364\364\364\377\364\365\364\377\365\366" +\
    "\365\377\365\366\366\377\366\366\366\377\366\366\366\377\366\366\366" +\
    "\377\366\367\366\377\365\366\366\377\365\366\366\377\365\366\366\377" +\
    "\365\365\365\377\364\366\365\377\364\365\365\377\364\364\364\377\365" +\
    "\365\365\377\261\262\263\377ijk\377\225\226\227\377\366\366\367\377\361" +\
    "\362\362\377\360\361\361\377\360\361\360\377\360\360\360\377\357\360" +\
    "\360\377\357\360\360\377\363\362\357\377\266\324\346\377o\262\340\377" +\
    "u\266\344\377u\266\345\377q\262\340\377g\240\312\377Q\201\243\377elr" +\
    "\377\237\240\237\377\313\314\313\377\341\342\341\377\334\335\334\377" +\
    "\330\331\330\377\325\326\325\377\321\323\321\377\315\317\315\377\311" +\
    "\313\312\377\304\307\304\377\277\301\300\377\272\274\272\377\264\267" +\
    "\265\377\257\261\260\377\252\254\252\377\245\250\246\377\242\245\242" +\
    "\377\237\241\236\376\235\240\235\377\233\240\234+\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0<i\242" +\
    "\313=l\244\376`\202\247\376\227\237\240\377\246\246\242\377\252\253\246" +\
    "\377\256\260\253\377\264\264\261\377\270\272\267\377\274\276\274\377" +\
    "\301\303\301\377\307\311\307\377\313\314\313\377\316\320\317\377\322" +\
    "\324\323\377\325\327\326\377\331\332\331\377\331\332\332\377\334\336" +\
    "\335\377\336\340\337\377\340\341\340\377\341\342\341\377\342\343\343" +\
    "\377\343\345\343\377\344\345\344\377\345\346\346\377\347\350\350\377" +\
    "\350\352\351\377\352\353\352\377\353\354\354\377\355\356\356\377\357" +\
    "\357\357\377\360\361\360\377\362\362\361\377\362\363\363\377\363\364" +\
    "\363\377\365\365\364\377\365\365\365\377\365\366\366\377\366\366\366" +\
    "\377\366\367\367\377\367\370\370\377\367\367\370\377\367\367\370\377" +\
    "\367\370\370\377\367\367\367\377\367\367\367\377\367\367\367\377\366" +\
    "\367\366\377\367\367\367\377\365\366\366\377\364\365\365\377\365\366" +\
    "\365\377\251\261\267\377*BW\377>Pb\377\325\326\324\377\361\363\362\377" +\
    "\362\362\361\377\361\361\361\377\361\361\360\377\357\361\360\377\357" +\
    "\360\361\377\357\360\357\377\360\361\360\377\341\351\354\377\201\272" +\
    "\340\377r\265\343\377t\265\344\377p\256\334\377c\233\304\377B]w\377H" +\
    "Q_\377TVZ\377\314\315\315\377\336\340\336\377\333\335\334\377\330\332" +\
    "\330\377\325\326\325\377\321\323\321\377\315\317\315\377\311\313\312" +\
    "\377\304\307\305\377\300\302\277\377\273\275\272\377\265\267\265\377" +\
    "\257\262\260\377\253\255\253\377\246\250\245\377\242\245\241\377\236" +\
    "\241\236\376\234\240\234\377\233\236\234\36\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\66f\241\277Sv\236\376\223" +\
    "\232\233\377\240\241\235\377\241\244\242\377\247\252\247\377\254\256" +\
    "\254\377\261\263\262\377\266\272\267\377\274\276\274\377\277\303\301" +\
    "\377\307\311\307\377\312\314\312\377\316\320\317\377\321\323\322\377" +\
    "\325\327\326\377\325\327\326\377\331\332\331\377\334\335\334\377\335" +\
    "\335\335\377\337\341\337\377\340\341\340\377\341\343\342\377\342\343" +\
    "\343\377\343\344\344\377\345\346\345\377\346\350\347\377\347\350\350" +\
    "\377\352\352\352\377\353\354\354\377\356\357\356\377\357\357\357\377" +\
    "\360\360\360\377\361\362\362\377\363\363\364\377\365\364\364\377\365" +\
    "\366\366\377\366\367\367\377\367\367\367\377\370\371\371\377\371\371" +\
    "\371\377\371\371\371\377\371\371\371\377\371\371\371\377\371\371\371" +\
    "\377\372\372\372\377\371\371\371\377\371\371\371\377\370\370\370\377" +\
    "\370\370\370\377\370\371\371\377\367\370\370\377\366\367\367\377\366" +\
    "\366\366\377\263\276\304\377Cj\201\377O{\225\377qy\202\377\366\366\366" +\
    "\377\361\362\362\377\361\362\362\377\361\362\362\377\361\361\361\377" +\
    "\360\361\360\377\357\361\360\377\357\360\357\377\357\357\357\377\363" +\
    "\362\360\377\261\320\345\377p\262\340\377s\264\342\377n\255\332\377b" +\
    "\232\303\377P~\237\377/Pk\377\246\253\256\377\340\341\340\377\335\336" +\
    "\335\377\333\334\333\377\327\331\331\377\324\326\324\377\320\323\321" +\
    "\377\315\317\316\377\312\313\312\377\305\307\305\377\301\303\301\377" +\
    "\273\275\274\377\266\270\266\377\260\262\260\377\253\256\253\377\245" +\
    "\250\246\377\241\245\241\377\236\241\236\376\234\237\233\377\234\241" +\
    "\233#\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0Su\237\253\204" +\
    "\217\231\377\236\236\230\377\235\240\234\377\241\244\241\377\246\251" +\
    "\247\377\253\256\254\377\261\263\261\377\266\271\267\377\274\276\274" +\
    "\377\277\302\300\377\306\310\307\377\312\314\312\377\315\317\315\377" +\
    "\321\323\321\377\324\325\324\377\325\327\326\377\330\331\331\377\332" +\
    "\334\333\377\334\337\335\377\336\337\336\377\337\340\337\377\340\342" +\
    "\341\377\342\342\342\377\343\344\342\377\344\345\345\377\346\347\346" +\
    "\377\347\350\350\377\352\353\352\377\353\354\354\377\355\356\356\377" +\
    "\357\357\357\377\360\361\361\377\362\363\363\377\365\365\365\377\365" +\
    "\366\366\377\367\370\367\377\371\371\371\377\371\371\371\377\372\372" +\
    "\372\377\373\373\373\377\373\373\373\377\373\373\373\377\373\373\373" +\
    "\377\373\373\373\377\373\373\373\377\373\373\373\377\373\373\373\377" +\
    "\373\373\373\377\372\373\373\377\372\372\372\377\371\371\371\377\372" +\
    "\373\373\377\374\374\374\377\377\377\377\377m~\213\377Z\213\246\377d" +\
    "\233\271\377X\204\242\377\343\343\342\377\362\363\363\377\361\363\362" +\
    "\377\361\362\362\377\360\362\361\377\361\361\361\377\360\361\360\377" +\
    "\360\360\360\377\357\361\357\377\357\360\360\377\361\360\357\377\315" +\
    "\336\351\377p\262\341\377s\264\342\377l\251\326\377]\221\270\377Ms\217" +\
    "\377}\207\222\377\344\345\344\377\337\341\340\377\334\335\335\377\332" +\
    "\334\332\377\327\331\330\377\324\325\324\377\321\322\321\377\315\320" +\
    "\316\377\312\313\313\377\306\310\306\377\301\303\301\377\273\276\273" +\
    "\377\267\272\267\377\261\263\261\377\253\256\254\377\246\250\246\377" +\
    "\241\244\241\377\235\237\235\376\234\236\233\365\231\233\231\20\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\211\221\226\243\227\232\226\377\230\233" +\
    "\230\376\234\236\234\377\240\243\240\377\245\247\245\377\253\255\253" +\
    "\377\257\262\260\377\266\270\266\377\273\275\273\377\277\301\300\377" +\
    "\305\307\305\377\311\313\312\377\313\315\314\377\320\322\320\377\322" +\
    "\324\323\377\323\325\324\377\326\327\327\377\331\332\331\377\332\333" +\
    "\333\377\335\336\335\377\336\337\337\377\336\340\337\377\340\341\341" +\
    "\377\341\343\342\377\343\345\344\377\344\346\345\377\347\347\350\377" +\
    "\350\351\351\377\353\354\353\377\354\356\354\377\356\357\357\377\360" +\
    "\361\361\377\363\364\363\377\365\365\365\377\367\367\367\377\370\371" +\
    "\370\377\371\371\371\377\372\372\372\377\373\373\373\377\374\373\374" +\
    "\377\374\374\374\377\374\375\375\377\375\374\375\377\375\375\375\377" +\
    "\374\375\374\377\374\375\375\377\374\374\374\377\374\373\373\377\375" +\
    "\374\375\377\374\374\374\377\374\374\374\377\367\367\367\377\257\257" +\
    "\256\377\224\224\224\377\203\203\204\377Nr\212\377k\245\306\377t\262" +\
    "\326\377m\257\325\377\321\325\330\377\364\364\364\377\363\363\363\377" +\
    "\361\362\362\377\361\362\362\377\360\361\362\377\360\361\361\377\360" +\
    "\360\361\377\360\360\360\377\357\361\360\377\360\360\357\377\323\336" +\
    "\345\377m\256\334\377r\264\341\377m\254\331\377Y\217\266\377\341\344" +\
    "\344\377\351\352\351\377\345\346\345\377\341\342\342\377\337\340\337" +\
    "\377\333\335\334\377\331\333\331\377\327\330\327\377\323\325\324\377" +\
    "\321\323\322\377\316\317\317\377\313\315\314\377\307\311\310\377\301" +\
    "\304\302\377\274\276\275\377\267\271\270\377\262\264\262\377\254\257" +\
    "\254\377\246\250\246\377\240\244\240\377\234\237\234\376\231\234\231" +\
    "\336\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\222\226\224\261\225\231\225\377\227" +\
    "\232\227\377\232\234\232\377\237\242\236\377\243\247\244\377\251\253" +\
    "\251\377\256\261\257\377\265\267\265\377\271\274\271\377\277\301\277" +\
    "\377\303\305\303\377\310\312\310\377\312\315\313\377\316\320\317\377" +\
    "\321\323\322\377\323\324\323\377\326\327\326\377\330\332\331\377\332" +\
    "\333\332\377\333\334\334\377\334\335\334\377\335\337\336\377\337\340" +\
    "\340\377\340\341\341\377\342\342\342\377\343\345\344\377\346\347\347" +\
    "\377\350\350\351\377\351\352\351\377\354\355\355\377\356\357\357\377" +\
    "\360\361\361\377\363\364\364\377\365\366\365\377\367\370\367\377\370" +\
    "\371\371\377\372\372\372\377\373\374\373\377\374\374\374\377\375\375" +\
    "\375\377\375\375\375\377\375\375\375\377\375\375\375\377\375\375\375" +\
    "\377\375\375\375\377\375\375\375\377\375\375\375\377\375\375\375\377" +\
    "\375\375\375\377\374\375\375\377\377\377\377\377\316\316\315\377ijn\377" +\
    "KZk\377Jbw\377Ll\207\377o\252\314\377{\276\342\377~\301\350\377t\267" +\
    "\336\377\307\322\331\377\364\364\364\377\363\363\363\377\362\364\363" +\
    "\377\362\362\362\377\361\361\361\377\360\361\361\377\360\361\361\377" +\
    "\360\361\361\377\365\365\365\377\302\303\302\377Xcn\377i\246\320\377" +\
    "o\257\333\377l\250\324\377T\210\255\377\345\345\345\377\350\351\350\377" +\
    "\346\346\346\377\343\344\344\377\341\342\342\377\336\337\336\377\333" +\
    "\335\334\377\331\332\331\377\327\330\327\377\324\326\325\377\321\323" +\
    "\322\377\317\321\317\377\314\316\315\377\310\312\310\377\304\306\304" +\
    "\377\276\300\277\377\271\272\270\377\262\265\262\377\254\256\254\377" +\
    "\245\250\246\377\240\242\237\376\234\236\233\376\230\235\231\302\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\222\226\222\222\222\226\223\377\225\230\225\377\231\233\230" +\
    "\377\235\240\235\377\242\245\242\377\247\252\247\377\255\260\255\377" +\
    "\263\266\264\377\272\273\271\377\275\277\275\377\302\303\303\377\307" +\
    "\311\307\377\311\314\312\377\315\317\316\377\320\321\320\377\322\323" +\
    "\322\377\324\326\324\377\326\330\327\377\330\331\330\377\331\332\332" +\
    "\377\333\334\334\377\334\336\335\377\336\337\336\377\336\340\340\377" +\
    "\341\342\341\377\342\343\343\377\345\346\345\377\347\350\350\377\350" +\
    "\351\351\377\354\355\354\377\356\356\357\377\360\361\360\377\363\364" +\
    "\364\377\366\366\366\377\367\367\367\377\371\371\371\377\373\373\373" +\
    "\377\373\374\374\377\375\375\375\377\375\375\375\377\375\375\375\377" +\
    "\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377" +\
    "\376\377\377\377\376\377\377\377\377\377\377\376\376\376\377\376\376" +\
    "\376\377\377\377\377\377\263\262\262\377NWe\377Hn\207\377`\224\256\377" +\
    "k\244\302\377u\263\325\377~\302\346\377\202\311\357\377\177\304\351\377" +\
    "p\265\334\377\304\323\334\377\365\365\365\377\364\365\364\377\363\362" +\
    "\363\377\361\363\362\377\362\362\362\377\361\361\361\377\361\362\362" +\
    "\377\352\353\352\377\213\214\214\377HQ_\377P}\235\377j\245\316\377p\257" +\
    "\333\377j\247\321\377P\203\247\377\305\307\311\377\351\352\352\377\347" +\
    "\350\350\377\345\346\345\377\343\344\343\377\340\341\341\377\335\337" +\
    "\336\377\333\334\334\377\331\332\331\377\330\330\330\377\325\327\326" +\
    "\377\323\324\324\377\321\322\321\377\316\317\316\377\312\314\312\377" +\
    "\306\307\306\377\277\302\300\377\272\274\272\377\263\265\264\377\253" +\
    "\256\253\377\244\247\244\377\236\241\236\377\231\235\231\377\231\235" +\
    "\230\203\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\221\224\220M\222\225\221\377\223\226\222\377\227\232\226\377\233" +\
    "\235\233\377\240\243\240\377\246\250\246\377\254\256\253\377\262\264" +\
    "\262\377\266\271\267\377\273\275\273\377\301\303\301\377\306\310\306" +\
    "\377\310\312\311\377\313\315\314\377\316\317\317\377\320\322\321\377" +\
    "\323\324\323\377\326\326\326\377\326\330\326\377\330\331\331\377\332" +\
    "\333\332\377\332\335\333\377\334\335\335\377\335\337\336\377\340\340" +\
    "\337\377\341\343\342\377\344\345\344\377\346\346\346\377\350\350\350" +\
    "\377\353\353\353\377\355\355\355\377\360\360\360\377\362\363\363\377" +\
    "\365\366\365\377\367\367\367\377\372\372\372\377\373\373\373\377\374" +\
    "\374\374\377\375\375\375\377\375\375\375\377\376\376\376\377\376\376" +\
    "\376\377\377\377\377\377\376\376\376\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377" +\
    "\377\377\377\377\240\237\240\377HZl\377Y\213\244\377l\247\305\377x\270" +\
    "\333\377\177\302\346\377\202\310\354\377\204\313\361\377~\306\354\377" +\
    "\243\321\353\377\325\346\357\377\370\370\370\377\365\365\365\377\364" +\
    "\366\365\377\363\363\363\377\363\362\363\377\361\362\362\377\364\365" +\
    "\365\377\277\300\277\377adh\377@Yq\377W\211\251\377^\223\266\377b\232" +\
    "\300\377s\263\340\377m\253\326\377\134\221\267\377KUa\377\304\305\303" +\
    "\377\351\352\351\377\346\347\347\377\345\345\345\377\342\343\343\377" +\
    "\340\341\340\377\335\337\336\377\334\335\334\377\331\333\332\377\330" +\
    "\331\331\377\326\330\327\377\325\326\325\377\323\324\323\377\317\321" +\
    "\320\377\314\315\315\377\310\312\310\377\302\304\302\377\302\304\303" +\
    "\377\271\274\271\377\261\263\261\377\251\254\251\377\243\246\242\377" +\
    "\227\232\225\377\235\237\233:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\221\221\223\16\221\223\217\377\222\225\221\377\224\230\224\377" +\
    "\230\234\230\377\236\240\235\377\243\246\243\377\251\253\251\377\260" +\
    "\262\260\377\265\270\265\377\272\274\272\377\277\301\300\377\303\306" +\
    "\304\377\307\311\307\377\312\314\313\377\315\317\316\377\317\321\320" +\
    "\377\322\323\322\377\325\326\326\377\326\327\326\377\326\330\327\377" +\
    "\330\333\331\377\332\334\332\377\333\334\333\377\334\336\335\377\337" +\
    "\337\336\377\340\342\341\377\342\343\342\377\344\345\344\377\346\347" +\
    "\347\377\352\353\352\377\354\355\355\377\356\357\357\377\362\362\362" +\
    "\377\364\365\365\377\366\367\367\377\371\371\371\377\373\373\373\377" +\
    "\374\374\374\377\375\375\375\377\376\376\376\377\376\376\376\377\377" +\
    "\377\377\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376" +\
    "\377\374\374\374\377\213\214\216\377F_t\377b\227\260\377t\261\321\377" +\
    "\177\304\345\377\205\314\360\377\207\317\364\377\206\316\363\377\203" +\
    "\312\357\377\251\325\354\377\377\375\373\377\371\370\371\377\367\367" +\
    "\367\377\366\366\366\377\366\366\366\377\363\363\364\377\363\363\363" +\
    "\377\361\361\361\377\207\210\212\377DQ_\377)@Q\377\27<I\377\4BL\377\0" +\
    "OZ\377\0S_\377\2KV\377\17CQ\377+CT\377@g\205\377EO\134\377\356\357\355" +\
    "\377\347\347\347\377\345\346\346\377\343\344\343\377\340\342\341\377" +\
    "\337\340\337\377\336\336\336\377\332\334\333\377\333\335\333\377\331" +\
    "\332\332\377\332\334\333\377\333\334\334\377\334\335\334\377\332\334" +\
    "\332\377\312\314\312\377\236\237\236\377YZY\377Z[Z\377XZY\377VVV\377" +\
    "MOR\377BFK\376_bd\376\0\0\20\17\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\216\222\216\315\220\224\220\376\223\225\222\376\226\231\226\377\233" +\
    "\236\233\377\241\244\241\377\247\252\247\377\255\260\255\377\263\266" +\
    "\263\377\270\273\271\377\275\277\275\377\302\304\302\377\307\310\306" +\
    "\377\312\314\312\377\314\316\315\377\317\321\320\377\321\323\322\377" +\
    "\323\325\324\377\325\327\325\377\326\327\326\377\330\332\331\377\331" +\
    "\332\331\377\333\333\333\377\334\335\334\377\335\336\335\377\336\340" +\
    "\337\377\341\343\342\377\342\343\344\377\345\346\346\377\347\350\350" +\
    "\377\353\354\353\377\355\356\355\377\361\361\361\377\363\364\364\377" +\
    "\366\366\366\377\371\371\371\377\373\373\373\377\374\374\374\377\375" +\
    "\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\372\372\372\377" +\
    "suz\377Ddz\377g\235\267\377x\267\330\377\203\310\353\377\210\320\365" +\
    "\377\212\323\370\377\210\322\366\377\206\316\363\377{\302\347\377\361" +\
    "\366\371\377\372\372\373\377\371\372\372\377\367\371\371\377\366\367" +\
    "\366\377\365\366\366\377\364\365\365\377\347\347\347\377npu\377\37.:" +\
    "\377\0@J\377\0\237\265\377\0\324\347\377\0\347\370\377\0\362\376\377" +\
    "\0\365\377\377\0\356\374\377\0\336\357\377\0\266\316\377\0S_\377\30*" +\
    "\67\377\253\254\255\377\351\352\351\377\344\345\345\377\342\343\343\377" +\
    "\341\342\341\377\337\340\337\377\336\340\336\377\336\336\336\377\334" +\
    "\335\334\377\336\337\337\377\215\216\214\377\200\201\200\377iii\377T" +\
    "UV\377KMP\3775@M\377-Ea\377,Fb\377+C`\377(A`\377$@b\377%Ci\377&Cm\377" +\
    "*L}W\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\215\221\215h\216\221\216\377\220" +\
    "\223\220\377\224\227\223\377\231\234\230\377\236\242\236\377\245\247" +\
    "\244\377\253\256\253\377\261\264\261\377\266\270\267\377\273\275\273" +\
    "\377\277\302\300\377\305\307\305\377\311\313\312\377\313\315\313\377" +\
    "\316\320\316\377\321\322\321\377\323\325\323\377\325\326\325\377\326" +\
    "\330\326\377\330\331\330\377\330\333\331\377\332\333\333\377\333\334" +\
    "\333\377\335\335\335\377\335\337\336\377\340\340\340\377\341\343\342" +\
    "\377\344\345\344\377\346\347\347\377\351\352\351\377\354\355\355\377" +\
    "\357\360\357\377\362\362\362\377\365\366\365\377\367\370\370\377\372" +\
    "\372\372\377\374\374\374\377\374\375\375\377\376\376\376\377\376\376" +\
    "\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\354\354\355\377.Oe\377d\231\263\377" +\
    "z\272\333\377\204\314\356\377\212\323\367\377\213\325\371\377\213\325" +\
    "\372\377\211\323\367\377\204\314\357\377\256\327\355\377\377\375\374" +\
    "\377\372\372\372\377\372\372\372\377\370\371\371\377\367\367\367\377" +\
    "\366\366\366\377\364\365\364\377\323\324\325\377\7\32!\377\0\225\252" +\
    "\377\0\344\365\377\0\376\376\377\0\377\377\377\0\377\376\377\0\377\377" +\
    "\377\0\377\376\377\0\376\377\377\0\377\376\377\0\377\377\377\0\355\374" +\
    "\377\0\263\310\377\4,\64\377\212\213\212\377\346\347\347\377\340\342" +\
    "\341\377\340\340\340\377\337\340\337\377\335\337\336\377\336\337\336" +\
    "\377\336\337\337\377\250\250\251\377,>R\3770F`\3771On\3775Xz\377:`\206" +\
    "\377Al\225\377Cp\231\377Bn\233\377@l\231\377<f\223\3778a\216\3775[\211" +\
    "\3772X\206\3770V\210\3777f\254\6\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\213\215\213\16\215\220" +\
    "\214\377\217\221\216\377\221\224\222\377\226\231\226\377\233\236\233" +\
    "\377\242\245\242\377\250\253\251\377\257\261\256\377\264\267\265\377" +\
    "\272\274\272\377\276\301\277\377\304\306\304\377\310\312\311\377\313" +\
    "\315\313\377\315\317\316\377\321\323\322\377\323\324\323\377\324\326" +\
    "\325\377\327\330\327\377\327\331\330\377\331\332\332\377\332\333\332" +\
    "\377\334\335\334\377\334\335\334\377\335\336\335\377\337\341\340\377" +\
    "\340\341\340\377\343\344\343\377\345\346\346\377\347\350\347\377\352" +\
    "\353\353\377\356\356\356\377\360\361\360\377\363\364\364\377\367\367" +\
    "\367\377\371\371\371\377\373\374\373\377\375\375\375\377\375\375\375" +\
    "\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\255\277\307\377l\250\306\377\203\312\352\377\210\322\365\377" +\
    "\214\325\371\377\214\327\372\377\213\326\372\377\211\323\366\377\203" +\
    "\313\356\377\265\327\351\377\376\377\376\377\370\371\370\377\340\341" +\
    "\340\377\264\265\264\377\230\230\230\377\221\222\222\377\212\213\213" +\
    "\377\3689\377\0\306\326\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\376\377\377\0\377\377\377\0\377\377\377\0\376\377\377\0\317\344\377" +\
    "\1:E\377uvv\377\343\344\343\377\334\336\335\377\334\334\334\377\333\334" +\
    "\334\377\333\334\333\377\331\332\331\377:HV\377>f\210\377Ix\237\377O" +\
    "\200\252\377P\202\260\377Q\204\263\377P\204\266\377Q\206\270\377N\201" +\
    "\265\377K~\262\377Hy\255\377Cq\245\377>j\236\3779c\226\3774[\216\375" +\
    "2Z\220\276\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\213\217\213\265\214\217\214\376\217\222\216" +\
    "\376\223\226\222\377\230\234\231\377\240\242\237\377\246\250\246\377" +\
    "\254\257\254\377\262\265\262\377\270\272\270\377\274\277\275\377\302" +\
    "\304\302\377\307\311\307\377\313\315\313\377\315\317\315\377\321\322" +\
    "\322\377\323\325\324\377\325\327\325\377\327\331\327\377\330\332\331" +\
    "\377\332\334\333\377\333\334\333\377\334\336\334\377\334\336\335\377" +\
    "\336\337\336\377\337\340\337\377\340\341\340\377\341\343\342\377\343" +\
    "\344\343\377\347\350\347\377\350\351\351\377\354\354\353\377\356\357" +\
    "\357\377\362\362\362\377\365\365\365\377\370\370\370\377\372\372\372" +\
    "\377\373\374\374\377\375\375\375\377\376\376\376\377\376\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\376\376\376\377\377\377\377\377\377\377\377" +\
    "\377\362\367\372\377\232\321\353\377\204\315\357\377\211\322\365\377" +\
    "\212\324\367\377\213\325\372\377\210\322\365\377\202\312\355\377Rs\210" +\
    "\377jji\3772!!\3776\0\0\377k\23\15\377r\16\10\3779\0\0\377\1\0\27\377" +\
    "\0\20}\377\0\3\237\377\0\0\260\377\0\0\257\377\0\17\264\377\0L\267\377" +\
    "\0\221\311\377\0\324\335\377\0\377\377\377\0\376\376\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\377\0\377\377\377\0\314\341\377" +\
    "\5.8\377``e\377\231\231\230\377\315\316\315\377\334\334\334\377\335\335" +\
    "\334\377vz~\377;b\204\377N~\247\377V\214\274\377Y\221\303\377Y\222\306" +\
    "\377Y\221\307\377X\220\306\377U\216\304\377S\211\300\377Q\207\274\377" +\
    "L\200\266\377Hz\257\377Cr\247\377=j\237\3778b\225\3772X\214\3773^\230" +\
    "N\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\211\215\211A\212\216\213\377\215\220\214\377\220\223\220\377\226\231" +\
    "\226\377\234\237\234\377\242\245\243\377\252\255\252\377\260\263\260" +\
    "\377\266\270\266\377\273\276\274\377\300\303\301\377\305\310\306\377" +\
    "\320\322\320\377\322\325\323\377\327\331\330\377\331\333\331\377\333" +\
    "\334\333\377\333\334\333\377\335\336\335\377\335\337\336\377\334\335" +\
    "\334\377\335\335\335\377\336\337\335\377\336\337\337\377\336\340\337" +\
    "\377\340\341\340\377\341\342\341\377\342\343\343\377\345\346\345\377" +\
    "\347\350\347\377\352\353\352\377\354\355\354\377\360\360\360\377\363" +\
    "\364\363\377\366\367\366\377\371\371\371\377\373\373\373\377\375\375" +\
    "\375\377\375\376\375\377\377\376\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\376\376" +\
    "\377\377\377\377\377\377\315\350\363\377\227\321\355\377\202\314\356" +\
    "\377\206\315\357\377h\241\274\377(08\377B\17\13\377\2526,\377\324qe\377" +\
    "\312\201w\377R49\377\0\0E\377\0\0\303\377\0\0\351\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\347\377\0\5\223\377\0\262\320\377\0\377\377\377\0\376\376\377\0" +\
    "\377\377\377\0\376\377\377\0\377\377\377\0\374\376\377\0\245\274\377" +\
    "\34\60@\3773G\134\377;BL\377``b\377rrr\3775Rl\377L{\243\377W\214\272" +\
    "\377[\224\307\377\134\226\312\377\134\227\315\377Z\224\312\377Y\223\311" +\
    "\377W\220\310\377U\215\303\377S\211\300\377O\204\271\377K~\264\377Ev" +\
    "\253\377An\244\377:f\232\3774]\220\3770V\213\364\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\205\211\211\303\212" +\
    "\215\212\376\216\221\215\376\222\226\222\377\231\234\231\377\240\243" +\
    "\237\377\247\252\247\377\255\260\255\377\264\266\264\377\272\274\273" +\
    "\377\277\301\277\377\312\314\312\377\240\242\240\377gii\377^`a\377VW" +\
    "Y\377MNR\377CFJ\377ACI\377DGL\377\220\222\221\377\323\325\324\377\342" +\
    "\343\341\377\337\340\340\377\337\341\340\377\341\342\340\377\341\342" +\
    "\342\377\342\343\342\377\344\344\344\377\346\347\347\377\350\351\350" +\
    "\377\353\354\353\377\355\356\356\377\360\361\360\377\363\364\364\377" +\
    "\367\367\367\377\372\371\372\377\373\373\373\377\375\375\375\377\376" +\
    "\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\373\373\373\377\301\330\342\377;Q]\3775" +\
    "\2\0\377o\37\32\377|C=\377l4.\377h63\377\0\0\30\377\0\0\253\377\0\0\372" +\
    "\377\0\0\377\377\0\0\376\377\0\0\377\377\0\0\376\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\376\377\0\0\376\377\0\0\377\377" +\
    "\0\0\362\377\0#\236\377\0\343\351\377\0\377\377\377\0\377\377\377\0\376" +\
    "\377\377\0\377\376\377\0\347\367\377\0AL\377Jw\231\377Do\217\3779Zy\377" +\
    "7Wu\377L|\244\377T\211\264\377Y\221\301\377[\225\310\377]\225\312\377" +\
    "[\224\312\377Z\223\311\377X\222\310\377W\220\307\377U\215\303\377S\211" +\
    "\300\377O\204\273\377K\177\265\377Hx\257\377Bq\247\377=i\236\3777`\225" +\
    "\3761W\211\3771Y\221\201\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0#L\215\149Le\377{\177|\377\222\225\222\377\226\230\225\377\234" +\
    "\237\235\377\244\247\244\377\253\255\252\377\262\265\262\377\271\273" +\
    "\270\377\302\304\303\377\263\265\263\377}~}\377.=O\3771Nl\3775Xx\377" +\
    "9^\201\377<d\210\377\77g\214\377@i\213\377=d\205\3775Pi\377@GP\377\225" +\
    "\226\225\377\314\314\314\377\342\343\342\377\342\343\343\377\342\344" +\
    "\343\377\344\344\344\377\345\345\345\377\346\350\347\377\352\352\352" +\
    "\377\353\354\354\377\357\357\356\377\361\361\362\377\365\365\364\377" +\
    "\367\370\370\377\372\373\373\377\374\374\374\377\375\375\375\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\371\371\371\377\301\301\301\377\26\26\27\377\0\35!\377\0" +\
    "P]\377\0\201\224\377\0\244\272\377\0\270\315\377\0\306\334\377\0\321" +\
    "\337\377\0\307\316\377\0\220\242\377\0\64\232\377\0\0\334\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\376\377\0\0\377\377\0\0\273\377" +\
    "\0\301\323\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377" +\
    "\0\240\267\3775Um\377Q\201\250\377P\177\246\377P\201\251\377T\205\260" +\
    "\377V\213\271\377Y\220\300\377Z\221\303\377Z\223\305\377Z\223\307\377" +\
    "X\221\307\377Y\221\307\377W\217\306\377U\216\304\377S\212\301\377P\206" +\
    "\275\377N\201\270\377I|\261\377Dt\251\377\77l\241\3779d\230\3773Z\216" +\
    "\377/S\206\377O\230\377\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "*M}\254#Ag\376\27-I\377=DN\377\221\224\221\377\241\244\241\377\247\251" +\
    "\247\377\257\261\257\377\270\272\270\377\266\270\266\377fgh\3771;H\377" +\
    "1Kg\377Dq\230\377M}\251\377S\207\265\377V\213\272\377X\217\277\377Z\221" +\
    "\300\377[\223\300\377Y\220\273\377T\210\260\377Jw\233\3774Ni\377KU`\377" +\
    "\347\350\347\377\344\344\344\377\344\345\344\377\344\346\345\377\346" +\
    "\346\346\377\350\351\350\377\352\353\352\377\354\355\354\377\357\360" +\
    "\360\377\362\363\362\377\365\366\366\377\370\370\370\377\373\373\373" +\
    "\377\374\374\374\377\375\375\375\377\376\376\376\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\376\376\376\377\357\357\357\377tuv\377\0\66@\377" +\
    "\0\247\300\377\0\331\352\377\0\362\377\377\0\374\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\376\377\0\377\377\377\0\377\377\377" +\
    "\0\366\377\377\0\267\263\377\0\0\340\377\0\0\376\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\376\377\0\0\377\377\0\0\377\377\0\0\317\377\0\301\321\377\0\377" +\
    "\377\377\0\377\377\377\0\376\376\377\0\312\341\377\33<L\377R\202\251" +\
    "\377Q\203\252\377R\203\253\377S\206\260\377T\210\265\377V\213\271\377" +\
    "W\215\275\377X\216\300\377W\217\302\377W\217\302\377X\217\304\377V\215" +\
    "\303\377T\214\303\377T\212\300\377P\207\274\377M\202\271\377K}\263\377" +\
    "Ew\255\377Ao\244\377<g\234\3776_\222\377/U\210\376/U\212\245\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\09j\255\27-Q\203\377.S\202\377-Nx\377&Df\377" +\
    ")6H\377\216\220\216\377\255\260\255\377\270\271\267\377\217\221\217\377" +\
    "7=G\377.Kk\377Bm\227\377L}\252\377T\211\273\377Z\223\306\377_\231\320" +\
    "\377a\235\323\377c\240\325\377e\242\327\377f\244\330\377f\244\326\377" +\
    "d\240\320\377_\230\304\377T\206\254\377<b\201\377\223\225\231\377\347" +\
    "\350\347\377\345\346\346\377\346\346\345\377\346\350\347\377\350\352" +\
    "\351\377\353\353\353\377\355\356\355\377\360\360\360\377\363\363\363" +\
    "\377\365\365\365\377\371\371\371\377\373\373\373\377\375\375\375\377" +\
    "\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377" +\
    "\324\324\324\377\35\64:\377\0\233\260\377\0\344\366\377\1\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\376\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\377\0\377\376\377\0\376\377\377" +\
    "\0\356\366\377\0\0\263\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\277\377\0\344\354\377\0\376\376" +\
    "\377\0\377\377\377\0\337\360\377\10\65A\377Mz\237\377M|\241\377N}\244" +\
    "\377O\177\250\377P\202\254\377Q\203\260\377S\207\264\377T\210\271\377" +\
    "U\213\275\377U\215\277\377V\214\301\377T\215\302\377T\214\301\377S\211" +\
    "\277\377Q\207\274\377N\201\270\377J~\264\377Gy\257\377Bq\246\377=j\237" +\
    "\3777a\225\3772X\214\377-Q\202\377=r\274\22\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0.T\210\2371W\213\3767`\225\377:e\232\377;e\226\3773Y\204\3778DR\377" +\
    "\223\225\222\377Y[]\377*=T\377:b\211\377Hv\243\377P\204\266\377X\217" +\
    "\304\377\134\227\315\377`\234\323\377c\240\327\377e\241\331\377e\246" +\
    "\333\377h\250\335\377i\250\336\377j\253\337\377k\253\336\377i\247\331" +\
    "\377c\234\312\377T\205\253\3777Qh\377\332\332\330\377\346\347\347\377" +\
    "\346\347\347\377\350\351\350\377\351\352\352\377\354\354\354\377\355" +\
    "\356\356\377\360\360\360\377\363\364\363\377\365\366\365\377\371\371" +\
    "\371\377\373\373\373\377\374\375\374\377\376\376\376\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377" +\
    "\377\377\374\374\374\377\302\302\302\377\0\66\77\377\1\312\340\377\0" +\
    "\373\377\377\0\376\376\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\377\0\372\377\377\0\64\241\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\32\246\377\0\377\377\377\0\377\377\377\0\347\364" +\
    "\377\1:F\377Fo\221\377Gq\223\377Gr\225\377Iv\233\377Ky\241\377L|\245" +\
    "\377N\177\252\377Q\204\261\377R\206\266\377R\210\271\377T\211\275\377" +\
    "S\213\277\377S\212\300\377R\211\277\377Q\206\274\377O\203\272\377K\177" +\
    "\266\377Iz\257\377Br\250\377@l\241\377:d\230\3773\134\216\377.S\204\376" +\
    ",P\204\233\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0<l\266\13.S\207\3773[\217\3779d\232\377" +\
    ">m\242\377Ct\252\377Cs\247\3778^\210\377-<P\3773U{\377Bo\232\377K}\255" +\
    "\377S\211\275\377X\221\311\377\134\227\317\377_\232\323\377a\236\326" +\
    "\377c\240\331\377e\243\333\377f\245\334\377h\250\335\377j\252\337\377" +\
    "j\254\341\377m\255\341\377m\256\341\377j\251\332\377a\232\305\377N|\237" +\
    "\377alw\377\356\356\356\377\350\351\350\377\351\351\351\377\352\353\352" +\
    "\377\354\354\354\377\356\356\356\377\360\361\360\377\364\364\364\377" +\
    "\365\366\365\377\370\371\371\377\373\374\373\377\375\374\375\377\376" +\
    "\376\376\377\352\352\352\377\307\307\307\377\227\227\227\377zzz\377w" +\
    "ww\377xxx\377~~~\377\236\236\236\377\323\323\323\377\365\365\365\377" +\
    "\376\376\376\377\376\376\376\377\362\362\362\377\264\264\264\377LLL\377" +\
    "\0\66\77\377\0\316\347\377\0\376\376\377\0\377\377\377\0\376\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\375\377\377\0]\252\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\376\377\0\0\366\377" +\
    "\0\214\272\377\0\377\377\377\0\342\361\377\5\67C\377>d\201\377\77e\205" +\
    "\377@h\210\377Bl\215\377Do\223\377Gs\233\377Jy\241\377M}\251\377N\201" +\
    "\257\377P\204\263\377R\206\270\377R\207\273\377R\211\275\377Q\207\274" +\
    "\377Q\206\273\377O\204\272\377L\200\266\377H{\261\377Eu\253\377@o\244" +\
    "\377;g\232\3776^\222\3770V\210\377+O\201\377B{\322\10\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0+S\211" +\
    "\201/T\210\3775]\222\376:f\234\377\77n\245\377Eu\254\377H{\262\377Gx" +\
    "\256\377Gx\251\377Iy\253\377N\201\265\377S\212\277\377W\221\312\377Z" +\
    "\225\316\377^\231\322\377_\234\324\377b\236\327\377c\241\331\377e\242" +\
    "\332\377f\245\334\377g\247\335\377j\252\337\377k\254\341\377l\256\341" +\
    "\377n\257\343\377n\256\341\377h\245\325\377\134\221\271\377:`~\377\265" +\
    "\266\267\377\350\352\351\377\351\352\352\377\353\353\353\377\355\355" +\
    "\354\377\356\357\356\377\361\361\360\377\364\364\364\377\365\365\365" +\
    "\377\371\371\371\377\363\363\363\377\252\253\252\377I>>\377.\0\0\377" +\
    "S\13\10\377\224\36\31\377\254*$\377\261+$\377\260+$\377\252)$\377\213" +\
    "\37\32\377H\13\10\377)\16\16\377iii\377\201\201\201\377.-\27\377QM\5" +\
    "\377\16\32\17\377\0\301\332\377\0\377\377\377\0\377\377\377\0\376\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0s\246\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\257\377\0\377\377\377\0\317\345\377\20*8\377" +\
    "7Xs\3778Zv\3779\134y\377<b\200\377\77f\210\377Aj\216\377Eq\226\377Iw" +\
    "\240\377Lz\247\377N\177\255\377P\203\263\377Q\204\267\377P\205\271\377" +\
    "Q\206\274\377P\204\271\377N\203\271\377M\200\267\377I{\261\377Fw\255" +\
    "\377Bq\246\377=h\235\3777`\224\3772Y\213\376,O\177\377+O\204z\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0,P\204\3770W\213\3777`\225\377<h\236\377Ap\246\377Ew\256\377J}\265" +\
    "\377M\177\267\377M\203\271\377P\206\274\377T\213\302\377W\220\310\377" +\
    "Y\222\314\377[\226\317\377^\231\322\377^\233\323\377a\236\326\377c\240" +\
    "\331\377d\243\333\377f\245\333\377h\247\335\377i\252\336\377j\253\340" +\
    "\377l\255\342\377n\257\344\377o\257\343\377m\254\336\377e\240\316\377" +\
    "V\210\254\377EYm\377\353\354\353\377\352\352\352\377\353\354\354\377" +\
    "\355\356\355\377\357\357\356\377\360\361\360\377\363\364\364\377\363" +\
    "\363\363\377\215\215\215\377#\6\6\377\205\24\21\377\301VK\377\336\217" +\
    "\204\377\365\237\227\377\377\245\234\377\377\247\236\377\377\253\237" +\
    "\377\377\254\240\377\377\247\234\377\377\243\231\377\356\232\222\377" +\
    "\325\203y\377\271TK\377\210\32\24\377U/\13\377QJ!\377\0|\222\377\0\367" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\210\252\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\376\377" +\
    "\0\0\356\377\0\246\300\377\0\260\314\377\26)\65\3770Md\3771Pi\3773Rl" +\
    "\3776Xt\3779]{\377=b\204\377@i\214\377Dn\226\377Gu\236\377Kz\247\377" +\
    "M~\255\377M\201\263\377O\204\267\377P\204\270\377O\203\270\377N\202\270" +\
    "\377L\201\266\377J|\261\377Fw\255\377Br\247\377>k\237\3778c\226\3774" +\
    "[\215\377.R\203\377)L~\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0-T\214[,O\202\3772Y\216\3777b\227\377=" +\
    "i\240\377Br\250\377Fx\257\377J~\266\377M\201\272\377P\206\276\377R\212" +\
    "\301\377U\215\306\377W\220\312\377Y\223\315\377[\225\320\377]\231\322" +\
    "\377^\234\324\377a\236\327\377b\240\331\377d\242\332\377f\245\334\377" +\
    "g\247\335\377i\251\337\377j\253\341\377l\255\341\377n\256\343\377o\260" +\
    "\344\377o\260\342\377l\252\332\377`\230\302\377Jw\230\377\214\221\227" +\
    "\377\355\355\354\377\354\355\354\377\355\356\355\377\356\357\356\377" +\
    "\361\361\360\377\314\315\315\377(\31\30\377\213\32\22\377\320vk\377\371" +\
    "\226\213\377\377\242\227\377\377\254\240\377\376\260\243\377\377\260" +\
    "\243\377\377\261\244\377\377\257\245\377\377\260\244\377\377\262\246" +\
    "\377\377\257\242\377\376\255\241\377\377\251\236\377\377\236\223\377" +\
    "\371\224\207\377\306ka\377\0\31 \377\0\321\350\377\0\377\376\377\0\376" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\217\254\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0H\244" +\
    "\377\0v\211\377\36\61@\377+DY\377,F\134\377.Ja\3770Oh\3774To\3777Zx\377" +\
    ";a\203\377\77h\215\377Do\226\377Gu\240\377Jz\250\377M\177\257\377M\201" +\
    "\264\377O\202\265\377N\202\266\377M\202\267\377L\200\265\377I}\263\377" +\
    "Fw\256\377Cs\250\377>l\240\377:e\231\3775\134\217\377/T\206\377)K{\377" +\
    ",Q\211V\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0*N\202\317.R\206\3773[\220\3779d\231\377>k\241\377Br\251\377Gy\261" +\
    "\377K~\267\377M\203\273\377Q\207\300\377R\212\303\377U\215\306\377W\220" +\
    "\312\377X\223\314\377[\226\317\377^\230\322\377^\232\323\377a\236\326" +\
    "\377c\240\330\377e\242\332\377e\245\333\377g\246\335\377i\251\336\377" +\
    "j\253\341\377k\254\341\377n\256\343\377n\260\344\377p\261\344\377o\257" +\
    "\341\377i\245\324\377[\217\265\3779Xr\377\343\343\342\377\353\354\353" +\
    "\377\355\356\356\377\356\357\357\377\221\221\221\377@\0\0\377\301SF\377" +\
    "\367\211}\377\377\234\216\377\377\242\224\377\377\246\227\377\377\246" +\
    "\227\377\377\243\227\377\377\245\227\377\377\244\230\377\377\245\231" +\
    "\377\377\244\230\377\377\243\227\377\377\243\226\377\377\244\227\377" +\
    "\377\245\227\377\377\245\226\377\377\224\210\377\265WL\377\0IW\377\0" +\
    "\361\374\377\0\376\376\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\215\251\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\11\216\377\6:=\377$:K\377&<N\377'" +\
    "\77R\377)BW\377,G^\377/Mf\3773Sp\3777Zy\377<b\204\377@i\217\377Dq\232" +\
    "\377Hv\242\377K{\253\377L\177\261\377N\201\263\377N\201\264\377M\200" +\
    "\265\377L\200\265\377I|\262\377Gx\256\377Dt\251\377@m\242\377:f\232\377" +\
    "6_\221\3770V\207\377+N~\376(J|\312\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0Ax\317\11)M\177\377.T\207\3775^\222\377:f\232\377" +\
    "\77l\244\377Ct\253\377Hy\261\377J\177\266\377N\203\273\377P\207\277\377" +\
    "R\211\302\377T\215\306\377W\220\312\377Y\223\314\377Z\225\317\377]\231" +\
    "\322\377^\233\323\377`\234\326\377c\240\330\377d\241\331\377f\243\334" +\
    "\377g\246\334\377h\250\336\377j\252\337\377k\255\341\377n\256\343\377" +\
    "o\257\343\377p\261\346\377p\261\344\377n\255\336\377d\236\311\377Q\201" +\
    "\243\377_jw\377\363\364\363\377\355\356\356\377|||\377e\0\0\377\327b" +\
    "U\377\377\207y\377\376\226\206\377\377\227\210\377\377\230\211\377\377" +\
    "\227\207\377\377\227\210\377\377\226\211\377\377\231\214\377\377\243" +\
    "\226\377\377\251\234\377\377\243\230\377\377\232\214\377\377\227\210" +\
    "\377\377\226\210\377\377\227\207\377\376\223\205\377\375\200r\377z'\35" +\
    "\377\0\224\254\377\0\375\377\377\0\376\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\215\247" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\207\377\24 *\377" +\
    " 4B\377!6F\377#8I\377%;N\377(@U\377+F]\377/Lg\3774Ur\3779\134~\377>e" +\
    "\212\377Bl\224\377Es\236\377Ix\246\377J}\256\377M\177\261\377L\177\263" +\
    "\377K\177\265\377L\177\264\377I|\261\377Fx\256\377Dt\252\377\77m\241" +\
    "\377<h\234\3777`\223\3772X\211\377,P\200\377'Gw\377j\274\377\4\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0(K\200\205*M\177\3760V\212" +\
    "\3775^\223\377;g\235\377\77n\244\377Dt\254\377Hz\262\377J\177\267\377" +\
    "M\202\274\377P\207\277\377R\211\302\377T\214\306\377V\217\311\377W\222" +\
    "\313\377Z\225\316\377]\227\321\377^\232\323\377`\235\325\377a\236\327" +\
    "\377d\242\332\377d\243\333\377f\246\334\377h\250\336\377i\252\340\377" +\
    "k\254\341\377m\256\342\377n\257\344\377o\261\344\377q\261\345\377o\260" +\
    "\342\377j\250\326\377[\220\266\3776\134w\377\323\323\322\377\205\205" +\
    "\205\377b\0\0\377\336J8\377\377\200o\377\377\212y\377\377\212y\377\377" +\
    "\211z\377\377\211x\377\377\210x\377\377\205u\377\377\207y\377\377\225" +\
    "\210\377\377\273\260\377\377\330\321\377\377\302\270\377\377\231\215" +\
    "\377\377\210z\377\377\207y\377\377\210v\377\377\203u\377\366l^\377F\16" +\
    "\13\377\0\257\313\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\207" +\
    "\250\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\217\377\25!" +\
    "+\377\35/=\377\36\61@\377 3C\377!7H\377%;N\377(@V\377,Ha\3771Ok\3776" +\
    "Xx\377;`\202\377@i\220\377Cp\231\377Gu\243\377Iz\252\377K|\257\377K~" +\
    "\261\377L\177\263\377J~\263\377I|\262\377Fy\255\377Eu\252\377Ao\243\377" +\
    "<h\234\3778a\224\3773Y\214\377-R\202\377(Hw\376&Hz\203\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0)K\177\320,O\202\3771W\212\3776`\225" +\
    "\377;h\235\377@n\245\377Dt\254\377Hz\262\377K\177\267\377M\203\273\377" +\
    "P\206\277\377Q\211\302\377T\213\305\377V\217\310\377X\222\313\377Y\225" +\
    "\316\377\134\230\321\377]\232\322\377_\234\325\377b\236\327\377d\241" +\
    "\331\377d\243\333\377f\244\334\377h\250\337\377i\251\340\377k\254\340" +\
    "\377l\255\342\377o\256\343\377o\260\344\377p\262\345\377q\262\344\377" +\
    "m\254\334\377`\227\277\377Bk\210\377\272\272\271\377J\0\0\377\331\6\0" +\
    "\377\376zh\377\377zh\377\377zf\377\377zf\377\377we\377\377ve\377\377" +\
    "rb\377\377o`\377\377rd\377\377\220\205\377\377\340\332\377\377\377\377" +\
    "\377\377\355\352\377\377\232\215\377\377uh\377\377sc\377\377td\377\376" +\
    "o^\377\354UF\377:\4\1\377\0\267\322\377\0\377\377\377\0\377\377\377\0" +\
    "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0s\243\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\376\377" +\
    "\0\0\205\377\24 )\377\33,9\377\34-;\377\35\60\77\377\37\63C\377\42\67" +\
    "I\377%<Q\377)D[\377.Kf\3773Tr\3779]\177\377>e\212\377Cm\226\377Fs\240" +\
    "\377Hy\247\377J|\254\377J}\260\377J}\261\377J~\262\377I{\261\377Gy\256" +\
    "\377Dt\252\377Ao\244\377=i\235\3778b\226\3773Z\215\377.S\204\377)Jy\377" +\
    "&Gx\312\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0:m\266\16'Hy\377,P\203" +\
    "\3772Y\215\3777a\226\377<i\237\377@o\246\377Du\254\377Hz\262\377K~\267" +\
    "\377M\202\273\377O\205\276\377R\210\302\377S\213\304\377V\217\311\377" +\
    "W\221\312\377Z\224\315\377\134\227\321\377^\231\322\377_\234\324\377" +\
    "`\236\327\377c\240\331\377d\242\332\377e\245\334\377h\247\335\377i\250" +\
    "\336\377j\252\341\377l\255\341\377m\257\343\377o\257\344\377p\261\345" +\
    "\377q\261\344\377l\253\334\377_\230\300\377Kr\214\377.\30\30\377\304" +\
    "\0\0\377\377(\33\377\377n[\377\377iU\377\377gT\377\377cR\377\377aO\377" +\
    "\377\134M\377\377XI\377\377UE\377\377VH\377\377ti\377\377\305\277\377" +\
    "\377\373\373\377\377\325\320\377\377}s\377\377\134M\377\377YJ\377\377" +\
    "]L\377\377[J\377\342A2\377@\0\0\377\0\253\306\377\0\377\377\377\0\376" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0X\254\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0k\377\27%\60\377\32*\66\377\33+8\377\34-;\377\35/\77\377" +\
    " 4E\377$:N\377(AX\377,Ic\3772Qn\3777Z|\377<c\211\377Ak\224\377Er\236" +\
    "\377Gw\245\377J{\254\377J}\260\377J}\261\377J{\261\377H|\260\377Gx\256" +\
    "\377Ct\251\377Ao\244\377=i\235\3779c\226\3774\134\216\377/T\205\377)" +\
    "K{\377$Cr\377>w\316\11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0&Fzf(Iz\377-R\205" +\
    "\3773[\216\3777b\227\377=i\237\377@p\246\377Du\255\377Hz\262\377J~\266" +\
    "\377M\202\272\377O\204\275\377Q\207\301\377S\213\304\377V\216\311\377" +\
    "W\220\312\377Z\223\316\377[\226\320\377]\231\322\377^\233\324\377a\236" +\
    "\326\377c\237\330\377c\242\332\377e\244\333\377g\246\335\377i\250\336" +\
    "\377i\252\340\377k\254\341\377m\255\343\377o\260\343\377p\261\345\377" +\
    "p\260\343\377k\252\331\377]\223\273\3777EO\377\214\0\0\377\370\0\0\377" +\
    "\376\42\24\377\377U@\377\377Q=\377\377M8\377\377I6\377\377C2\377\377" +\
    "<,\377\3779*\377\3778*\377\3776(\377\377D8\377\377h`\377\377\204~\377" +\
    "\377oh\377\377F<\377\377;+\377\377;,\377\377B1\377\377\77.\377\341,\35" +\
    "\377d\3\0\377\0\204\231\377\0\371\377\377\0\376\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\375\377\377" +\
    "\0\77\247\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\370\377\0\0S\377\31" +\
    "'\63\377\30(\64\377\32)\66\377\33+9\377\34.=\377\37\62C\377\428L\377" +\
    "'\77U\377,G`\3771Pm\3776Yz\377;b\206\377@i\221\377Cp\234\377Gv\245\377" +\
    "Iz\253\377J{\256\377J{\260\377J|\261\377Hz\257\377Gy\256\377Ct\251\377" +\
    "Ap\244\377=j\236\3779c\226\3774\134\217\377/T\205\377*M|\377%Dq\377$" +\
    "Dtc\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0&H{\247(J{\376.S\205\3774[\217\377" +\
    "8b\227\377=j\240\377Ap\247\377Dt\254\377Hz\262\377J}\266\377L\201\272" +\
    "\377O\204\275\377Q\207\300\377S\212\303\377T\215\310\377W\220\311\377" +\
    "Y\222\314\377[\226\317\377]\230\321\377^\232\323\377`\235\326\377a\237" +\
    "\327\377d\241\331\377d\244\333\377g\246\335\377h\246\336\377i\252\340" +\
    "\377j\254\340\377m\255\343\377n\256\343\377o\260\344\377o\260\343\377" +\
    "i\247\327\377X\214\262\377:\5\5\377\326\0\0\377\377\0\0\377\377\7\0\377" +\
    "\377<&\377\3773\37\377\3771\35\377\377+\31\377\377%\25\377\377\42\25" +\
    "\377\377\36\21\377\377\33\21\377\377\33\20\377\377\34\23\377\377%\35" +\
    "\377\377+#\377\377'\35\377\377\36\24\377\377\34\20\377\377\37\23\377" +\
    "\377#\25\377\376'\26\377\351\34\13\377\217\3\0\377\0;E\377\0\347\371" +\
    "\377\11\377\377\377\35\377\377\377\20\377\377\377\5\377\377\377\2\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\367\375\377\0\22\241\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\353\377\2\4\67\377\27&\61\377\30'\63\377\30(\64\377" +\
    "\32*\67\377\34-<\377\36\61B\377!6J\377&>S\377*F^\3770Ok\3775Xy\377:`" +\
    "\204\377\77h\220\377Co\234\377Fu\243\377Ix\252\377Iz\255\377Hz\257\377" +\
    "H{\261\377Hy\256\377Ew\253\377Dt\252\377Ao\244\377=j\235\377:d\227\377" +\
    "5]\217\3770V\207\377+M}\377%Et\376$Eu\240\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0$Eu\377(K|\377/T\207\3773\134\220\3778c\230\377=j\240\377@o\246\377" +\
    "Dt\254\377Gy\262\377I}\266\377K\200\271\377N\204\274\377P\206\277\377" +\
    "R\212\303\377T\214\307\377V\217\311\377X\222\314\377Z\225\316\377[\227" +\
    "\321\377^\232\323\377`\235\326\377a\236\327\377c\240\331\377e\243\333" +\
    "\377e\244\333\377h\247\335\377i\251\337\377j\253\340\377l\255\342\377" +\
    "m\255\343\377n\260\344\377n\257\341\377h\244\323\377/Lb\377\210\0\0\377" +\
    "\371\0\0\377\376\0\0\377\377\0\0\377\377\24\5\377\377\25\3\377\377\22" +\
    "\0\377\377\17\0\377\377\14\0\377\377\7\0\377\377\4\0\377\377\3\0\377" +\
    "\377\0\0\377\377\0\0\377\377\1\0\377\377\1\0\377\377\1\0\377\377\1\0" +\
    "\377\377\1\0\377\377\4\0\377\377\11\0\377\377\13\0\377\363\5\0\377\260" +\
    "\0\0\377\24\16\20\377\0\274\337\377A\377\377\377D\377\377\377;\377\377" +\
    "\377/\377\377\377!\377\377\377\31\377\377\377\22\377\377\377\15\377\377" +\
    "\377\15\377\377\377\7\377\377\377\1\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\376\377\0\337\347\377\0\0\273" +\
    "\377\0\11\376\377\0\7\377\377\0\3\377\377\0\1\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\326\377\4\7\11\377\27%\60\377" +\
    "\27&\62\377\30'\63\377\31)\66\377\33,;\377\36\61B\377\42\66I\377%=S\377" +\
    "*E]\377/Nk\3775Wx\377:`\205\377\77h\220\377Co\233\377Fu\243\377Hx\251" +\
    "\377Hz\255\377Hz\256\377H{\260\377Fx\255\377Fw\254\377Cs\250\377Ao\244" +\
    "\377<j\235\377:d\227\3774\134\217\3771V\207\377+N~\377'Ft\377\42@n\377" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0*N\210\27$Ds\377*L}\376/U\207\3774\134\220\377" +\
    "8c\230\377=j\240\377Ao\246\377Ct\253\377Gy\261\377I|\264\377K\177\271" +\
    "\377N\203\274\377P\205\277\377Q\210\302\377T\214\306\377V\217\311\377" +\
    "W\221\313\377Z\224\315\377\134\226\321\377]\231\322\377_\233\324\377" +\
    "`\235\327\377c\240\331\377d\242\333\377e\244\333\377h\246\335\377h\251" +\
    "\336\377i\252\340\377k\254\341\377m\256\342\377n\256\344\377m\255\340" +\
    "\377g\243\323\377%\32!\377\313\0\0\377\377\0\0\377\376\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\2\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\376\0\0\377\303\0\0\377_\0\0\377\0Ug\377M\362\374\377" +\
    "a\377\376\377^\377\376\377T\377\377\377M\377\377\377A\377\377\3778\377" +\
    "\377\377F\377\377\377{\377\377\377k\377\377\3770\377\377\377\34\377\377" +\
    "\377\27\377\377\377\26\377\377\377\31\377\377\377\32\377\377\377\2\255" +\
    "\270\377\2\24\370\377\1\42\377\377\0\35\377\377\0\30\377\377\0\24\377" +\
    "\377\0\16\377\377\0\13\377\377\0\10\377\377\0\3\377\377\0\2\377\377\0" +\
    "\2\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\227\377" +\
    "\5\11\13\377\27%\60\377\27&\62\377\30'\63\377\31)\66\377\33,;\377\36" +\
    "\60A\377!6I\377%=S\377*F_\377/Nk\3775Wx\377:`\206\377\77g\220\377Bn\232" +\
    "\377Fu\243\377Hw\251\377Hy\255\377Hz\256\377Hz\257\377Fx\256\377Dv\253" +\
    "\377Cr\247\377@n\243\377=j\235\377:c\227\3775^\220\3770W\210\377,O~\377" +\
    "'Gu\376\42\77k\377*M\210\23\0\0\0\0\0\0\0\0%Ezj%Dt\377*L~\377/U\207\377" +\
    "4\134\220\3778c\230\377=j\237\377@o\245\377Ct\253\377Fx\260\377I{\263" +\
    "\377K\177\267\377M\202\273\377O\205\275\377Q\207\302\377S\213\304\377" +\
    "U\216\310\377W\220\312\377Y\223\316\377Z\226\317\377]\230\322\377^\232" +\
    "\323\377`\235\326\377b\237\330\377c\241\331\377e\243\333\377f\245\335" +\
    "\377h\250\336\377i\252\340\377j\252\337\377l\255\343\377m\256\343\377" +\
    "l\255\341\377Z\220\271\377G\0\0\377\353\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\376\0\0\377\377\0\0\377\342\0\0\377\241\0\0\377 \0\0\377" +\
    ")\251\274\377t\376\377\377w\376\377\377s\377\376\377m\377\377\377f\377" +\
    "\377\377c\377\377\377\222\377\377\377\375\377\377\377\357\377\377\377" +\
    "n\377\377\377D\377\377\377A\377\377\377@\377\377\377A\377\377\377:\377" +\
    "\377\377\6n\234\3778O\377\377\77W\376\377'@\377\377\22.\377\377\16)\377" +\
    "\377\14'\377\377\11\42\377\377\13!\377\377\17 \377\377\20\36\377\377" +\
    "\20 \377\377\10\15\377\377\0\0\377\377\0\0\377\377\0\0\376\377\08x\377" +\
    "\6\11\14\377\26$/\377\27&\62\377\30&\63\377\31)\66\377\34-<\377\36\60" +\
    "A\377!7J\377&>T\377*F_\3770Nl\3775Wy\377:`\205\377\77h\221\377Co\233" +\
    "\377Et\243\377Hx\252\377Gx\255\377Hx\255\377Hz\257\377Ew\254\377Eu\252" +\
    "\377Cs\250\377@o\244\377<i\236\3779d\227\3775^\220\3771V\207\377,P~\377" +\
    "(Gu\377\42\77k\377%Dvd\0\0\0\0\0\0\0\0#Br\233%Eu\376*M~\377/U\207\377" +\
    "4\134\220\3778b\230\377<j\237\377\77n\245\377Bt\252\377Fw\257\377H{\262" +\
    "\377I}\267\377M\201\272\377O\204\275\377Q\207\300\377R\212\303\377T\215" +\
    "\310\377W\220\312\377Y\222\314\377Z\225\317\377\134\230\321\377^\232" +\
    "\323\377_\235\326\377b\236\327\377b\240\331\377d\242\333\377e\245\333" +\
    "\377g\246\335\377h\251\337\377j\252\340\377k\254\341\377m\255\343\377" +\
    "n\255\341\377@e\203\377\203\0\0\377\373\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\376\0\0\377\373\0\0\377\277\0\0\377\214\0\0" +\
    "\377\0\21\27\377Q\276\314\377\202\377\377\377\207\377\377\377\206\377" +\
    "\377\377\201\377\377\377\177\377\377\377\227\377\377\377\326\377\377" +\
    "\377\307\377\377\377\201\377\377\377h\377\377\377d\377\377\377a\377\377" +\
    "\377]\377\376\377M\373\377\377\34L\242\377\247\261\377\377\322\330\377" +\
    "\377~\215\377\377:L\377\377,@\377\377.@\377\377-<\377\377/<\377\377/" +\
    "<\377\37709\377\377-6\377\377(2\377\377\0\0\377\377\0\0\377\377\0\0\270" +\
    "\377\0\314\332\377\4#,\377\26$\60\377\27%\61\377\30'\64\377\31)\67\377" +\
    "\33,;\377\36\61B\377\42\67K\377&>U\377+Ga\3770On\3776Xz\377;`\206\377" +\
    "\77h\222\377Bp\234\377Et\244\377Gw\251\377Hx\254\377Gy\255\377Gx\257" +\
    "\377Ew\254\377Ct\251\377Cq\247\377@m\243\377=i\235\3779d\227\3775]\220" +\
    "\3771V\207\377,P\177\377'Hv\377#@n\376 >j\225\0\0\0\0\0\0\0\0\42@o\335" +\
    "%Eu\377*M\177\3770V\207\3774\134\220\3778c\230\377<h\237\377@n\244\377" +\
    "Cr\252\377Ev\256\377Gy\261\377J}\265\377L\200\271\377M\203\274\377P\206" +\
    "\277\377R\211\302\377T\214\306\377V\217\311\377X\221\314\377Y\224\316" +\
    "\377\134\226\321\377^\231\322\377^\234\324\377`\234\326\377b\240\330" +\
    "\377d\242\332\377d\243\333\377g\246\335\377h\250\336\377i\252\340\377" +\
    "k\253\341\377m\255\342\377n\255\341\3771Me\377\252\0\0\377\376\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0" +\
    "\377\355\0\0\377\256\0\0\377\200\0\0\377\0\17\23\377K\261\274\377\211" +\
    "\372\375\377\226\377\377\377\227\376\376\377\223\377\377\377\224\377" +\
    "\377\377\230\377\377\377\223\377\377\377\210\377\377\377\200\377\377" +\
    "\377\177\377\377\377z\377\377\377u\377\377\377L\332\336\377\134h\315" +\
    "\377\341\345\377\377\377\377\377\377\272\301\377\377`n\377\377N]\377" +\
    "\377NZ\377\377MZ\377\377MV\377\377HS\377\377HR\377\377DL\377\377EM\377" +\
    "\377\0\0\377\377\0\0\352\377\0\233\300\377\0\341\363\377\2\62<\377\26" +\
    "$\60\377\27&\62\377\30'\64\377\31*8\377\34-=\377\37\62D\377\428L\377" +\
    "'\77V\377+Gb\3771Po\3776Y|\377;a\211\377@i\224\377Co\234\377Et\243\377" +\
    "Gw\252\377Hx\253\377Fy\256\377Gx\255\377Dv\253\377Br\247\377Bq\246\377" +\
    ">l\241\377<h\234\3779c\226\3775]\217\3770V\207\377,P~\377(Hv\377#@l\377" +\
    "\37<i\332\0\0\0\0\0\0\0\0!\77m\377&Fu\376+N\177\377/U\207\3774\134\217" +\
    "\3778b\227\377<i\235\377\77m\244\377Br\251\377Du\254\377Fx\261\377I{" +\
    "\264\377K\177\270\377M\202\273\377O\205\277\377R\210\301\377S\212\304" +\
    "\377U\216\311\377W\221\312\377Y\222\315\377Z\226\317\377\134\230\322" +\
    "\377^\232\323\377_\235\325\377b\237\330\377c\241\332\377d\243\333\377" +\
    "e\245\334\377h\246\335\377h\251\337\377j\252\340\377l\253\342\377l\255" +\
    "\342\3779H^\377\266\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\343\0\0\377\252" +\
    "\0\0\377\207\0\0\377\10\0\0\377\22s\177\377~\327\341\377\227\373\375" +\
    "\377\241\377\376\377\241\377\377\377\240\377\377\377\234\377\377\377" +\
    "\232\377\377\377\226\377\377\377\223\377\377\377\222\376\377\377\210" +\
    "\377\377\3773\210\233\377\210\214\377\377\261\270\377\377\313\320\377" +\
    "\377\235\244\377\377t\177\377\377mu\377\377jq\377\377en\377\377cl\377" +\
    "\377aj\377\377_f\377\377]c\377\377FN\376\377\0\0\370\377\0`\245\377\0" +\
    "\377\377\377\0\343\364\377\1\66B\377\26$\60\377\27%\62\377\30(\65\377" +\
    "\32*8\377\34.=\377\37\62D\377#9M\377'@W\377,Hc\3771Rq\3776Y|\377;b\211" +\
    "\377@j\225\377Cp\235\377Et\243\377Fw\251\377Gx\254\377Gx\254\377Fw\254" +\
    "\377Et\252\377Br\247\377Bp\245\377\77l\241\377<g\233\3779c\226\3775]" +\
    "\216\3771V\207\377,P\177\377(Hv\377#Al\376\37;f\374\0\0\0\0\0\0\0\0!" +\
    ">l\377%Fu\377+M~\3770U\207\3773[\217\3778a\226\377;g\235\377>m\243\377" +\
    "Ap\247\377Dt\254\377Ew\257\377Hz\263\377J~\266\377L\201\272\377O\204" +\
    "\276\377P\207\300\377R\212\303\377T\214\310\377V\217\312\377X\222\314" +\
    "\377Y\225\316\377\134\227\321\377^\230\323\377^\234\325\377a\235\326" +\
    "\377b\240\330\377c\241\332\377d\243\333\377g\246\335\377g\247\336\377" +\
    "i\252\337\377j\253\340\377k\254\342\377:G]\377\272\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\376\0\0\377\377\0\0\377\346\0\0\377\260\0\0\377{\0\0\377\36\0\0" +\
    "\377\2\4\5\377\10l|\377b\275\306\377\224\346\354\377\234\367\373\377" +\
    "\235\374\375\377\234\375\375\377\234\375\376\377\233\375\376\377\231" +\
    "\375\376\377\204\356\364\377>]\241\377\231\241\377\377\227\235\377\377" +\
    "\230\235\377\377\215\225\377\377\206\216\377\377\202\211\377\377\177" +\
    "\210\377\377}\203\377\377y\201\377\377w~\377\377t|\376\377qx\376\377" +\
    "\35\35\366\377\0P\231\377\0\377\377\377\0\377\377\377\0\332\355\377\4" +\
    ",\67\377\26$/\377\27%\62\377\30(\65\377\31)8\377\34-=\377\37\62D\377" +\
    "#9N\377(AY\377,Ie\3772Rr\3777Z\177\377<c\212\377\77j\225\377Cp\236\377" +\
    "Et\245\377Fw\252\377Gx\254\377Fw\254\377Ev\253\377Dt\252\377Aq\247\377" +\
    "Ao\244\377>k\237\377;g\233\3778b\224\3774\134\215\3770V\206\377,O~\377" +\
    "(Hu\377#Am\377\369d\377\0\0\0\0#E{B!>j\377%Et\377+M~\377/U\206\3774Z" +\
    "\216\3777b\226\377;f\233\377>k\242\377Ap\246\377Cs\252\377Ew\257\377" +\
    "Gy\261\377J}\266\377K\177\271\377M\203\274\377O\205\277\377R\211\302" +\
    "\377T\213\306\377V\216\311\377W\221\313\377X\224\316\377[\225\320\377" +\
    "]\231\322\377^\232\324\377_\235\326\377a\236\327\377c\241\332\377d\243" +\
    "\333\377e\244\333\377g\247\335\377h\251\337\377j\252\337\377k\253\341" +\
    "\377:H^\377\272\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\357\0\0\377\246\0\0\3778\0\0\377\207r\0\377lS\0\377\10\0\0\377\2" +\
    "\0\0\377\0\61:\377\0]l\377\1p\177\377\11w\203\377\4p\203\377\11ax\377" +\
    "9T\220\377\246\251\377\377\243\251\377\377\237\245\377\377\234\242\377" +\
    "\377\232\241\377\377\227\235\377\377\224\233\377\377\222\230\377\377" +\
    "\220\225\377\377\215\224\377\377\211\217\377\377~\204\376\37712\334\377" +\
    "\0\207\255\377\0\377\377\377\0\377\377\377\0\377\377\377\0\305\334\377" +\
    "\10\15\26\377\26$/\377\27%\62\377\30'\65\377\32*9\377\34.\77\377\37\63" +\
    "F\377#:O\377(B[\377-Jf\3772Ss\3777\134\201\377<d\214\377@k\226\377Cp" +\
    "\236\377Et\245\377Fv\251\377Fw\254\377Fw\253\377Eu\253\377Cr\250\377" +\
    "Ap\246\377@n\242\377=j\236\377;f\231\3777a\223\3774[\214\3770U\205\377" +\
    ",O}\377'Hv\377\42@l\377\368b\377%Ez:\37=lu!=k\377&Fu\377*L|\377/T\206" +\
    "\3772[\216\3777`\224\377;f\233\377=j\240\377\77n\245\377Br\251\377Dt" +\
    "\254\377Fy\261\377I{\265\377J~\267\377M\202\273\377O\205\276\377Q\207" +\
    "\301\377R\213\303\377U\215\310\377V\220\312\377Y\222\314\377Z\225\317" +\
    "\377\134\227\321\377^\231\323\377_\234\326\377`\235\326\377b\237\331" +\
    "\377c\241\332\377e\243\333\377f\245\335\377g\247\335\377h\251\337\377" +\
    "i\252\340\377:G^\377\270\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\326\0\0\377Z\10\0\377\314\260\0\377\255" +\
    "\216\0\377\232\177\0\377\225y\0\377\221v\0\377\210k\0\377\203g\0\377" +\
    "\200e\0\377'\35\0\377\0\0f\377[\134\340\377\242\246\375\377\254\261\377" +\
    "\377\254\260\377\377\254\260\377\377\253\256\377\377\247\254\377\377" +\
    "\245\253\377\377\241\245\377\377\233\240\377\377\220\224\376\377nn\353" +\
    "\377\7!\222\377\0\363\350\377\0\376\376\377\0\377\377\377\0\376\377\377" +\
    "\0\375\377\377\0\226\257\377\14\24\32\377\26$\60\377\27%\61\377\30'\65" +\
    "\377\32*9\377\34/\77\377\37\64F\377#:O\377(B[\377-Jg\3773Tu\3777[\201" +\
    "\377<d\215\377@k\226\377Bp\236\377Ds\245\377Eu\250\377Ev\252\377Ev\253" +\
    "\377Du\253\377Br\246\377@o\243\377\77l\241\377<i\235\3779d\230\3777`" +\
    "\223\3773Z\213\3770T\205\377,N}\377'Gt\377\42Ak\377\369b\377\36:hp\35" +\
    "9e\207!>k\377%Es\377)L|\377/S\205\3773Z\214\3776_\223\377:e\232\377<" +\
    "i\240\377\77m\243\377Aq\250\377Ct\253\377Ew\260\377Hz\262\377I}\267\377" +\
    "L\200\271\377N\204\274\377P\206\300\377R\212\302\377T\214\306\377V\217" +\
    "\311\377W\220\313\377Y\224\316\377Z\226\321\377]\227\322\377^\232\324" +\
    "\377_\235\326\377b\236\327\377b\240\332\377d\242\333\377e\244\333\377" +\
    "g\246\335\377g\250\336\377i\252\337\3771Kc\377\256\0\0\377\376\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\346\0\0\377\212" +\
    "G\0\377\377\351\0\377\367\320\0\377\344\276\0\377\326\261\0\377\315\253" +\
    "\0\377\310\246\0\377\302\240\0\377\252\214\0\377\220u\0\377\0!.\377\1" +\
    "\277\313\377\20>\207\377\4\6\254\377\34\36\333\377W[\361\377\215\222" +\
    "\367\377\215\220\366\377\202\206\363\377]^\344\377\34\34\256\377\0O\211" +\
    "\377\0\365\361\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\376\377\0\343\364\377\0>K\377\24 +\377\26$\60\377\26%\61\377" +\
    "\30&\64\377\31*9\377\34/@\377 4G\377#:Q\377)C]\377-Kh\3773Tv\3777\134" +\
    "\202\377;d\214\377\77k\227\377Cp\236\377Ds\244\377Eu\250\377Eu\252\377" +\
    "Dt\251\377Ct\251\377Bq\245\377\77m\242\377>j\240\377<h\233\3779d\227" +\
    "\3777_\220\3773Z\212\377/S\203\377+N|\377'Fs\377#@l\377\369c\376\33\64" +\
    "^\204\359e\225!=j\377$Es\377)L|\377.S\204\3772X\213\3776_\223\3778d\230" +\
    "\377<h\236\377>l\242\377Ao\246\377Br\252\377Dv\256\377Gy\261\377I|\265" +\
    "\377K\177\270\377M\202\274\377O\205\276\377Q\210\301\377S\213\305\377" +\
    "U\215\310\377W\220\312\377X\222\314\377Z\225\317\377\134\227\320\377" +\
    "^\230\322\377_\234\325\377`\235\327\377b\237\330\377c\241\332\377c\242" +\
    "\333\377f\245\334\377g\246\335\377g\247\336\377:^{\377\225\0\0\377\374" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\314\0\0" +\
    "\377\303\234\0\377\376\371\0\377\377\363\0\377\376\356\0\377\377\350" +\
    "\0\377\377\345\0\377\377\342\0\377\377\336\0\377\350\302\0\377\254\217" +\
    "\0\377C,\0\377\0\212\241\377e\374\377\377d\377\377\377[\377\377\377D" +\
    "\377\377\3772\355\350\3775\363\355\377~\377\377\377r\377\377\377+\377" +\
    "\377\377\37\376\376\377\37\377\377\377\42\377\377\377#\377\377\377#\376" +\
    "\377\377\26\377\377\377\0\372\377\377\0\244\300\377\10\16\22\377\24!" +\
    "-\377\26$\60\377\27%\62\377\30'\65\377\32+:\377\34.@\377\37\64G\377$" +\
    ";R\377(C]\377.Ki\3772Uw\3777\134\202\377<d\215\377\77j\227\377Bo\237" +\
    "\377Cr\244\377Ds\247\377Du\250\377Ds\251\377Cr\250\377Ap\244\377\77m" +\
    "\243\377<h\235\377:f\232\3779c\226\3776]\217\3772Y\212\377.R\203\377" +\
    "*M{\377&Fs\377\42\77j\377\369a\377\34\65_\223\35\67b\236 <i\377%Ds\377" +\
    ")Kz\377-R\202\3771W\212\3775]\221\3778c\230\377:f\234\377=j\241\377\77" +\
    "m\245\377Aq\250\377Dt\255\377Ew\260\377Gz\263\377J~\267\377L\200\272" +\
    "\377N\204\275\377P\206\300\377R\211\302\377T\214\307\377U\216\311\377" +\
    "X\221\313\377X\223\316\377[\225\320\377\134\230\322\377^\232\324\377" +\
    "_\234\325\377a\236\327\377b\240\331\377c\242\332\377e\243\333\377f\245" +\
    "\334\377g\246\336\377S\207\263\377L\0\0\377\357\0\0\377\376\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\375\0\0\377\216\0\0\377\363\344\0\377\377\372" +\
    "\0\377\377\371\0\377\377\371\0\377\377\367\0\377\377\371\0\377\377\371" +\
    "\0\377\377\366\0\377\377\345\0\377\324\261\0\377\230|\0\377\4\16\21\377" +\
    "<\303\323\377v\377\377\377w\377\377\377r\377\377\377j\376\376\377\177" +\
    "\377\377\377\364\377\377\377\336\376\376\377`\377\377\377O\377\377\377" +\
    "M\377\377\377L\377\377\377G\377\376\377E\377\377\3776\376\376\377\0\300" +\
    "\341\377\1(/\377\23\36)\377\24\42.\377\25#\60\377\26$\61\377\30'\65\377" +\
    "\32+:\377\34.\77\377 4H\377$<R\377(B\134\377-Kj\3772Tw\3778\134\202\377" +\
    ";c\215\377\77j\226\377Ao\237\377Cq\243\377Dt\247\377Cs\250\377Br\247" +\
    "\377Bq\246\377@n\243\377=j\237\377;g\233\377:d\230\3777a\223\3774\134" +\
    "\216\3771W\210\377.Q\202\377*Ly\377%Fr\377\42\77i\377\358`\377\33\63" +\
    "[\235\34\66a\247 <h\377$Cp\377(Jy\377-P\202\3770W\211\3774\134\217\377" +\
    "7a\226\377:e\233\377=h\237\377\77l\243\377@o\247\377Cs\252\377Ev\256" +\
    "\377Gx\261\377I|\265\377K\200\271\377M\201\273\377O\205\277\377Q\210" +\
    "\301\377S\212\305\377T\214\310\377W\217\312\377X\221\314\377Z\224\317" +\
    "\377[\227\320\377]\230\322\377^\233\324\377`\234\326\377a\236\327\377" +\
    "b\240\331\377c\241\333\377e\243\333\377f\245\333\377g\245\334\377-\16" +\
    "\22\377\326\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\367\0\0\377" +\
    "\213+\0\377\377\377\0\377\377\370\0\377\377\370\0\377\377\370\0\377\377" +\
    "\370\0\377\377\371\0\377\377\371\0\377\377\370\0\377\376\363\0\377\364" +\
    "\321\0\377\265\226\0\377~f\0\377\0\37+\377`\310\324\377\207\377\377\377" +\
    "\215\377\377\377\211\376\377\377\214\377\377\377\252\377\377\377\235" +\
    "\377\377\377z\377\377\377s\377\377\377n\377\377\377k\376\377\377f\377" +\
    "\377\377]\377\376\377&\322\343\377\0:H\377\17\31!\377\24 ,\377\25#/\377" +\
    "\26#\60\377\26%\62\377\30(\66\377\32*:\377\34/@\377 4I\377#;R\377)C^" +\
    "\377-Lk\3772Uv\3776[\202\377<c\215\377>j\227\377Am\236\377Cp\243\377" +\
    "Br\246\377Br\246\377Bq\246\377@o\245\377\77m\241\377<i\236\377;f\233" +\
    "\3779c\226\3776_\222\3774[\215\3770V\206\377-Q\177\377*Ky\377&Dp\377" +\
    "!=h\377\358_\377\32\62Z\243\33\65a\266\37<g\377$Bp\377'Ix\377,O\200\377" +\
    "0V\207\3773[\216\3776_\224\3779d\231\377;g\235\377=k\242\377@n\245\377" +\
    "Aq\250\377Dt\255\377Ew\260\377G{\263\377J~\267\377K\200\272\377N\204" +\
    "\275\377P\206\300\377Q\211\302\377T\213\307\377V\216\311\377W\220\313" +\
    "\377X\223\315\377Z\225\320\377\134\227\321\377]\231\322\377^\234\325" +\
    "\377a\235\327\377a\237\330\377c\241\332\377c\242\333\377f\244\334\377" +\
    "e\244\334\3771Oi\377\242\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\314\0\0\377\262~\0\377\377\372\0\377\377\371\0\377\377\371\0\377" +\
    "\377\371\0\377\377\371\0\377\377\370\0\377\377\370\0\377\377\370\0\377" +\
    "\377\372\0\377\377\354\0\377\345\301\0\377\246\212\0\377{d\0\377\0\11" +\
    "\22\377S\255\267\377\210\365\372\377\232\376\376\377\234\377\377\377" +\
    "\232\376\377\377\226\377\376\377\220\377\376\377\215\376\377\377\210" +\
    "\377\376\377\204\377\376\377q\370\377\377J\274\307\377\0*\64\377\15\26" +\
    "\35\377\23\37*\377\24!-\377\25#/\377\25#\60\377\26$\62\377\30(\67\377" +\
    "\32+;\377\34/A\377 5J\377$<T\377(D^\377.Lk\3772Tv\3777\134\203\377;d" +\
    "\216\377\77i\227\377@m\235\377Bp\242\377Cp\244\377Cq\246\377Ao\244\377" +\
    "@m\243\377=k\237\377<i\235\377:e\231\3778a\225\3776^\217\3773Z\214\377" +\
    "0U\205\377,P\177\377(Iw\377%Co\377!>g\377\35\66_\377\32\62Z\257\34\65" +\
    "_\301\37:e\377\42Ao\377'Hv\377+N~\377.T\205\3772Y\215\3775^\222\3777" +\
    "b\227\377:f\234\377<i\237\377>l\243\377Ao\247\377Bs\253\377Dv\256\377" +\
    "Gx\262\377I|\265\377K\177\271\377L\201\273\377O\205\276\377Q\210\301" +\
    "\377R\212\304\377T\215\307\377V\217\312\377X\220\314\377Y\224\316\377" +\
    "Z\225\320\377\134\227\321\377^\232\324\377^\234\325\377a\235\327\377" +\
    "a\237\330\377c\241\332\377c\242\333\377d\242\332\377Z\220\300\377M\0" +\
    "\0\377\342\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\367\0\0\377\223\0\0\377\373\362\0\377" +\
    "\377\371\0\377\377\371\0\377\377\370\0\377\377\371\0\377\377\371\0\377" +\
    "\377\371\0\377\377\370\0\377\377\372\0\377\377\371\0\377\377\370\0\377" +\
    "\377\345\0\377\335\273\0\377\247\212\0\377\210q\0\377\34\16\0\377\5G" +\
    "T\377\134\265\276\377\211\341\352\377\224\367\371\377\230\373\377\377" +\
    "\225\373\376\377\215\371\373\377~\350\362\377a\277\312\377\26it\377\10" +\
    "\2\0\377\35\32\0\377\22\35'\377\24!-\377\25\42.\377\25\42/\377\26#\60" +\
    "\377\26%\62\377\30'\66\377\32+<\377\35/B\377 5J\377$<U\377)D`\377.Lk" +\
    "\3772Tx\3776\134\203\377;c\216\377>h\226\377\77l\235\377Ao\241\377Bp" +\
    "\244\377Ap\244\377\77n\244\377@m\241\377=i\235\377;g\233\377:d\227\377" +\
    "7`\222\3774]\216\3772X\211\377/T\204\377+N{\377(Hu\377$Cn\377!<f\377" +\
    "\34\66^\377\31\61X\273\33\65_\307\37:e\377\42@m\377&Gu\377+M}\377.R\203" +\
    "\3771W\213\3774\134\220\3777a\225\3779d\231\377;h\236\377=k\241\377@" +\
    "n\245\377Bq\251\377Ct\254\377Ew\260\377Hz\264\377J}\266\377K\200\272" +\
    "\377N\203\275\377O\205\277\377Q\210\302\377S\213\306\377T\215\311\377" +\
    "V\217\311\377W\222\315\377Z\224\317\377[\226\320\377\134\227\322\377" +\
    "^\233\323\377_\234\325\377`\235\327\377a\240\330\377c\241\332\377b\240" +\
    "\331\377e\242\332\377\42\67I\377\245\0\0\377\375\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\341\0\0" +\
    "\377\221Y\0\377\377\377\0\377\377\371\0\377\377\370\0\377\377\371\0\377" +\
    "\377\371\0\377\377\370\0\377\377\371\0\377\377\371\0\377\377\371\0\377" +\
    "\377\372\0\377\376\375\0\377\377\370\0\377\376\347\0\377\344\303\0\377" +\
    "\265\232\0\377\223~\0\377|h\0\377(\32\0\377\0\6\14\377\0$+\377\12Sa\377" +\
    "\20Wc\377\118B\377\0\13\21\377\34\25\0\377\224\206\0\377\226\214\0\377" +\
    "\37\33\2\377\24 ,\377\24\42.\377\24!-\377\25\42.\377\25#\60\377\26%\63" +\
    "\377\30(\67\377\32+<\377\35\60B\377!6L\377$=U\377)Da\377-Ll\3772Tx\377" +\
    "7\134\203\377:b\215\377=h\225\377\77k\234\377@n\240\377@o\242\377\77" +\
    "m\241\377\77m\241\377>k\237\377;h\235\377:f\231\3778b\225\3776_\221\377" +\
    "3[\214\3771W\207\377.R\201\377+M{\377'Hs\377#Al\377\37;d\377\34\65\134" +\
    "\377\30\60W\301\31\63]\307\358c\377!\77l\377%Fs\377)K{\377,Q\201\377" +\
    "0V\211\3774[\217\3776`\223\3778b\227\377:f\234\377<i\240\377\77l\243" +\
    "\377Ap\247\377Cr\253\377Dv\256\377Gy\262\377H|\265\377K~\270\377L\202" +\
    "\274\377N\203\275\377P\210\301\377Q\211\303\377T\213\306\377U\216\311" +\
    "\377W\221\313\377X\223\315\377Z\224\317\377\134\226\320\377]\231\322" +\
    "\377]\233\324\377_\234\326\377a\235\327\377b\240\331\377b\237\330\377" +\
    "b\240\330\377Z\223\304\3773\4\5\377\321\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\376\0\0\377\371\0\0\377\233\0\0\377\371\353" +\
    "\0\377\376\373\0\377\377\372\0\377\377\373\0\377\377\370\0\377\377\371" +\
    "\0\377\377\371\0\377\377\371\0\377\377\372\0\377\377\372\0\377\377\374" +\
    "\0\377\377\374\0\377\376\376\0\377\376\374\0\377\377\360\0\377\367\327" +\
    "\0\377\324\270\0\377\263\235\0\377\237\212\0\377\222\201\0\377\216}\0" +\
    "\377\214}\0\377\217\200\0\377\234\214\0\377\257\236\0\377\312\272\0\377" +\
    "\337\316\0\377\260\244\0\377\13\14\10\377\24!-\377\24!-\377\24\42.\377" +\
    "\25\42/\377\25#\61\377\26%\63\377\30(\67\377\32,=\377\35\61D\377!7M\377" +\
    "%>X\377)Ea\377.Nn\3773Uy\3777\134\205\377:b\216\377<h\226\377>j\233\377" +\
    "\77k\236\377@m\241\377>m\241\377=k\237\377=j\235\377:e\231\3779c\227" +\
    "\3777a\223\3774]\216\3773Z\212\3770V\205\377,Q\177\377*Ky\377&Fr\377" +\
    "\42@j\377\36:b\377\33\63Z\377\31\62[\274\31\62Z\277\35\67a\377!=h\377" +\
    "%Dr\377)Jy\377,O\177\377/U\207\3772Z\215\3775^\222\3777a\225\3779d\232" +\
    "\377;g\235\377>k\241\377\77n\245\377Bp\250\377Cs\254\377Ew\260\377Gy" +\
    "\262\377I|\267\377K\200\272\377M\202\274\377O\205\277\377Q\210\301\377" +\
    "R\212\304\377T\214\310\377V\216\311\377W\221\314\377Y\223\315\377Y\224" +\
    "\320\377\134\227\321\377]\230\322\377^\233\325\377`\234\326\377a\236" +\
    "\327\377a\236\330\377`\237\330\377a\236\325\377Ah\214\377c\0\0\377\346" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\335\0\0\377" +\
    "\234h\0\377\377\377\0\377\377\373\0\377\377\372\0\377\377\373\0\377\377" +\
    "\372\0\377\377\370\0\377\377\370\0\377\377\372\0\377\377\371\0\377\377" +\
    "\373\0\377\377\373\0\377\377\376\0\377\377\377\0\377\377\376\0\377\376" +\
    "\377\0\377\377\373\0\377\376\360\0\377\372\340\0\377\350\316\0\377\332" +\
    "\301\0\377\320\272\0\377\321\274\0\377\325\302\0\377\345\320\0\377\366" +\
    "\343\0\377\377\366\0\377\372\355\0\377\234\221\0\377\11\17\24\377\24" +\
    "!-\377\24!-\377\25\42.\377\25\42/\377\25$\61\377\27%\64\377\31)9\377" +\
    "\33-\77\377\36\62F\377!8O\377&\77Y\377*Fd\377.No\3773V{\3777]\206\377" +\
    ":b\216\377=h\227\377>k\233\377\77l\236\377\77k\236\377>k\237\377=h\235" +\
    "\377<h\234\3779e\227\3778b\225\3776^\221\3773[\215\3771W\211\377/T\203" +\
    "\377,O~\377)Jw\377&Dq\377\42>h\377\368a\377\32\63Y\377\26-S\271\30\60" +\
    "X\263\34\65_\377 <h\377$Cp\377(Hw\377+N~\377.S\205\3772X\213\3773\134" +\
    "\217\3776_\223\3779c\227\377:e\233\377<i\237\377>l\243\377@o\247\377" +\
    "Cr\252\377Du\256\377Fx\260\377G{\264\377J}\267\377L\201\273\377M\204" +\
    "\274\377O\206\300\377Q\210\302\377S\212\305\377T\215\310\377V\217\311" +\
    "\377W\221\314\377Y\223\315\377[\225\317\377\134\226\321\377]\231\322" +\
    "\377^\233\325\377`\233\326\377_\234\325\377a\235\327\377_\234\324\377" +\
    "_\233\322\377!7I\377\204\0\0\377\356\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\360\0\0\377\177\5\0\377\377\374\0\377\377\376\0\377\377\375\0\377\377" +\
    "\373\0\377\377\372\0\377\377\373\0\377\377\373\0\377\377\373\0\377\377" +\
    "\372\0\377\377\372\0\377\377\373\0\377\377\374\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\376\0\377\376\377\0\377\377\377\0\377\377" +\
    "\376\0\377\377\375\0\377\376\372\0\377\376\371\0\377\376\372\0\377\376" +\
    "\374\0\377\377\376\0\377\377\376\0\377\377\377\0\377\357\343\0\377SK" +\
    "\0\377\17\31\42\377\24!-\377\24!-\377\24\42.\377\25\42/\377\26$\62\377" +\
    "\27&\65\377\31*:\377\33.@\377\37\64I\377\42:Q\377&@[\377*Hf\377/Pr\377" +\
    "3W}\3778^\206\377:b\217\377<g\226\377=j\233\377>j\235\377>k\237\377=" +\
    "j\236\377<h\234\377:f\231\3778b\226\3776_\221\3775]\217\3773Z\213\377" +\
    "1W\207\377.R\202\377+N|\377'Iu\377%Cn\377!>g\377\34\67^\377\31\62X\376" +\
    "\26+P\254\27/V\243\34\65]\377\37;e\377#An\377'Hu\377)M|\377,R\202\377" +\
    "0U\210\3773[\215\3775^\221\3777a\225\3778d\231\377;g\235\377=j\241\377" +\
    "\77n\244\377Ap\250\377Cs\253\377Dv\257\377Fx\262\377I|\266\377K\177\270" +\
    "\377L\202\273\377O\204\276\377O\207\300\377R\211\302\377S\213\306\377" +\
    "U\215\310\377V\220\312\377X\222\314\377Y\223\317\377Z\225\317\377\134" +\
    "\227\321\377]\231\323\377^\233\325\377^\233\325\377`\234\325\377_\233" +\
    "\323\377^\232\321\377/Mj\377\11\0\7\377\213\0\0\377\347\0\0\377\377\0" +\
    "\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\371\0\0" +\
    "\377\241\0\0\377\311\266\0\377\377\377\0\377\376\376\0\377\377\375\0" +\
    "\377\377\375\0\377\377\374\0\377\377\374\0\377\377\373\0\377\377\372" +\
    "\0\377\377\374\0\377\377\374\0\377\377\375\0\377\377\375\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\376\0\377\376\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\331\312" +\
    "\0\377($\3\377\23 +\377\24!-\377\24 ,\377\24\42.\377\25#\61\377\26%\63" +\
    "\377\30'\67\377\31*;\377\34/C\377 4J\377#;T\377'B^\377+Ji\3770Qt\377" +\
    "4Y\177\3778^\211\377:c\217\377=g\226\377=h\233\377=i\233\377=j\234\377" +\
    "<i\235\377;f\232\3779d\227\3778b\224\3776^\221\3774[\215\3772X\211\377" +\
    "/T\204\377-P~\377)Ly\377'Fs\377$Bl\377 <e\377\35\67^\377\31\60V\377\26" +\
    "+O\241\27-U\234\33\63[\377\369d\377\42\77k\377&Fs\377)Ky\377,O\200\377" +\
    "/U\206\3771Y\212\3773[\217\3776_\223\3777a\226\3779f\233\377<h\237\377" +\
    ">k\242\377@o\246\377Br\251\377Cs\255\377Ew\260\377Gz\263\377J|\266\377" +\
    "K\200\271\377L\202\273\377N\204\276\377P\207\301\377R\211\303\377S\213" +\
    "\307\377T\216\310\377V\220\313\377X\221\314\377Z\223\317\377Z\225\317" +\
    "\377\134\226\321\377]\231\322\377\134\231\323\377^\232\324\377]\231\321" +\
    "\377]\230\317\377,\26\64\377\232\0x\377\20\0\13\377q\0\0\377\322\0\0" +\
    "\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\374\0\0\377\277\0\0" +\
    "\377\245x\0\377\377\377\0\377\376\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\375\0\377\377\376\0\377\377\373\0\377\377\373\0\377\377\373\0\377" +\
    "\377\373\0\377\377\375\0\377\377\376\0\377\377\376\0\377\377\376\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\376\0\377\377\371\0\377\270\252\0\377" +\
    "\4\6\11\377\24!-\377\24 ,\377\24!-\377\24\42/\377\25#\60\377\26%\64\377" +\
    "\27'\67\377\32,=\377\35\61E\377 6M\377$=X\377)Eb\377-Lm\3771Sx\3774Y" +\
    "\202\3777_\212\377:d\221\377<f\226\377<i\232\377=h\234\377<h\233\377" +\
    ";f\232\3779d\230\3778b\226\3776^\222\3774\134\216\3773Y\213\3770V\206" +\
    "\377/R\202\377,O}\377)Jw\377%Eq\377#@i\377\37:c\377\33\65]\377\30/T\377" +\
    "\26+O\233\26-S\222\32\62Z\377\358a\377!>i\377$Cp\377(Iw\377+N}\377.R" +\
    "\203\3770V\211\3773Z\214\3774]\221\3776`\225\3778b\230\377;g\234\377" +\
    "<i\240\377>l\244\377@o\247\377Bq\252\377Du\256\377Fw\261\377Gz\264\377" +\
    "I}\266\377K\200\272\377M\203\274\377N\204\277\377P\207\301\377Q\211\303" +\
    "\377T\213\307\377U\215\311\377V\220\312\377W\221\314\377Y\224\317\377" +\
    "Z\225\317\377\134\227\321\377\134\226\320\377]\230\322\377]\227\320\377" +\
    "W\217\305\377E\0\65\377\310\0\243\377\254\0\214\377:\0,\377'\0\0\377" +\
    "\257\0\0\377\345\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\376\0\0\377\374\0\0\377\312\0\0\377\215N\0\377\377" +\
    "\377\0\377\377\377\0\377\377\376\0\377\377\377\0\377\377\377\0\377\377" +\
    "\376\0\377\377\375\0\377\377\375\0\377\377\375\0\377\377\375\0\377\377" +\
    "\375\0\377\377\376\0\377\377\376\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\364\345\0\377{X\0\3771\0\0\377" +\
    "\22\36*\377\23 ,\377\23!-\377\24!/\377\25#\62\377\26%\64\377\30(9\377" +\
    "\32,\77\377\36\62G\377\428P\377%\77Y\377)Fe\377.Np\3772Tz\3775Z\204\377" +\
    "9_\214\377:c\222\377;f\227\377;h\231\377;g\232\377;f\232\377:d\230\377" +\
    "8c\226\3776`\223\3774\134\217\3773Z\214\3771X\211\377/T\204\377-Q\200" +\
    "\377+L{\377(Hu\377$Cn\377\42>h\377\369a\377\33\63Y\377\30.S\377\24*M" +\
    "\220\25+R\203\30\60V\377\35\67_\377 ;f\377#Bn\377&Gu\377*L{\377,P\201" +\
    "\377/U\206\3771X\213\3773[\216\3775^\223\3777b\227\3779d\231\377;g\235" +\
    "\377=k\241\377\77m\245\377Ap\250\377Bs\253\377Ev\257\377Fx\261\377H{" +\
    "\265\377J~\267\377K\200\273\377M\203\274\377O\205\277\377P\207\302\377" +\
    "R\212\304\377T\214\307\377U\215\311\377V\220\313\377W\222\314\377Y\223" +\
    "\317\377Z\224\317\377Z\225\317\377[\226\320\377[\226\317\377T\212\275" +\
    "\377d\0J\377\371\0\320\377\352\0\303\377\247\0\222\377(\0\0\377\0\0\0" +\
    "\377H\0\0\377\256\0\0\377\326\0\0\377\367\0\0\377\377\0\0\377\377\0\0" +\
    "\377\376\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377" +\
    "\0\0\377\361\0\0\377\260\0\0\377\225]\0\377\377\377\0\377\376\376\0\377" +\
    "\376\376\0\377\377\377\0\377\377\377\0\377\377\376\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\376\0\377\377\376\0\377\377\376\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\376\0\377\377\371\0\377\324\312\0\377}\0\0\377L\0\0\377\20\33%\377" +\
    "\23 -\377\23 -\377\24\42/\377\26$\63\377\27&\66\377\31*;\377\33.A\377" +\
    "\37\64J\377\42:S\377'A]\377+Ii\377/Ps\3772V}\3776\134\207\3778`\215\377" +\
    ":c\223\377;f\230\377;g\230\377;e\230\377:e\232\3778c\226\3777b\224\377" +\
    "6_\222\3774[\216\3772Y\212\3771V\206\377.R\202\377,O}\377)Kx\377'Gs\377" +\
    "$Bm\377!=f\377\358_\377\32\62X\377\27-Q\377\23'I\201\23(Kj\30/U\377\33" +\
    "\64\134\377\37:d\377\42@k\377%Er\377(Jx\377,O~\377.R\204\3770V\210\377" +\
    "2Y\214\3774\134\220\3776_\223\3778c\227\3779e\233\377<h\236\377>k\242" +\
    "\377\77n\246\377Aq\250\377Cs\254\377Dv\257\377Fy\262\377I{\266\377J~" +\
    "\270\377L\201\274\377N\204\275\377O\205\300\377P\207\301\377R\211\304" +\
    "\377S\214\307\377U\215\311\377W\220\312\377W\221\315\377X\222\316\377" +\
    "Z\225\317\377Z\224\317\377Z\224\316\377R\211\275\377j\0O\377\377\0\356" +\
    "\377\222\0R\377\266LC\377\302`_\377\257QO\377}//\377\10\0\0\377\24\0" +\
    "\0\377u\0\0\377\255\0\0\377\321\0\0\377\351\0\0\377\362\0\0\377\362\0" +\
    "\0\377\357\0\0\377\345\0\0\377\305\0\0\377u\0\0\377\301\233\0\377\376" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\376\0\377\377\377\0\377\360\335\0\377\203" +\
    "U\0\377\373\0\0\377c\0\0\377\17\30#\377\23 -\377\23 -\377\24\42\60\377" +\
    "\25$\63\377\27'\67\377\32+=\377\34/C\377 6L\377#<V\377'C`\377,Kl\377" +\
    "/Qv\3773W\200\3776]\210\3778a\217\3779c\223\377:e\225\377;f\230\3779" +\
    "d\230\3779d\230\3779a\225\3776`\222\3775]\220\3772Y\213\3770W\207\377" +\
    "/S\204\377-P\177\377+Mz\377)Iv\377&Do\377#Ak\377\37<c\377\35\67]\377" +\
    "\31\60U\377\25+N\377\23'Ie\23(M\62\26,Q\377\32\62Z\377\359a\377!>i\377" +\
    "$Cp\377'Gv\377*L|\377-Q\201\377.T\205\3771W\211\3773Z\215\3775]\221\377" +\
    "6`\225\3778c\230\377:f\234\377<i\240\377>l\243\377@n\247\377Aq\251\377" +\
    "Ct\255\377Ev\257\377Fz\262\377H{\266\377K\177\270\377L\201\273\377M\203" +\
    "\275\377O\205\277\377Q\207\301\377R\211\304\377S\214\307\377U\215\311" +\
    "\377V\217\312\377V\220\313\377X\222\316\377X\222\315\377X\224\315\377" +\
    "R\207\274\377a\0R\377\221\11\25\377\373\200}\377\376\214\211\377\377" +\
    "\205\202\377\366sp\377\331``\377\276NM\377\241;;\377h !\377\17\0\0\377" +\
    "\12\0\0\377a\22\0\377\202&\0\377\214.\0\377\2162\0\377\215R\0\377\335" +\
    "\314\0\377\373\372\0\377\377\377\0\377\376\376\0\377\376\376\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\372\356\0\377\255\253\0\377\316\0\0\377\366\0\0\377g\0\0\377" +\
    "\17\30\42\377\23 ,\377\23 .\377\24\42\60\377\25$\63\377\27'8\377\32," +\
    ">\377\35\61F\377 6N\377$=X\377)Ed\377,Kn\3771Rx\3773X\202\3776]\211\377" +\
    "8a\220\3779c\224\377:d\226\3779d\226\3778c\226\3778b\225\3776_\223\377" +\
    "6]\220\3773Z\214\3772X\211\3770U\205\377-R\201\377,N|\377)Ky\377'Gs\377" +\
    "%Cn\377\42\77g\377\379a\377\33\64Z\377\30/T\377\25)L\377\22$F)\0\0\0" +\
    "\0\25*O\377\31\61W\377\35\67_\377 <f\377#Al\377&Fs\377)Jy\377,O~\377" +\
    ".R\203\377/U\206\3772X\212\3773[\216\3775^\222\3777`\226\3779c\231\377" +\
    ";g\235\377=i\240\377>l\244\377@o\247\377Ar\252\377Du\255\377Ex\261\377" +\
    "Gy\263\377H|\266\377J\177\271\377L\201\273\377N\203\275\377N\205\277" +\
    "\377Q\210\302\377R\211\304\377S\213\307\377U\215\311\377V\217\312\377" +\
    "V\217\312\377W\222\315\377X\221\315\377J{\255\377W\0\0\377\371ro\377" +\
    "\377\203\200\377\377\204\201\377\377\177|\377\376{y\377\376rq\377\375" +\
    "ig\377\360^^\377\326bb\377\262ba\377f&&\37766\0\377\322\303\0\377\377" +\
    "\375\0\377\377\377\0\377\377\377\0\377\377\377\0\377\376\376\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\376\0\377\376\376\0\377\377\370\0\377\330\320\0\377\240" +\
    "\21\0\377\377\0\0\377\366\0\0\377g\0\0\377\16\27!\377\22\37+\377\23 " +\
    "-\377\24\42\60\377\26%\64\377\30(9\377\33-@\377\36\62G\377!8Q\377%\77" +\
    "[\377)Ff\377.Mq\3771T{\3773Y\203\3776^\212\3778a\220\3779b\223\3778c" +\
    "\225\3778d\226\3779b\225\3777a\224\3776_\220\3774Z\215\3773Y\213\377" +\
    "1W\207\377.S\203\377-P~\377,N{\377)Iv\377&Fp\377#Ak\377 =e\377\35\67" +\
    "_\377\33\63X\377\27.R\377\24'J\377\0\0\0\0\0\0\0\0\24)M\370\27/T\377" +\
    "\33\64\134\377\37:c\377\42\77j\377$Cp\377(Hv\377*L{\377,P\200\377.S\204" +\
    "\3770V\210\3772Y\214\3774\134\217\3775_\223\3778a\227\3779e\232\377;" +\
    "g\236\377=j\241\377>l\244\377@p\250\377Br\253\377Du\256\377Fx\261\377" +\
    "Hz\263\377H}\266\377J\177\271\377L\201\273\377N\203\275\377N\205\300" +\
    "\377P\207\302\377Q\211\303\377S\213\306\377T\214\310\377U\216\311\377" +\
    "U\217\312\377W\220\313\3779\10\13\377\351,+\377\376ii\377\377lj\377\377" +\
    "kh\377\377ih\377\377hg\377\377ge\377\376bc\377\377hi\377\377\245\246" +\
    "\377\355\334\334\377\266\203\202\377F\16\21\377[Q\0\377\334\314\0\377" +\
    "\377\375\0\377\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\376\0\377\377\373\0\377\341\322\0\377\213;\0\377\377\0\0\377\376" +\
    "\0\0\377\364\0\0\377f\0\0\377\16\26 \377\22\37,\377\23\37-\377\24\42" +\
    "\60\377\25$\64\377\30(9\377\32-@\377\36\62I\377!9R\377&@]\377*Gh\377" +\
    ".Ns\3771T|\3774Y\204\3776]\213\3778`\220\3778b\223\3778b\225\3778b\223" +\
    "\3776_\222\3776_\221\3774\134\216\3774Y\213\3771W\207\3770S\203\377-" +\
    "Q\177\377,N|\377*Kx\377'Gr\377%Cm\377#@i\377\37:c\377\34\66\134\377\32" +\
    "\60U\377\26,O\377\23'I\365\0\0\0\0\0\0\0\0\23'I\320\26-R\377\32\62Y\377" +\
    "\358a\377 <g\377#Bn\377&Fs\377)Ky\377+N}\377-Q\202\377/T\205\3770V\211" +\
    "\3773Z\214\3774]\221\3776`\224\3777b\227\3779e\233\377;g\237\377=k\241" +\
    "\377\77m\245\377@p\247\377Br\253\377Du\256\377Fw\260\377Gz\264\377I|" +\
    "\266\377J~\271\377K\201\273\377M\203\274\377N\204\277\377P\207\301\377" +\
    "Q\210\302\377R\212\306\377T\214\307\377U\216\311\377)/C\377\313\0\0\377" +\
    "\377HD\377\377XU\377\376VU\377\376TS\377\377SR\377\377PR\377\376KL\377" +\
    "\376FJ\377\377OT\377\377\222\226\377\376\341\343\377\352\216\220\377" +\
    "\256\37!\377%\0\0\377sh\0\377\341\317\0\377\377\376\0\377\377\376\0\377" +\
    "\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\376\376\0\377\377\373\0\377\347\327\0\377\177I\0\377\375" +\
    "\0\0\377\376\0\0\377\377\0\0\377\361\0\0\377P\0\0\377\15\26!\377\22\37" +\
    "+\377\23\37-\377\24\42\60\377\25$\64\377\30(:\377\32-A\377\36\63J\377" +\
    "!9S\377&A^\377*Hi\377.Ot\3771T}\3774Y\205\3775]\213\3776^\216\3777`\223" +\
    "\3777`\223\3777_\222\3776_\221\3774\134\216\3773X\212\3772X\212\3770" +\
    "U\205\377/R\201\377,O|\377+My\377(Ht\377&Ep\377%Bl\377!=f\377\368`\377" +\
    "\34\64Y\377\31/T\377\25*L\377\22%D\314\0\0\0\0\0\0\0\0\22%G\217\25+O" +\
    "\376\31\60V\377\35\65]\377\37;c\377#\77j\377$Dp\377'Hu\377*Kz\377,O\177" +\
    "\377-Q\203\377/U\206\3771X\212\3773Z\215\3775]\222\3776`\225\3778b\230" +\
    "\377:f\234\377<h\237\377=k\242\377\77m\245\377Ap\251\377Br\252\377Du" +\
    "\256\377Fx\261\377Gz\263\377I|\266\377J\177\271\377L\200\272\377M\202" +\
    "\275\377N\205\277\377P\206\301\377Q\210\302\377Q\210\304\377@m\233\377" +\
    "y\0\0\377\375\0\0\377\377;7\377\377D:\377\317#\27\377|\1$\377t\1\65\377" +\
    "u\0\63\377\206\0\32\377\337\23\12\377\377&/\377\377:E\377\377V_\377\377" +\
    "<F\377\341\16\27\377\247\0\0\377'\0\0\377k_\0\377\327\306\0\377\377\373" +\
    "\0\377\377\377\0\377\376\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\376\377" +\
    "\0\377\377\377\0\377\377\367\0\377\337\321\0\377yD\0\377\372\0\0\377" +\
    "\376\0\0\377\377\0\0\377\377\0\0\377\346\0\0\377<\0\0\377***\377\34$" +\
    ",\377\22\37,\377\24\42\60\377\26$\64\377\30(;\377\33-B\377\36\63J\377" +\
    "\429T\377&A_\377*Gi\377.Nt\3770T}\3773Y\206\3775\134\213\3776_\217\377" +\
    "6^\220\3777_\221\3775^\217\3775]\216\3773Z\214\3771X\211\3771V\206\377" +\
    "/S\202\377-P~\377+Lz\377)Jw\377'Gr\377&Cn\377#\77i\377 <e\377\35\66]" +\
    "\377\32\61W\377\27-Q\377\24)J\376\22\42B\213\0\0\0\0\0\0\0\0\21#BT\24" +\
    ")M\377\27.S\377\33\64[\377\359a\377 =g\377#Am\377&Er\377(Iw\377*M}\377" +\
    ",O\177\377.R\203\377/U\207\3772X\213\3773[\216\3775^\222\3776`\225\377" +\
    "8c\230\377:f\234\377;h\237\377=k\243\377\77n\245\377Ap\250\377Bs\254" +\
    "\377Du\256\377Ew\261\377Gz\263\377I|\266\377J~\270\377L\200\272\377M" +\
    "\202\274\377M\204\276\377O\206\301\377P\207\301\3778);\377\336\0\0\377" +\
    "\364\0\0\377\217\6E\377\324[\277\377\363\214\351\377\374\232\373\377" +\
    "\376\235\374\377\376\236\374\377\373\231\372\377\360\211\345\377\315" +\
    "\77\263\377\217\0\61\377\375\7\14\377\376\4\26\377\377\0\13\377\341\0" +\
    "\0\377\252\0\0\377+\0\0\377KC\0\377\311\270\0\377\374\360\0\377\376\377" +\
    "\0\377\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\376\0\377\376\377\0\377\374\355\0\377\330\320" +\
    "\0\377}(\0\377\375\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0" +\
    "\0\377\320\0\0\377\34\6\6\377()(\377//.\377\21\35+\377\23!/\377\25$\65" +\
    "\377\30(:\377\32-B\377\36\63K\377\42:U\377%@_\377)Gj\377-Ms\3770R|\377" +\
    "3X\204\3773[\211\3775]\215\3775\134\216\3774]\217\3773[\215\3774Z\214" +\
    "\3772X\211\3771V\206\377.R\202\377.Q\200\377+N|\377*Kw\377(Ht\377&Do" +\
    "\377#Aj\377\42=f\377\37:`\377\33\65Z\377\30\60T\377\26+N\377\23'H\377" +\
    "\20 =M\0\0\0\0\0\0\0\0\12\21%\13\23'I\377\26,P\377\31\60V\377\34\66^" +\
    "\377\37;d\377\42\77j\377$Cp\377'Gu\377)Jy\377*N}\377,P\200\377.S\204" +\
    "\377/V\210\3771X\213\3773[\217\3775^\223\3777a\226\3778c\230\3779f\234" +\
    "\377;h\237\377>j\243\377\77n\246\377@p\250\377Br\253\377Ct\256\377Ew" +\
    "\260\377Fy\262\377H|\265\377I}\267\377K\177\272\377L\201\273\377M\203" +\
    "\275\377H{\261\377c\0\0\377\231\0\24\377\322]\301\377\376\217\373\377" +\
    "\376\233\377\377\377\235\377\377\377\235\377\377\377\234\377\377\377" +\
    "\235\377\377\377\234\377\377\377\235\377\377\377\231\376\377\375\214" +\
    "\371\377\3079\256\377\274\0\10\377\377\0\0\377\376\0\0\377\344\0\0\377" +\
    "\261\0\0\377\134\0\0\377\20\25\0\377\250\231\0\377\347\325\0\377\377" +\
    "\372\0\377\377\376\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\376\0\377\376" +\
    "\377\0\377\377\366\0\377\354\331\0\377\245\240\0\377\245\11\0\377\376" +\
    "\0\0\377\376\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\375\0\0\377" +\
    "\237\0\0\377\21\22\22\377)))\377++*\377\32#-\377\22 .\377\25#\63\377" +\
    "\27(:\377\32-A\377\35\63K\377!9T\377%@_\377)Fi\377,Ms\377/R{\3772V\202" +\
    "\3773Y\210\3774[\212\3773Z\213\3773Z\214\3773Y\213\3772W\211\3770U\206" +\
    "\377.R\203\377.R\200\377,O|\377+Kx\377(Ht\377'Fq\377%Cm\377\42\77h\377" +\
    " <c\377\36\67^\377\32\63X\377\30/R\377\25)L\377\22$F\377\12\21\42\11" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\22$D\376\25)M\376\30/T\377\33\64[\377\369a\377" +\
    "!=g\377\42@l\377%Dq\377(Iw\377)Ky\377+N~\377-P\201\377.S\204\3770V\211" +\
    "\3772X\214\3773\134\217\3776^\223\3776a\225\3779b\231\377:f\235\377;" +\
    "i\237\377=j\242\377\77m\245\377@p\250\377Br\253\377Ct\255\377Ew\260\377" +\
    "Fy\262\377H{\265\377I}\267\377K\177\271\377K\200\273\3771Ty\377f\0\42" +\
    "\377\350a\331\377\377\203\377\377\376\205\376\377\377\205\377\377\377" +\
    "\205\377\377\377\207\377\377\377\231\377\377\377\236\377\377\377\210" +\
    "\377\377\377\204\376\377\377\205\377\377\376\205\377\377\377\202\377" +\
    "\377\346A\322\377\255\0\30\377\377\0\0\377\377\0\0\377\357\0\0\377\277" +\
    "\0\0\377\207\0\0\377\16\3\0\377YM\0\377\323\304\0\377\372\350\0\377\377" +\
    "\374\0\377\376\377\0\377\377\377\0\377\377\377\0\377\377\376\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\376\376\0\377\377" +\
    "\377\0\377\377\377\0\377\377\366\0\377\364\341\0\377\320\316\0\377u=" +\
    "\0\377\345\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\351\0\0\377M\0\0\377   \377)))\377***\377\37%,\377" +\
    "\22\37-\377\24#\63\377\27'9\377\31,A\377\35\62J\377 8T\377$\77^\377(" +\
    "Fi\377+Lq\377.Pz\3770U\201\3771W\204\3773Y\211\3773Y\211\3773Y\211\377" +\
    "2X\211\3771U\206\377/S\203\377/R\201\377,O}\377+Ly\377)Iv\377(Gr\377" +\
    "&Do\377$Bj\377!=e\377 :`\377\34\65Z\377\31\61T\377\27-O\377\24(J\376" +\
    "\21!@\373\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20!\77\220\23(I\377\27-P\377" +\
    "\31\61W\377\34\66^\377\37;c\377!\77i\377$Cn\377&Fr\377(Iv\377)Lz\377" +\
    "+N~\377-P\201\377.T\205\3770V\211\3771Y\213\3773[\217\3776_\223\3777" +\
    "`\226\3778c\230\377:e\234\377;i\240\377=j\242\377\77m\245\377@p\250\377" +\
    "Aq\252\377Cs\255\377Dv\257\377Fx\262\377Hz\265\377H|\266\377J}\271\377" +\
    "#\379\377\327'\270\377\377h\377\377\377i\376\377\377i\377\377\377g\377" +\
    "\377\377g\377\377\377o\377\377\377\331\377\377\377\363\377\377\377}\377" +\
    "\377\377d\377\377\377g\377\377\377h\377\377\377j\376\377\376o\377\377" +\
    "\343\10\305\377\302\0\10\377\376\0\0\377\376\0\0\377\372\0\0\377\322" +\
    "\0\0\377\245\0\0\3770\0\0\3770\12\0\377\215y\0\377\327\314\0\377\362" +\
    "\335\0\377\376\357\0\377\377\374\0\377\376\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\376\377\0\377\377\376\0\377\377\371\0\377\372\350\0\377\354" +\
    "\330\0\377\302\275\0\377xI\0\377\314\4\0\377\374\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\275\0\0\377\12\10\10\377&&&\377'('\377)*)\377 %*\377\17\35+\377" +\
    "\26#\62\377\24%\67\377\31+\77\377\34\61I\377 7S\377$>]\377'Dg\377*Jq" +\
    "\377-Ox\377/S~\3771V\203\3772W\205\3772V\210\3772W\207\3770U\204\377" +\
    "/S\203\377-Q\177\377+M{\377,M{\377)Jw\377(Gt\377&Eo\377%Cm\377#\77g\377" +\
    " ;c\377\368^\377\32\63W\377\31.R\377\26*L\377\23&G\377\20\37<\214\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20\36;Q\23%G\377\25*M\376\30/T\377\33\63" +\
    "Z\377\359`\377 <e\377#@k\377%Cp\377&Gt\377(Iw\377*L{\377+O~\377-Q\202" +\
    "\377/T\206\3770V\211\3772Y\214\3773[\220\3775^\223\3776`\226\3778b\230" +\
    "\3779f\234\377;h\237\377=j\242\377>m\244\377@o\247\377Aq\251\377Bs\255" +\
    "\377Du\256\377Ew\260\377Gy\263\3772V\177\377\224\0r\377\377,\360\377" +\
    "\376M\376\377\377J\377\377\377I\377\377\377D\377\377\377<\377\377\377" +\
    "\77\377\377\377\222\377\377\377\256\377\377\377H\377\377\3776\377\377" +\
    "\3779\377\377\377A\377\377\377F\376\377\377K\376\377\377\37\363\377\264" +\
    "\0\215\377\362\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\332\0\0\377" +\
    "\232\0\0\377\24\0\0\377\270\0\0\377\252\12\0\377|7\0\377\241\240\0\377" +\
    "\323\315\0\377\347\331\0\377\363\341\0\377\367\345\0\377\371\352\0\377" +\
    "\372\351\0\377\371\351\0\377\370\351\0\377\366\344\0\377\357\336\0\377" +\
    "\340\326\0\377\312\311\0\377\201o\0\377\217#\0\377\332\1\0\377\374\0" +\
    "\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\351\0\0\377Y\0\0\377\33\33\33\377%%" +\
    "%\377'''\377()(\377(*+\377/02\377<<;\377@AC\3770:F\377\32.G\377\36\65" +\
    "P\377\42<[\377&Ce\377)In\377,Nv\377.Q}\377/T\201\3770U\203\3770V\203" +\
    "\3770T\204\3770S\202\377-Q\177\377,O}\377*L{\377*Jw\377(Ht\377&Fp\377" +\
    "%Cm\377#@j\377!=e\377\379_\377\34\65Z\377\32\61U\377\27-P\377\25)J\376" +\
    "\22$D\377\16\34\66N\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\21#C\377" +\
    "\24(K\377\27-Q\377\32\62W\377\34\65\134\377\36:b\377!>h\377#Ak\377%D" +\
    "p\377'Hu\377(Jw\377*L{\377+N~\377-Q\203\377.T\205\3770V\211\3772Y\214" +\
    "\3773\134\220\3775^\223\3776a\225\3778b\230\377:e\233\377;g\237\377=" +\
    "j\241\377=l\244\377@n\246\377Ap\251\377Bs\254\377Du\255\377Ev\260\377" +\
    ";\17>\377\351\0\301\377\375\31\370\377\377-\377\377\377'\377\377\377" +\
    "!\377\377\377\25\377\377\377\17\377\377\377\14\377\377\377\24\377\377" +\
    "\377\26\377\377\377\14\377\377\377\14\377\377\377\16\377\377\377\21\377" +\
    "\377\377\26\377\377\377\35\377\377\376\1\374\377\375\0\336\377\271\0" +\
    ")\377\377\0\0\377\377\0\0\377\376\0\0\377\374\0\0\377\305\0\0\377H\0" +\
    "\0\377^\0\0\377\352\0\0\377\376\0\0\377\355\0\0\377\333\5\0\377\225\26" +\
    "\0\377l\34\0\377\220R\0\377\226]\0\377\227]\0\377\227^\0\377\224Y\0\377" +\
    "\2025\0\377o\34\0\377\270\20\0\377\343\0\0\377\365\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\376\0\0\377\372\0\0\377\250\0\0\377\12\12" +\
    "\12\377$%$\377%&%\377&'&\377()(\377*++\377///\377454\377;<;\377IIH\377" +\
    "ZZ[\377HR_\377FUg\377FYq\3779Rs\377)Js\377.Oy\377.Q~\3770R\201\377/S" +\
    "\201\377.Q\200\377.P\177\377,O~\377+Lz\377*Jw\377(Ht\377&Fp\377%Dn\377" +\
    "#Ak\377\42>f\377 ;b\377\35\67]\377\32\64W\377\31\60S\377\26,M\377\24" +\
    "&G\377\21 \77\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\20" +\
    "\37=\270\23&H\377\25*N\377\30/S\377\33\64Y\377\35\67_\377\37;d\377!\77" +\
    "i\377$Bm\377%Eq\377'Gt\377(Jx\377+M|\377-P\177\377.Q\202\377.S\205\377" +\
    "0V\211\3771Y\214\3774[\220\3775^\224\3776`\225\3778b\230\3779e\233\377" +\
    ":g\236\377<j\241\377=k\243\377\77m\245\377Ap\250\377Ar\253\3774Z\206" +\
    "\377\204\0f\377\377\0\347\377\377\0\372\377\377\7\377\377\377\2\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\375\377\377\0\362\377\253\0\205\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\355\0\0\377\257\0\0" +\
    "\377\22\0\0\377\230\0\0\377\366\0\0\377\377\0\0\377\376\0\0\377\377\0" +\
    "\0\377\377\0\0\377\375\0\0\377\374\0\0\377\374\0\0\377\374\0\0\377\374" +\
    "\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\306\0\0\377!\1\1" +\
    "\377\37  \377$$$\377$%%\377&'&\377(((\377*+*\377/0/\377343\377:;;\377" +\
    "CDC\377LML\377^_^\377nnm\377\200\200\177\377\232\231\226\377\230\234" +\
    "\241\3771Qz\377,Nz\377.P}\377-P~\377,O~\377+N|\377+Lz\377*Jx\377(Ht\377" +\
    "'Fp\377%Dn\377$Aj\377\42>g\377!<d\377\368_\377\34\65Z\377\31\62U\377" +\
    "\30-O\377\24(I\377\22$D\377\17\36:\263\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\16\33\66q\22$E\377\24(J\377\27-Q\377\31\61V\377\34" +\
    "\65[\377\369a\377 <f\377\42\77i\377$Cn\377%Eq\377'Gu\377)Jx\377+M|\377" +\
    ",P\177\377.Q\202\377/S\206\3770V\211\3772X\214\3773[\217\3775^\222\377" +\
    "5`\225\3778b\227\3779d\232\377:f\235\377;h\237\377=k\242\377>l\244\377" +\
    "\77o\247\377\33/F\377\327\0\255\377\377\0\366\377\377\0\374\377\377\0" +\
    "\375\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377\0\377\377\377" +\
    "\0\374\377\347\0\313\377\325\0\0\377\376\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\331\0\0\377\231\0\0\377\7\0\0\377\261\0\0\377\372\0" +\
    "\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\315" +\
    "\0\0\377B\0\0\377\30\31\30\377#$#\377$%$\377%&%\377&'&\377(((\377+,+" +\
    "\377./.\377454\377:<;\377CDC\377LML\377VWV\377`b`\377kmk\377sus\377\201" +\
    "\204\201\377\242\244\245\377o\177\226\3776U\177\377+Ny\377+M{\377+Kz" +\
    "\377(Iw\377(Ht\377&Fq\377%Dm\377$Aj\377\42\77g\377 =d\377\37:`\377\35" +\
    "\66\134\377\32\62W\377\31/R\377\25*L\377\23&G\377\22\42A\377\15\32\61" +\
    "m\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\21!\77\377" +\
    "\23&G\377\25+N\377\30/S\377\32\63Y\377\34\66]\377\37:b\377 =g\377\42" +\
    "@k\377$Cn\377&Eq\377'Hu\377*Kx\377+M{\377,N~\377.Q\203\377/S\205\377" +\
    "1V\210\3772X\213\3773[\216\3775]\221\3775_\224\3777b\227\3778c\231\377" +\
    ":f\234\377<h\237\377=j\242\377>k\244\3779\30F\377\351\0\304\377\376\0" +\
    "\374\377\377\0\377\377\377\0\376\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\375\0\336\377\267\0\21\377\376" +\
    "\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377\313\0\0\377" +\
    "\206\0\0\377\2\0\0\377\256\0\0\377\364\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\376\0\0\377" +\
    "\375\0\0\377\313\0\0\377C\0\0\377\25\25\24\377\42\42\42\377$$$\377$$" +\
    "$\377%%%\377&'&\377()(\377+,+\377/0/\377454\377;<;\377DED\377MNM\377" +\
    "WYW\377aca\377lmk\377vxv\377~\200~\377\206\211\206\377\231\232\230\377" +\
    "\256\255\252\377,Ly\377*Kx\377)Kw\377(Gt\377'Gr\377%Cm\377$Bl\377#\77" +\
    "h\377!<e\377\37;`\377\36\67]\377\34\64Y\377\32\61U\377\27,N\377\24(H" +\
    "\377\22$D\377\20\37<\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\16\348\260\22#C\376\24)J\377\27-Q\377\31\60U\377" +\
    "\34\64[\377\35\67_\377\37;d\377!=g\377\42@k\377$Bn\377'Eq\377'Gu\377" +\
    "*Kx\377*M|\377,N~\377-Q\202\377/S\204\3770V\210\3771W\213\3772Y\215\377" +\
    "4]\221\3775^\223\3777a\227\3778b\230\3779e\233\377;f\236\377<i\240\377" +\
    "D\26M\377\357\0\313\377\377\0\374\377\377\0\376\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377\0\375\377\377" +\
    "\0\343\377\300\0#\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\372\0\0\377\307\0\0\377U\0\0\377\2\0\0\377\224\0\0\377\342" +\
    "\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377" +\
    "\0\0\377\365\0\0\377\271\0\0\3771\0\0\377\26\26\26\377!!!\377\42#\42" +\
    "\377#$#\377$$$\377%%%\377&'&\377()(\377,,,\377010\377565\377<=<\377E" +\
    "FE\377NON\377YZY\377cec\377lom\377uxv\377~\200~\377\205\210\206\377\212" +\
    "\214\212\377\220\222\216\3772Ov\377(Ht\377(Gs\377&Eq\377&Fp\377$Bl\377" +\
    "#@i\377!>f\377 ;a\377\368^\377\35\65Z\377\32\61V\377\30.P\377\25*L\377" +\
    "\23&F\377\21\42\77\376\16\33\64\255\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\11\22&\67\21\42B\377\23&G\377\26+N\377" +\
    "\30.S\377\32\62X\377\34\65]\377\359a\377 ;d\377\42>h\377#Ak\377$Bn\377" +\
    "&Eq\377'Gu\377)Jx\377*L{\377,N~\377-Q\201\377.R\204\3770U\210\3771W\212" +\
    "\3772Y\214\3773\134\220\3774]\222\3776`\225\3777b\227\3778c\231\377:" +\
    "e\234\377D\25L\377\357\0\313\377\377\0\375\377\377\0\376\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\375" +\
    "\377\377\0\344\377\277\0!\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\376\0\0\377\362\0\0\377d\0\0\377\237\0\221\377\36" +\
    "\0\32\377M\0\0\377\277\0\0\377\357\0\0\377\377\0\0\377\377\0\0\377\376" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\371\0\0" +\
    "\377\322\0\0\377\200\0\0\377\20\5\5\377\33\34\33\377 ! \377\42#\42\377" +\
    "#$#\377###\377$%$\377%&%\377'''\377)*)\377,-,\377121\377787\377>\77>" +\
    "\377FGF\377PQP\377Y\134Z\377dec\377mpn\377vxv\377~\200~\377\204\206\204" +\
    "\377\210\213\210\377\217\221\215\377/Il\377&Eo\377&Do\377%Cn\377%Cm\377" +\
    "$\77h\377!=e\377 ;c\377\369_\377\35\66Z\377\33\63W\377\31/S\377\27,N" +\
    "\377\24(H\377\22#B\377\20\37=\377\11\20!\63\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\17\35:\363\22#C\376\23" +\
    "(I\377\27-Q\377\32\61V\377\33\64Z\377\34\67^\377\37:a\377 <e\377!>i\377" +\
    "$Ak\377%Co\377&Er\377'Ft\377)Iw\377+L{\377+N~\377-P\200\377.R\203\377" +\
    "0T\207\3771V\211\3772X\213\3774[\217\3775]\222\3775_\224\3777a\227\377" +\
    "8b\230\377;\26E\377\353\0\305\377\376\0\373\377\377\0\377\377\377\0\376" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\374" +\
    "\377\374\0\337\377\267\0\24\377\377\0\0\377\377\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\377\0\0\377\371\0\0\377\253\0t\377\337\0\306\377" +\
    "\263\0\234\377_\0Q\377\5\0\0\377g\0\0\377\276\0\0\377\341\0\0\377\371" +\
    "\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\352\0\0\377\312\0\0\377\227\0\0" +\
    "\377\36\0\0\377\23\23\23\377\42\42\42\377!\42!\377##\42\377\42##\377" +\
    "#$#\377$$$\377%%%\377&&&\377(((\377*+*\377./.\377232\3779:9\377@A@\377" +\
    "IJI\377RTR\377\134^\134\377fhf\377npo\377xzx\377~\201~\377\204\206\204" +\
    "\377\205\211\207\377\214\216\212\377(@d\377$Ak\377&Cm\377$Ak\377#>h\377" +\
    "\42>f\377!<c\377\369`\377\35\66[\377\34\63X\377\32/T\377\30,O\377\25" +\
    "*J\377\22%D\377\21!>\376\15\32\64\360\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\15\31\62d\21\42A\377" +\
    "\22&F\377\26*K\377\31/S\377\32\62W\377\35\66\134\377\368`\377\37:b\377" +\
    "\42=f\377\42>i\377$@k\377%Cn\377&Eq\377'Ft\377(Iw\377*Kz\377+M|\377," +\
    "O\177\377-R\202\3770T\205\3770U\210\3771W\212\3772Z\215\3774\134\220" +\
    "\3775^\223\3775`\225\377\25&<\377\334\0\261\377\377\0\370\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376" +\
    "\377\377\0\374\377\353\0\316\377\320\0\0\377\377\0\0\377\377\0\0\377" +\
    "\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\267\0\0\377\366\0\372" +\
    "\377\377\0\366\377\362\0\325\377\314\0\261\377\247\0\214\377\134\0M\377" +\
    "\14\0\3\377)\0\0\377w\0\0\377\256\0\0\377\310\0\0\377\323\0\0\377\325" +\
    "\0\0\377\325\0\0\377\315\0\0\377\272\0\0\377\214\0\0\377F\0\0\377\27" +\
    "\5\5\377\24\24\24\377 ! \377\42##\377\42#\42\377\42#\42\377\42#\42\377" +\
    "\42##\377#$#\377%%%\377%&%\377'''\377)*)\377-.-\377000\377565\377<=<" +\
    "\377CEC\377KMK\377UVU\377^`^\377hji\377prp\377wyx\377|\200}\377\200\204" +\
    "\201\377\203\207\204\377pw|\377\37;b\377$@i\377$@k\377#>h\377\42=e\377" +\
    "!=c\377 :`\377\35\67]\377\34\64Y\377\32\60T\377\30-Q\377\26+L\377\23" +\
    "&E\377\22#A\377\17\36;\377\13\26,a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\17\35:\377\22" +\
    "#C\377\24(J\377\27,O\377\31\60U\377\33\63Y\377\35\67^\377\368`\377 ;" +\
    "b\377!=f\377\42\77h\377#@k\377%Bn\377%Eq\377'Fs\377)Hw\377)Jy\377+M|" +\
    "\377,N\177\377-P\201\377.S\204\3770T\206\3770W\211\3772Y\214\3773Z\216" +\
    "\3774[\220\377'Fn\377\214\0n\377\377\0\354\377\377\0\376\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377" +\
    "\377\377\0\377\377\377\0\377\377\377\0\376\377\377\0\376\377\377\0\364" +\
    "\377\262\0\215\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377\376" +\
    "\0\0\377\376\0\0\377\371\0\0\377\262\0q\377\377\0\377\377\377\0\376\377" +\
    "\377\0\375\377\376\0\351\377\360\0\315\377\325\0\261\377\274\0\232\377" +\
    "\206\0j\377\35\0\25\377\4\4\4\377\30\4\4\377#\3\3\377$\3\3\377$\3\3\377" +\
    " \4\4\377\14\10\10\377\23\23\23\377\36\36\36\377\42##\377##\42\377\42" +\
    "#\42\377\42#\42\377\42\42\42\377\42#\42\377#$#\377#$#\377$$$\377%&%\377" +\
    "&'&\377)))\377+,+\377///\377343\377898\377@A@\377FGF\377OPO\377XYX\377" +\
    "aca\377iki\377oqp\377vyw\377{~|\377\177\202\177\377nuy\377\358]\377#" +\
    ">f\377#@h\377\42\77h\377!<e\377!<b\377 <a\377\379^\377\34\65Z\377\32" +\
    "\61V\377\31/R\377\27,N\377\24'G\377\22$B\377\21 <\377\15\32\64\377\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\15\31\65\205\21!@\377\23%F\376\26*L\377\30" +\
    "-Q\377\32\61W\377\33\64Y\377\35\67^\377\369`\377 ;d\377!<e\377\42>h\377" +\
    "#@j\377%Bn\377%Dq\377'Er\377(Hu\377)Jy\377+Lz\377+N}\377,O\177\377.R" +\
    "\203\377/S\205\3770U\210\3771W\212\3772Y\215\3773[\220\377\77\11;\377" +\
    "\354\0\310\377\377\0\371\377\376\0\377\377\377\0\376\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377" +\
    "\377\0\377\377\377\0\374\377\377\0\343\377\263\0/\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\377\0\0\377\242\0\23\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377\0\377\377" +\
    "\377\0\371\377\377\0\351\377\373\0\325\377\306\0\243\3775\0&\377\36\36" +\
    "\36\377!\42\42\377\42#\42\377###\377#$#\377#$#\377###\377###\377\42#" +\
    "\42\377###\377###\377#$#\377$$$\377#$#\377$$$\377$%%\377%&%\377&'&\377" +\
    "'('\377()(\377++*\377./.\377232\377676\377<=<\377CDC\377KLK\377RTT\377" +\
    "Z\134Z\377cec\377jlj\377prq\377uxv\377|~{\377fns\377\35\66[\377!=d\377" +\
    "#\77g\377\42\77g\377!=e\377!<b\377 ;a\377\379_\377\35\66\134\377\34\63" +\
    "X\377\32\60T\377\27-O\377\25*K\377\22%D\377\21!\77\376\17\36:\377\13" +\
    "\27.\203\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\17\36;\377\22#D\377\24'" +\
    "H\377\26+N\377\30/S\377\32\62W\377\34\65[\377\35\67^\377\369`\377 ;c" +\
    "\377!<e\377\42>h\377#@j\377$Am\377%Dp\377&Fs\377(Gt\377)Ix\377)Kz\377" +\
    "*L{\377+N~\377-Q\202\377.S\204\377/S\206\3771V\211\3770W\211\377 :\134" +\
    "\377\231\0y\377\377\0\346\377\377\0\375\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\375\377\377\0\362\377\265\0\223\377\361\0\0\377\377\0\0\377\377" +\
    "\0\0\377\377\0\0\377\376\0\0\377\377\0\0\377\260\0\0\377\360\0\355\377" +\
    "\376\0\376\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377" +\
    "\377\0\377\377\377\0\374\377\377\0\353\377\271\0\225\377\3\7\13\377 " +\
    "!!\377\42#\42\377#$#\377#$#\377###\377\42##\377\42#\42\377###\377\42" +\
    "#\42\377#$#\377#$#\377$%$\377$%$\377%%%\377$%$\377&&&\377&'&\377()(\377" +\
    ")*)\377+,+\377./.\377232\377575\377;<;\377ABA\377GIH\377NPN\377UXV\377" +\
    "]_]\377dfd\377kmk\377psq\377wyw\377ahn\377\33\63V\377\42<b\377#>f\377" +\
    "\42=e\377!=f\377 <d\377 ;a\377\379_\377\36\67]\377\33\63W\377\32\60U" +\
    "\377\30/Q\377\26+M\377\24'F\377\22#A\377\20\37<\377\15\32\64\377\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\26,\204\21!@\377\22%F\376" +\
    "\25)J\377\27,P\377\31\60T\377\32\63X\377\34\65\134\377\35\67^\377\36" +\
    "9`\377 :b\377!<e\377!>i\377#\77j\377$Al\377&Cp\377'Fr\377'Gt\377(Hv\377" +\
    ")Ky\377*L{\377+N}\377,O\177\377.Q\202\377.S\205\377/S\206\377/U\207\377" +\
    "\31\30.\377\314\0\246\377\377\0\354\377\377\0\375\377\376\0\376\377\377" +\
    "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\377\0\376\377\377\0\376\377\377" +\
    "\0\367\377\344\0\307\377\306\0\12\377\377\0\0\377\377\0\0\377\377\0\0" +\
    "\377\376\0\0\377\377\0\0\377\261\0\0\377\351\0\342\377\376\0\376\377" +\
    "\376\0\376\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377" +\
    "\377\0\376\377\377\0\367\377\351\0\303\3779\1,\377\12\22\35\377\26\32" +\
    "\36\377$$$\377#$#\377###\377\42#\42\377\42#\42\377#$#\377#$#\377$%$\377" +\
    "$$$\377%%%\377%&%\377&&&\377&'&\377'('\377()(\377)*)\377+,+\377---\377" +\
    "000\377333\377787\377;<;\377\77@\77\377DFD\377KML\377QTS\377Z[Z\377_" +\
    "b`\377fhf\377knl\377prp\377cij\377\26,K\377 8]\377!<b\377#=e\377\42=" +\
    "e\377 ;c\377\37:a\377\37:_\377\368^\377\34\64Y\377\32\61U\377\31/S\377" +\
    "\27,M\377\25(H\377\22$C\377\21 =\376\17\359\377\10\23&\201\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\16\348\377\22\42B\377\24&" +\
    "H\377\26*K\377\30-Q\377\31\60U\377\32\62X\377\35\65\134\377\35\67_\377" +\
    "\369a\377 ;c\377!=f\377\42>g\377#@k\377$Ak\377%Cn\377'Dq\377'Fr\377(" +\
    "Hu\377(Ix\377*L{\377+M}\377,O\177\377-P\200\377,Q\202\377.S\204\377," +\
    "R\201\377\34\16$\377\312\0\243\377\377\0\346\377\377\0\373\377\377\0" +\
    "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\376\377\377" +\
    "\0\376\377\377\0\377\377\376\0\377\377\377\0\375\377\377\0\364\377\350" +\
    "\0\316\377\255\0\26\377\377\0\0\377\377\0\0\377\377\0\0\377\377\0\0\377" +\
    "\370\0\0\377\236\0\37\377\357\0\351\377\376\0\376\377\377\0\377\377\377" +\
    "\0\377\377\377\0\377\377\377\0\376\377\377\0\377\377\377\0\376\377\376" +\
    "\0\365\377\355\0\307\377_\0J\377\11\22\33\377\14\25 \377\14\24\36\377" +\
    "!\42\42\377##\42\377#$#\377#$#\377#$#\377$%$\377$%$\377%%%\377&&&\377" +\
    "'''\377(((\377()(\377)*)\377*+*\377+,+\377-.-\377/0/\377121\377454\377" +\
    "787\377:;:\377\77A\77\377CED\377IKJ\377OQP\377VWV\377\134^\134\377bd" +\
    "b\377hjg\377kok\377orp\377LU]\377\33\61R\377 :^\377!=c\377\42;d\377!" +\
    "<c\377\37:b\377\379`\377\37\67]\377\35\65Z\377\34\63X\377\31\60T\377" +\
    "\30-O\377\26*K\377\22%D\377\22\42\77\377\20\36;\377\14\31\61\377\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\24'`\21 " +\
    "\77\377\22$D\377\24'I\377\26*M\377\30.R\377\31\60T\377\32\62X\377\35" +\
    "\65\134\377\36\67^\377 :a\377 ;d\377 =e\377\42>h\377\42\77i\377$@j\377" +\
    "%Am\377&Do\377&Er\377&Gt\377(Hv\377)Ky\377*L{\377*M}\377*N}\377+O\177" +\
    "\377,P\200\377,N~\377\32\27.\377\226\0w\377\354\0\307\377\377\0\353\377" +\
    "\377\0\372\377\377\0\376\377\377\0\377\377\377\0\377\377\376\0\376\377" +\
    "\377\0\372\377\377\0\362\377\376\0\341\377\273\0\241\377\300\0\13\377" +\
    "\377\0\0\377\377\0\0\377\363\0\0\377\337\0\0\377\232\0\0\377\270\0\206" +\
    "\377\377\0\377\377\376\0\377\377\377\0\377\377\377\0\376\377\377\0\377" +\
    "\377\377\0\376\377\377\0\377\377\377\0\371\377\377\0\352\377\335\0\266" +\
    "\377M\0<\377\11\21\32\377\14\25!\377\14\25 \377\13\24\37\377\12\22\35" +\
    "\377\30\34\37\377$$$\377$$$\377$%$\377$%$\377%&%\377&'&\377()(\377)*" +\
    ")\377+,+\377+,+\377-.-\377/0/\377010\377121\377454\377676\3779;9\377" +\
    "<>=\377@AA\377CED\377IJI\377NPN\377TVT\377Y[Y\377^`^\377cfd\377gjh\377" +\
    "knk\377nqo\377EO^\377\35\65W\377 ;a\377\42;b\377!<c\377 ;b\377\369a\377" +\
    "\378^\377\35\66[\377\34\64Y\377\32\61U\377\30.Q\377\26,M\377\24'H\377" +\
    "\22#B\377\20 >\377\16\359\377\10\22$\134\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\15\31\62\334\21!@\376\22$E\377" +\
    "\25(I\377\26+N\377\30.R\377\31\60U\377\32\62X\377\35\66\134\377\368_" +\
    "\377 :a\377 :b\377!<d\377\42=f\377\42>h\377#@k\377$Al\377%Cn\377&Ep\377" +\
    "'Er\377(Gt\377'Hv\377(Jx\377)Kz\377*Lz\377*L{\377*L{\377*Lz\377\33\62" +\
    "Q\3778\7\64\377\205\0j\377\333\0\263\377\354\0\310\377\363\0\322\377" +\
    "\363\0\323\377\352\0\306\377\333\0\261\377\231\0o\377|\0.\377\262\0\0" +\
    "\377\312\0\0\377\247\0\0\377b\0\0\377=\2\3\377\6\11\17\377\34\4 \377" +\
    "\212\0p\377\341\0\272\377\371\0\332\377\377\0\355\377\377\0\364\377\377" +\
    "\0\365\377\377\0\356\377\371\0\332\377\341\0\272\377\207\0l\377\35\4" +\
    "\31\377\12\23\35\377\14\25!\377\14\25 \377\14\25 \377\13\24 \377\13\24" +\
    "\37\377\12\22\35\377\15\22\31\377\42##\377%&%\377&'&\377(('\377***\377" +\
    "++*\377-.-\377/0/\377010\377121\377343\377455\377776\3778:9\377<=<\377" +\
    ">\77\77\377ABA\377EFE\377IKI\377MOM\377RTQ\377WYW\377[^\134\377aba\377" +\
    "dgd\377fig\377ink\377mpm\377\35\63P\377\37\67[\377 ;`\377!:b\377!;c\377" +\
    "\379`\377\379`\377\34\65[\377\34\64X\377\33\62W\377\30/R\377\27,O\377" +\
    "\25)J\377\22%E\377\21!@\377\17\36:\376\13\26.\331\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\13\24/\17" +\
    "\36<\377\22\42@\377\22%F\377\25)K\377\26+N\377\30/R\377\32\61V\377\33" +\
    "\64Y\377\35\66\134\377\379_\377\37:a\377!:b\377\42<c\377\42=e\377\42" +\
    "\77g\377#\77j\377$Ak\377%Cn\377&Dp\377'Eq\377(Fs\377&Ft\377(Hv\377)I" +\
    "x\377)Jx\377)Jw\377(Iv\377(Hs\377'Gq\377\34\64S\377\23\33,\377,\12-\377" +\
    "5\6\61\3774\6\60\377'\10(\377\12\22\36\377\14\26#\377\12\23\36\377\11" +\
    "\21\33\377\10\17\31\377\11\17\31\377\12\23\37\377\14\25\42\377\14\25" +\
    "\42\377\14\25!\377\11\17\30\377\33\6\33\377A\0\61\377\213\0m\377\254" +\
    "\0\212\377\256\0\213\377\214\0n\377@\0\62\377\33\6\32\377\10\17\30\377" +\
    "\14\25!\377\14\25 \377\14\25!\377\14\25!\377\14\25!\377\14\25!\377\13" +\
    "\25 \377\13\23\36\377\10\17\30\377\25\27\32\377'('\377)*)\377*+*\377" +\
    "-.-\377/0/\377120\377343\377565\377687\377899\377;<;\377=>=\377\77A\77" +\
    "\377ACB\377CDC\377GIG\377IKJ\377MPN\377RTR\377UXV\377Z\134Z\377^a^\377" +\
    "adb\377egf\377fih\377ilj\377DO\134\377\36\65W\377 ;^\377!;a\377 :a\377" +\
    "\37:`\377\378_\377\36\67]\377\34\65Z\377\33\62W\377\30/S\377\30.P\377" +\
    "\25*L\377\23'G\377\22#B\377\20\37=\377\16\33\66\377\3\7\17+\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\13\25)\232\20 >\377\22#B\376\23&G\377\25)K\377\30-P\377\31/S\377" +\
    "\32\61V\377\36\65Z\377\36\67\134\377\378_\377!9a\377!;b\377!;c\377#=" +\
    "f\377$\77h\377$\77i\377%Ak\377$Bl\377&Dn\377&Dp\377'Dq\377&Fs\377&Gs" +\
    "\377)Ht\377(Ht\377'Gs\377'Fp\377%Cl\377#Ah\377!=c\377 9\134\377\36\64" +\
    "U\377\32/K\377\30+D\377\24&<\377\22!\65\377\21\36\60\377\17\33+\377\16" +\
    "\31(\377\15\27%\377\14\26#\377\14\25\42\377\14\25!\377\13\24 \377\13" +\
    "\25!\377\13\25!\377\13\24 \377\10\20\31\377\10\17\30\377\10\17\30\377" +\
    "\11\20\31\377\13\24\37\377\14\25!\377\14\25!\377\14\25!\377\14\25!\377" +\
    "\14\25!\377\14\25!\377\14\25!\377\14\25!\377\14\25!\377\13\23\37\377" +\
    "\10\17\31\377\32\34\36\377)*(\377+,+\377./.\377000\377243\377566\377" +\
    "888\377:;:\377<>=\377>\77>\377ABA\377BCB\377DED\377GHF\377IKI\377KML" +\
    "\377OPO\377RSR\377UYW\377X[Y\377\134^]\377_a`\377aeb\377dfe\377fig\377" +\
    "U\134`\377\33\63U\377 8]\377 :_\377!;`\377\379a\377\35\67^\377\36\67" +\
    "]\377\35\65Z\377\33\63X\377\31\61U\377\30.R\377\26+N\377\24'I\377\23" +\
    "$E\377\21!@\377\16\36:\377\11\22%\230\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\15\31\62\363\20 >\376\22#B\377\23&G\377\27*M\377\27-P\377\31/S\377\34" +\
    "\62V\377\36\65Z\377\36\66\134\377\378^\377 9`\377!:b\377\42<c\377#=e" +\
    "\377#>g\377$\77h\377%@j\377%Ak\377&Cm\377%Cn\377%Co\377&Dq\377'Ep\377" +\
    "&Eq\377&Dp\377&Co\377$Bk\377#@g\377!<a\377\368[\377\34\64S\377\32.K\377" +\
    "\26*D\377\24%=\377\22\42\66\377\21\36\61\377\17\34,\377\16\31)\377\15" +\
    "\27&\377\14\26#\377\14\26#\377\14\25\42\377\14\25\42\377\14\25\42\377" +\
    "\13\25!\377\13\25!\377\14\25\42\377\14\25!\377\14\25\42\377\14\26\42" +\
    "\377\14\25\42\377\14\25\42\377\14\25\42\377\14\25!\377\14\25\42\377\14" +\
    "\25\42\377\14\25\42\377\14\25\42\377\14\25\42\377\14\25\42\377\13\24" +\
    " \377\10\17\31\377\35\36\37\377+,+\377./.\377121\377454\377687\377:;" +\
    ":\377<><\377\77A\77\377BCB\377CED\377FGF\377HIH\377JKJ\377KML\377NPO" +\
    "\377PRR\377RUS\377UXV\377YZY\377Z]\134\377]`^\377^a`\377aca\377`ca\377" +\
    "Y^`\377\35\63T\377 8[\377\42:a\377 ;a\377\378`\377\36\67^\377\35\65\134" +\
    "\377\34\64Y\377\33\62W\377\32\61U\377\30/R\377\26+N\377\24)K\377\23%" +\
    "E\377\22#A\376\17\36;\376\14\27\60\361\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\4\13\24/\17\349\377\22!>\377\22#C\377\24'G\377\26*M\377\27" +\
    "-O\377\33\61T\377\34\63X\377\34\64Y\377\36\66\134\377 9^\377!:a\377#" +\
    "<c\377#<d\377#=d\377#>f\377$\77h\377%\77i\377%Aj\377$Ak\377%Bl\377%C" +\
    "n\377&Bm\377&Cn\377$Bl\377$Aj\377$@i\377#=e\377!;_\377\378Z\377\34\63" +\
    "S\377\32/K\377\30+E\377\25'>\377\23#8\377\21\37\63\377\17\34.\377\16" +\
    "\32*\377\16\31(\377\15\30&\377\14\27%\377\14\26$\377\14\26#\377\14\26" +\
    "#\377\14\26#\377\14\26#\377\14\26#\377\14\26#\377\15\27$\377\14\26$\377" +\
    "\14\26#\377\14\26#\377\14\26#\377\14\26#\377\14\26#\377\14\26#\377\14" +\
    "\26#\377\14\26#\377\15\26$\377\15\26$\377\14\25!\377\10\17\32\377#$$" +\
    "\377.//\377121\377465\377898\377;<:\377>@>\377BCB\377EFD\377GHG\377I" +\
    "JJ\377KML\377NON\377OQO\377QSR\377RTT\377TWU\377UXV\377VYX\377Y\134Z" +\
    "\377Z][\377[^\134\377]`^\377_b_\377Y]]\377\42\67V\377 8]\377\42:`\377" +\
    "!9a\377 8_\377\36\67]\377\35\66[\377\35\65Z\377\34\64X\377\33\62V\377" +\
    "\31/S\377\26,N\377\25*L\377\23&G\377\22#D\377\20 =\377\16\33\67\377\3" +\
    "\7\21+\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\17\37\205\17" +\
    "\36<\377\21 >\377\23%D\377\24(H\377\26*M\377\31.Q\377\33\61T\377\34\63" +\
    "W\377\37\64Y\377\36\66[\377 8^\377\42;a\377#;b\377#<d\377$=d\377#>f\377" +\
    "%\77g\377%@i\377%@j\377%Aj\377%Ak\377%@k\377$Bj\377%Bk\377$Ai\377#\77" +\
    "g\377\42<c\377!:_\377\378Z\377\35\63S\377\32/M\377\30+F\377\25'@\377" +\
    "\24$:\377\22!\66\377\20\36\60\377\17\34-\377\17\33+\377\16\31(\377\15" +\
    "\30'\377\15\30&\377\15\27%\377\15\27&\377\15\30&\377\15\30&\377\15\30" +\
    "&\377\15\30&\377\15\30&\377\15\30&\377\15\30&\377\15\30&\377\15\30&\377" +\
    "\15\30&\377\15\30&\377\15\30%\377\15\30&\377\15\30&\377\15\30'\377\15" +\
    "\27&\377\14\26#\377\10\20\33\377++*\377121\377565\3779:8\377<=<\377@" +\
    "A@\377DED\377GHG\377JKJ\377KNL\377MON\377PRP\377PSQ\377RUS\377SUT\377" +\
    "TWU\377UWW\377WZX\377Y[Z\377Y\134[\377Z\134Z\377\134`]\377SYZ\3776EX" +\
    "\377\35\65Y\377\429_\377\42:`\377!9`\377 9`\377\36\67]\377\35\66[\377" +\
    "\35\64Y\377\34\64X\377\32\61U\377\31/T\377\27,P\377\25*L\377\23'H\377" +\
    "\22#D\377\20 \77\377\17\36=\377\7\16\35\201\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\25*\313\20\35:\376\21!\77\376" +\
    "\22$C\377\25'G\377\27+L\377\31.Q\377\33\60T\377\34\62U\377\36\65Z\377" +\
    "\37\67]\377!9^\377\42:a\377#<b\377%=d\377%=e\377%\77f\377%\77g\377&@" +\
    "h\377&@h\377%@h\377%Ai\377%Ai\377$@h\377$\77g\377#>e\377\42=b\377!:^" +\
    "\377\37\67Y\377\35\64T\377\32\60O\377\31-H\377\27)C\377\25&=\377\23#" +\
    "8\377\22 \64\377\20\36\60\377\20\34.\377\17\33+\377\16\32*\377\16\32" +\
    ")\377\16\31)\377\16\31)\377\16\31)\377\16\32)\377\16\32)\377\16\32)\377" +\
    "\16\32*\377\16\32*\377\16\32)\377\16\32*\377\16\31)\377\16\31)\377\16" +\
    "\31)\377\16\31(\377\16\31(\377\16\31)\377\16\32)\377\16\31)\377\15\30" +\
    "&\377\11\21\34\377120\377565\3778:9\377=>=\377@BA\377DFE\377GHG\377J" +\
    "LK\377MOM\377NQO\377PRQ\377RUS\377SUT\377SVV\377UWV\377UXW\377VYW\377" +\
    "WYX\377WYX\377Y[Y\377KRW\377,>V\377\37\66[\377#:^\377\429_\377\42;`\377" +\
    "!9_\377 8^\377\378^\377\36\66\134\377\35\65[\377\33\62W\377\33\62U\377" +\
    "\31/S\377\27-P\377\25*L\377\23'H\377\22#C\377\20 \77\376\17\36<\376\12" +\
    "\24+\310\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\14\27/\365\20\36:\376\21!\77\376\22$C\377\25(H\377" +\
    "\30+L\377\32/Q\377\33\61T\377\35\63V\377\37\65Y\377 8\134\377\42:_\377" +\
    "\42:`\377$=b\377&>d\377%=d\377%\77g\377&\77g\377'@h\377%\77g\377&@g\377" +\
    "%\77f\377%\77g\377$>f\377#=c\377\42<a\377!:^\377\37\67Z\377\36\65U\377" +\
    "\34\62Q\377\32.K\377\30+F\377\26'@\377\25$<\377\23\428\377\22 \65\377" +\
    "\21\36\62\377\21\36\60\377\20\35/\377\17\34.\377\20\35.\377\17\34-\377" +\
    "\20\34-\377\20\35.\377\20\35.\377\20\35.\377\20\35.\377\20\35.\377\20" +\
    "\35.\377\20\35.\377\20\34-\377\20\34-\377\20\34-\377\20\34-\377\17\34" +\
    "-\377\20\34.\377\20\35.\377\20\34-\377\16\31)\377\13\23\36\377675\377" +\
    "8:9\377<=<\377\77A@\377CEC\377GIG\377JLK\377LON\377OQP\377RSR\377SUT" +\
    "\377SVU\377TVV\377TWV\377TWW\377TXW\377TWW\377UXX\377QUV\377\42\62K\377" +\
    "\37\66X\377#9]\377#;a\377#<b\377\42:a\377\42:`\377 8_\377\378^\377\36" +\
    "\67]\377\36\65Z\377\34\63X\377\33\62V\377\32\60S\377\27,P\377\25)M\377" +\
    "\23&H\377\22#C\377\21!@\376\17\36<\376\14\30\61\362\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\1\7\16$\14\30\60\377\17\35:\376\22!\77\377\23%C\377\26)I\377\30,L" +\
    "\377\32.P\377\34\61T\377\37\64X\377 6Z\377!8\134\377#9^\377$;a\377%>" +\
    "c\377%=d\377'>e\377'@f\377'@h\377'\77g\377'@h\377'@g\377%\77f\377&\77" +\
    "e\377$=d\377$<b\377\42;_\377 9\134\377\36\65W\377\35\62S\377\34\61N\377" +\
    "\32.J\377\30*E\377\26(@\377\25%=\377\24#9\377\23\42\67\377\22 \65\377" +\
    "\22\37\64\377\21\37\63\377\21\37\63\377\22 \63\377\21 \63\377\22 \64" +\
    "\377\22 \63\377\22 \64\377\22 \64\377\22 \64\377\22 \64\377\22 \64\377" +\
    "\22 \63\377\22\37\63\377\21\37\62\377\21\37\62\377\21\37\62\377\22\37" +\
    "\63\377\22 \63\377\22\37\62\377\20\34-\377\17\27#\377:;:\377<==\377\77" +\
    "A\77\377BDD\377FHG\377HJJ\377LNN\377NPO\377PRR\377QTT\377SVV\377SVU\377" +\
    "TWW\377UVW\377SVV\377RUU\377SVW\377SVV\377JOT\377\37\65W\377$;_\377%" +\
    "=c\377$=c\377\42:`\377#;`\377!9`\377 7^\377\36\65[\377\36\66[\377\35" +\
    "\64Y\377\32\61U\377\32/T\377\30-Q\377\25*M\377\23'H\377\22#D\377\21!" +\
    "@\377\17\37=\376\15\31\64\377\3\6\16!\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\10" +\
    "\23H\15\31\63\377\17\36:\376\22!\77\377\23$D\377\26)I\377\31,L\377\31" +\
    ".O\377\35\62T\377\36\64X\377!6Z\377\42\67\134\377%;_\377&<a\377'>b\377" +\
    "(\77e\377'\77e\377(\77e\377(@g\377(Ah\377(Ag\377(@g\377&\77e\377&>c\377" +\
    "%=b\377#;_\377\429\134\377!6X\377\37\64U\377\35\62Q\377\34/M\377\33-" +\
    "I\377\31+E\377\30)A\377\26'\77\377\25%<\377\25$;\377\24$9\377\24#9\377" +\
    "\24#8\377\24#8\377\24#8\377\24#8\377\25#9\377\24#9\377\24$:\377\25$:" +\
    "\377\25#:\377\24#9\377\24#9\377\24#8\377\24\428\377\24\428\377\24#\67" +\
    "\377\24#8\377\24#8\377\24\42\67\377\22\37\62\377\23\34(\377=>=\377>@" +\
    "\77\377ACB\377DFE\377HJI\377JML\377LNN\377NQQ\377QSS\377QTT\377RTT\377" +\
    "SUV\377SUV\377QUV\377QTU\377PTT\377PTT\377QRS\3774AT\377%:^\377%=c\377" +\
    "&<b\377%<b\377#;a\377\42:`\377!9^\377 7]\377\37\65[\377\35\64X\377\33" +\
    "\62V\377\33\60T\377\30-Q\377\25*L\377\24&H\377\22$D\377\21\42B\377\17" +\
    "\37>\376\16\339\377\5\11\25C\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\6\15\33m\15\32\64\377\17\359\377\22!>\377\23$B\377\27)H\377\31," +\
    "M\377\33.O\377\36\62T\377 4W\377\42\67Z\377#9]\377&;`\377&=a\377(>c\377" +\
    "*Ae\377)@f\377*Ah\377(@f\377)Ag\377)Ag\377)@g\377)@e\377'\77c\377&=b" +\
    "\377$;^\377#9[\377\42\66X\377 4U\377\36\62Q\377\35\60N\377\33.K\377\33" +\
    ",G\377\31+E\377\30*C\377\27(A\377\30(@\377\27(\77\377\27'\77\377\27'" +\
    "\77\377\27'\77\377\27(@\377\27(@\377\27(@\377\27(@\377\27(@\377\27(@" +\
    "\377\27(@\377\27'@\377\27'\77\377\27'\77\377\27'>\377\27'>\377\27'\77" +\
    "\377\27'\77\377\27&<\377\24!\65\377\27\37+\377@BA\377@CC\377CEE\377E" +\
    "HH\377HJJ\377JMM\377LPP\377NRQ\377PRS\377PST\377QTU\377QTU\377PST\377" +\
    "PST\377NQS\377NQR\377NQR\377=FS\377%:^\377&=d\377&=c\377&>e\377$<c\377" +\
    "\42;b\377!9`\377!8^\377\37\66\134\377\36\65Z\377\33\62W\377\32\60U\377" +\
    "\30.Q\377\26*M\377\24'I\377\22$E\377\21\42B\376\17\37>\377\16\34:\377" +\
    "\7\16\36g\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\5\14\27\203\15\32\65\377\17\359\377\21 =\377\23$A\377\27)H\377\31+K" +\
    "\377\34/P\377\37\63T\377!6X\377#7Z\377$:]\377';`\377'>b\377)\77d\377" +\
    "+Ae\377,Bg\377+Af\377*Bh\377+Bg\377*Af\377*Ag\377*Af\377*@d\377(>b\377" +\
    "&<_\377%9[\377\42\67X\377!6U\377!4S\377\37\62P\377\35\61M\377\35.J\377" +\
    "\34-I\377\34-H\377\33,F\377\33+F\377\32+E\377\32,F\377\32+F\377\32+E" +\
    "\377\33,G\377\33,G\377\32,G\377\33,G\377\33,G\377\32,F\377\32,G\377\33" +\
    ",G\377\32+E\377\32+E\377\32+D\377\33+F\377\32+D\377\31)A\377\27$8\377" +\
    "\33\42-\377BDD\377BED\377EGG\377FII\377HKL\377JMN\377LOP\377MPQ\377N" +\
    "QS\377OQS\377PRT\377NQS\377MPR\377LOQ\377KNO\377LNP\377AHR\377&<_\377" +\
    "(>d\377(@e\377'\77f\377%=d\377#;b\377#:a\377!8^\377\37\65[\377\36\64" +\
    "Z\377\34\63X\377\33\61U\377\30-Q\377\25)L\377\24'I\377\22$E\377\21!B" +\
    "\377\17\37>\377\17\35;\377\6\14\31}\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\15\32\217\14\31\63\377\16" +\
    "\358\377\21 <\377\23$A\377\26(F\377\31+J\377\34.O\377\37\62T\377!6W\377" +\
    "$8[\377&;^\377'<_\377*\77c\377+Ae\377-Bg\377,Cg\377,Bg\377-Ch\377-Cg" +\
    "\377,Ch\377,Bg\377+Ae\377+Ae\377*@c\377(=`\377'<^\377%:[\377#8X\377\42" +\
    "\65T\377!5S\377 3P\377 1O\377\36\61M\377\37\60M\377\36\60K\377\36\60" +\
    "L\377\36\60L\377\36\60L\377\36\60L\377\36\61M\377\36\61M\377\36\61M\377" +\
    "\36\61M\377\36\61M\377\37\61M\377\36\60M\377\36\60K\377\36\60L\377\36" +\
    "\60L\377\36\60L\377\36\60K\377\36/I\377\34,D\377\31%:\377(,3\377BEF\377" +\
    "CFG\377EGJ\377GIK\377IKM\377JMO\377KNQ\377KOQ\377MPR\377LOR\377KNR\377" +\
    "LOR\377KNQ\377IMP\377HKO\377DHM\377)>_\377)\77d\377*@g\377)@g\377'>f" +\
    "\377%=e\377$<c\377!9_\377!8^\377\37\65\134\377\34\64X\377\33\60U\377" +\
    "\27-Q\377\25*M\377\24'I\377\22$E\377\21\42C\377\17\37<\377\16\34:\377" +\
    "\6\17\36\207\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\14\32\213\14\31\63\377\16\34\67" +\
    "\377\21 <\376\23#@\377\27(G\377\32,K\377\35/P\377 3T\377#7Y\377%9\134" +\
    "\377'<_\377)>a\377,@d\377-Bf\377.Dh\377/Di\377/Ci\3770Di\377/Ei\377/" +\
    "Ei\377.Dh\377-Cg\377-Be\377,@d\377+\77c\377*>`\377(<^\377(;[\377&9Y\377" +\
    "%8X\377$7V\377#5T\377\42\66S\377\42\65S\377\42\65R\377\42\65R\377\42" +\
    "\65R\377\42\65R\377\42\65S\377\42\65S\377\42\66S\377\42\65S\377#7T\377" +\
    "\42\66S\377#6S\377\42\66S\377#5R\377\42\65R\377\42\65R\377\42\65Q\377" +\
    "\42\63O\377 /G\377\34':\3779;>\377EGI\377EHI\377FJL\377GKM\377ILN\377" +\
    "JMP\377JNP\377KNQ\377JMQ\377JMQ\377JMP\377HLP\377HKN\377GJM\377EHK\377" +\
    "-@`\377+Bg\377+Ah\377)Ah\377(Ah\377'>f\377%<c\377#:a\377!9_\377\37\66" +\
    "\134\377\36\64Z\377\33\60U\377\27-Q\377\26*M\377\23'J\377\22%E\377\21" +\
    "\42B\376\17\37=\377\16\35;\377\7\17 \204\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\5\12\26}\15\31\64\377\16\33\66\376\21\37;\377\22\42\77\377" +\
    "\27'E\377\30+J\377\36\60P\377!3T\377#5W\377&9[\377(<_\377*>a\377,Ad\377" +\
    "/Cg\3770Eh\3771Fj\3771Fk\3772Gl\3773Gm\3773Hm\3771Gl\3771Gm\3770Fk\377" +\
    "0Ch\377.Cg\377-Ae\377,@c\377*\77a\377)>^\377)<^\377(<]\377';[\377(<[" +\
    "\377(<[\377';Z\377(;Z\377'<[\377';Z\377';Z\377(;[\377(<[\377(;[\377(" +\
    "<[\377(;Z\377(;Z\377';Z\377)<Z\377(;[\377(:Y\377(9W\377%3M\377*1>\377" +\
    "CEJ\377EIK\377EHL\377GIN\377GKO\377ILP\377ILP\377IMP\377IMQ\377HKP\377" +\
    "HLP\377FJO\377CGL\377@FO\377BFL\3772C`\377-Ci\377.Dk\377+Ck\377+Bi\377" +\
    "(\77g\377&=d\377$<c\377\429`\377\37\67]\377\35\64Z\377\32\60U\377\27" +\
    "-R\377\25*M\377\23(J\377\22$E\377\21!B\377\17\37=\376\16\36>\377\6\15" +\
    "\33v\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\12\25" +\
    "f\14\30\62\377\15\32\64\376\20\369\376\22!>\377\26&D\377\31*I\377\36" +\
    "/N\377!3T\377$6W\377'9\134\377)<^\377,\77b\377/Bf\3771Eh\3772Fk\3773" +\
    "Gl\3774Im\3774In\3775Jn\3775Ko\3774Io\3774In\3774Im\3773Gk\3771Ei\377" +\
    "0Ei\3770Cg\377/Cf\377/Ce\377-Bd\377-Ac\377.Ab\377-Ac\377,Ab\377-@a\377" +\
    "-Ab\377,Ab\377-Ab\377-Ac\377-Ab\377.Bc\377.Bd\377.Bc\377-Ab\377-Ac\377" +\
    "-Ac\377.Bc\377.Ab\377-\77]\377*9T\3776;E\377FIM\377FIO\377HKP\377HKP" +\
    "\377HLR\377ILQ\377ILQ\377ILR\377HKQ\377GKP\377FJO\377FIN\377>CN\377." +\
    "Ac\3770Ej\3770Fm\377.El\377-Dl\377,Bj\377)@h\377'\77f\377%<d\377#:a\377" +\
    "!7^\377\35\64Z\377\32\60U\377\27-R\377\24)M\377\23&I\377\22#E\377\20" +\
    "!A\376\17\36=\376\16\35;\377\5\12\27`\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\10\21;\13\27\60\375\15\32" +\
    "\63\376\17\358\377\21!=\377\25&C\377\30)H\377\36/O\377\42\64T\377$6X" +\
    "\377':[\377*<_\377-@d\3770Dg\3772Fj\3774Hl\3776Jn\3776Ko\3776Kp\3777" +\
    "Lq\3777Lp\3776Kp\3777Lq\3776Ko\3776Ko\3774Im\3775Im\3774Gj\3773Gk\377" +\
    "4Gk\3773Fj\3772Gi\3772Fi\3772Fh\3772Eg\3773Gi\3772Fi\3772Fi\3772Fi\377" +\
    "3Gj\3773Gi\3773Gj\3773Gj\3773Gj\3774Hj\3774Hj\3774Gj\3774Fg\3773Dc\377" +\
    "0=Z\377\77DO\377GKQ\377HMR\377HLR\377IKS\377ILS\377HLR\377ILS\377HLR" +\
    "\377GLR\377FJP\377FJO\377DGM\377BFK\3770Fj\3772Hn\3771Go\3770Fm\377-" +\
    "Dl\377*Aj\377)\77h\377&<e\377#:b\377 7^\377\35\63Z\377\32\60U\377\26" +\
    ",Q\377\24(L\377\23&I\377\22#D\377\20!A\377\16\36=\376\16\33:\374\3\10" +\
    "\20\66\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\33\12\25,\351\14\31\65\377\16\33\66" +\
    "\377\21 ;\377\23#@\377\27)G\377\34-M\377!3R\377%7X\377);]\377,>b\377" +\
    ".Bd\3771Dg\3774Fk\3775Im\3778Kq\3778Mr\3779Mr\377:Nt\377:Ot\377:Ou\377" +\
    ";Pu\377:Ot\3779Ns\3779Ms\3779Nr\3778Mp\3778Lp\3777Lo\3777Ko\3778Ln\377" +\
    "7Ko\3777Jm\3777Ko\3777Ko\3777Ko\3777Ko\3778Lp\3779Lp\3778Lp\3778Mp\377" +\
    "9Lo\3779Lo\3779Lp\3779Mp\377:Lo\3779Jj\3775C`\377DJT\377JMU\377JMT\377" +\
    "IMU\377INU\377ILT\377HLS\377HLS\377ILS\377GKQ\377EIP\377EHN\377BDI\377" +\
    "7Hf\3774Ip\3772Ho\3770Fn\377-Dm\377+Bi\377(\77g\377&=d\377#:a\377 6]" +\
    "\377\34\62Y\377\31/T\377\25,P\377\23(L\377\22%H\377\21#D\377\20 @\377" +\
    "\17\36>\377\14\31\65\346\0\0\0\30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\11\23'\266\15\32\66\377\15\32\65\376\20\359\376\21!>\377\25" +\
    "%D\377\33,J\377\37\62Q\377$6W\377)<]\377,\77a\3770Cf\3771Ej\3775In\377" +\
    "7Kp\3778Lr\377:Nt\377<Pv\377<Qv\377<Qw\377>Sx\377=Qx\377=Rx\377=Rw\377" +\
    "=Qv\377=Qx\377=Qv\377<Qv\377<Pu\377;Pu\377;Pt\377<Ot\377;Ot\377<Pt\377" +\
    "<Ou\377<Qu\377<Pv\377=Qv\377=Qv\377=Qv\377>Qv\377>Rv\377\77Ru\377\77" +\
    "Sv\377\77Ru\377>Oq\377:Ig\377FKY\377KNW\377JNW\377KPW\377JNW\377IMV\377" +\
    "IMU\377HLT\377FJR\377EHO\377DHO\377>I]\3777Kn\3775Kr\3774Ip\3771Ho\377" +\
    ".Fn\377,Cj\377)@g\377&=d\377\429`\377\36\64\134\377\32\60V\377\27,R\377" +\
    "\25*O\377\22'K\377\22%H\377\21#D\376\20 A\376\20 B\377\12\25,\261\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\13" +\
    "\30i\14\30\63\377\15\31\63\376\16\34\67\377\20\37:\377\23#A\377\30(G" +\
    "\377\35\60O\377\42\64V\377(:]\377,\77a\377/Cf\3773Gl\3776Io\3778Mr\377" +\
    "<Pv\377=Rx\377<Qx\377\77Sz\377\77T{\377@T|\377@T{\377\77Tz\377\77Sz\377" +\
    "\77Sz\377\77Sx\377@Ty\377\77Ty\377\77Ux\377@Tx\377@Ty\377\77Tx\377@T" +\
    "y\377\77Tx\377@Uz\377@Ty\377AVy\377AUz\377AUz\377BV{\377BV|\377BV{\377" +\
    "CV|\377BUz\377BSu\377=Lj\377FM[\377LPY\377KOX\377LPW\377JOX\377JNV\377" +\
    "IMV\377GKT\377GKS\377>Jc\377:Ou\3779Nu\3777Mt\3775Kr\3772Hq\3770Fm\377" +\
    ",Cj\377*@g\377%<c\377 6]\377\33\61X\377\27-R\377\25*O\377\23(L\377\22" +\
    "%I\377\21#E\377\20!B\377\17\37@\376\16\35<\377\6\15\33f\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\33\13\26/\326\14\32\67\377\16\33\66\377\17\36:\376\22!\77\377" +\
    "\24%D\377\32+J\377\37\62S\377&9\134\377+\77b\3770Ch\3773Hl\3776Io\377" +\
    "8Mt\377<Pv\377>Ry\377\77Tz\377@T{\377@T|\377AV~\377BV}\377BV~\377BV}" +\
    "\377BW~\377CW~\377BW|\377CX}\377CW|\377DW}\377CW|\377CX|\377DW}\377D" +\
    "W}\377DX~\377DX~\377EX}\377EX}\377EW}\377GY}\377FZ\177\377GZ\177\377" +\
    "EW|\377EUw\377@Ok\377GN\134\377LPZ\377LPZ\377KPY\377JNW\377INV\377HM" +\
    "U\377HKS\377;Jh\377;Os\377:Ov\3778Nu\3775Ks\3772Hp\377/El\377,Bi\377" +\
    "'=d\377\42\67^\377\34\62X\377\27-S\377\25+O\377\23(L\377\22%J\377\21" +\
    "$G\377\21\42D\376\20 A\376\17 C\377\15\32\67\321\0\0\0\27\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\6\15\35}\13\32\66\377\15\32\66\377\16\34" +\
    "8\377\20\37<\377\22\42B\377\26(G\377\34.O\377\42\65X\377)<_\377-@f\377" +\
    "3El\3775Io\3778Lr\377;Ov\377>Qy\377@Sz\377BV|\377AW|\377AU|\377BV}\377" +\
    "CW}\377CW}\377DW~\377DX~\377EX~\377EX~\377DX~\377FY\177\377FY\177\377" +\
    "FY\177\377FY\177\377FZ\200\377GZ\200\377FZ\200\377GZ\200\377GZ\200\377" +\
    "FZ\200\377G[\177\377G[\177\377GZ~\377DUw\377ANk\377HM]\377LP[\377KNY" +\
    "\377JNW\377JOX\377JMV\377HLT\377GJR\3779Jk\377:Mr\3777Mt\3775Jq\3771" +\
    "Fm\377-Ci\377(=d\377\42\67]\377\34\62X\377\30-S\377\25*O\377\23'L\377" +\
    "\22%I\377\22$G\377\21\42D\377\20 B\377\17\37@\377\16\36@\377\6\17\37" +\
    "x\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\24\12\24)\300\16\339\377\14\32\65\376\17\35:\377\21!\77\377\24$E\377" +\
    "\27)K\377\34\60Q\377\42\66Z\377)<`\377/Bg\3773Fl\3776Jp\3779Nt\377=P" +\
    "v\377>Ry\377\77Sz\377\77Sy\377BV|\377CV}\377CV}\377CV}\377DW}\377DX~" +\
    "\377DX~\377FX~\377EX~\377EX~\377EW~\377FY\177\377FY\177\377FY~\377FY" +\
    "\177\377GZ\200\377H[\201\377GZ\201\377H[\200\377G[\200\377FX|\377EUt" +\
    "\377HPf\377QT_\377KPY\377KOZ\377JNW\377JNW\377HMU\377HKR\377AHV\3776" +\
    "Gj\3775In\3772Fl\377-Bh\377';a\377!6[\377\34\61V\377\27,Q\377\25)M\377" +\
    "\23(K\377\22%I\377\22$F\377\20\42D\377\20 A\377\17\37@\376\20 C\377\13" +\
    "\27/\274\0\0\0\23\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\7\17A\11\25+\343\15\34:\377\15" +\
    "\349\376\17\36=\377\22\42A\377\23$F\377\27*L\377\32.R\377\37\63X\377" +\
    "&9^\377,@e\3771Dk\3775Io\3779Mr\377;Ou\377>Qw\377>Qx\377@Sy\377@Ty\377" +\
    "ATy\377BU|\377CW{\377DW|\377DX{\377EX}\377EX}\377EX~\377EY~\377GY~\377" +\
    "EX~\377GY~\377FY\177\377FY~\377GY\177\377GZ\177\377EW}\377EUy\377BQq" +\
    "\377DMb\377OS]\377KOY\377JNW\377IMV\377HKR\377EIP\377CFK\377.<X\377," +\
    ">`\377)=a\377$8]\377\36\63X\377\31.S\377\26+O\377\24(M\377\22&J\377\22" +\
    "$G\377\22#E\377\20\42C\377\20 A\377\17\37\77\376\17 C\377\13\27\61\337" +\
    "\3\6\15\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\10\21" +\
    "^\12\26/\354\16\35=\377\16\35;\376\20\37>\377\21\42C\377\23$F\377\25" +\
    "'J\377\31,O\377\35\60U\377!4Y\377':_\377,\77e\3771Di\3775Hm\3778Jo\377" +\
    "9Lq\377;Nr\377=Pt\377>Pu\377@Rw\377\77Rw\377@Rx\377BTy\377CUy\377BVz" +\
    "\377CUz\377CVz\377DV{\377DV{\377DVz\377CV{\377DV|\377CU{\377DVz\377A" +\
    "Sv\377\77Nn\377BJ[\377HLT\377FIQ\377DHO\377AEL\377\77CI\377=@D\377-3" +\
    "=\377\37.K\377\35/P\377\32.Q\377\27+O\377\24(L\377\23&J\377\22%G\377" +\
    "\22#F\377\21\42D\377\20 A\377\17\37\77\377\17\36>\376\17\37B\377\13\30" +\
    "\63\354\2\7\20\134\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\5\2\5\14\201\12\25,\345\17\37@\377\16" +\
    "\35=\377\20\37>\377\20 A\377\21#D\377\22%F\377\25(J\377\31+N\377\33/" +\
    "S\377 3X\377\42\66Z\377':^\377+>b\377.Ad\3771Cg\3774Fi\3776Hl\3777Im" +\
    "\3777Jn\377:Lo\377:Lq\377:Mq\377;Mq\377=Nr\377<Os\377<Nr\377<Or\377;" +\
    "Nr\377:Lq\377;Mp\3779Kp\3776Hk\3774Dd\3778@P\377=@E\377;>B\3777;>\377" +\
    "58:\377145\377031\377\32$\65\377\24$A\377\23%E\377\23&G\377\22$E\377" +\
    "\22#E\377\20!B\377\20!A\377\20\37\77\377\16\36<\376\16\35=\377\17\37" +\
    "@\377\12\25-\345\2\5\13\204\0\0\0\7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\25\0\2\5~\7\17!\350\16\35\77\376\17\36>\377\16\36=\376\17 \77\377" +\
    "\21 A\377\21\42C\377\23%E\377\23%F\377\24'H\377\26)K\377\31,M\377\34" +\
    ".P\377\36\60S\377!3V\377#5W\377%6Y\377):]\377)<^\377+=`\377+>a\377,\77" +\
    "a\377-\77a\377-@b\377-@b\377,>a\377+=`\377*=_\377(:]\377'9\134\377%7" +\
    "Y\377\42\63S\377 .F\377&,5\377)-.\377,.+\377,.+\377#')\377\24 \63\377" +\
    "\17\35;\377\20 \77\377\21 @\377\17 >\377\17\37\77\377\17\36<\377\16\35" +\
    ";\377\15\34:\376\16\34;\377\16\34;\376\7\17 \346\1\2\4\177\0\0\0\25\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\14\0\0\0i\4\11\22\332\12\25,\374\16\35\77\377\16\35=\377\16\35;\377" +\
    "\16\35=\377\17\36=\377\20\37\77\377\20 @\377\21!@\377\22\42B\377\23$" +\
    "D\377\23$E\377\25&F\377\26'H\377\26(I\377\30*J\377\30*K\377\31+M\377" +\
    "\32-M\377\32,L\377\33,N\377\32,M\377\31+L\377\31+L\377\30+K\377\27)J" +\
    "\377\26(I\377\25'G\377\24&F\377\22#B\377\21 @\377\17\36<\377\16\348\377" +\
    "\16\34\67\377\15\34:\377\17\36<\377\16\36=\377\17\36<\377\16\34:\377" +\
    "\15\348\377\15\33\67\376\15\338\377\15\33:\377\11\24)\373\3\10\21\324" +\
    "\0\0\0e\0\0\0\12\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0;\0\0\0\220" +\
    "\5\13\27\363\11\21&\377\15\35;\377\16\34;\377\15\338\376\16\349\376\15" +\
    "\35:\377\16\35;\377\16\35;\377\17\35;\377\17\36<\377\20\36<\377\17\37" +\
    "=\377\20 >\377\21\37\77\377\21 @\377\21 \77\377\21 @\377\20 @\377\21" +\
    "!@\377\21!@\377\21!\77\377\20 >\377\20 >\377\20 >\377\17\37=\377\17\36" +\
    "<\377\17\36<\377\17\36;\377\17\35;\377\17\359\377\16\349\377\16\338\377" +\
    "\16\33\67\377\14\32\66\376\15\32\65\376\14\338\377\15\33\67\377\10\20" +\
    "$\377\5\12\26\352\0\0\0\211\0\0\0\66\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0>\0\0\0{\3" +\
    "\7\16\345\5\14\31\377\11\22&\377\15\339\376\15\339\377\14\31\65\376\14" +\
    "\31\65\377\14\31\65\377\14\32\65\377\14\32\66\376\15\33\66\377\15\33" +\
    "\67\377\15\33\67\377\15\34\67\377\15\33\67\377\16\33\67\377\15\33\67" +\
    "\377\15\33\67\377\15\33\67\377\15\33\66\377\15\33\66\377\15\33\67\377" +\
    "\15\33\66\377\14\32\65\377\15\32\64\376\14\31\64\377\14\31\64\377\14" +\
    "\31\63\377\13\30\64\377\14\31\65\377\15\32\66\377\10\21$\377\5\13\30" +\
    "\374\3\6\16\331\0\0\0s\0\0\08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\0\0\0G\0\0\0\211\0\2\4\312\3\10\21" +\
    "\357\6\14\32\377\10\22'\377\12\24,\377\13\30\63\377\14\31\64\377\14\31" +\
    "\65\377\14\31\66\377\14\31\65\377\14\31\64\377\14\31\63\377\14\31\64" +\
    "\377\14\30\63\377\14\30\62\377\14\31\63\377\14\31\64\377\14\30\64\377" +\
    "\14\31\63\377\14\31\63\377\12\27\61\377\11\24*\377\10\22%\377\5\14\31" +\
    "\377\3\10\21\346\0\2\4\301\0\0\0\177\0\0\0@\0\0\0\6\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0<\0\0\0h\0\0" +\
    "\0z\0\0\0\217\0\0\0\243\1\4\10\264\4\10\23\306\4\11\25\322\5\13\26\333" +\
    "\5\12\26\336\5\13\26\336\5\12\26\333\4\11\24\321\4\11\23\304\1\3\10\262" +\
    "\0\0\0\240\0\0\0\213\0\0\0v\0\0\0a\0\0\0\67\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" +\
    "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
